<?php
class ArticuloAlmacenController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Almacenes';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $almacen = new Default_Model_ArticuloAlmacen();
        $this->view->almacenes = $almacen->getAll();
        $this->view->title = 'Almacenes';
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_ArticuloAlmacen();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $almacen = new Default_Model_ArticuloAlmacen();
                    $almacen->crear($form->getValues());
                    $mSession->mensajes[] = 'El almacen fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el almacén.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_redirect('/articulo-almacen');

            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Crear almacén de artículos";
        $this->view->form = $form;
        $this->renderScript('articulo-almacen/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $almacen = new Default_Model_ArticuloAlmacen();

        $request = $this->getRequest();
        
        $form = new Default_Form_ArticuloAlmacen();
        

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $id = (int)$form->getValue('id');
                    $almacen->editar($form->getValues(), $id);

                    $mSession->mensajes[] = 'El almacen fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el almacen.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                 $this->_redirect('/articulo-almacen');

            } else {
                $form->populate($request->getPost());
                
            }
        } 
        
        $id = (int)$this->_getParam('id');
        $almacen->setId($id);
        $form->populate($almacen->getRow()->toArray());
        $form->setAction('/articulo-almacen/edit');
        $form->submit->setLabel("Guardar");
        $this->view->form = $form;
        $this->view->title = "Editar almacén de artículos";
        $this->renderScript('articulo-almacen/form.phtml');
    }

    public function deleteAction()
    {

        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
            
        $id = (int)$this->_getParam('id');
        
        try {

            $almacen = new Default_Model_ArticuloAlmacen();
            $almacen->setId($id);
            $almacen->eliminar();
            
            $mSession->mensajes[] = 'El almacén fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/articulo-almacen');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el almacén';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/articulo-almacen');

        }
    }
}