<?php
class ArticuloCategoriaController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Categorías de Artículos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $categoria = new Default_Model_ArticuloCategoria();
        $categorias = $categoria->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $categoria->getOrderByOptions();
        $this->view->orderBy = $categoria->getOrderBy();
        $this->view->orderType = $categoria->getOrderType();
        $this->view->action = '/articulo-categoria/index/';
        $this->view->categorias = $categorias;
        $this->view->title = 'Listado categorías de artículos';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaArticulosCategorias();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_ArticuloCategoria();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
        
                    $categoria = new Default_Model_ArticuloCategoria();
                    $categoria->crear($form->getValues());
                    
                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/articulo-categoria/index/1/nombre/ASC');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/articulo-categoria/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Crear categoría de artículos";
        $this->view->form = $form;
        $this->renderScript('articulo-categoria/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $categoria = new Default_Model_ArticuloCategoria();
        $request = $this->getRequest();
        $form = new Default_Form_ArticuloCategoria();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $id = (int)$form->getValue('id');
                    $categoria->editar($form->getValues(), $id);

                    $mSession->mensajes[] = 'La categoría fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/articulo-categoria/index/1/nombre/ASC');
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la categoría.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/articulo-categoria/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        
        $id = (int)$this->_getParam('id');
        $categoria->setId($id);
        $form->populate($categoria->getRow()->toArray());
        $form->setAction('/articulo-categoria/edit');
        $form->submit->setLabel("Guardar");
        $this->view->form = $form;
        $this->view->title = "Editar categoría de artículos";
        $this->renderScript('articulo-categoria/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $categoria = new Default_Model_ArticuloCategoria();
            $categoria->setId($id);
            $categoria->eliminar();
            
            $mSession->mensajes[] = 'La categoría fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/articulo-categoria/index/1/nombre/ASC');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la categoría';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/articulo-categoria/index/1/nombre/ASC');
        }
    }
    
    public function getListadoPopupAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $categoria = new Default_Model_ArticuloCategoria();
            $this->view->categorias = $categoria->getAllToPopup();
            $this->renderScript('articulo-categoria/listado-popup.phtml');
        }
    }
}