<?php
class ArticuloController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Artículos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $articulo = new Default_Model_Articulo();
        $articulos = $articulo->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $articulo->getOrderByOptions();
        $this->view->orderBy = $articulo->getOrderBy();
        $this->view->orderType = $articulo->getOrderType();
        $this->view->action = '/articulo/index/';
        $this->view->articulos = $articulos;
        $this->view->title = 'Listado artículos';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Articulo();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $articulo = new Default_Model_Articulo();
                    $id = $articulo->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/articulo/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el artículo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/articulo/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = 'Crear artículo';
        $this->renderScript('articulo/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Articulo();
        $articulo = new Default_Model_Articulo();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    
                    $articulo->editar($form->getValues());
                    $mSession->mensajes[] = 'El artículo fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/articulo/view/' . $form->getValue('id'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el artículo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/articulo/view/' . $form->getValue('id'));
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $id = (int)$this->_getParam('id');
        $articulo->setId($id);
        $form->populate($articulo->getRow()->toArray());
        $form->categoria_nombre->setValue($articulo->getCategoriaNombre());
        $this->view->form = $form;
        $form->setAction('/articulo/edit');
        $form->submit->setLabel('Guardar');
        $this->view->title = "Editar artículo";
        $this->renderScript('articulo/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        try {
            
            $id = (int)$this->_getParam('id');
            $articulo = new Default_Model_Articulo();
            $articulo->setId($id);
            
            if($articulo->getEstado()=='BORRADOR'){
                $articulo->eliminar();
                $mSession->mensajes[] = 'El artículo fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
            } else {
                $mSession->mensajes[] = 'No se puede eliminar el artículo porque ya fue habilitado';
                $mSession->claseMensaje = 'error';
            }
            $this->_redirect('/articulo/index/1/nombre/ASC');
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el artículo';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/articulo/index/1/nombre/ASC');
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');

        try {
            
            $articulo = new Default_Model_Articulo();
            $articulo->setId($id);
            
            $this->view->title = "Artículo";
            $this->view->articulo = $articulo->getRowFull();
            
            if($articulo->getEstado()=='BORRADOR') {
                $this->renderScript('articulo/view-borrador.phtml');
            } else {
                $this->view->stockActual = $articulo->getStock();
                $this->renderScript('articulo/view.phtml');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar el artículo";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/articulo/index/1/nombre/ASC');
            
        }
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaArticulos();
        
        $this->view->form = $form;
    }

    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $articulo = new Default_Model_VistaArticulos();

            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));

            if($criterio!='' AND $valor!='') {

                if($criterio=='codigo') {

                    $valor = strtoupper($valor);
                    $where = "$criterio='$valor'";

                } else {

                    $where = "$criterio LIKE '%$valor%'";
                }

                $this->view->articulos = $articulo->fetchAll($where)->toArray();
            }

            $this->renderScript('articulo/search.phtml');
        }
    }

    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $this->view->t  = $this->_getParam('t');
            $id = $this->_getParam('id');
            $articulo = new Default_Model_Articulo();
            $where = $articulo->getAdapter()->quoteInto("id=?", $id);
            $this->view->articulo = $articulo->fetchRow($where)->toArray();
            $this->renderScript('articulo/view-tooltip.phtml');
        }
    }

    public function ajustarStockMinimoAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('codigo') AND
           $this->_helper->validateRecordExists('articulos', 'codigo', $this->_getParam('codigo'))){

            $codigo = $this->_getParam('codigo');
            $valor = (int)$this->_getParam('valor');

            try {

                $articulo = new Default_Model_Articulo();
                $where = $articulo->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $articulo->fetchRow($where);
                $row->stock_minimo = $valor;
                $row->save();

                $data = array();
                $data['mensaje'] = array("valor" => "Valor guardado", "style" => "color:green;");
                $data['valores'] = 0;

                echo Zend_Json_Encoder::encode($data);

            } catch (Exception $e) {

                echo '<span style="color:red;">No se pudo guardar el nuevo valor</span>';
            }
        }
    }

    public function ajustarPrecioVentaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('codigo') AND
           $this->_helper->validateRecordExists('articulos', 'codigo', $this->_getParam('codigo'))){

            $codigo = $this->_getParam('codigo');
            $valor = (int)$this->_getParam('valor');

            try {

                $precio = new Default_Model_PrecioArticulo();
                $row = $precio->createRow();
                $row->creador = $this->usuario->id;
                $row->articulo = $codigo;
                $row->precio_unitario_neto = $valor;
                $row->tipo_valor = 'MANUAL';
                $row->save();

                $costo = new Default_Model_CostoArticulo();
                $where_costo = $costo->getAdapter()->quoteInto("articulo=?", $codigo);
                $order_costo = 'id DESC';
                $row_costo = $costo->fetchRow($where_costo, $order_costo)->toArray();

                $margen = round((($valor * 100) / $row_costo['costo_neto_corregido']) - 100, 2);

                $data = array();
                $data['mensaje'] = array("valor" => "Valor guardado", "style" => "color:green;");
                $data['valores'] = array(
                    array('id' => '#porcentaje_margen', 'html' => $margen)
                );

                /*
                $data['cambios'] = array(
                    array('id' => '#porcentaje_margen', 'attrs' => array('key' => 'value', 'value' => $margen))
                );
                */

                echo Zend_Json_Encoder::encode($data);

            } catch (Exception $e) {

                echo '<span style="color:red;">No se pudo guardar el nuevo valor</span>';
            }
        }
    }

    public function habilitarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $id = (int)$this->_getParam('id');
        
        try {
            
            $articulo = new Default_Model_Articulo();
            $articulo->setId($id);
            $articulo->setEstado('DISPONIBLE');
            $mSession->mensajes[] = 'El artículo ya se encuentra disponible para la venta.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/articulo/view/' . $id);

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar habilitar el artículo para la venta.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/articulo/view/' . $id);
        }
    }

    public function deshabilitarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $id = (int)$this->_getParam('id');
        
        try {
            
            $articulo = new Default_Model_Articulo();
            $articulo->setId($id);
            $articulo->setEstado('NO DISPONIBLE');
            $mSession->mensajes[] = 'El artículo ya no se encuentra disponible para la venta.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/articulo/view/' . $id);

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar deshabilitar el artículo para la venta.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/articulo/view/' . $id);
        }
    }

    public function getListadoPopupAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $articulo = new Default_Model_Articulo();
            $this->view->articulos = $articulo->getAllToPopup();
            $this->renderScript('articulo/listado-popup.phtml');
        }
    }
}