<?php
class ArticuloFabricanteController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Fabricantes';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $fabricante = new Default_Model_ArticuloFabricante();
        $fabricantes = $fabricante->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $fabricante->getOrderByOptions();
        $this->view->orderBy = $fabricante->getOrderBy();
        $this->view->orderType = $fabricante->getOrderType();
        $this->view->action = '/articulo-fabricante/index/';
        $this->view->fabricantes = $fabricantes;
        $this->view->title = 'Listado marcas & fabricantes';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaArticulosFabricantes();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_ArticuloFabricante();

        if ($this->_request->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $fabricante = new Default_Model_ArticuloFabricante();
                    $fabricante->crear($form->getValues());
                    
                    $mSession->mensajes[] = 'El fabricante fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/articulo-fabricante/index/1/nombre/ASC');
                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/articulo-fabricante/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Agregar marca o fabricante";
        $this->view->form = $form;
        $this->renderScript('articulo-fabricante/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $fabricante = new Default_Model_ArticuloFabricante();
        $request = $this->getRequest();
        $form = new Default_Form_ArticuloFabricante();

        if ($this->_request->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $id = (int)$form->getValue('id');
                    $fabricante->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_redirect('/articulo-fabricante/index/1/nombre/ASC');

            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $fabricante->setId($id);
        $form->populate($fabricante->getRow()->toArray());
        $form->setAction('/articulo-fabricante/edit');
        $form->submit->setLabel("Guardar");
        $this->view->title = "Editar marca o fabricante";
        $this->view->form = $form;
        $this->renderScript('articulo-fabricante/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {

            $fabricante = new Default_Model_ArticuloFabricante();
            $fabricante->setId($id);
            $fabricante->eliminar();
            
            $mSession->mensajes[] = 'El fabricante fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/articulo-fabricante/index/1/nombre/ASC');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el fabricante:';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/articulo-fabricante/index/1/nombre/ASC');
        }
    }
}