<?php
class ArticuloIngresoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Ingresos de articulos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $propietario = new Default_Model_SistemaPropietario();
        $this->view->propietario = $propietario->get();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $ingreso = new Default_Model_ArticuloIngreso();
        $ingresos = $ingreso->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $ingreso->getOrderByOptions();
        $this->view->orderBy = $ingreso->getOrderBy();
        $this->view->orderType = $ingreso->getOrderType();
        $this->view->action = '/articulo-ingreso/index/';
        $this->view->ingresos = $ingresos;
        $this->view->title = 'Ingresos de artículos';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaArticulosIngresos();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_ArticuloIngreso();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $ingreso = new Default_Model_ArticuloIngreso();
                    $id = $ingreso->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/articulo-ingreso/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el ingreso del artículo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/articulo-ingreso/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = 'Registrar ingreso de artículos';
        $this->renderScript('articulo-ingreso/form.phtml');
    }
    
    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_ArticuloIngreso();
        $ingreso = new Default_Model_ArticuloIngreso();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    
                    $ingreso->editar($form->getValues());
                    $mSession->mensajes[] = 'El ingreso fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/articulo-ingreso/view/' . $form->getValue('id'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el ingreso.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/articulo-ingreso/view/' . $form->getValue('id'));
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $id = (int)$this->_getParam('id');
        $ingreso->setId($id);
        $form->populate($ingreso->getRow()->toArray());
        $this->view->form = $form;
        $form->setAction('/articulo-ingreso/edit');
        $form->submit->setLabel('Guardar');
        $this->view->title = "Editar ingreso de artículos";
        $this->renderScript('articulo-ingreso/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        try {
            
            $id = (int)$this->_getParam('id');
            $ingreso = new Default_Model_ArticuloIngreso();
            $ingreso->setId($id);
            
            if($ingreso->getEstado()=='BORRADOR'){
                $ingreso->eliminar();
                $mSession->mensajes[] = 'El ingreso fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
            } else {
                $mSession->mensajes[] = 'No se puede eliminar el ingreso porque ya fue habilitado';
                $mSession->claseMensaje = 'error';
            }
            $this->_redirect('/articulo_ingreso/index/1/id/DESC');
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el ingreso';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/articulo-ingreso/index/1/nombre/ASC');
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');

        try {
        
            $ingreso = new Default_Model_ArticuloIngreso();
            $ingreso->setId($id);
            $this->view->ingreso = $ingreso->getRowFull();
            $this->view->title = "Ingreso de artículos Nº $id";

        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar el ingreso de artículo.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensajes = "error";
            $this->_redirect("articulo-ingreso/index/1/id/DESC");
            
        }
    }
    
    /*
    public function getFormCostoAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_CostoArticulo(null, $this->path);
            $this->view->title = "Crear ingreso";

            if(isset($mSession->documentoIngreso)) {
                $form->populate($mSession->documentoIngreso);
            }

            $this->view->form = $form;
            $this->renderScript('ingreso-articulo/form-costo.phtml');
        }
    }
    
    public function costoAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_CostoArticulo(null, $this->path);
        $this->view->title = 'Costo del artículo';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost()) AND isset($mSession->ingresoArticulo)) {

                try {

                    $ingreso = new Default_Model_IngresoArticulo();
                    $row = $ingreso->createRow();
                    $row->creador = $mSession->ingresoArticulo['creador'];
                    $row->tipo_ingreso_id = $mSession->ingresoArticulo['tipo_ingreso_id'];
                    $row->articulo = $mSession->ingresoArticulo['articulo'];
                    $row->cantidad = $mSession->ingresoArticulo['cantidad'];
                    $row->observaciones = $mSession->ingresoArticulo['observaciones'];
                    $row->save();

                    $documento = new Default_Model_DocumentoIngresoArticulo();
                    $row_doc = $documento->createRow();
                    $row_doc->ingreso_id = $row->id;
                    $row_doc->proveedor = $form->getValue('proveedor');
                    $row_doc->tipo_id = $form->getValue('tipo_id');
                    $row_doc->numero_documento = $form->getValue('numero_documento');
                    $row_doc->save();


                    $costo = new Default_Model_CostoArticulo();
                    $row_costo = $costo->createRow();
                    $row_costo->documento_id = $row_doc->id;
                    $row_costo->costo_neto_real = $form->getValue('costo_neto_real');
                    $row_costo->costo_neto_corregido =  $row_costo->costo_neto_real;
                    $row_costo->save();

                    $mSession->mensajes[] = 'El ingreso fue realizado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    if($form->getValue('accion')=='1'){

                        unset($mSession->ingresoArticulo);

                        $mSession->documentoIngreso = array();
                        $mSession->documentoIngreso['proveedor'] = $form->getValue('proveedor');
                        $mSession->documentoIngreso['tipo_id'] = $form->getValue('tipo_id');
                        $mSession->documentoIngreso['numero_documento'] = $form->getValue('numero_documento');
                        
                        $this->_forward('get-form','ingreso-articulo');

                    } elseif($form->getValue('accion')=='2') {

                        if(isset($mSession->documentoIngreso)) {
                            unset($mSession->documentoIngreso);
                        }

                        $this->_forward('get-form','ingreso-articulo');

                    } else {

                        if(isset($mSession->documentoIngreso)) {
                            unset($mSession->documentoIngreso);
                        }

                        $this->_forward('index','ingreso-articulo');

                    }
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar realizar el ingreso.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','ingreso-articulo');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('ingreso-articulo/form.phtml');
            }
        }
    }
    */
}