<?php
class ArticuloPedidoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $action = $this->getRequest()->getActionName();
        if($action != 'export-pdf' AND $action != 'create-pdf'){
            $auth = Zend_Auth::getInstance();
            if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
                $this->_redirect('/sistema-acceso/logout');
            }
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Artículos :: Pedidos a bodega';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $propietario = new Default_Model_Propietario();
        $this->view->propietario = $propietario->fetchRow();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            $response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $pedido = new Default_Model_ArticuloPedido();
        $pedidos = $pedido->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $pedido->getOrderByOptions();
        $this->view->orderBy = $pedido->getOrderBy();
        $this->view->orderType = $pedido->getOrderType();
        $this->view->action = '/articulo-pedido/index/';
        $this->view->pedidos = $pedidos;
        $this->view->title = 'Pedidos a bodega';
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_ArticuloPedido();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    $pedido = new Default_Model_ArticuloPedido();
                    $id = $pedido->crear($form->getValues(), $this->usuario->rut);
                    $mSession->mensajes[] = 'El pedido fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_redirect('/articulo-pedido/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el pedido a bodega.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/articulo-pedido/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $pedido = new Default_Model_ArticuloPedido();
        $request = $this->getRequest();
        $form = new Default_Form_ArticuloPedido();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $id = (int)$form->getValue('id');
                    $pedido->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'La pedido a bodega fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/articulo-pedido/view/' . $id);
                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el pedido a bodega.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/artculo-pedido/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $pedido->setId($id);
        $form->submit->setLabel('Guardar cambios');
        $form->id->setValue($id);
        $form->setAction('/articulo-pedido/edit');
        $form->populate($pedido->getRow()->toArray());
        $this->view->title = 'Editar pedido a bodega';
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }
    
    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $pedido = new Default_Model_ArticuloPedido();
            $pedido->setId($id);
            
            $this->view->pedido = $pedido->getRowFull();
            $this->view->items = $pedido->getItems();
            $this->view->title = "Pedido a bodega Nº $id";
            
            if($pedido->getEstado()=='BORRADOR') {
                $this->renderScript('articulo-pedido/view-borrador.phtml');
            } else {
                $this->renderScript('articulo-pedido/view.phtml');
            }
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un problema al intentar visualizar la solicitud.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect("/articulo-pedido/index/1/id/DESC");
        }
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $pedido = new Default_Model_ArticuloPedido();
            $pedido->setId($id);
            $pedido->eliminar();
            $mSession->mensajes[] = 'El pedido a bodega fue eliminado de forma satisfactoria.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect("/articulo-pedido/index/1/id/DESC");
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el pedido a bodega';
            $mSession->mensajez[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect("/articulo-pedido/index/1/id/DESC");
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            $pedido = new Default_Model_ArticuloPedido();
            $pedido->setId($id);
            
            if($pedido->getEstado()=='BORRADOR'){
                $pedido->setEstado('ENTREGADA');
            }
            
            $mSession->mensajes[] = 'El pedido fue enviado a la bodega';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect("/articulo-pedido/index/1/id/DESC");
            
        } catch (Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar enviar el pedido a la bodega';
            $mSession->mesnajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect("/articulo-pedido/index/1/id/DESC");
        }
    }
}