<?php
class BancoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Bancos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $banco = new Default_Model_Banco();
        $this->view->bancos = $banco->getAll();
        $this->view->title = 'Bancos';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Banco();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {

                    $banco = new Default_Model_Banco();
                    $banco->crear($form->getValues());
                    $mSession->mensajes[] = 'El banco fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/banco');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el banco.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/banco');
                    
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = 'Agregar banco';
        $this->view->form = $form;
        $this->renderScript('banco/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $banco = new Default_Model_Banco();
        $request = $this->getRequest();
        $form = new Default_Form_Banco();
        $form->id->setRequired(true);
        $form->setAction('/banco/edit');
        $form->submit->setLabel("Guardar cambios");
        $id = (int)$this->_getParam('id');
        $form->id->setValue($id);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    $banco->editar($form->getValues());
                    $mSession->mensajes[] = 'El banco fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/banco');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el banco.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/banco');
                    
                }

            } else {
                $form->populate($request->getPost());
            }
        } 
        $banco->setid($id);
        $form->populate($banco->getRow()->toArray());
        $this->view->title = "Editar banco";
        $this->view->form = $form;
        $this->renderScript('banco/form.phtml');
    }


    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        try {
            $id = (int)$this->_getParam('id');
            $banco = new Default_Model_Banco();
            $banco->setId($id);
            $banco->eliminar();
            $mSession->mensajes[] = 'El banco fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/banco');
        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar crear el banco.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/banco');
        }
    }
}