<?php
class BancoCuentaController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Cuentas Bancarias';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cuenta = new Default_Model_BancoCuenta();
        $this->view->cuentas = $cuenta->getAll();
        $this->view->title = 'Cuentas Bancarias';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BancoCuenta();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {

                    $cuenta = new Default_Model_BancoCuenta();
                    $cuenta->crear($form->getValues());
                    $mSession->mensajes[] = 'La cuenta bancaria fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/banco-cuenta');

                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la cuenta bancaria.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/banco-cuenta');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = 'Agregar cuenta bancaria';
        $this->view->form = $form;
        $this->renderScript('banco-cuenta/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cuenta = new Default_Model_BancoCuenta();
        $request = $this->getRequest();
        $form = new Default_Form_BancoCuenta();
        $form->id->setRequired(true);
        $form->setAction('/banco-cuenta/edit');
        $form->submit->setLabel("Guardar cambios");
        $id = (int)$this->_getParam('id');
        $form->id->setValue($id);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $cuenta->editar($form->getValues());
                    $mSession->mensajes[] = 'La cuenta bancaria fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/banco-cuenta/');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la cuenta bancaria.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/banco-cuenta/');

                }
                
            } else {
                $form->populate($request->getPost());
            }
        }
        $cuenta->setid($id);
        $form->populate($cuenta->getRow()->toArray());
        $this->view->title = "Editar cuenta bancaria";
        $this->view->form = $form;
        $this->renderScript('banco-cuenta/form.phtml');
    }


    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        try {
            $id = (int)$this->_getParam('id');
            $cuenta = new Default_Model_BancoCuenta();
            $cuenta->setId($id);
            $cuenta->eliminar();
            $mSession->mensajes[] = 'La cuenta bancaria fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/banco-cuenta');
        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la cuenta bancaria.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/banco-cuenta');
        }
    }
}