<?php
class ClienteController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Clientes';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            $response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }

    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cliente = new Default_Model_Cliente();
        $clientes = $cliente->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $cliente->getOrderByOptions();
        $this->view->orderBy = $cliente->getOrderBy();
        $this->view->orderType = $cliente->getOrderType();
        $this->view->action = '/cliente/index/';
        $this->view->clientes = $clientes;
        $this->view->title = 'Clientes';
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Cliente();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                 try {

                    $cliente = new Default_Model_Cliente();
                    $id = $cliente->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes[] = 'El cliente fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/cliente/view/' . $id);
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el cliente.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/cliente/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Crear cliente";
        $this->view->form = $form;
        $this->renderScript('cliente/form.phtml');
    }
    
    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $cliente = new Default_Model_Cliente();
        $request = $this->getRequest();
        $form = new Default_Form_Cliente();
        $form->id->setRequired(true);
        $form->setAction('/cliente/edit');
        $form->submit->setLabel('Guardar cambios');
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $cliente->editar($form->getValues(), $form->getValue('id'));
                    $mSession->mensajes[] = 'El cliente fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/cliente/view/' . $form->getValue('id'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/cliente/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        
        $id = (int)$this->_getParam('id');
        $cliente->setid($id);
        $form->populate($cliente->getRow()->toArray());
        $form->id->setValue($id);
        $this->view->title = "Editar cliente";
        $this->view->form = $form;
        $this->renderScript('cliente/form.phtml');
    }
    
    public function setFlotaAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $id = (int)$this->_getParam('id');
        try {
            $cliente = new Default_Model_Cliente();
            $cliente->setId($id);
            $flota = $cliente->setFlota();
            if($flota == 'SI'){
                $mSession->mensajes[] = 'El cliente convertido a la categoría flota de forma exitosa.';
            } else {
                $mSession->mensajes[] = 'El cliente ha dejado de pertenecer a la categoría de flota de forma exitosa.';
            }
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/cliente/view/' . $id );
            
        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/cliente/index/1/nombre/ASC');
        }
    }
    
    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        $cliente = new Default_Model_Cliente();
        $cliente->setId($id);

        $this->view->cliente = $cliente->getRow();
        /*
        $this->view->num_vehiculos = $cliente->getNumVehiculos();
        $this->view->num_cotizaciones = $cliente->getNumCotizaciones();
        $this->view->num_notas_ventas = $cliente->getNumNotasVentas();
         */
        $this->view->title = $this->view->cliente->nombre;
    }
    
    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');

        try {
            
            $cliente = new Default_Model_Cliente();
            $cliente->setId($id);
            $cliente->eliminar();
            $mSession->mensajes[] = 'El cliente fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/cliente/index/1/nombre/ASC');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el cliente.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/cliente/view/' . $id);
        }
    }

    public function estadoCuentaAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            
        }
    }
    
    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));
            
            $cliente = new Default_Model_Cliente();
            $this->view->clientes = $cliente->searchToTooltip($criterio, $valor);
            $this->renderScript('cliente/search.phtml');
        }
    }
    
    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();

            $id = (int)$this->_getParam('id');
            
            
            try {
                
                $cliente = new Default_Model_Cliente();
                $cliente->setId($id);
                $this->view->cliente = $cliente->getRow()->toArray();
                $this->view->t  = $this->_getParam('type_user');
                $this->renderScript('cliente/view-tooltip.phtml');
                
            } catch(Exception $e){
                
                echo $e->getMessage();
            }
        }
    }

    public function searchToFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            $param = $this->_getParam('term');
            $cliente = new Default_Model_Cliente();
            $data = $cliente->searchToForm($param);
            $result = Zend_Json_Encoder::encode($data);
            echo $result;
        }
    }

    public function getListadoPopupAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $cliente = new Default_Model_Cliente();
            $this->view->clientes = $cliente->getAllToPopup();
            $this->renderScript('cliente/listado-popup.phtml');
        }
    }
    
    /*    
    public function ajustarLineaCreditoAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('rut') AND
           $this->_helper->validateRecordExists('clientes', 'rut', App_Rut::cleanToDb($this->_getParam('rut')))){

            $rut = App_Rut::cleanToDb($this->_getParam('rut'));
            $valor = (int)$this->_getParam('valor');
            try {
                $cliente = new Default_Model_Cliente();
                $where = $cliente->getAdapter()->quoteInto("rut=?", $rut);
                $row = $cliente->fetchRow($where);
                $row->monto_linea_credito = $valor;
                $row->save();
                $data = array();
                $data['mensaje'] = array("valor" => "Valor guardado", "style" => "color:green;");
                $data['valores'] = 0;
                echo Zend_Json_Encoder::encode($data);
            } catch (Exception $e) {
                echo '<span style="color:red;">No se pudo guardar el nuevo valor</span>';
            }
        }
    }

    public function ajustarPlazoPagoMaxAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('rut') AND
           $this->_helper->validateRecordExists('clientes', 'rut', App_Rut::cleanToDb($this->_getParam('rut')))){

            $rut = App_Rut::cleanToDb($this->_getParam('rut'));
            $valor = (int)$this->_getParam('valor');

            try {

                $cliente = new Default_Model_Cliente();
                $where = $cliente->getAdapter()->quoteInto("rut=?", $rut);
                $row = $cliente->fetchRow($where);
                $row->plazo_pago_max = $valor;
                $row->save();

                $data = array();
                $data['mensaje'] = array("valor" => "Valor guardado", "style" => "color:green;");
                $data['valores'] = 0;

                echo Zend_Json_Encoder::encode($data);

            } catch (Exception $e) {

                echo '<span style="color:red;">No se pudo guardar el nuevo valor</span>';
            }
        }
    }
    */
}