<?php
class CobroInsumoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Cobros Insumos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $currentPage = $this->_getParam('page', 1);
        $cobro = new Default_Model_CobroInsumo();
        $order = "valor";
        $cobros = $cobro->fetchAll(null, $order);
        $paginador = Zend_Paginator::factory($cobros);
        $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                  ->setPageRange($this->paginacion['cant_pages'])
                  ->setCurrentPageNumber($currentPage);
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        $this->view->cobros = $paginador;
        $this->view->title = 'Cobros de insumos';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_CobroInsumo();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {

                    $cobro = new Default_Model_CobroInsumo();
                    $cobro->crear($form->getValues());
                    $mSession->mensajes[] = 'La valor creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/cobro-insumo/index/1/nombre/ASC');

                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/error/error-delete-registro');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = 'Agregar tramo de cobro de insumos';
        $this->view->form = $form;
        $this->renderScript('cobro-insumo/form.phtml');
    }
    
    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cobro = new Default_Model_CobroInsumo();
        $request = $this->getRequest();
        $form = new Default_Form_CobroInsumo();
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    $cobro->editar($form->getValues(), $form->getValue('id'));
                    $mSession->mensajes[] = 'El valor fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el valor.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_redirect('/cobro-insumo');
                
            } else {
                $form->populate($request->getPost());
            }
        }
        $id = (int)$this->_getParam('id');
        $cobro->setId($id);
        $form->populate($cobro->getRow()->toArray());
        $form->setAction('/cobro-insumo/edit/'. $id);
        $form->submit->setLabel("Guardar cambios");
        $this->view->title = "Editar tramo de cobro de insumos";
        $this->view->form = $form;
        $this->renderScript('cobro-insumo/form.phtml');
    }
    

    public function deleteAction()
    {

        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            $cobro = new Default_Model_CobroInsumo();
            $cobro->setId($id);
            $cobro->eliminar();
            $mSession->mensajes[] = 'El valor fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/cobro-insumo');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el valor.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/cobro-insumo');
        }
    }
}