<?php
class ContratoEmpleadoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {

                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $contrato = new Default_Model_VistaContratosEmpleados();
            $contratos = $contrato->fetchAll();

            $paginador = Zend_Paginator::factory($contratos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->contratos = $paginador;
            $this->view->title = "Contratos de empleados";
            $this->renderScript('contrato-empleado/index.phtml');

        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_ContratoEmpleado(null, $this->path);
            
            if($this->_request->getParam('id')) {

                $contrato = new Default_Model_ContratoEmpleado();
                $id = $contrato->getAdapter()->quote($this->_request->getParam('id'));
                $row = $contrato->fetchRow('id='.$id)->toArray();
                $form->populate($row);
                $form->setAction('contrato-empleado/edit');
                $rut = App_Rut::format($form->empleado->getValue());
                $form->empleado->setValue($rut);
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar contrato de empleado";

            } else {

                $this->view->title = "Agregar contrato de empleado";
                if($this->_request->getParam('rut')) {

                    $rut = App_Rut::format($this->_request->getParam('rut'));
                    $form->empleado->setValue($rut);

                }

            }
            $this->view->form = $form;
            $this->renderScript('contrato-empleado/form.phtml');
        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_ContratoEmpleado(null, $this->path);
        $this->view->title = "Agregar contrato empleado";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

               
                $mSession->contrato = array();
                $mSession->contrato['empleado'] = App_Rut::cleanToDb($form->getValue('empleado'));
                $mSession->contrato['cargo'] = $form->getValue('cargo');
                $mSession->contrato['fecha_i'] = $form->getValue('fecha_i');

                if(($form->getValue('fecha_t')!='')
                    AND ($form->tipo_contrato!='INDEFINIDO')) {
                        $mSession->contrato['fecha_t'] = $form->getValue('fecha_t');
                } else {
                    $mSession->contrato['fecha_t'] = NULL;
                }

                $mSession->contrato['tipo_contrato'] = $form->getValue('tipo_contrato');
                $mSession->contrato['bono_produccion'] = $form->getValue('bono_produccion');
                $mSession->contrato['comision_ventas'] = $form->getValue('comision_ventas');

                if($form->getValue('observaciones')=='') {
                    $mSession->contrato['observaciones'] = NULL;
                } else {
                    $mSession->contrato['observaciones'] = $form->getValue('observaciones');
                }

                $this->_forward('calculo-sueldo','contrato-empleado');

                
            } else {

                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('contrato-empleado/form.phtml');
            }
        } else {
            $this->_forward('logout','index');
        }
    }


    public function calculoSueldoAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $valores_default = array();
            $valores_default['RMN_VALOR_IMM']= Default_Model_Preferencia::getPref('RMN_VALOR_IMM');
            $valores_default['RMN_MULT_GRATIFICACION']= Default_Model_Preferencia::getPref('RMN_MULT_GRATIFICACION');
            $valores_default['RMN_PORC_EFECTO_SEMANA_CORRIDA']= Default_Model_Preferencia::getPref('RMN_PORC_EFECTO_SEMANA_CORRIDA');
            $valores_default['RMN_PORC_AFP_DEFAULT']= Default_Model_Preferencia::getPref('RMN_PORC_AFP_DEFAULT');
            $valores_default['RMN_PORC_SALUD_DEFAULT']= Default_Model_Preferencia::getPref('RMN_PORC_SALUD_DEFAULT');
            $valores_default['RMN_PORC_SEG_ACC_DEFAULT']= Default_Model_Preferencia::getPref('RMN_PORC_SEG_ACC_DEFAULT');
            $valores_default['RMN_PORC_SEG_CESANTIA_EMPLEADOR']= Default_Model_Preferencia::getPref('RMN_PORC_SEG_CESANTIA_EMPLEADOR');
            $valores_default['RMN_PORC_SEG_CESANTIA_EMPLEADO']= Default_Model_Preferencia::getPref('RMN_PORC_SEG_CESANTIA_EMPLEADO');
            $this->view->valores_default = $valores_default;
            $form = new Default_Form_CalculoSueldoEmpleado(null, $this->path);
            $form->afp->setValue($valores_default['RMN_PORC_AFP_DEFAULT']);
            $form->salud->setValue($valores_default['RMN_PORC_SALUD_DEFAULT']);
            $form->seguro_accidentes->setValue($valores_default['RMN_PORC_SEG_ACC_DEFAULT']);
            $this->view->form = $form;
            $this->view->title = 'Cálculo de sueldo';
            $this->renderScript('contrato-empleado/calculo-sueldo.phtml');
        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function saveAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_CalculoSueldoEmpleado(null, $this->path);
        $this->view->title = "Agregar proveedor";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                $mSession->contrato['sueldo_base'] = $form->getValue('sueldo_base');
                /*
                try {
                    $proveedor = new Default_Model_Proveedor();
                    $row = $proveedor->createRow();
                    $row->razon_social = $form->getValue('razon_social');
                    $row->rut = App_Rut::cleanToDb($form->getValue('rut'));
                    $row->direccion = $form->getValue('direccion');
                    $row->comuna = $form->getValue('comuna');
                    $row->ciudad = $form->getValue('ciudad');
                    $row->telefono = $form->getValue('telefono');
                    $row->giro = $form->getValue('giro');
                    $row->web = $form->getValue('web');
                    $row->monto_linea_credito = $form->getValue('monto_linea_credito');
                    $row->plazo_pago_max = $form->getValue('plazo_pago_max');
                    $row->save();
                    $mSession->mensajes[] = 'El proveedor fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('index','proveedor');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el proveedor.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('new','proveedor');
                }
                */
                var_dump($mSession->contrato);
            } else {

                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('contrato-empleado/calculo-sueldo.phtml');
            }
        } else {
            $this->_forward('logout','index');
        }
    }
    
    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = $this->_getParam('id');
            $contrato = new Default_Model_VistaContratosEmpleados();
            $this->view->contrato = $contrato->fetchRow('id=' . $id);
            $this->view->title = 'Contrato de empleado';

            if(false==$this->view->contrato) {
                $this->_forward('index','contrato-empleado');
            } else {
                $this->renderScript('contrato-empleado/view.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_ContratoEmpleado();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $id = $form->getValue('id');
                    $contrato = new Default_Model_ContratoEmpleado();
                    $row = $contrato->fetchRow('id='.$id);
                    $row->cargo = $form->getValue('cargo');
                    $row->fecha_i = $form->getValue('fecha_i');

                    if(($form->getValue('fecha_t')!='') 
                        AND ($form->tipo_contrato!='INDEFINIDO')) {
                            $row->fecha_t = $form->getValue('fecha_t');      
                    } else {
                        $row->fecha_t = NULL;
                    }

                    $row->tipo_contrato = $form->getValue('tipo_contrato');
                    $row->sueldo_base = $form->getValue('sueldo_base');
                    $row->bono_variable = $form->getValue('bono_variable');
                    $row->save();

                    $mSession->mensajes[] = 'El contrato fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view', 'contrato-empleado', null, array('id'=> $id));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el contrato.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('edit','contrato-empleado');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/contrato-empleado/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar contrato de empleado";
                $this->renderScript('contrato-empleado/form.phtml');
            }
        }

    }
}