<?php
class CostoArticuloController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function listByArticuloAction()
    {

        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $articulo = $this->_getParam('codigo');
            $this->view->t = $this->_getParam('t');

            $currentPage = $this->_getParam('page', 1);

            $costo = new Default_Model_CostoArticulo();
            $where = $costo->getAdapter()->quoteInto("articulo=?", $articulo);
            $order = "id DESC";
            $costos = $costo->fetchAll($where, $order);

            $paginador = Zend_Paginator::factory($costos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');

            $this->view->costos = $paginador;
            $this->renderScript('costo-articulo/list-by-articulo.phtml');
        }
    }

    public function getFormRefAction()
    {


        if($this->getRequest()->isXmlHttpRequest()){

            if($this->_request->getParam('codigo')) {

                $mSession = new Zend_Session_Namespace('expressauto');

                if($mSession->mensajes!='') {
                    $this->view->mensajes = $mSession->mensajes;
                    $this->view->claseMensaje = $mSession->claseMensaje;
                    $mSession->mensajes = '';
                    $mSession->claseMensaje = '';
                }

                $codigo = $this->_request->getParam('codigo');
                
                $request = $this->getRequest();
                $form = new Default_Form_CostoRefArticulo(null, $this->path);
                $form->articulo->setValue($codigo);
                $form->articulo->setAttrib('disabled','disabled');
                $this->view->title = "Ingresar costo referencial";
                $this->view->form = $form;
                $this->renderScript('costo-articulo/form.phtml');

            } else {
                $this->_redirect('/articulo/index/t/a');
            }
        }
    }

    public function newRefAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_CostoRefArticulo();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $costo = new Default_Model_CostoArticulo();
                   
                    $row = $costo->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->articulo = $form->getValue('articulo');
                    $row->costo_neto_real = $form->getValue('costo');
                    $row->costo_neto_corregido = $form->getValue('costo');
                    $row->tipo_costo = 'REF';
                    $row->save();

                    $precio = new Default_Model_PrecioArticulo();
                    $row_precio = $precio->createRow();
                    $row_precio->creador = $this->usuario->rut;
                    $row_precio->articulo = $row->articulo;
                    $row_precio->tipo_valor = 'REF';
                    $row_precio->precio_unitario_neto = $this->_calcularPrecioVentaSugerido($row->articulo, $row->costo_neto_corregido);
                    $row_precio->save();

                    $mSession->mensajes[] = 'El costo referencial fue guardado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'articulo', null, array('codigo'=> $form->getValue('articulo'), 't' => 'a'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar el costo referencial al artículo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','articulo', null, array('t' => 'a'));
                }
            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Ingresar costo referencial";
                $this->renderScript('costo-articulo/form.phtml');
            }
        }
    }

    private function _calcularPrecioVentaSugerido($codigo, $valor)
    {
        $articulo = new Default_Model_VistaArticulos();
        $where = $articulo->getAdapter()->quoteInto("codigo=?", $codigo);
        $row = $articulo->fetchRow($where)->toArray();

        $margen = 1 + (Default_Model_PreferenciaMargenDefault::getMargenByValue('ARTICULO', $valor) / 100);
        $precioVenta = round($valor * $margen, -2);
        return $precioVenta;
    }
}