<?php
class CotizacionController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $action = $this->getRequest()->getActionName();
        if($action != 'export-pdf' AND $action != 'create-pdf'){
            $auth = Zend_Auth::getInstance();
            if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
                $this->_redirect('/sistema-acceso/logout');
            }
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Cotizaciones';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->preferencias = Default_Model_Cotizacion::getPrefs();
        $this->view->propietario = Default_Model_SistemaPropietario::get();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cotizacion = new Default_Model_Cotizacion();
        $cotizaciones = $cotizacion->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $cotizacion->getOrderByOptions();
        $this->view->orderBy = $cotizacion->getOrderBy();
        $this->view->orderType = $cotizacion->getOrderType();
        $this->view->action = '/cotizacion/index/';
        $this->view->cotizaciones = $cotizaciones;
        $this->view->title = 'Cotizaciones';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Cotizacion();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $cotizacion = new Default_Model_Cotizacion();
                    $id = $cotizacion->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/cotizacion/view/' . $id);
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/cotizacion/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        if($this->_getParam('from_id')){
            $presupuesto_id = (int)$this->_getParam('from_id');
            
            $presupuesto = new Default_Model_Presupuesto();
            $presupuesto->setId($presupuesto_id);
            $form->presupuesto_id->setValue($presupuesto_id);
            $form->cliente_id->setValue($presupuesto->getClienteId());
        }
        $form->emitida_por->setValue($this->usuario->nombre);
        $this->view->title = 'Crear cotización';
        $this->view->form = $form;
        $this->renderScript('cotizacion/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $cotizacion = new Default_Model_Cotizacion();
        $request = $this->getRequest();
        $form = new Default_Form_Cotizacion();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $id = (int)$form->getValue('id');
                    $cotizacion->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'La cotizacion fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/cotizacion/view/' . $id);
                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/cotizacion/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $cotizacion->setId($id);
        $form->submit->setLabel('Guardar cambios');
        $form->id->setValue($id);
        $form->setAction('/cotizacion/edit/' . $id);
        $form->populate($cotizacion->getRow()->toArray());
        $this->view->title = 'Editar encabezado cotización';
        $this->view->form = $form;
        $this->renderScript('cotizacion/form.phtml');
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
           
            $cotizacion = new Default_Model_Cotizacion();
            $cotizacion->setId($id);
            
            $row = $cotizacion->getRow();
            $rowEnvio = $cotizacion->getUltimoEnvio();
            $rowsItems = $cotizacion->getItems();
            
            $modosVisualizacion = array(1,2,3,4);
            $modeView =  (int)$this->_getParam('mode_view', 1);
            
            if(in_array($modeView, $modosVisualizacion)){
                $this->view->mode_view = (int)$modeView;
            } else {
                $this->view->mode_view = 1;
            }
            
            $this->view->condiciones_generales = Default_Model_DocumentoCondicionGeneral::getTexto('COTIZACION');
            $this->view->title = "Cotización Nº $id";
            $this->view->cotizacion = $row;
            $this->view->items = $rowsItems;
            $this->view->ultimoEnvio = $rowEnvio;
            
            if($row->estado=='BORRADOR') {
                $this->renderScript('cotizacion/view-borrador.phtml');
            } else {
                $this->renderScript('cotizacion/view.phtml');
            } 
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar la cotización";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/cotizacion/index/1/id/DESC');
        }
    }
    
    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            
            $cotizacion = new Default_Model_Cotizacion();
            $cotizacion->setId($id);
            $cotizacion->eliminar();
            
            $mSession->mensajes[] = 'La cotización fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/cotizacion/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la cotización.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/cotizacion/index/1/id/DESC');
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $cotizacion = new Default_Model_Cotizacion();
            $cotizacion->setId($id);
            $neto = $cotizacion->getNeto($id);
            
            if($cotizacion->getEstado()=='BORRADOR' && $neto!==NULL && $neto!==0){
                
                if($neto >= $this->preferencias['CT_MONTO_APROB']) {
                        
                    $cotizacion->updateIva();
                    $cotizacion->setEstado('PENDIENTE');
                    $cotizacion->requerirAutorizacion($this->usuario->id);
                    $mSession->claseMensaje = 'advertencia';
                    $mSession->mensajes[] = 'La cotización fue emitida de forma exitosa pero quedó a la espera de aprobación';

                } else {

                    $cotizacion->updateIva();
                    $cotizacion->setEstado('EMITIDA');
                    $mSession->mensajes[] = 'La cotización fue emitida de forma exitosa';
                    $mSession->claseMensaje = 'confirmacion';
                }
            } else {
                
                $mSession->mensajes[] = 'Debe agregar ítems a la cotización';
                $mSession->claseMensaje = 'error';
            }
            
            $this->_redirect('/cotizacion/view/' . $id);
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar terminar la cotización';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/cotizacion/view/' . $id);
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $id = (int)$this->_getParam('id');

            try {
                $this->view->condiciones_generales = Default_Model_DocumentoCondicionGeneral::getTexto('COTIZACION');
                $cotizacion = new Default_Model_Cotizacion();
                $cotizacion->setId($id);
                $this->view->cotizacion = $cotizacion->getRow();
                $this->view->items = $cotizacion->getItems();
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function viewAuthAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();

            $id = (int)$this->_getParam('id');

            try {
                
                $cotizacion = new Default_Model_Cotizacion();
                $cotizacion->setId($id);
                $this->view->cotizacion = $cotizacion->getRow();
                $this->view->items = $cotizacion->getItems();
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }

    public function listByClienteAction()
    {
        $this->_helper->layout->disableLayout();

        if($this->getRequest()->isXmlHttpRequest()){

            $id = (int)$this->_getParam('id');
            $model = new Default_Model_Cotizacion();
            $cotizaciones = $model->getListByCliente($id);
            $this->view->cotizaciones = $cotizaciones;
        }
    }

    public function printAction()
    {
        if($this->_getParam('id')){
            $this->_helper->layout->setLayout('print');

            $id = (int)$this->_getParam('id');
            $cotizacion = new Default_Model_Cotizacion();
            $cotizacion->setId($id);

            if($cotizacion->getEstado()=='EMITIDA') {
                $this->view->title = "Cotización Nº $id";
                $this->view->cotizacion = $cotizacion->getRow();;
                $this->view->items = $cotizacion->getItems();
                $this->view->modeView = $this->_getParam('mode_view');
                $this->view->condiciones_generales = Default_Model_DocumentoCondicionGeneral::getTexto('COTIZACION');
            }
        }
    }

    public function mailAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->_getParam('mode_view')=='f') {
            $modeView = 'f';
        } else {
            $modeView = '0';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_SendAttach(null, '/cotizacion/mail/0/0/0/0/' . $modeView);
        $form->copia->setLabel('Enviar una copia a mi casilla ('.  $this->usuario->mail .')');

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $mail = new App_HtmlMailerDocument('UTF-8');
                    $mail->setFrom($this->usuario->mail, $this->usuario->empleado);
                    $mail->setType(Zend_Mime::MULTIPART_RELATED);
                    $mail->setSubject($form->getValue('asunto'))
                         ->setViewParam('nombre', $form->getValue('nombre'))
                         ->setViewParam('usuario', $this->usuario->empleado)
                         ->setViewParam('mensaje', $form->getValue('texto_mensaje'));

                    $mail->addTo($form->getValue('mail'), $form->getValue('nombre'));

                    if($form->copia->getValue()==1){
                        $mail->addBcc($this->usuario->mail);
                    }

                    if($modeView=='f'){
                        $path = '/cotizacion/create-pdf/' . $form->getValue('id') . '/0/0/0/f';
                    } else {
                        $path = '/cotizacion/create-pdf/' . $form->getValue('id') . '/0/0/0/0';
                    }

                    $pdf = new App_Pdf($path);
                    
                    $attach = $mail->createAttachment($pdf->getContent());
                    $attach->filename = $form->getValue('archivo');
                    
                    $mail->sendHtmlTemplate('send-attach.phtml');

                    $envio = new Default_Model_DocumentoEnvio();
                    $envio->log(
                        array(
                            'creador' => $this->usuario->id,
                            'tipo' => 'cotizacion',
                            'documento_id' => $form->getValue('id'),
                            'nombre' => $form->getValue('nombre'),
                            'mail' => $form->getValue('mail')
                        )
                    );

                    $mSession->mensajes[] = 'El mensaje fue enviado de forma satisfactoria.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/cotizacion/view/' . $form->getValue('id'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar enviar el mensaje, por favor inténtelo más tarde.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/error/error-sending-attach');
                }
            } else {
                $form->populate($request->getPost());
            }
        }    
        
        if($this->_getParam('id')){

            $documento = 'cotizacion';
            $id = (int)$this->_getParam('id');
            $name = $documento . '-' . $id .'.pdf';
            $formValues = array(
                'archivo'       => $name,
                'id'            => $id,
                'documento'     => $documento,
                'asunto'        => 'ExpressAuto S.p.A. - Cotización Nº ' . $id,
                'texto_mensaje' => 'Adjunto cotización según lo solicitado'
            );
            $form->populate($formValues);
        }
        
        $this->view->title = "Enviar documento adjunto por mail";
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }

    public function pdfAction()
    {
        $documento = 'cotizacion';
        $id = (int)$this->_getParam('id');

        if($this->_getParam('mode_view')=='f') {
            $path = '/cotizacion/create-pdf/'. $id . '/0/0/0/f';
        } else {
            $path = '/cotizacion/create-pdf/'. $id . '/0/0/0/0';
        }

        $name = $documento . '-' . $id .'.pdf';
        $pdf = new App_Pdf($path);
        $pdf->setName($name);
        $pdf->download();
    }

    public function createPdfAction()
    {
        $this->_helper->layout->setLayout('pdf');
        $id = (int)$this->_getParam('id');
        $cotizacion = new Default_Model_Cotizacion();
        $cotizacion->setId($id);

        if($cotizacion->getEstado()=='EMITIDA') {
            $this->view->title = "Cotización Nº $id";
            $this->view->cotizacion = $cotizacion->getRow();
            $this->view->items = $cotizacion->getItems();
            $this->view->modeView = $this->_getParam('mode_view');
            $this->view->condiciones_generales = Default_Model_DocumentoCondicionGeneral::getTexto('COTIZACION');
        }
    }
    
    public function newFromAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $id = $this->_getParam('id');
        
        try {
            $cotizacion = new Default_Model_Cotizacion();
            $cotizacion->setId($id);
            $nueva_id = $cotizacion->clonar($this->usuario->id);
            $this->_redirect('/cotizacion/view/' . $nueva_id);
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar duplicar la cotización";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/cotizacion/view/' . $id);
        }
            
    }

    /************************ FUNCIONES PARA ÍTEMS ****************************/
    public function agregarItemAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_ItemCotizacion();
        $id = (int)$this->_getParam('id');
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    $item = new Default_Model_ItemCotizacion();
                    $item->crear($form->getValues());
                    $mSession->mensajes[] = "El ítem fue agregado de forma satisfactoria. "
                                          . "¿Desea agregar otro o prefiere <a href=\"/cotizacion/view/" 
                                          . $id ."\">Volver a la cotización</a>?";
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/cotizacion/agregar-item/' . $id);
                } catch(Exception $e){
                    $mSession->mensajes[] = "Ocurrió un error al intentar agregar el ítem a la cotización";
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/cotizacion/agregar-item/' . $id);
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
            
        try {
            $cotizacion = new Default_Model_Cotizacion();
            $cotizacion->setId($id);
            $form->cotizacion_id->setValue($id);
            $form->setAction('/cotizacion/agregar-item/' . $id);
            $form->cancel->setAttrib('onclick', "javascript:goTo('/cotizacion/view/$id');");
            $this->view->form = $form;
            $row = $cotizacion->getRow();
            $this->view->cotizacion = $row;
        } catch(Exception $e) {
            $mSession->mensajes[] = "Ocurrió un error al requerir la información de la cotización";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/cotizacion/view/' . $id);
        }
    }
    
    public function editarItemAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_ItemCotizacion();
        $id = (int)$this->_getParam('id');
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $item = new Default_Model_ItemCotizacion();
                    $item->editar($form->getValues());
                    $mSession->mensajes[] = "El ítem fue editado de forma satisfactoria. ";
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/cotizacion/view/' . $form->getValue('cotizacion_id'));
                    
                } catch(Exception $e){
                    $mSession->mensajes[] = "Ocurrió un error al intentar editar el ítem";
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/cotizacion/view/' . $form->getValue('cotizacion_id'));
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
            
        try {
            
            $item = new Default_Model_ItemCotizacion();
            $item->setId($id);
            $rowItem = $item->getRow();
            $rowCotizacion = $item->getCotizacion($rowItem['cotizacion_id']);
            $form->populate($rowItem);
            $form->vehiculo->setValue(Default_Model_Vehiculo::getPatenteById($rowItem['vehiculo_id']));
            $form->setAction('/cotizacion/editar-item/' . $id);
            $form->submit->setLabel('Guardar cambios');
            $form->cancel->setAttrib('onclick', "javascript:goTo('/cotizacion/view/$rowCotizacion->id');");
            $this->view->form = $form;
            $this->view->cotizacion = $rowCotizacion;
            
        } catch(Exception $e) {
            $mSession->mensajes[] = "Ocurrió un error al requerir el item a editar";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/cotizacion/index/1/id/DESC');
        }
    }
    
    public function eliminarItemsAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();

            try {
                
                $data = $this->_getParam('data');
                $item = new Default_Model_ItemCotizacion();
                $item->eliminar($data);
                return true;
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    /********************** FIN FUNCIONES PARA ÍTEMS ***************************/
}