<?php
class CuentaCorrienteController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Cuentas Corrientes';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {

        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $currentPage = $this->_getParam('page', 1);

        $cuenta = new Default_Model_CuentaCorriente();
        $cuentas = $cuenta->fetchAll();

        $paginador = Zend_Paginator::factory($cuentas);
        $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                    ->setPageRange($this->paginacion['cant_pages'])
                    ->setCurrentPageNumber($currentPage);

        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

        $this->view->cuentas = $paginador;
        $this->view->title = 'Listado cuentas corrientes';

    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_CuentaCorriente(null, $this->path);

            if($this->_request->getParam('id')) {

                $cuenta = new Default_Model_CuentaCorriente();
                $where = $cuenta->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $cuenta->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/cuenta-corriente/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar cuenta corriente";

            } else {

                $this->view->title = "Crear cuenta corriente";

            }
            $this->view->form = $form;
            $this->renderScript('cuenta-corriente/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_CuentaCorriente(null, $this->path);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $cuenta = new Default_Model_CuentaCorriente();
                    $row = $cuenta->createRow();
                    $row->banco = $form->getValue('banco');
                    $row->numero_cuenta = $form->getValue('numero_cuenta');
                    $row->titular = $form->getValue('titular');
                    $row->save();
                    $mSession->mensajes[] = 'La cuenta corriente fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la cuenta corriente.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                }

                $this->_forward('index', 'cuenta-corriente');

            } else {
                $this->view->title = 'Crear cuenta corriente';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('cuenta-corriente/form.phtml');
            }
        }
        $this->view->form = $form;
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cuenta = new Default_Model_CuentaCorriente();

        $request = $this->getRequest();
        $form = new Default_Form_CuentaCorriente(null, $this->path);
        $form->setAction($this->path . '/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $where = $cuenta->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $cuenta->fetchRow($where);
                    $row->banco = $form->getValue('banco');
                    $row->numero_cuenta = $form->getValue('numero_cuenta');
                    $row->titular = $form->getValue('titular');
                    $row->save();
                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }

                $this->_forward('index', 'cuenta-corriente');

            } else {
                $this->view->title = 'Editar cuenta corriente';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('cuenta-corriente/form.phtml');
            }
        } else {

            if ($this->_request->getParam('id')) {

                $where = $cuenta->getAdapter()->quoteInto("id=?", $this->_request->getParam('id'));
                $registro = $cuenta->fetchRow($where);
                $form->populate($registro->toArray());
            }
        }
        $this->view->form = $form;
    }
    

    public function deleteAction()
    {
        if($this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');
            
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {

                $model = new Default_Model_CuentaCorriente();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);

                $mSession->mensajes[] = 'La cuenta corriente fue eliminada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                
                $this->_forward('index','cuenta-corriente');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();

                $this->_forward('error-delete-registro','error');

            }
        }
    }
}