<?php
class DatosFacturacionController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Clientes - Información de facturación';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $dato = new Default_Model_DatosFacturacion();
        $datos = $dato->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $dato->getOrderByOptions();
        $this->view->orderBy = $dato->getOrderBy();
        $this->view->orderType = $dato->getOrderType();
        $this->view->action = '/datos-facturacion/index/';
        $this->view->datos = $datos;
        $this->view->title = 'Datos de facturación';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaDatosFacturacion();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_DatosFacturacion();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $datosFacturacion = new Default_Model_DatosFacturacion();
                    $rut = $datosFacturacion->crear($form->getValues(), $this->usuario->id);
                    
                    $mSession->mensajes[] = 'Los datos de facturación fueron agregados de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/datos-facturacion/view/' . $rut);
                        
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar agregar los datos de facturación.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/datos-facturacion/index/1/razon_social/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = "Agregar datos de facturación";
        $this->renderScript('datos-facturacion/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $datosFacturacion = new Default_Model_DatosFacturacion();
        $request = $this->getRequest();
        $form = new Default_Form_DatosFacturacion();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $id = (int)$form->getValue('id');
                    $datosFacturacion->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'La información de facturación fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_redirect('/datos-facturacion/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar los datos de facturación.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/datos/facturacion/index/1/razon_social/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $rut = App_Rut::cleanToDb($this->_getParam('id'));
        $datosFacturacion->setRut($rut);
        
        $form->populate($datosFacturacion->getRow()->toArray());
        $form->setAction('/datos-facturacion/edit');
        $form->submit->setLabel('Guardar');
        $form->id->setValue($rut);
        
        $this->view->form = $form;
        $this->view->title = "Editar datos de facturación";
        $this->renderScript('datos-facturacion/form.phtml');
    }
    
    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $rut = App_Rut::cleanToDb($this->_getParam('id'));
        
        try {
            $datos = new Default_Model_DatosFacturacion();
            $datos->setRut($rut);
            $this->view->datos = $datos->getRow();
            $this->view->title = "Datos de facturación";
            $this->renderScript('datos-facturacion/view.phtml');
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar los datos de facturación";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/datos-facturacion/index/1/razon_social/ASC');
        }
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $rut = App_Rut::cleanToDb($this->_getParam('id'));
        
        try {
            
            $datos = new Default_Model_DatosFacturacion();
            $datos->setRut($rut);
            $datos->eliminar();
            $mSession->mensajes[] = 'Los datos de facturación fueron eliminados de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/datos-facturacion/index/1/razon_social/ASC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar los datos de facturación.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/datos-facturacion/index/1/razon_social/ASC');
        }
    }
    
    public function getListadoPopupAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $datos = new Default_Model_DatosFacturacion();
            $this->view->datos = $datos->getAllToPopup();
            $this->renderScript('datos-facturacion/listado-popup.phtml');
        }
    }
}