<?php
class DteBoletaController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Boletas';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $boleta = new Default_Model_DteBoleta();
        $boletas = $boleta->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $boleta->getOrderByOptions();
        $this->view->orderBy = $boleta->getOrderBy();
        $this->view->orderType = $boleta->getOrderType();
        $this->view->action = '/dte-boleta/index/';
        $this->view->boletas = $boletas;
        $this->view->title = 'Boletas';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaDteBoletas();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $optionsNumero = array('table' => 'dte_boletas', 'field' => 'numero');
        $validadorNumero = new Zend_Validate_Db_NoRecordExists($optionsNumero);

        $request = $this->getRequest();
        $form = new Default_Form_DteBoleta();
        $form->numero->addValidator($validadorNumero);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $boleta = new Default_Model_DteBoleta();
                    $id = $boleta->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/dte-boleta/view/' . $id );
                    
                } catch (Exception $e) {

                    $this->view->mensajes[] = 'Ocurrió un error al intentar crear la Boleta.';
                    $this->view->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dte-boleta/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = 'Crear boleta';
        $this->renderScript('dte-boleta/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $optionsNumero = array('table' => 'dte_boletas', 'field' => 'numero');
        $validadorNumero = new Zend_Validate_Db_RecordExists($optionsNumero);
        
        $boleta = new Default_Model_DteBoleta();
        $request = $this->getRequest();
        $form = new Default_Form_DteBoleta();
        $form->numero->addValidator($validadorNumero);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $boleta->editar($form->getValues(), $form->getValue('id'), $this->usuario->id);
                    $mSession->mensajes[] = 'La boleta fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/dte-boleta/view/' . $form->getValue('id'));
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la boleta.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dte-boleta/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $id = (int)$this->_getParam('id');
        $boleta->setId($id);
        $form->populate($boleta->getRow()->toArray());
        $form->setAction('/dte-boleta/edit');
        $form->submit->setLabel('Guardar');
        $this->view->title = "Editar boleta";
        $this->view->form = $form;
        $this->renderScript('dte-boleta/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $boleta = new Default_Model_DteBoleta();
            $boleta->setId($id);
            $boleta->eliminar();
            $mSession->mensajes[] = 'La boleta fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dte-boleta/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la boleta.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dte-boleta/index/1/id/DESC');
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            $boleta = new Default_Model_DteBoleta();
            $boleta->setId($id);
            $boleta->terminar();
            $mSession->mensajes[] = "La boleta ha sido emitida de forma satisfactoria. Ahora puede imprimirla.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/dte-boleta/view/' . $id);

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar emitir la boleta";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-boleta/view/' . $id) ;
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $boleta = new Default_Model_DteBoleta();
            $boleta->setId($id);
            $this->view->boleta = $boleta->getRowFull();
            $this->view->items = $boleta->getItems();
            $this->view->title = "Boleta";
            
            if($boleta->getEstado()=='BORRADOR'){
                $this->renderScript('dte-boleta/view-borrador.phtml');
            } else {
                $this->view->pagos = $boleta->getPagos();
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar la Boleta";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-boleta/index/1/id/DESC');
        }
    }
    
    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();

            $id = (int)$this->_getParam('id');
            
            try {
                
                $boleta = new Default_Model_DteBoleta();
                $boleta->setId($id);
                $this->view->boleta = $boleta->getRow();
                $this->view->items = $boleta->getItems();
                $this->renderScript('dte-boleta/detalle.phtml');
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function printAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $this->_helper->layout->setLayout('print');
        $id = (int)$this->_getParam('id');
            
        try {
            $boleta = new Default_Model_DteBoleta();
            $boleta->setId($id);
            $this->view->boleta = $boleta->getRow();
            $this->view->items = $boleta->getItems();

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al tratar de visualizar la boleta en formato de impresión.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-boleta/view/' . $id);
        }
    }

    public function addItemsAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $boleta_id = $this->_getParam('id');
            $data = $this->_getParam('data');

            try {
                
                $item = new Default_Model_DteBoletaItem();
                $item->addFromNotaVenta($data, $boleta_id);
                $this->view->estado = 1;
                $this->renderScript('partes-comunes/mensaje-add-items.phtml');
                
            } catch (Exception $e) {
                
                $this->view->estado = 2;
                $this->view->error = $e->getMessage();
                $this->renderScript('partes-comunes/mensaje-add-items.phtml');
                
            }
        }
    }
    
    public function deleteItemsAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $data = $this->_getParam('data');

            try {
                $item = new Default_Model_DteBoletaItem();
                $item->eliminar($data);
                return true;
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
}