<?php
class DteFacturaCompraController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Facturas de compra';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $factura = new Default_Model_DteFacturaCompra();
        $facturas = $factura->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $factura->getOrderByOptions();
        $this->view->orderBy = $factura->getOrderBy();
        $this->view->orderType = $factura->getOrderType();
        $this->view->action = '/dte-factura-compra/index/';
        $this->view->facturas = $facturas;
        $this->view->title = 'Facturas de compra';
    }
    
    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaDteFacturasCompras();
        
        $this->view->form = $form;
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $optionsNumero = array('table' => 'dte_facturas_compras', 'field' => 'numero');
        $validadorNumero = new Zend_Validate_Db_NoRecordExists($optionsNumero);
        
        $request = $this->getRequest();
        $form = new Default_Form_DteFacturaCompra();
        $form->numero->addValidator($validadorNumero);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $factura = new Default_Model_DteFacturaCompra();
                    $id = $factura->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/dte-factura-compra/view/' . $id );
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la factura de compra.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dte-factura-compra/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Crear factura de compra";
        $this->view->form = $form;
        $this->renderScript('dte-factura-compra/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $optionsNumero = array('table' => 'dte_factura_compras', 'field' => 'numero');
        $validadorNumero = new Zend_Validate_Db_RecordExists($optionsNumero);
        
        $factura = new Default_Model_DteFacturaCompra();
        
        $request = $this->getRequest();
        
        $form = new Default_Form_DteFacturaCompra();
        $form->numero->addValidator($validadorNumero);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $factura->editar($form->getValues(), $form->getValue('id'), $this->usuario->id);
                    $mSession->mensajes[] = 'La factura de compra fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/dte-factura-compra/view/' . $form->getValue('id'));
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la factura.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dte-factura-compra/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $id = (int)$this->_getParam('id');
        $factura->setId($id);
        $form->populate($factura->getRow()->toArray());
        $form->setAction('/dte-factura-compra/edit');
        $form->submit->setLabel('Guardar');
        $this->view->title = "Editar factura de compra";
        $this->view->form = $form;
        $this->renderScript('dte-factura-compra/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $factura = new Default_Model_DteFacturaCompra();
            $factura->setId($id);
            $factura->eliminar();
            $mSession->mensajes[] = 'La factura de compra fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dte-factura-compra/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la factura de compra.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dte-factura-compra/index/1/id/DESC');
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            $factura = new Default_Model_DteFacturaCompra();
            $factura->setId($id);
            $factura->terminar();
            $mSession->mensajes[] = "La factura de comrpa ha sido emitida de forma satisfactoria. Ahora puede imprimirla.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/dte-factura-compra/view/' . $id);

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar terminar la factura";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-factura-compra/view/' . $id) ;
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $factura = new Default_Model_DteFacturaCompra();
            $factura->setId($id);
            $this->view->factura = $factura->getRow();
            $this->view->items = $factura->getItems();
            $this->view->title = "Factura de compra";
            
            if($factura->getEstado()=='BORRADOR'){
                $this->renderScript('dte-factura-compra/view-borrador.phtml');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar la factura";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-factura-compra/index/1/id/DESC');
        }
    }
    
    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();

            $id = (int)$this->_getParam('id');
            
            try {
                $factura = new Default_Model_DteFacturaCompra();
                $factura->setId($id);
                $this->view->factura = $factura->getRow();
                $this->view->items = $factura->getItems();
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function printAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $this->_helper->layout->setLayout('print');
        $id = (int)$this->_getParam('id');
            
        try {
            $factura = new Default_Model_DteFacturaCompra();
            $factura->setId($id);
            $this->view->factura = $factura->getRow();
            $this->view->items = $factura->getItems();

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al tratar de visualizar la factura de compra en formato de impresión.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-factura-compra/view/' . $id);
        }
    }
}