<?php
class DteGuiaDespachoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Guías de Despacho';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $guia = new Default_Model_DteGuiaDespacho();
        $guias = $guia->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $guia->getOrderByOptions();
        $this->view->orderBy = $guia->getOrderBy();
        $this->view->orderType = $guia->getOrderType();
        $this->view->action = '/dte-guia-despacho/index/';
        $this->view->guias = $guias;
        $this->view->title = 'Guías de despacho';
    }
    
    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaDteGuiasDespachos();
        
        $this->view->form = $form;
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $optionsNumero = array('table' => 'dte_guias_despacho', 'field' => 'numero');
        $validadorNumero = new Zend_Validate_Db_NoRecordExists($optionsNumero);
        
        $request = $this->getRequest();
        $form = new Default_Form_DteGuiaDespacho();
        $form->numero->addValidator($validadorNumero);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $guia = new Default_Model_DteGuiaDespacho();
                    $id = $guia->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/dte-guia-despacho/view/' . $id );
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la Guía de despacho.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dte-guia-despacho/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = "Crear guía";
        $this->renderScript('dte-guia-despacho/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $optionsNumero = array('table' => 'dte_guias_despacho', 'field' => 'numero');
        $validadorNumero = new Zend_Validate_Db_RecordExists($optionsNumero);
        
        $guia = new Default_Model_DteGuiaDespacho();
        
        $request = $this->getRequest();
        
        $form = new Default_Form_DteGuiaDespacho();
        $form->numero->addValidator($validadorNumero);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $guia->editar($form->getValues(), $form->getValue('id'), $this->usuario->id);
                    $mSession->mensajes[] = 'La Guía de despacho fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/dte-guia-despacho/view/' . $form->getValue('id'));
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la Guía de despacho.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dte-guia-despacho/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $id = (int)$this->_getParam('id');
        $guia->setId($id);
        $form->populate($guia->getRow()->toArray());
        $form->setAction('/dte-guia-despacho/edit');
        $form->submit->setLabel('Guardar');
        $this->view->form = $form;
        $this->view->title = "Editar guía";
        $this->renderScript('dte-guia-despacho/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $guia = new Default_Model_DteGuiaDespacho();
            $guia->setId($id);
            $guia->eliminar();
            $mSession->mensajes[] = 'La Guía de despacho fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dte-guia-despacho/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la guía de despacho.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dte-guia-despacho/index/1/id/DESC');
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            $guia = new Default_Model_DteGuiaDespacho();
            $guia->setId($id);
            $guia->terminar();
            $mSession->mensajes[] = "La Guía ha sido emitida de forma satisfactoria. Ahora puede imprimirla.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/dte-guia-despacho/view/' . $id);

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar terminar la Guía de Despacho";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-guia-despacho/view/' . $id) ;
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $guia = new Default_Model_DteGuiaDespacho();
            $guia->setId($id);
            $this->view->guia = $guia->getRow();
            $this->view->items = $guia->getItems();
            $this->view->title = "Guía de despacho";
            
            if($guia->getEstado()=='BORRADOR'){
                $this->renderScript('dte-guia-despacho/view-borrador.phtml');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar la Guía de despacho";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-guia-despacho/index/1/id/DESC');
        }
    }
    
    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();

            $id = (int)$this->_getParam('id');
            
            try {
                $guia = new Default_Model_DteGuiaDespacho();
                $guia->setId($id);
                $this->view->guia = $guia->getRow();
                $this->view->items = $guia->getItems();
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function printAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $this->_helper->layout->setLayout('print');
        $id = (int)$this->_getParam('id');
            
        try {
            $guia = new Default_Model_DteGuiaDespacho();
            $guia->setId($id);
            $this->view->guia = $guia->getRow();
            $this->view->items = $guia->getItems();

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al tratar de visualizar la Guía de Despacho en formato de impresión.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-guia-despacho/view/' . $id);
        }
    }
}