<?php
class DteNotaDebitoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Notas de débito';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $nota = new Default_Model_DteNotaDebito();
        $notas = $nota->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $nota->getOrderByOptions();
        $this->view->orderBy = $nota->getOrderBy();
        $this->view->orderType = $nota->getOrderType();
        $this->view->action = '/dte-nota-debito/index/';
        $this->view->notas = $notas;
        $this->view->title = 'Notas de débito';
    }
    
    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaDteNotasDebito();
        
        $this->view->form = $form;
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $optionsNumero = array('table' => 'dte_notas_debito', 'field' => 'numero');
        $validadorNumero = new Zend_Validate_Db_NoRecordExists($optionsNumero);
        
        $request = $this->getRequest();
        $form = new Default_Form_DteNotaDebito();
        $form->numero->addValidator($validadorNumero);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $nota = new Default_Model_DteNotaDebito();
                    $id = $nota->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/dte-nota-debito/view/' . $id );
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la nota de débito.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dte-nota-debito/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $optionsNumero = array('table' => 'dte_notas_debito', 'field' => 'numero');
        $validadorNumero = new Zend_Validate_Db_RecordExists($optionsNumero);
        
        $nota = new Default_Model_DteNotaDebito();
        
        $request = $this->getRequest();
        
        $form = new Default_Form_DteNotaDebito();
        $form->numero->addValidator($validadorNumero);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $nota->editar($form->getValues(), $form->getValue('id'), $this->usuario->id);
                    $mSession->mensajes[] = 'La nota de débito fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/dte-nota-debito/view/' . $form->getValue('id'));
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la nota de débito.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dte-nota-debito/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $id = (int)$this->_getParam('id');
        $nota->setId($id);
        $form->populate($nota->getRow()->toArray());
        $form->setAction('/dte-nota-debito/edit');
        $form->submit->setLabel('Guardar');
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtmll');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $nota = new Default_Model_DteNotaDebito();
            $nota->setId($id);
            $nota->eliminar();
            $mSession->mensajes[] = 'La nota de débito fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dte-nota-debito/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la nota de débito.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dte-nota-debito/index/1/id/DESC');
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            $nota = new Default_Model_DteNotaDebito();
            $nota->setId($id);
            $nota->terminar();
            $mSession->mensajes[] = "La nota de débito ha sido emitida de forma satisfactoria. Ahora puede imprimirla.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/dte-nota-debito/view/' . $id);

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar terminar la nota de débito";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-nota-debito/view/' . $id) ;
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $nota = new Default_Model_DteNotaDebito();
            $nota->setId($id);
            $this->view->nota = $nota->getRow();
            $this->view->title = "Nota de débito";
            
            if($nota->getEstado()=='BORRADOR'){
                $this->renderScript('dte-nota-debito/view-borrador.phtml');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar la nota de débito";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-nota-debito/index/1/id/DESC');
        }
    }
    
    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();

            $id = (int)$this->_getParam('id');
            
            try {
                $nota = new Default_Model_DteNotaDebito();
                $nota->setId($id);
                $this->view->nota = $nota->getRow();
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function printAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $this->_helper->layout->setLayout('print');
        $id = (int)$this->_getParam('id');
            
        try {
            $nota = new Default_Model_DteNotaDebito();
            $nota->setId($id);
            $this->view->nota = $nota->getRow();

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al tratar de visualizar la nota de débito en formato de impresión.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dte-nota-debito/view/' . $id);
        }
    }
}