<?php
class DtrBoletaController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Proveedores :: Boletas';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $boleta = new Default_Model_DtrBoleta();
        $boletas = $boleta->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $boleta->getOrderByOptions();
        $this->view->orderBy = $boleta->getOrderBy();
        $this->view->orderType = $boleta->getOrderType();
        $this->view->action = '/dtr-boleta/index/';
        $this->view->boletas = $boletas;
        $this->view->title = 'Boletas de proveedores';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaDtrBoletas();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_DtrBoleta();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $boleta = new Default_Model_DtrBoleta();
                    $id = $boleta->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/dtr-boleta/view/' . $id );
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la boleta.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dtr-boleta/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Ingresar boleta";
        $this->view->form = $form;
        $this->renderScript('dtr-boleta/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $boleta = new Default_Model_DtrBoleta();
        $request = $this->getRequest();
        $form = new Default_Form_DtrBoleta();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $boleta->editar($form->getValues(), $form->getValue('id'), $this->usuario->id);
                    $mSession->mensajes[] = 'La boleta fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/dtr-boleta/view/' . $form->getValue('id'));
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la boleta.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dtr-boleta/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $id = (int)$this->_getParam('id');
        $boleta->setId($id);
        $form->populate($boleta->getRow()->toArray());
        $form->setAction('/dtr-boleta/edit');
        $form->submit->setLabel('Guardar');
        $this->view->title = "Editar boleta";
        $this->view->form = $form;
        $this->renderScript('dtr-boleta/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $boleta = new Default_Model_DtrBoleta();
            $boleta->setId($id);
            $boleta->eliminar();
            $mSession->mensajes[] = 'La boleta fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dtr-boleta/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la boleta.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dtr-boleta/index/1/id/DESC');
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            $boleta = new Default_Model_DtrBoleta();
            $boleta->setId($id);
            $boleta->terminar();
            $mSession->mensajes[] = "La ingreso de la boleta ha concluído de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/dtr-boleta/view/' . $id);

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar terminar la boleta";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dtr-boleta/view/' . $id) ;
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $boleta = new Default_Model_DtrBoleta();
            $boleta->setId($id);
            $this->view->boleta = $boleta->getRowFull();
            $this->view->title = "Boleta";
            
            if($boleta->getEstado()=='BORRADOR'){
                $this->renderScript('dtr-boleta/view-borrador.phtml');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar la boleta";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dtr-boleta/index/1/id/DESC');
        }
    }
}