<?php
class DtrFacturaController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Proveedores :: Facturas';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $factura = new Default_Model_DtrFactura();
        $facturas = $factura->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $factura->getOrderByOptions();
        $this->view->orderBy = $factura->getOrderBy();
        $this->view->orderType = $factura->getOrderType();
        $this->view->action = '/dtr-factura/index/';
        $this->view->facturas = $facturas;
        $this->view->title = 'Facturas de proveedores';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaDtrFacturas();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_DtrFactura();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $factura = new Default_Model_DtrFactura();
                    $id = $factura->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/dtr-factura/view/' . $id );
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la factura.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dtr-factura/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Ingresar factura";
        $this->view->form = $form;
        $this->renderScript('dtr-factura/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $factura = new Default_Model_DtrFactura();
        $request = $this->getRequest();
        $form = new Default_Form_DtrFactura();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $factura->editar($form->getValues(), $form->getValue('id'), $this->usuario->id);
                    $mSession->mensajes[] = 'La factura fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/dtr-factura/view/' . $form->getValue('id'));
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la factura.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dtr-factura/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Editar factura";
        $id = (int)$this->_getParam('id');
        $factura->setId($id);
        $form->populate($factura->getRow()->toArray());
        $form->setAction('/dtr-factura/edit');
        $form->submit->setLabel('Guardar');
        $this->view->form = $form;
        $this->renderScript('dtr-factura/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $factura = new Default_Model_DtrFactura();
            $factura->setId($id);
            $factura->eliminar();
            $mSession->mensajes[] = 'La factura fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dtr-factura/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la factura.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dtr-factura/index/1/id/DESC');
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            $factura = new Default_Model_DtrFactura();
            $factura->setId($id);
            $factura->terminar();
            $mSession->mensajes[] = "La ingreso de la factura ha concluído de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/dtr-factura/view/' . $id);

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar terminar la factura";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dtr-factura/view/' . $id) ;
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $factura = new Default_Model_DtrFactura();
            $factura->setId($id);
            $this->view->factura = $factura->getRowFull();
            $this->view->title = "Factura";
            
            if($factura->getEstado()=='BORRADOR'){
                $this->renderScript('dtr-factura/view-borrador.phtml');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar la factura";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dtr-factura/index/1/id/DESC');
        }
    }
}