<?php
class DtrGuiaDespachoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Proveedores :: Guías de despacho';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $guia = new Default_Model_DtrGuiaDespacho();
        $guias = $guia->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $guia->getOrderByOptions();
        $this->view->orderBy = $guia->getOrderBy();
        $this->view->orderType = $guia->getOrderType();
        $this->view->action = '/dtr-guia-despacho/index/';
        $this->view->guias = $guias;
        $this->view->title = 'Guías de Despacho de Proveedores';
    }
    
    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaDtrGuiasDespacho();
        
        $this->view->form = $form;
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_DtrGuiaDespacho();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $guia = new Default_Model_DtrGuiaDespacho();
                    $id = $guia->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/dtr-guia-despacho/view/' . $id );
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la guía de despacho';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dtr-guia-despacho/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Ingresar guía de despacho";
        $this->view->form = $form;
        $this->renderScript('dtr-guia-despacho/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $guia = new Default_Model_DtrGuiaDespacho();
        $request = $this->getRequest();
        $form = new Default_Form_DtrGuiaDespacho();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $guia->editar($form->getValues(), $form->getValue('id'), $this->usuario->id);
                    $mSession->mensajes[] = 'La guía de despacho fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/dtr-guia-despacho/view/' . $form->getValue('id'));
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la guía de despacho.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dtr-guia-despacho/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Editar guía de despacho";
        $id = (int)$this->_getParam('id');
        $guia->setId($id);
        $form->populate($guia->getRow()->toArray());
        $form->setAction('/dtr-guia-despacho/edit');
        $form->submit->setLabel('Guardar');
        $this->view->form = $form;
        $this->renderScript('dtr-guia-despacho/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $guia = new Default_Model_DtrGuiaDespacho();
            $guia->setId($id);
            $guia->eliminar();
            $mSession->mensajes[] = 'La guía de despacho fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dtr-guia-despacho/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la guía de despacho.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dtr-guia-despacho/index/1/id/DESC');
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            $guia = new Default_Model_DtrGuiaDespacho();
            $guia->setId($id);
            $guia->terminar();
            $mSession->mensajes[] = "La ingreso de la guía de despacho ha concluído de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/dtr-guia-despacho/view/' . $id);

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar terminar la guía de despacho.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dtr-guia-despacho/view/' . $id) ;
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $guia = new Default_Model_DtrGuiaDespacho();
            $guia->setId($id);
            $this->view->guia = $guia->getRowFull();
            $this->view->title = "Guía de despacho";
            
            if($guia->getEstado()=='BORRADOR'){
                $this->renderScript('dtr-guia-despacho/view-borrador.phtml');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar la guía de despacho";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dtr-guia-despacho/index/1/id/DESC');
        }
    }
}