<?php
class DtrNotaDebitoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Proveedores :: Notas de débito';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $nota = new Default_Model_DtrNotaDebito();
        $notas = $nota->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $nota->getOrderByOptions();
        $this->view->orderBy = $nota->getOrderBy();
        $this->view->orderType = $nota->getOrderType();
        $this->view->action = '/dtr-nota-debito/index/';
        $this->view->notas = $notas;
        $this->view->title = 'Notas de débito';
    }
    
    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaDtrNotasDebito();
        
        $this->view->form = $form;
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_DtrNotaDebito();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $nota = new Default_Model_DtrNotaDebito();
                    $id = $nota->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/dtr-nota-debito/view/' . $id );
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la nota de débito';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dtr-nota-debito/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Ingresar nota de débito";
        $this->view->form = $form;
        $this->renderScript('dtr-nota-debito/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $nota = new Default_Model_DtrNotaDebito();
        $request = $this->getRequest();
        $form = new Default_Form_DtrNotaDebito();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $nota->editar($form->getValues(), $form->getValue('id'), $this->usuario->id);
                    $mSession->mensajes[] = 'La nota de débito fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/dtr-nota-debito/view/' . $form->getValue('id'));
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la nota de débito.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dtr-nota-debito/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $id = (int)$this->_getParam('id');
        $nota->setId($id);
        $form->populate($nota->getRow()->toArray());
        $form->setAction('/dtr-nota-debito/edit');
        $form->submit->setLabel('Guardar');
        $this->view->title = "Editar nota de débito";
        $this->view->form = $form;
        $this->renderScript('dtr-nota-debito/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $nota = new Default_Model_DtrNotaDebito();
            $nota->setId($id);
            $nota->eliminar();
            $mSession->mensajes[] = 'La nota de débito fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dtr-nota-debito/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la nota de débito.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/dtr-nota-debito/index/1/id/DESC');
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            $nota = new Default_Model_DtrNotaDebito();
            $nota->setId($id);
            $nota->terminar();
            $mSession->mensajes[] = "La ingreso de la nota de débito ha concluído de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/dtr-nota-debito/view/' . $id);

        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar terminar la nota de débito";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dtr-nota-debito/view/' . $id) ;
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $nota = new Default_Model_DtrNotaDebito();
            $nota->setId($id);
            $this->view->nota = $nota->getRowFull();
            $this->view->title = "Nota de débito";
            
            if($nota->getEstado()=='BORRADOR'){
                $this->renderScript('dtr-nota-debito/view-borrador.phtml');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar la nota de débito";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/dtr-nota-débito/index/1/id/DESC');
        }
    }
}