<?php
class EmpleadoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Empleados';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
	
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $empleado = new Default_Model_Empleado();
        $empleados = $empleado->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $empleado->getOrderByOptions();
        $this->view->orderBy = $empleado->getOrderBy();
        $this->view->orderType = $empleado->getOrderType();
        $this->view->action = '/empleado/index/';
        $this->view->empleados = $empleados;
        $this->view->title = 'Empleados';
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Empleado();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    $empleado = new Default_Model_Empleado();
                    $rut = $empleado->crear($form->getValues());
                    $mSession->mensajes[] = 'El empleado fue agregado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_redirect('/empleado/view/' . $rut);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el proveedor.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/empleado/index/1/nombre_corto/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $empleado = new Default_Model_Empleado();
        $request = $this->getRequest();
        $form = new Default_Form_Empleado();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $id = App_Rut::cleanToDb($form->getValue('id'));
                    $rut = $empleado->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'El empleado fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/empleado/view/' . $rut);

                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/empleado/index/1/nombres/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $rut = App_Rut::cleanToDb($this->_getParam('id'));
        $empleado->setRut($rut);
        $form->populate($empleado->getRow()->toArray());
        $form->setAction('/empleado/edit');
        $form->id->setValue($rut);
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $rut = App_Rut::cleanToDb($this->_getParam('id'));
        
        try {
            
            $empleado = new Default_Model_Empleado();
            $empleado->setRut($rut);
            $this->view->empleado = $empleado->getRow();
            
        } catch(Exception $e) {
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar el empleado";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/empleado/index/1/nombre_completo/ASC');
        }
    }
    
    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $rut = App_Rut::cleanToDb($this->_getParam('id'));
        
        try {
            
            $empleado = new Default_Model_Empleado();
            $empleado->setRut($rut);
            $empleado->eliminar();
            
            $mSession->mensajes[] = 'El empleado fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/empleado/index/1/nombre_completo/ASC');
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar eliminar el empleado";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/empleado/index/1/nombre_completo/ASC');
        }
    }

    public function fichaAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {

            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $rut = App_Rut::cleanToDb($this->usuario->rut);
        
        try {
        
            $empleado = new Default_Model_Empleado();
            $empleado->setRut($rut);
            $this->view->empleado = $empleado->getRow();
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar su ficha personal";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/');
        }
    }
}