<?php
class EnvaseController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Envase';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $currentPage = $this->_getParam('page', 1);

        $envase = new Default_Model_VistaEnvases();
        $order = "nombre_corto";
        $envases = $envase->fetchAll(null, $order);
        $paginador = Zend_Paginator::factory($envases);
        $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                  ->setPageRange($this->paginacion['cant_pages'])
                  ->setCurrentPageNumber($currentPage);
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        $this->view->envases = $paginador;
        $this->view->title = 'Envases';
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Envase(null, $this->path);

            if($this->_request->getParam('id')) {

                $envase = new Default_Model_Envase();
                $where = $envase->getAdapter()->quoteInto("id=?", $this->_request->getParam('id'));
                $row = $envase->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/envase/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar envase";

            } else {

                $this->view->title = "Crear envase";

            }
            $this->view->form = $form;
            $this->renderScript('envase/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_Envase(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $envase = new Default_Model_Envase();
                    $row = $envase->createRow();
                    $row->tipo_id = $form->getValue('tipo_id');
                    $row->unidad_id = $form->getValue('unidad_id');
                    $row->cantidad = $form->getValue('cantidad');
                    $row->save();
                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_redirect('/envase/index/1/nombre_corto/ASC');
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = 'Crear envase';
        $this->view->form = $form;
        $this->renderScript('envase/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $envase = new Default_Model_Envase();
        $request = $this->getRequest();
        $form = new Default_Form_Envase();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $where = $envase->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $envase->fetchRow($where);
                    $row->tipo_id = $form->getValue('tipo_id');
                    $row->unidad_id = $form->getValue('unidad_id');
                    $row->cantidad = $form->getValue('cantidad');
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_forward('/envase/index/1/nombre_corto/ASC');
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_request->getParam('id');
        $where = $envase->getAdapter()->quoteInto("id=?", $id);
        $registro = $envase->fetchRow($where);
        $form->populate($registro->toArray());
        $form->setAction('/envase/edit');
        $form->submit->setLabel("guardar cambios");
        $this->view->title = 'Editar envase';
        $this->view->form = $form;
        $this->renderScript('envase/form.phtml');
    }

    public function deleteAction()
    {
        if($this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {
                $id = (int)$this->_getParam('id');
                $model = new Default_Model_Envase();
                $where = $model->getAdapter()->quoteInto("id=?", $id);
                $model->delete($where);
                $mSession->mensajes[] = 'El envase fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_redirect('/envase/index/1/nombre_corto/ASC');

            } catch (Exception $e) {
                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();
                $this->_redirect('/error/error-delete-registro');
            }
        }
    }
}