<?php
class EquivalenciaArticuloController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {

        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $equivalencia = new Default_Model_VistaEquivalenciasArticulos();
            $equivalencias = $equivalencia->fetchAll();

            $paginador = Zend_Paginator::factory($equivalencias);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->equivalencias = $paginador;
            $this->view->title = 'Equivalencias Artículos';
            $this->renderScript('equivalencia-articulo/index.phtml');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_EquivalenciaArticulo(null, $this->path);

            if($this->_request->getParam('id')) {

                $equivalencia = new Default_Model_EquivalenciaArticulo();
                $id = $equivalencia->getAdapter()->quote($this->_request->getParam('id'));
                $row = $equivalencia->fetchRow('id='.$id)->toArray();
                $form->populate($row);
                $form->setAction('/equivalencia-articulo/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar equivalencia de artículos";

            }  else {

                if($this->_request->getParam('codigo')) {
                    $form->codigo1->setValue($this->_request->getParam('codigo'));
                }

                $this->view->title = "Crear equivalencia de artículos";

            }
            $this->view->form = $form;
            $this->renderScript('equivalencia-articulo/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_EquivalenciaArticulo(null, $this->path);
        $this->view->title = 'Crear equivalencia de artículos';

       
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                if($form->getValue('codigo1') == $form->getValue('codigo2')) {

                    $this->view->mensajes = array('Debe seleccionar artículos distintos.');
                    $this->view->claseMensaje = 'error';
                    $this->view->form = $form;
                    $form->populate($request->getPost());
                    $this->renderScript('equivalencia-articulo/form.phtml');

                } else {

                    try {

                        $equivalencia = new Default_Model_EquivalenciaArticulo();
                        $row = $equivalencia->createRow();
                        $row->creador = $this->usuario->rut;
                        $row->codigo1 = $form->getValue('codigo1');
                        $row->codigo2 = $form->getValue('codigo2');
                        if($form->getValue('observaciones')!='') {
                            $row->observaciones = $form->getValue('observaciones');
                        } else {
                            $row->observaciones = NULL ;
                        }
                        $row->save();

                        $mSession->mensajes[] = 'La equivalencia de artículos fue creada de forma exitosa.';
                        $mSession->claseMensaje = 'confirmacion';
                        $this->_forward('index','equivalencia-articulo');

                    } catch (Exception $e) {

                        $mSession->mensajes[] = 'Ocurrió un error al intentar crear la equivalencia de artículos.';
                        $mSession->mensajes[] = $e->getMessage();
                        $mSession->claseMensaje = 'error';
                        $this->_forward('index','equivalencia-articulo');
                    }
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('equivalencia-articulo/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $equivalencia = new Default_Model_EquivalenciaArticulo();

        $request = $this->getRequest();
        $form = new Default_Form_EquivalenciaArticulo();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                if($form->getValue('codigo1') == $form->getValue('codigo2')) {

                    $this->view->mensajes = array('Debe seleccionar artículos distintos.');
                    $this->view->claseMensaje = 'error';
                    $this->view->form = $form;
                    $form->populate($request->getPost());
                    $this->renderScript('equivalencia-articulo/form.phtml');

                } else {

                    try {

                        $id = (int)$form->getValue('id');
                        $where = $equivalencia->getAdapter()->quoteInto("id=?", $id);
                        $row = $equivalencia->fetchRow($where);
                        $row->codigo1 = $form->getValue('codigo1');
                        $row->codigo2 = $form->getValue('codigo2');
                        if($form->getValue('observaciones')!='') {
                            $row->observaciones = $form->getValue('observaciones');
                        } else {
                            $row->observaciones = NULL;
                        }
                        $row->save();

                        $mSession->mensajes[] = 'La equivalencia fue editada de forma exitosa.';
                        $mSession->claseMensaje = 'confirmacion';
                        $this->_forward('index', 'equivalencia-articulo');

                    } catch (Exception $e) {

                        $mSession->mensajes[] = 'Ocurrió un error al intentar editar la equivalencia.';
                        $mSession->mensajes[] = $e->getMessage();
                        $mSession->claseMensaje = 'error';

                        $this->_forward('index','equivalencia-articulo');
                    }
                }

                

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/equivalencia-articulo/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar equivalencia";
                $this->renderScript('equivalencia-articulo/form.phtml');
            }
        }
    }
    
    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $id = (int)$this->_getParam('id');
            $equivalencia = new Default_Model_EquivalenciaArticulo();
            $where = $equivalencia->getAdapter()->quoteInto('id = ?' , $id);
            $equivalencia->delete($where);
            $mSession->mensajes[] = 'La equivalencia de artículos fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','equivalencia-articulo');
        }
    }

    public function listByArticuloAction()
    {

        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $codigo = $this->_getParam('codigo');
            $currentPage = $this->_getParam('page', 1);

            $equivalencia = new Default_Model_VistaEquivalenciasArticulos();
            $where = $equivalencia->getAdapter()->quoteInto('codigo1=? OR codigo2=?', $codigo);
            $equivalencias = $equivalencia->fetchAll();

            $paginador = Zend_Paginator::factory($equivalencias);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control_extra.phtml');
            $this->view->codigo = $codigo;
            $this->view->equivalencias = $paginador;
            $this->view->title = 'Equivalencias Artículos';
            $this->renderScript('equivalencia-articulo/list-by-articulo.phtml');
        }
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $formularios = array(
                new Default_Form_ConsultaEquivalenciaArticulo(null, $this->path),
            );

            $request = $this->getRequest();
            $this->view->formularios = $formularios;
            $this->view->title = 'Equivalencias de Artículos : Buscar';
            $this->renderScript('equivalencia-articulo/find.phtml');

        }
    }

    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $equivalencia = new Default_Model_VistaEquivalenciasArticulos();
            $criterio = $this->_getParam('criterio');
            $this->view->t  = $this->_getParam('t');

            if($criterio!='') {
                $where = $equivalencia->getAdapter()->quoteInto('codigo1=? OR codigo2=?', $criterio);
                $this->view->codigo = $criterio;
                $this->view->equivalencias = $equivalencia->fetchAll();
            }

            $this->renderScript('equivalencia-articulo/search.phtml');
        }
    }

    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $this->view->t  = $this->_getParam('t');
            $codigo = $this->_getParam('codigo');
            $articulo = new Default_Model_VistaArticulos();
            $where = $articulo->getAdapter()->quoteInto("codigo=?", $codigo);
            $this->view->articulo = $articulo->fetchRow($where)->toArray();
            $this->renderScript('equivalencia-articulo/view-tooltip.phtml');
        }
    }
}