<?php
class FormaPagoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Formas de pago';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }

    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $formaPago = new Default_Model_FormaPago();
        $this->view->formas = $formaPago->getAll();
        $this->view->title = 'Formas de pago';
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $request = $this->getRequest();
        $form = new Default_Form_FormaPago();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    $forma_pago = new Default_Model_FormaPago();
                    $forma_pago->crear($form->getValues());
                    $mSession->mensajes[] = 'La forma de pago fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/forma-pago');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la forma de pago.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/forma-pago');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        $formaPago = new Default_Model_FormaPago();
        $request = $this->getRequest();
        $form = new Default_Form_FormaPago();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $formaPago->editar($form->getValues(), $form->getValue('id'));
                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/forma-pago');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/forma-pago');
                    
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $formaPago->setId($id);
        $form->populate($formaPago->getRow()->toArray());
        $form->setAction('/forma-pago/edit');
        $form->submit->setLabel("Guardar cambios");
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $id = (int)$this->_getParam('id');
        try {

            $formaPago = new Default_Model_FormaPago();
            $formaPago->setId($id);
            $formaPago->eliminar();
            $mSession->mensajes[] = 'La forma de pago fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/forma-pago');

        } catch (Exception $e) {
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la forma de pago.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/forma-pago');
        }
    }
}