<?php
class NotaVentaController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $action = $this->getRequest()->getActionName();
        if($action != 'export-pdf' AND $action != 'create-pdf'){
            $auth = Zend_Auth::getInstance();
            if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
                $this->_redirect('/sistema-acceso/logout');
            }
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Notas de venta';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();

        $this->view->propietario = Default_Model_SistemaPropietario::get();
        $this->preferencias = Default_Model_NotaVenta::getPrefs();
	
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $nota = new Default_Model_NotaVenta();
        $notas = $nota->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $nota->getOrderByOptions();
        $this->view->orderBy = $nota->getOrderBy();
        $this->view->orderType = $nota->getOrderType();
        $this->view->action = '/nota-venta/index/';
        $this->view->notas = $notas;
        $this->view->title = 'Notas de Venta';
    }
    
    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaNotasVentas();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_NotaVenta();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $nota = new Default_Model_NotaVenta();
                    $id = $nota->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/nota-venta/view/' . $id);
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la nota de venta.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nota-venta/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $this->view->title = 'Crear nota de venta';
        $this->view->form = $form;
        $this->renderScript('nota-venta/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $nota = new Default_Model_NotaVenta();
        $request = $this->getRequest();
        $form = new Default_Form_NotaVenta();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $id = (int)$form->getValue('id');
                    $nota->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'La nota de venta fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/nota-venta/view/' . $id);
                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la nota de venta.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/nota-venta/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $nota->setId($id);
        $form->submit->setLabel('Guardar');
        $form->id->setValue($id);
        $form->setAction('/nota-venta/edit');
        $form->populate($nota->getRow()->toArray());
        $this->view->title = 'Editar encabezado';
        $this->view->form = $form;
        $this->renderScript('nota-venta/form.phtml');
    }
    
    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');

        try {
            $nota = new Default_Model_NotaVenta();
            $nota->setId($id);
            $this->view->nota = $nota->getRowFull();
            $this->view->items = $nota->getItems();
            $this->view->title = "Nota de venta Nº ";

            if($this->view->nota['estado'] == 'BORRADOR') {
                $this->renderScript('nota-venta/view-borrador.phtml');
            } elseif($this->view->nota['estado'] =='EN PROCESO') {
                $this->renderScript('nota-venta/view-en-proceso.phtml');
            } else {
                $this->renderScript('nota-venta/view.phtml');
            } 
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar la nota de venta";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/nota-venta/index/1/id/DESC');
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
	    
	    $this->_helper->layout->disableLayout();

            try {
                
                $id = (int)$this->_getParam('id');
                $nota = new Default_Model_NotaVenta();
                $nota->setId($id);
                $this->view->nota = $nota->getRow();
                $this->view->items = $nota->getItems();
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            
            $nota = new Default_Model_NotaVenta();
            $nota->setId($id);
            $nota->eliminar();
            
            $mSession->mensajes[] = 'La nota de venta fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/nota-venta/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la nota de venta.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/nota-venta/index/1/id/DESC');
        }
    }

    public function newFromAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        $cotizacion_id = $this->_getParam('id');
        
        try {
            
            $nota = new Default_Model_NotaVenta();
            $id = $nota->crearFromCotizacion($cotizacion_id, $this->usuario->id);
            $this->_redirect('/nota-venta/view/' . $id);
            
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un erro al intentar crear la nota de venta desde la cotización";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/cotizacion/view/' . $cotizacion_id);
        }
    }

    public function cotizacionesDisponiblesAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
	    
            $this->_helper->layout->disableLayout();
            
            $id = (int)$this->_getParam('id');
            $cliente_id = (int)$this->_getParam('from_id');

            try {
                
                $cotizacion = new Default_Model_Cotizacion();
                $this->view->cotizaciones = $cotizacion->getDisponiblesByClienteId($cliente_id);
                $this->view->nota_id = $id;
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }

    public function listarItemsCotizacionAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
	    
            $nota_id = (int)$this->_getParam('id');
            $cotizacion_id = (int)$this->_getParam('from_id');
            
            $cotizacion = new Default_Model_Cotizacion();
            $cotizacion->setId($cotizacion_id);
            
            $this->view->items = $cotizacion->getItems();
            $this->view->nota_id = $nota_id;
            $this->view->cotizacion_id = $cotizacion_id;
        }
    }

    public function emitirAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        $nota = new Default_Model_NotaVenta();
        $nota->setId($id);

        $rowNota = $nota->getRow();
        $totalNeto = $nota->getNeto();

        if($rowNota->estado=='BORRADOR' AND $totalNeto > 0) {
            if($totalNeto < (int)$this->preferencias['NV_MONTO_APROB']) {

                $nota->setEstado('EN PROCESO');
                $nota->checkInsumos();
                $mSession->mensajes[] = 'La nota de venta ha sido emitida de forma satisfatoria.';
                $mSession->claseMensaje = 'confirmacion';
                
            } else {

                $nota->setEstado('PENDIENTE');
                $mSession->mensajes[] = 'La nota de venta ha quedado a la espera de aprobación.';
                $mSession->claseMensaje = 'advertencia';
            }
        }
        $this->_redirect('/nota-venta/view/' . $id);
    }

    public function listByClienteAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();

            $id = (int)$this->_getParam('id');
            $nota = new Default_Model_NotaVenta();
            $this->view->notas = $nota->getRowsByCliente($id);
        }
    }

    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));
            
            $nota = new Default_Model_NotaVenta();
            $this->view->notas = $nota->searchToTooltip($criterio, $valor);
            $this->renderScript('nota-venta/search.phtml');
        }
    }
    
    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_ventas', 'id', $this->_getParam('id'))){
	    
            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $nota = new Default_Model_NotaVenta();
            $nota->setId($id);

            $this->view->title = "Nota de venta Nº $id";
            $this->view->nota = $nota->getRow();
            $this->view->items = $nota->getItems();
            $this->renderScript('nota-venta/view-small.phtml');
        }
    }

    public function printInformeServiciosAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('notas_ventas','id', $this->_getParam('id'))){

            $this->_helper->layout->setLayout('print');

            $id = (int)$this->_getParam('id');
            
            $nota = new Default_Model_NotaVenta();
            $nota->setId($id);
            
            if($nota->getEstado()=='TERMINADA') {
                
                /* 
                 * pendiente el orden de las ordenes de servicio 
                 */
                
                $orden = new Default_Model_VistaOrdenesServicios();
                $whereOrden = $orden->getAdapter()->quoteInto("nota_id=?", $id);
                $rowsOrdenes = $orden->fetchAll($whereOrden);

                $this->view->title = "Informe servicios Nº $id";
                $this->view->nota = $rowNota;
                $this->view->condiciones_generales = Default_Model_CondicionGeneral::getTexto('INFORME_SERVICIOS');
                $this->view->ordenes = $rowsOrdenes;
            }
        }
    }
    
    public function disponiblesFacturacionAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
	    
            $this->_helper->layout->disableLayout();
            
            $id = (int)$this->_getParam('id');
            $cliente_id = (int)$this->_getParam('from_id');

            try {
                
                $nota = new Default_Model_NotaVenta();
                $this->view->notas = $nota->getDisponiblesFacturacion($cliente_id);
                $this->view->documento_id = $id;
                $this->view->controller = $this->_getParam('ref_id');
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function listarItemsFacturacionAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
	    
            $documento_id = (int)$this->_getParam('id');
            $nota_id = (int)$this->_getParam('from_id');
            $controller = $this->_getParam('ref_id');
            
            $nota = new Default_Model_NotaVenta();
            $nota->setId($nota_id);
            
            $this->view->items = $nota->getItemsToFacturacion();
            $this->view->documento_id = $documento_id;
            $this->view->nota_id = $nota_id;
            $this->view->controller = $controller;
        }
    }
    
    public function vehiculosConTrabajosNoAsignadosAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $nota = new Default_Model_NotaVenta();
        $this->view->title = "Vehículos con trabajos pendientes";
        $this->view->vehiculos = $nota->getVehiculosConTrabajosNoAsignados();
    }

    /************************** FUNCIONES PARA ITEMS **************************/
    public function agregarItemsAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        $nota = new Default_Model_NotaVenta();
        $nota->setId($id);
        
        
        $this->view->nota = $nota->getRow();
    }
    
    public function eliminarItemsAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            try {
                $data = $this->_getParam('data');
                $itemNota = new Default_Model_ItemNotaVenta();
                $itemNota->eliminar($data);
                return true;
            } catch (Exception $e) {
                echo $e->getMessage();
            }
        }
    }
}
