<?php
class OrdenCompraController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $action = $this->getRequest()->getActionName();
        if($action != 'export-pdf' AND $action != 'create-pdf'){
            $auth = Zend_Auth::getInstance();
            if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
                $this->_redirect('/sistema-acceso/logout');
            }
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Órdenes de compra';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->preferencias = Default_Model_OrdenCompra::getPrefs();
        $this->view->propietario = Default_Model_SistemaPropietario::get();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $orden = new Default_Model_OrdenCompra();
        $ordenes = $orden->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $orden->getOrderByOptions();
        $this->view->orderBy = $orden->getOrderBy();
        $this->view->orderType = $orden->getOrderType();
        $this->view->action = '/orden-compra/index/';
        $this->view->ordenes = $ordenes;
        $this->view->title = 'Órdenes de compra';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_OrdenCompra($this->usuario->nombre);
        $orden = new Default_Model_OrdenCompra();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $id = $orden->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/orden-compra/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la solicitud de compra.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('/orden-compra/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
                $form->proveedor_nombre->setValue($orden->getProveedorRazonSocial());
                
            }
        }
        $this->view->form = $form;
        $this->view->title = 'Crear orden de compra';
        $this->renderScript('orden-compra/form.phtml');
    }

    public function newFromAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $id = $this->_getParam('id');
        try {
            $orden = new Default_Model_OrdenCompra();
            $orden->setId($id);
            $nueva_id = $orden->clonar($this->usuario->id);
            $this->_redirect('/orden-compra/view/' . $nueva_id);
        } catch(Exception $e){
            $mSession->mensajes[] = "Ocurrió un error al intentar duplicar la orden de compra";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/orden-compra/view/' . $id);
        }
            
    }
    
    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $orden = new Default_Model_OrdenCompra();
        $request = $this->getRequest();
        $form = new Default_Form_OrdenCompra($this->usuario->nombre);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $id = (int)$form->getValue('id');
                    $orden->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'La orden de compra fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/orden-compra/view/' . $id);

                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la orden de compra.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('/orden-compra/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $id = (int)$this->_getParam('id');
        $orden->setId($id);
        $form->submit->setLabel('Guardar cambios');
        $form->id->setValue($id);
        $form->setAction('/orden-compra/edit');
        $form->populate($orden->getRow()->toArray());
        $this->view->title = 'Editar encabezado orden de compra';
        $this->view->form = $form;
        $this->renderScript('orden-compra/form.phtml');
    }
    
    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');

        $orden = new Default_Model_OrdenCompra();
        $orden->setId($id);
        $this->view->orden = $orden->getRowFull();
        $this->view->items = $orden->getItems();
        
        $this->view->title = "Orden de compra Nº $id";
        $this->view->ultimoEnvio = $orden->getUltimoEnvio();
        $this->view->condiciones_generales = Default_Model_DocumentoCondicionGeneral::getTexto('ORDEN_COMPRA');
        
        if($orden->getEstado()=='BORRADOR') {
            $this->renderScript('orden-compra/view-borrador.phtml');
        } else {
            $this->renderScript('orden-compra/view.phtml');
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        $orden = new Default_Model_OrdenCompra();
        $orden->setId($id);
        
         if($orden->getEstado()=='BORRADOR') {
             
             $neto = $orden->getNeto($id);
             
             if(NULL!=$neto && $neto!==0) {

                if($neto >= $this->preferencias['OC_MONTO_APROB']) {

                    $orden->updateIva();
                    $orden->setEstado('PENDIENTE');
                    $orden->requerirAutorizacion($this->usuario->rut);
                    $mSession->mensajes[] = 'La orden de compra fue emitida de forma exitosa pero quedó a la espera de aprobación.';
                    $mSession->claseMensaje = 'advertencia';

                } else {
                    
                    $orden->updateIva();
                    $orden->setEstado('EMITIDA');
                    $mSession->mensajes[] = 'La orden de compra fue emitida de forma exitosa';
                    $mSession->claseMensaje = 'confirmacion';
                }
                
            }  else {
                $mSession->mensajes[] = 'Debe agregar ítems a la orden de compra';
                $mSession->claseMensaje = 'error';
            }
        }
        $this->_redirect('/orden-compra/view/' . $id);
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $orden = new Default_Model_OrdenCompra();
            $orden->setId($id);
            $orden->eliminar();
            
            $mSession->mensajes[] = 'La orden de compra fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/orden-compra/index/1/id/DESC');
            
        } catch (Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la orden';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/orden-compra/index/1/id/DESC');
            
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();

            $id = (int)$this->_getParam('id');

            try {
                
                $orden = new Default_Model_OrdenCompra();
                $orden->setId($id);
                $this->view->condiciones_generales = Default_Model_DocumentoCondicionGeneral::getTexto('ORDEN_COMPRA');
                $this->view->orden = $orden->getRow();
                $this->view->items = $orden->getItems();
                $this->renderScript('orden-compra/detalle.phtml');
                
            } catch (Exception $e) {
                echo $e->getMessage();
            }
        }
    }
    
    public function viewAuthAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();

            $id = (int)$this->_getParam('id');

            try {
                
                $orden = new Default_Model_OrdenCompra();
                $orden->setId($id);
                $this->view->orden = $orden->getRow();
                $this->view->items = $orden->getItems();
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }

    public function listByProveedorAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();

            $rut = App_Rut::cleanToDb($this->_getParam('id'));

            try {
                
                $orden = new Default_Model_OrdenCompra();
                $this->view->ordenes = $orden->getRowsByProveedor($rut);
                $this->renderScript('orden-compra/list-by-proveedor.phtml');
                
            } catch(Exception $e) {
                echo $e->getMessage();
            }
        }
    }

    public function printAction()
    {
        $this->_helper->layout->setLayout('print');

        $id = (int)$this->_getParam('id');
        
        $orden = new Default_Model_OrdenCompra();
        $orden->setId($id);
        
        if($orden->getEstado()=='EMITIDA') {

            $this->view->title = "Orden de compra Nº $id";
            $this->view->orden = $orden->getRow();
            $this->view->items = $orden->getItems();
            $this->view->condiciones_generales = Default_Model_CondicionGeneral::getTexto('ORDEN_COMPRA');
        }
    }

    public function mailAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->_getParam('mode_view')=='f') {
            $modeView = 'f';
        } else {
            $modeView = '0';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_SendAttach(null, $this->path . '/mail/0/0/0/0/' . $modeView);
        $form->copia->setLabel('Enviar una copia a mi casilla ('.  $this->usuario->mail .')');

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $mail = new App_HtmlMailerDocument('UTF-8');
                    $mail->setFrom($this->usuario->mail, $this->usuario->empleado);
                    $mail->setType(Zend_Mime::MULTIPART_RELATED);
                    $mail->setSubject($form->getValue('asunto'))
                         ->setViewParam('nombre', $form->getValue('nombre'))
                         ->setViewParam('usuario', $this->usuario->empleado)
                         ->setViewParam('mensaje', $form->getValue('texto_mensaje'));

                    $mail->addTo($form->getValue('mail'), $form->getValue('nombre'));

                    if($form->copia->getValue()==1){
                        $mail->addBcc($this->usuario->mail);
                    }

                    if($modeView=='f'){
                        $path = '/orden-compra/create-pdf/' . $form->getValue('id') . '/0/0/0/f';
                    } else {
                        $path = '/orden-compra/create-pdf/' . $form->getValue('id') . '/0/0/0/0';
                    }

                    $pdf = new App_Pdf($path);
                    
                    $attach = $mail->createAttachment($pdf->getContent());
                    $attach->filename = $form->getValue('archivo');
                    
                    $mail->sendHtmlTemplate('send-attach.phtml');

                    $envio = new Default_Model_DocumentoEnvio();
                    $envio->log(
                        array(
                            'creador' => $this->usuario->id,
                            'tipo' => 'orden-compra',
                            'documento_id' => $form->getValue('id'),
                            'nombre' => $form->getValue('nombre'),
                            'mail' => $form->getValue('mail')
                        )
                    );

                    $mSession->mensajes[] = 'El mensaje fue enviado de forma satisfactoria.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/orden-compra/view/' . $form->getValue('id'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar enviar el mensaje, por favor inténtelo más tarde.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/error/error-sending-attach');
                }
            } else {
                $form->populate($request->getPost());
            }
        }    
        
        if($this->_getParam('id')){

            $documento = 'orden-compra';
            $id = (int)$this->_getParam('id');
            $name = $documento . '-' . $id .'.pdf';
            $formValues = array(
                'archivo'       => $name,
                'id'            => $id,
                'documento'     => $documento,
                'asunto'        => 'ExpressAuto S.p.A. - Orden de compra Nº ' . $id,
                'texto_mensaje' => 'Adjunto orden de compra'
            );
            $form->populate($formValues);
        }
        
        $this->view->title = "Enviar documento adjunto por mail";
        $this->view->form = $form;
        $this->renderScript('archivos-comunes/form.phtml');
    }
    
    public function pdfAction()
    {
        $documento = 'orden-compra';

        $id = (int)$this->_getParam('id');

        if($this->_getParam('mode_view')=='f') {
            $path = '/orden-compra/create-pdf/'. $id . '/0/0/0/f';
        } else {
            $path = '/orden-compra/create-pdf/'. $id . '/0/0/0/0';
        }

        $name = $documento . '-' . $id .'.pdf';
        $pdf = new App_Pdf($path);
        $pdf->setName($name);
        $pdf->download();
    }

    public function createPdfAction()
    {
        $this->_helper->layout->setLayout('pdf');
        $id = (int)$this->_getParam('id');
        
        $orden = new Default_Model_OrdenCompra();
        
        try {
            
            $orden->setId($id);
            
            if($orden->getEstado()=='EMITIDA') {
                $this->view->title = "Orden de compra Nº $id";
                $this->view->orden = $orden->getRow();
                $this->view->items = $orden->getItems();
                $this->view->condiciones_generales = Default_Model_CondicionGeneral::getTexto('ORDEN_COMPRA');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar crear el PDF.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/orden-compra/index/1/id/DESC');
            
        }
    }

    /************************ FUNCIONES PARA ÍTEMS ****************************/
    public function agregarItemAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_ItemOrdenCompra();
        $id = (int)$this->_getParam('id');
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    $item = new Default_Model_ItemOrdenCompra();
                    $item->crear($form->getValues());
                    $mSession->mensajes[] = "El ítem fue agregado de forma satisfactoria. "
                                          . "¿Desea agregar otro o prefiere <a href=\"/orden-compra/view/" 
                                          . $id ."\">Volver a la orden de compra</a>?";
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/orden-compra/agregar-item/' . $id);
                } catch(Exception $e){
                    $mSession->mensajes[] = "Ocurrió un error al intentar agregar el ítem a la orden de compra";
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/orden-compra/agregar-item/' . $id);
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
            
        try {
            $orden = new Default_Model_OrdenCompra();
            $orden->setId($id);
            $form->orden_id->setValue($id);
            $form->setAction('/orden-compra/agregar-item/' . $id);
            $form->cancel->setAttrib('onclick', "javascript:goTo('/orden-compra/view/$id');");
            $this->view->form = $form;
            $row = $orden->getRow();
            $this->view->orden = $row;
            $this->view->title = "Agregar ítem a la Orden de Compra Nº " . $id ; 
            $this->renderScript('orden-compra/form-item.phtml');
            
        } catch(Exception $e) {
            $mSession->mensajes[] = "Ocurrió un error al requerir la información de la orden de compra";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/orden-compra/view/' . $id);
        }
    }
    
    public function editarItemAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_ItemOrdenCompra();
        $id = (int)$this->_getParam('id');
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $item = new Default_Model_ItemOrdenCompra();
                    $item->editar($form->getValues());
                    $mSession->mensajes[] = "El ítem fue editado de forma satisfactoria. ";
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/orden-compra/view/' . $form->getValue('orden_id'));
                    
                } catch(Exception $e){
                    $mSession->mensajes[] = "Ocurrió un error al intentar editar el ítem";
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/orden-compra/view/' . $form->getValue('orden_id'));
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
            
        try {
            
            $item = new Default_Model_ItemOrdenCompra();
            $item->setId($id);
            $rowItem = $item->getRow();
            $rowOrden = $item->getOrdenCompra($rowItem['orden_id']);
            $form->populate($rowItem);
            
            $form->setAction('/orden-compra/editar-item/' . $id);
            $form->submit->setLabel('Guardar cambios');
            $form->cancel->setAttrib('onclick', "javascript:goTo('/orden-compra/view/$rowOrden->id');");
            $this->view->form = $form;
            $this->view->orden = $rowOrden;
            $this->view->title = "Editarr ítem de la Orden de Compra Nº " . $id ; 
            $this->renderScript('orden-compra/form-item.phtml');
            
        } catch(Exception $e) {
            $mSession->mensajes[] = "Ocurrió un error al requerir el item a editar";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/orden-compra/index/1/id/DESC');
        }
    }
    
    public function eliminarItemsAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();

            try {
                
                $data = $this->_getParam('data');
                $item = new Default_Model_ItemOrdenCompra();
                $item->eliminar($data);
                return true;
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    /********************** FIN FUNCIONES PARA ÍTEMS ***************************/
}