<?php
class OrdenServicioController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $action = $this->getRequest()->getActionName();
        if($action != 'export-pdf' AND $action != 'create-pdf'){
            $auth = Zend_Auth::getInstance();
            if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
                $this->_redirect('/sistema-acceso/logout');
            }
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Órdenes de servicio';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();

        $this->view->propietario = Default_Model_SistemaPropietario::get();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $orden = new Default_Model_OrdenServicio();
        $ordenes = $orden->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $orden->getOrderByOptions();
        $this->view->orderBy = $orden->getOrderBy();
        $this->view->orderType = $orden->getOrderType();
        $this->view->action = '/orden-servicio/index/';
        $this->view->ordenes = $ordenes;
        $this->view->title = 'Órdenes de servicio';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_OrdenServicio();
        $vehiculosDisponibles = Default_Model_OrdenServicio::getVehiculosDisponibles();
        
        if(count($vehiculosDisponibles) > 0 ){ 
            $form->vehiculo_id->addMultiOptions($vehiculosDisponibles);
        } else {
            $mSession->mensajes[] = "No hay ítems disponibles para crear órdenes de servicios";
            $mSession->claseMensaje = "error";
            $this->_redirect('/orden-servicio/index/1/id/DESC');
        }

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $orden = new Default_Model_OrdenServicio();
                    $id = $orden->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/orden-servicio/view/' . $id);
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/orden-servicio/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }

        $this->view->title = 'Crear orden de servicio';
        $this->view->form = $form;
        $this->renderScript('orden-servicio/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $orden = new Default_Model_OrdenServicio();
        $request = $this->getRequest();
        $form = new Default_Form_OrdenServicio();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $id = (int)$form->getValue('id');
                    $orden->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'La orden de servicio fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/orden-servicio/view/' . $id);
                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la orden de servicio.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/orden-servicio/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $orden->setId($id);
        $form->submit->setLabel('Guardar cambios');
        $form->id->setValue($id);
        $form->setAction('/orden-servicio/edit');
        $form->populate($orden->getRow()->toArray());
        $this->view->title = 'Editar orden de servicio';
        $this->view->form = $form;
        $this->renderScript('orden-servicio/form.phtml');
    }
    
    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaOrdenesServicio();
        
        $this->view->form = $form;
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        
        try {
            
            $orden = new Default_Model_OrdenServicio();
            $orden->setId($id);
            $this->view->title = "Orden de servicio Nº $id";
            $this->view->orden = $orden->getRowFull();
            $this->view->items = $orden->getItems();
            
            if($orden->getEstado()=='BORRADOR') {
                $this->renderScript('orden-servicio/view-borrador.phtml');
            } elseif($orden->getEstado()=='EN PROCESO') {
                $this->renderScript('orden-servicio/view-en-proceso.phtml');
            } else {
                $this->renderScript('orden-servicio/view.phtml');
            }
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar visualizar el registro.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/orden-servicio/index/1/id/DESC');
        }
    }

    public function emitirAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        $orden = new Default_Model_OrdenServicio();
        $orden->setId($id);
        
        
        if($orden->getEstado()=='BORRADOR' AND count($orden->getItems() > 0)) {
            $orden->setEstado('EN PROCESO');
            $mSession->mensajes[] = 'La nota de venta ha sido emitida de forma satisfatoria.';
            $mSession->claseMensaje = 'confirmacion';
        }
        $this->_redirect('/orden-servicio/view/' . $id);
    }
    
    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            
            $orden = new Default_Model_OrdenServicio();
            $orden->setId($id);
            $orden->eliminar();
            
            $mSession->mensajes[] = 'La orden de servicio fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/orden-servicio/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la orden de servicio.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/orden-servicio/index/1/id/DESC');
        }
    }
    
    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
           
            $this->_helper->layout->disableLayout();
            $id = (int)$this->_getParam('id');
            
            try {
                
                $orden = new Default_Model_OrdenServicio();
                $orden->setId($id);
                $this->view->title = "Orden de servicio Nº $id";
                $this->view->orden = $orden->getRowFull();
                $this->view->items = $orden->getItems();
                
            } catch(Exception $e){
                
                echo $e->getMessage();
                
            }
        }
    }
    
    public function detalleProcesoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
           
            $this->_helper->layout->disableLayout();
            $id = (int)$this->_getParam('id');
            
            try {
                $orden = new Default_Model_OrdenServicio();
                $orden->setId($id);
                $this->view->title = "Orden de servicio Nº $id";
                $this->view->orden = $orden->getRowFull();
                $this->view->recomendaciones = $orden->getRecomendaciones();
                $this->view->items = $orden->getItems();
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }

    public function itemDisponiblesAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
	    
            $this->_helper->layout->disableLayout();
            $id = (int)$this->_getParam('id');

            try {
                $orden = new Default_Model_OrdenServicio();
                $orden->setId($id);
                $this->view->items = $orden->getItemsDisponibles();
                $this->view->orden_id = $id;
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function addItemsNotaAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $orden_id = $this->_getParam('id');
            $data = $this->_getParam('data');
            try {
                
                $itemOrdenServicio = new Default_Model_OrdenServicioItem();
                $itemOrdenServicio->addFromNota($data, $orden_id);
                $this->view->estado = 1;
                $this->renderScript('partes-comunes/mensaje-add-items.phtml');
                
            } catch (Exception $e) {
                $this->view->estado = 2;
                $this->view->error = $e->getMessage();
                $this->renderScript('partes-comunes/mensaje-add-items.phtml');
            }
        }
    }
    
    public function deleteItemsAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $data = $this->_getParam('data');

            try {
                
                $item = new Default_Model_OrdenServicioItem();
                $item->eliminar($data);
                return true;
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function editarInformeAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();

        try {
            $id = (int)$this->_getParam('id');
            $informe = $this->_getParam('data');
            $orden = new Default_Model_OrdenServicio();
            $orden->editarInforme($informe, $id);
            echo nl2br($informe);

        } catch (Exception $e) {
            $data['error'] = true;
            $data['mensaje'] = "Ocurrió un error al intentar guardar el informe: " . $e->getMessage();
            echo Zend_Json::encode($data);
        }
    }
    
    public function editarRecomendacionesAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();

        try {
            $id = (int)$this->_getParam('id');
            $recomendaciones = $this->_getParam('data');
            $orden = new Default_Model_OrdenServicio();
            $orden->editarRecomendaciones($recomendaciones, $id);
            echo nl2br($recomendaciones);

        } catch (Exception $e) {
            $data['error'] = true;
            $data['mensaje'] = "Ocurrió un error al intentar guardar las recomendaciones: " . $e->getMessage();
            echo Zend_Json::encode($data);
        }
    }
    
    public function terminarServicioAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $id = (int)$this->_getParam('id');
            
            try {
                $item = new Default_Model_ItemNotaVenta();
                $item->setId($id);
                $item->terminar();
                return true;
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $this->_helper->layout->disableLayout();
            
            $orden = new Default_Model_VistaOrdenesServicios();
            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));

            if($criterio!='' AND $valor!='') {
                if($criterio=='numero') {
                    $where = "id='$valor'";
                } else {
                    $where = "modelo LIKE '%$valor%' OR marca LIKE '%$valor%' OR vehiculo='$valor'";
                }
                $this->view->ordenes = $orden->fetchAll($where)->toArray();
            }
        }
    }

    public function terminarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $id = (int)$this->_getParam('id');
        try {

            $orden = new Default_Model_OrdenServicio();
            $orden->setId($id);
            $orden->cerrar(array(
                'cierre_prueba_ruta' => (int)$this->_getParam('cierre_prueba_ruta', NULL),
                'cierre_control_calidad' => (int)$this->_getParam('cierre_control_calidad', NULL),
                'fecha_entrega' => (int)$this->_getParam('fecha_entrega', NULL)
            ));
            $mSession->mensajes[] = 'La orden fue cerrada de forma satisfactoria';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/orden-servicio/view/' . $id);

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar crear la solicitud de servicio.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/orden-servicio/view/' . $id);

        }
    }

    public function listByVehiculoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $this->_helper->layout->disableLayout();
            $patente = strtoupper($this->_getParam('id'));
            try {
                $orden = new Default_Model_OrdenServicio();
                $this->view->ordenes = $orden->getRowsByVehiculo($patente);
            } catch (Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function printAction()
    {
        $this->_helper->layout->setLayout('print');
        $id = (int)$this->_getParam('id');
        try {
            
            $orden = new Default_Model_OrdenServicio();
            $orden->setId($id);
            if($orden->getEstado()!='BORRADOR') {
                $this->view->title = "Orden de servicio Nº $id";
                $this->view->orden = $orden->getRow();
            }
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'No se pudo visualizar la orden para su impresión.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/orden-servicio/index/1/id/DESC');
        }
    }
}