<?php

class PagoRecibidoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $action = $this->getRequest()->getActionName();
        if($action != 'export-pdf' AND $action != 'create-pdf'){
            $auth = Zend_Auth::getInstance();
            if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
                $this->_redirect('/sistema-acceso/logout');
            }
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Pagos recibidos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $pago = new Default_Model_PagoRecibido();
        $pagos = $pago->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $pago->getOrderByOptions();
        $this->view->orderBy = $pago->getOrderBy();
        $this->view->orderType = $pago->getOrderType();
        $this->view->action = '/pago-recibido/index/';
        $this->view->pagos = $pagos;
        $this->view->title = 'Pagos recibidos';
    }
    
    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaPagosRecibidos();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_PagoRecibido();
        $this->view->title = 'Ingresar pago recibido';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $pago = new Default_Model_PagoRecibido();
                    $id = $pago->crear($form->getValues(), $this->usuario->id);
                    
                    
                    $mSession->mensajes[] = 'El pago fue ingresado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_redirect('/pago-recibido/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar ingresar el pago recibido.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/pago-recibido/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->renderScript('pago-recibido/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $pago = new Default_Model_PagoRecibido();
        
        $request = $this->getRequest();
        $form = new Default_Form_PagoRecibido();
        $form->id->setRequired(true);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $id = (int)$form->getValue('id');
                    $pago->editar($form->getValues(), $id);
                    
                    $mSession->mensajes[] = 'El pago recibido fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/pago-recibido/view/' . $id);


                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el pago recibido.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_redirect('/pago-recibido/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $id = (int)$this->_getParam('id');
        
        $pago->setId($id);
        
        $form->populate($pago->getRow()->toArray());
        $form->setAction('/pago-recibido/edit');
        $form->submit->setLabel('Guardar cambios');
        $this->view->title = "Editar pago recibido";
        $this->view->form = $form;
        $this->renderScript('pago-recibido/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            
            $pago = new Default_Model_PagoRecibido();
            $pago->setId($id);
            $pago->eliminar();
            
            $mSession->mensajes[] = 'El pago fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/pago-recibido/index/1/id/DESC');
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el pago.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/pago-recibido/index/1/id/DESC');
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $pago = new Default_Model_PagoRecibido();
            $pago->setId($id);

            $this->view->title = "Pago recibido";
            $this->view->pago = $pago->getRowFull();

            if($pago->getEstado()=='BORRADOR') {
                $this->renderScript('pago-recibido/view-borrador.phtml');
            } else {

                if($pago->getInfoExtra()=='CODIGO'){
                    $this->view->codigoTransaccion = $pago->getCodigoTransaccion();
                } elseif($pago->getInfoExtra()=='DOCUMENTO'){
                    $this->view->documentoBancario = $pago->getDocumentoBancario();
                }

                $this->view->dteBoletasAsociadas = $pago->getDteBoletasAsociadas();
                $this->view->dteFacturasAsociadas = $pago->getDteFacturasAsociadas();
                $this->view->totalAsignado = $pago->getTotalAsignado();

                $this->renderScript('pago-recibido/view.phtml');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar el pago recibido";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/pago-recibido/index/1/id/DESC');
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();

            $id = (int)$this->_getParam('id');

            try {
                
                $pago = new Default_Model_PagoRecibido();
                $pago->setId($id);

                $this->view->title = "Pago recibido";
                $this->view->pago = $pago->getRowFull();

                if($pago->getInfoExtra()=='CODIGO'){
                    $this->view->codigoTransaccion = $pago->getCodigoTransaccion();
                } elseif($pago->getInfoExtra()=='DOCUMENTO'){
                    $this->view->documentoBancario = $pago->getDocumentoBancario();
                }

                $this->view->dteBoletasAsociadas = $pago->getDteBoletasAsociadas();
                $this->view->dteFacturasAsociadas = $pago->getDteFacturasAsociadas();
                $this->view->totalAsignado = $pago->getTotalAsignado();
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $pago = new Default_Model_PagoRecibido();
            $pago->setId($id);
            
            if($pago->getEstado()=='BORRADOR'){
                $pago->setEstado('RECIBIDO');
            } else {
                $mSession->mensajes[] = 'Operación incorrecta';
                $mSession->claseMensaje = 'error';
            }
            $this->_redirect('/pago-recibido/view/' . $id);
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar terminar el pago';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/pago-recibido/view/' . $id);
        }
    }

    public function printAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('pagos_recibidos','id', $this->_getParam('id'))){

            $this->_helper->layout->disableLayout(false);
            $this->_helper->viewRenderer->setNoRender(false);
            $this->_helper->layout->setLayout('print');

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $pago = new Default_Model_VistaPagosRecibidos();
            $where = $pago->getAdapter()->quoteInto("id=?", $id);
            $row = $pago->fetchRow($where)->toArray();

            if($row['estado']=='TERMINADO') {

                if($row['detallar']!='NO'){
                    if($row['detallar']=='DOCUMENTO') {
                        $this->view->documentoBancario = Default_Model_VistaPagosRecibidos::getDocumentoBancario($id);
                    } elseif($row['detallar']=='CODIGO') {
                        $this->view->codigoTransaccion = Default_Model_VistaPagosRecibidos::getCodigoTransaccion($id);
                    }
                }

                $this->view->title = "Recepción de pago Nº $id";
                $this->view->pago = $row;
                $this->view->condiciones_generales = Default_Model_CondicionGeneral::getTexto('PAGO_RECIBIDO');
            }
        }
    }

    
    /* 
     * Operaciones relacionadas a los documentos tributarios 
     */
    
    public function formDocumentoTributarioAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $id = (int)$this->_getParam('id');
            
            $pago = new Default_Model_PagoRecibido();
            $pago->setId($id);
            $saldo = $pago->getRow()->monto - $pago->getTotalAsignado();
            
            $form = new Default_Form_PagoRecibidoDocumentoTributario();
            $form->pago_id->setValue($id);
            $form->monto->setAttrib('class', 'help');
            $form->monto->setAttrib('title', 'El máximo a a asignar es de ' . $this->view->formatNumber($saldo));
            
            $this->view->title = "Formulario asociación documento tributario";
            $this->view->form = $form;
            $this->renderScript('partes-comunes/form-items.phtml');
        }
    }
    
    public function asociarDocumentoTributarioAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
            
        $request = $this->getRequest();
        $form = new Default_Form_PagoRecibidoDocumentoTributario();
        
        $this->view->title = "Formulario asociación documento tributario";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $id = (int)$form->getValue('pago_id');
                    $documento_tipo = $form->getValue('documento_tipo');
                    
                    $pago= new Default_Model_PagoRecibido();
                    $pago->setId($id);
                    
                    $saldoPago = $pago->getRow()->monto - $pago->getTotalAsignado();
                    
                    if($documento_tipo=='BOLETA'){
                        $saldoDocumento = Default_Model_PagoRecibidoDteBoleta::getTotalAsignado($form->getValue('documento_id'));
                    } elseif($documento_tipo=='FACTURA') {
                        $saldoDocumento = Default_Model_PagoRecibidoDteFactura::getTotalAsignado($form->getValue('documento_id'));
                    } 
                    
                    if($form->getValue('monto') <= $saldoPago){
                        if($form->getValue('monto') <= $saldoDocumento){
                            
                            $pago->asociarDocumentoTributario($form->getValues(), $this->usuario->rut);
                            $this->view->estado = 1;
                            $this->renderScript('partes-comunes/mensaje-add-items.phtml');
                        } else {
                            
                            $error = 'El monto máximo asignable a la ' 
                                   . $documento_tipo . ' Nº ' . $form->getValue('documento_id') 
                                   . ' es de: ' . $this->view->formatNumber($saldoDocumento);
                            
                            $form->populate($request->getPost());
                            $form->monto->setErrors(array($error));
                            $this->view->form = $form;
                            $this->renderScript('partes-comunes/form-items.phtml');
                        
                        }
                    } else {
                        
                        $form->populate($request->getPost());
                        
                        $form->monto->setErrors(array(
                            'El monto ingresado es superior al máximo asignable de: ' . $this->view->formatNumber($saldoPago)
                        ));
                        
                        $this->view->form = $form;
                        $this->renderScript('partes-comunes/form-items.phtml');
                        
                    }

                } catch (Exception $e) {
                    echo $e->getMessage();
                }

            } else {
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('partes-comunes/form-items.phtml');
            }
        }
    }
    
    public function deleteAsociacionDteBoletaAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            
            $asociacion = new Default_Model_PagoRecibidoDteBoleta();
            $pago_id = $asociacion->eliminar($id);
            
            $mSession->mensajes[] = 'El pago fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/pago-recibido/view/' . $pago_id);
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el pago.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/pago-recibido/index/1/id/DESC');
        }
    }
    
    public function deleteAsociacionDteFacturaAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            
            $asociacion = new Default_Model_PagoRecibidoDteFactura();
            $pago_id = $asociacion->eliminar($id);
            
            $mSession->mensajes[] = 'El pago fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/pago-recibido/view/' . $pago_id);
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el pago.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/pago-recibido/index/1/id/DESC');
        }
    }

    
    /* 
     * Operaciones relacionadas a los códigos de transacciones 
     */
    
    public function formCodigoTransaccionAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $form = new Default_Form_PagoRecibidoCodigoTransaccion();
            $form->pago_id->setValue((int)$this->_getParam('id'));
            $this->view->title = "Formulario código transacción";
            $this->view->form = $form;
            $this->renderScript('partes-comunes/form-items.phtml');
        }
    }
    
    public function newCodigoTransaccionAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        $request = $this->getRequest();
        $form = new Default_Form_PagoRecibidoCodigoTransaccion();
        
        $this->view->title = "Formulario código transacción";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $pago= new Default_Model_PagoRecibidoCodigoTransaccion();
                    $pago->crear($form->getValues(), $this->usuario->id);
                    $this->view->estado = 1;
                    $this->renderScript('partes-comunes/form-items.phtml');

                } catch (Exception $e) {
                    echo $e->getMessage();
                }

            } else {
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('partes-comunes/form-items.phtml');
            }
        }
    }

    
    /* 
     * Operaciones relacionadas a los documentos bancarios 
     */
    
    public function formDocumentoBancarioAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $form = new Default_Form_PagoRecibidoDocumentoBancario();
            $form->pago_id->setValue((int)$this->_getParam('id'));
            $this->view->title = "Formulario documento bancario";
            $this->view->form = $form;
            $this->renderScript('partes-comunes/form-items.phtml');
        }
    }
    
    public function newDocumentoBancarioAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        $request = $this->getRequest();
        $form = new Default_Form_PagoRecibidoDocumentoBancario();
        $this->view->title = "Formulario documento bancario";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $documento = new Default_Model_PagoRecibidoDocumentoBancario();
                    $documento->crear($form->getValues(), $this->usuario->id);
                    $this->view->estado = 1;
                    $this->renderScript('partes-comunes/form-items.phtml');

                } catch (Exception $e) {
                    echo $e->getMessage();
                }

            } else {
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('partes-comunes/form-items.phtml');
            }
        }
    }

    public function deleteDocumentoBancarioAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $documento = new Default_Model_PagoRecibidoDocumentoBancario();
            $documento->setId($id);
            $documento->eliminar();
            
            $mSession->mensajes[] = 'La información del documento fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/pago-recibido/view/' . $id);
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar la información del documento bancario';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/pago-recibido/view/' . $id);
        }
    }
    
    public function cobrarDocumentoBancarioAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            $documento = new Default_Model_PagoRecibidoDocumentoBancario();
            $documento->setId($id);
            
            if($documento->getEstado()=='PENDIENTE'){
                $documento->setEstado('COBRADO');
            } else {
                $mSession->mensajes[] = 'Operación incorrecta';
                $mSession->claseMensaje = 'error';
            }
            $this->_redirect('/pago-recibido/view/' . $id);
            
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al marcar como cobrado el documento';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/pago-recibido/view/' . $id);
        }
    }
}