<?php
class PautaMantenimientoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Pautas de mantenimiento';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }

    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $pauta = new Default_Model_PautaMantenimiento();
        $pautas = $pauta->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $pauta->getOrderByOptions();
        $this->view->orderBy = $pauta->getOrderBy();
        $this->view->orderType = $pauta->getOrderType();
        $this->view->action = '/pauta-mantenimiento/index/';
        $this->view->pautas = $pautas;
        $this->view->title = 'Pautas de mantenimiento';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaPautasMantenimiento();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_PautaMantenimiento();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $pauta = new Default_Model_PautaMantenimiento();
                    $id = $pauta->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/pauta-mantenimiento/view/' . $id);
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/pauta-mantenimiento/index/1/id/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Crear pauta de mantenimiento";
        $this->view->form = $form;
        $this->renderScript('pauta-mantenimiento/form.phtml');
    }
    
    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $pauta = new Default_Model_PautaMantenimiento();
        $request = $this->getRequest();
        $form = new Default_Form_PautaMantenimiento();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $id = (int)$form->getValue('id');
                    $pauta->editar($form->getValues(), $id);

                    $mSession->mensajes[] = 'La pauta fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/pauta-mantenimiento/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la pauta.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/pauta-mantenimiento/index/1/id/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Editar pauta de mantenimiento";
        $id = (int)$this->_getParam('id');
        $pauta->setId($id);
        $form->populate($pauta->getRow()->toArray());
        $form->setAction('/pauta-mantenimiento/edit');
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->renderScript('pauta-mantenimiento/form.phtml');
    }
    
    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            $pauta = new Default_Model_PautaMantenimiento();
            $pauta->setId($id);
            $this->view->title = 'Pauta de mantenimiento';
            $this->view->pauta = $pauta->getRowFull();
            $this->view->items = $pauta->getItems();
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar visualizar la pauta de mantenimiento';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/pauta-mantenimiento/index/1/id/ASC');
        }
    }
    
    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $pauta = new Default_Model_PautaMantenimiento();
            $pauta->setId($id);
            $pauta->eliminar();
            $mSession->mensajes[] = 'La pauta de mantención fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/pauta-mantenimiento/index/1/id/ASC');
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar eliminar la pauta";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/pauta-mantenimiento/index/1/id/ASC');
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();

            $id = (int)$this->_getParam('id');

            try {
                
                $pauta = new Default_Model_PautaMantenimiento();
                $pauta->setId($id);
                $this->view->pauta = $pauta->getRow();
                $this->view->items = $pauta->getItems();
                $this->renderScript('pauta-mantenimiento/detalle.phtml');
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }

    public function formItemAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $form = new Default_Form_ItemPautaMantenimiento();
            
            if($this->_getParam('id')) {
                
                $id = (int)$this->_getParam('id');
                
                $item = new Default_Model_ItemPautaMantenimiento();
                $item->setId($id);
                $form->populate($item->getRow()->toArray());
                $form->setAction('/pauta-mantenimiento/edit-item');

            } elseif($this->_request->getParam('from_id')) {
                $form->pauta_id->setValue($this->_getParam('from_id'));
            }
            
            $this->view->form = $form;
            $this->renderScript('pauta-mantenimiento/form-item.phtml');
        }
    }
    
    public function newItemAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        $request = $this->getRequest();
        $form = new Default_Form_ItemPautaMantenimiento();
        
        $this->view->title = "Formulario ítem pauta mantenimiento";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $item = new Default_Model_ItemPautaMantenimiento();
                    $item->crear($form->getValues());
                    $this->view->estado = 1;
                    $this->renderScript('partes-comunes/form-items.phtml');

                } catch (Exception $e) {
                    echo $e->getMessage();
                }

            } else {
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('partes-comunes/form-items.phtml');
            }
        }
    }

    public function editItemAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        $request = $this->getRequest();
        $form = new Default_Form_ItemPautaMantenimiento();
        
        $this->view->title = "Formulario ítem pauta mantenimiento";
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    $id = $form->getValue('id');
                    $item = new Default_Model_ItemPautaMantenimiento();
                    $item->editar($form->getValues(), $id);
                    $this->view->estado = 1;
                    $this->renderScript('partes-comunes/mensaje-add-items.phtml');

                } catch (Exception $e) {
                    echo $e->getMessage();
                }
            } else {
                $form->setAction('/pauta-mantenimiento/edit-item');
                $form->submit->setLabel('Guardar');
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('partes-comunes/form-items.phtml');
            }
        }
    }

    public function deleteItemsAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->viewRenderer->setNoRender();
            $this->_helper->viewRenderer->setNoRender();
            
            $data = $this->_getParam('data');
            try {
                $item = new Default_Model_ItemPautaMantenimiento();
                $item->eliminar($data);
                return true;
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function getFormLotesAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_PautasMantenciones(null, $this->path);
            $this->view->title = "Agregar pautas de mantenciones por lotes";
            $this->view->form = $form;
            $this->renderScript('pauta-mantencion/form-lotes.phtml');
        }
    }
    
    public function modalListAllAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('patente') AND
           $this->_helper->validateRecordExists('vehiculos', 'patente', $this->_getParam('patente'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $patente = $this->_getParam('patente');

            $pauta = new Default_Model_VistaPautasMantenciones();
            $pautas = $pauta->fetchAll();

            $this->view->patente = $patente;
            $this->view->pautas = $pautas;
            $this->renderScript('pauta-mantencion/modal-list-all.phtml');
        }
    }

    public function modalListAllToModelAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('modelo_id') AND
           $this->_helper->validateRecordExists('modelos_vehiculos', 'id', $this->_getParam('modelo_id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $modelo_id = $this->_getParam('modelo_id');

            $pauta = new Default_Model_VistaPautasMantenciones();
            $pautas = $pauta->fetchAll();

            $this->view->modelo_id = $modelo_id;
            $this->view->pautas = $pautas;
            $this->renderScript('pauta-mantencion/modal-list-all-to-model.phtml');
        }
    }
}