<?php
class PautaModeloController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function indexAction()
    {
        $this->_redirect('/modelos-vehiculos/list');
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $this->view->titulo_pagina = "Modelos de vehículos > Agregar detalles";

        $form = new PautaModeloForm(null, $this->path);

        if ($this->_request->isPost()) {
            $formData = $this->_request->getPost();
            if ($form->isValid($formData)) {

                try {
                    
                    $pauta_modelo = new PautaModelo();
                    $row = $pauta_modelo->createRow();
                    $row->modelo_id = $form->getValue('modelo_id');
                    $row->pauta_id = $form->getValue('pauta_id');
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    
                }
                
                $this->_redirect('/modelo-vehiculo/view/id/'.$row->modelo_id);
                
            } else {
                $form->populate($formData);
            }
        }

        if($this->_request->getParam('id', 0)) {
            
            $id = (int)$this->_request->getParam('id', 0);
            $m = new ModeloVehiculo();
            $modelo = $m->fetchRow('id='.$id);
            if($modelo==false){
                $this->_redirect('/modelo-vehiculo/list');
            }
            $form->modelo_id->setValue($id);
            
        }
  
        $this->view->form = $form;
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $this->view->titulo_pagina = "Modelos de vehículos > Editar detalles";

        $form = new PautaModeloForm(null, $this->path);
        $form->setAction($this->view->baseUrl(). $this->path . '/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->_request->isPost()) {
            $formData = $this->_request->getPost();
            if ($form->isValid($formData)) {

                try {
                    
                    $pauta_modelo = new PautaModelo();
                    $id = (int)$form->getValue('id');
                    $row = $pauta_modelo->fetchRow('id='.$id);
                    $row->modelo_id = $form->getValue('modelo_id');
                    $row->pauta_id = $form->getValue('pauta_id');
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                }           
                $this->_redirect('/modelo-vehiculo/view/id/'.$row->modelo_id);

            } else {
                $form->populate($formData);
            }
        } else {
            
            $id = (int)$this->_request->getParam('id', 0);
            if ($id > 0) {
                $pauta_modelo = new PautaModelo();
                $registro = $pauta_modelo->fetchRow('id='.$id);
                $form->populate($registro->toArray());
            }
        }
        $this->view->form = $form;
    }


    public function modalListByModeloAction()
    {
        if($this->getRequest()->isXmlHttpRequest()) {

           if($this->_getParam('modelo_id') AND
              $this->_helper->validateRecordExists('modelos_vehiculos', 'id', $this->_getParam('modelo_id')) AND
              $this->_getParam('patente') AND 
              $this->_helper->validateRecordExists('vehiculos', 'patente', $this->_getParam('patente'))){

                $mSession = new Zend_Session_Namespace('expressauto');

                if($mSession->mensajes!='') {
                    $this->view->mensajes = $mSession->mensajes;
                    $this->view->claseMensaje = $mSession->claseMensaje;
                    $mSession->mensajes = '';
                    $mSession->claseMensaje = '';
                }

                $modelo_id = (int)$this->_getParam('modelo_id');
                $patente = $this->_getParam('patente');

                $pauta = new Default_Model_VistaPautasModelos();
                $where = $pauta->getAdapter()->quoteInto("modelo_id=?", $modelo_id);
                $pautas = $pauta->fetchAll($where);

                $this->view->patente = $patente;
                $this->view->pautas = $pautas;
                $this->renderScript('pauta-modelo/modal-list-by-modelo.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('pautas_modelos', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = $this->_getParam('id');

            try {

                $pautaModelo = new Default_Model_PautaModelo();
                $where = $pautaModelo->getAdapter()->quoteInto("id=?", $id);

                $row = $pautaModelo->fetchRow($where)->toArray();

                $pautaModelo->delete($where);

                $this->_forward('view', 'modelo-vehiculo', null, array('id' => $row['modelo_id']));

            } catch (Exception $e) {

                $this->_forward('index', 'modelo-vehiculo');

            }
        }
    }
}