<?php
class PresupuestoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Presupuestos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->propietario = Default_Model_SistemaPropietario::get();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
        
        if($this->_getParam('tab')){
            $this->view->tab = $this->_getParam('tab');
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $presupuesto = new Default_Model_Presupuesto();
        $presupuestos = $presupuesto->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $presupuesto->getOrderByOptions();
        $this->view->orderBy = $presupuesto->getOrderBy();
        $this->view->orderType = $presupuesto->getOrderType();
        $this->view->action = '/presupuesto/index/';
        $this->view->presupuestos = $presupuestos;
        $this->view->title = 'Presupuestos';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_Presupuesto();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    
                    $presupuesto = new Default_Model_Presupuesto();
                    $id = $presupuesto->crear($form->getValues(), $this->usuario->id);
                    $this->_redirect('/presupuesto/view/' . $id);
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el presupuesto.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/presupuesto/index/1/id/DESC');
                }
                
            } else {
                $form->populate($request->getPost());
            }
        }
        if($this->_getParam('from_id')){
            $form->vehiculo->setValue($this->_getParam('from_id'));
        }
        $this->view->title = 'Crear presupuesto';
        $this->view->form = $form;
        $this->renderScript('presupuesto/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $presupuesto = new Default_Model_Presupuesto();
        $request = $this->getRequest();
        $form = new Default_Form_Presupuesto();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $id = (int)$form->getValue('id');
                    $presupuesto->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'El presupuesto fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/presupuesto/view/' . $id);
                    
                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el presupuesto.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/presupuesto/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
            
        $id = (int)$this->_getParam('id');
        $presupuesto->setId($id);
        $form->submit->setLabel('Guardar cambios');
        $form->id->setValue($id);
        $form->setAction('/presupuesto/edit');
        $form->populate($presupuesto->getRow()->toArray());
        $this->view->title = 'Editar encabezado presupuesto';
        $this->view->form = $form;
        $this->renderScript('presupuesto/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $presupuesto = new Default_Model_Presupuesto();
            $presupuesto->setId($id);
            $presupuesto->eliminar();
            
            $mSession->mensajes[] = 'El presupuesto fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/presupuesto/index/1/id/DESC');
            
        } catch (Exception $e) {
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el presupuesto.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/presupuesto/index/1/id/DESC');
            
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $presupuesto = new Default_Model_Presupuesto();
            $presupuesto->setId($id);
            
            $this->view->title = "Presupuesto Nº $id";
            $this->view->presupuesto = $presupuesto->getRow();
            $this->view->vehiculo = $presupuesto->getVehiculo();
            $this->view->repuestosExternos = $presupuesto->getRepuestosExternos();
            $this->view->repuestosInternos = array();
            $this->view->serviciosExternos = $presupuesto->getServiciosExternos();
            $this->view->serviciosInternos = $presupuesto->getServiciosInternos();
            $this->view->cobroInsumos = $presupuesto->getListInsumos();
            
            
        } catch(Exception $e) {
            
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/presupuesto/index/1/id/DESC');
            
        }
    }

    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();

            $id = (int)$this->_getParam('id');

            try {
            
                $presupuesto = new Default_Model_Presupuesto();
                $presupuesto->setId($id);
                $this->view->title = "Presupuesto Nº $id";
                $this->view->presupuesto = $presupuesto->getRow();
                $this->view->vehiculo = $presupuesto->getVehiculo();
                $this->view->repuestos = $presupuesto->getRepuestos();
                $this->view->serviciosTerceros = $presupuesto->getServiciosTerceros();
                $this->view->manosObras = $presupuesto->getManosObra();
                $this->view->cobroInsumos = $presupuesto->getListInsumos();
                
            } catch(Exception $e){
                echo $e->getMessage();    
            }
        }
    }

    public function listByVehiculoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $patente = strtoupper($this->_getParam('id'));
            
            try {
            
                $presupuesto = new Default_Model_Presupuesto();
                $this->view->presupuestos = $presupuesto->getRowsByVehiculo($patente);

            } catch (Exception $e) {

                echo $e->getMessage();

            }
        }
    }

    public function setValorInsumosAction()
    {   
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        try { 

            $presupuesto_id = (int)$this->_getParam('presupuesto_id');
            $modelPresupuesto = new Default_Model_Presupuesto();
            $wherePresupuesto = $modelPresupuesto->getAdapter()->quoteInto("id=?", $presupuesto_id);
            $rowPresupuesto = $modelPresupuesto->fetchRow($wherePresupuesto);
            $rowPresupuesto->insumos = (int)$this->_getParam('cobro_insumos');
            $rowPresupuesto->save();

            $mSession->mensajes[] = "El valor fue cambiado de forma satisfactoria";
            $mSession->claseMensaje = "confirmacion";

        } catch (Exception $e) {

            $mSession->mensajes[] = "Ocurrió un error al intentar cambiar el valor asignado a los insumos";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
        }
        $this->_redirect('/presupuesto/view/' . $presupuesto_id . '/insumos');
        
    }
    
    public function printHojaComprasAction()
    {
        $this->_helper->layout->setLayout('print');
        $id = (int)$this->_getParam('id');
        try {
            $presupuesto = new Default_Model_Presupuesto();
            $presupuesto->setId($id);
            $this->view->presupuesto = $presupuesto->getRow();
            $this->view->vehiculo = $presupuesto->getVehiculo();
            $this->view->repuestos = $presupuesto->getRepuestosExternos();
        } catch (Exception $e){
            echo $e->getMessage();
        }
    }
}
