<?php
class PresupuestoRepuestoExternoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Presupuestos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->view->propietario = Default_Model_SistemaPropietario::get();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function agregarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_PresupuestoRepuestoExterno();
        $id = (int)$this->_getParam('id');
        $this->view->title = "Agregar repuesto externo al presupuesto ";
        $this->view->titleBreadcrumb = "Formulario repuesto externo ";
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    $item = new Default_Model_PresupuestoRepuestoExterno();
                    $item->crear($form->getValues());
                    $mSession->mensajes[] = "El repuesto externo fue agregado de forma satisfactoria. "
                                          . "¿Desea agregar otro o prefiere <a href=\"/presupuesto/view/" 
                                          . $id ."/repuestos-externos\">Volver al presupuesto</a>?";
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/presupuesto-repuesto-externo/agregar/' . $id);
                } catch(Exception $e){
                    $mSession->mensajes[] = "Ocurrió un error al intentar agregar el repuesto externo al presupuesto";
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/presupuesto-repuesto-externo/agregar/' . $id);
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
            
        try {
            $presupuesto = new Default_Model_Presupuesto();
            $presupuesto->setId($id);
            $form->presupuesto_id->setValue($id);
            $form->setAction('/presupuesto-repuesto-externo/agregar/' . $id);
            $form->cancel->setAttrib('onclick', "javascript:goTo('/presupuesto/view/$id/repuestos-externos');");
            $this->view->form = $form;
            $row = $presupuesto->getRow();
            $this->view->presupuesto = $row;
        } catch(Exception $e) {
            $mSession->mensajes[] = "Ocurrió un error al requerir la información del presupuesto";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/presupuesto/view/' . $id);
        }
        
        $this->renderScript('presupuesto/form-item.phtml');
    }

    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_PresupuestoRepuestoExterno();
        $id = (int)$this->_getParam('id');
        $this->view->title = "Editar repuesto externo del presupuesto ";
        $this->view->titleBreadcrumb = "Formulario repuesto externo ";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $id = $form->getValue('id');
                    $item = new Default_Model_PresupuestoRepuestoExterno();
                    $item->editar($form->getValues(), $id);
                    $mSession->mensajes[] = "El repuesto externo fue editado de forma satisfactoria";
                    $mSession->claseMensaje = "confirmacion";
                    $this->_redirect('/presupuesto/view/' . $form->getValue('presupuesto_id') . '/repuestos-externos');

                } catch (Exception $e) {
                    $mSession->mensajes[] = "Ocurrió un error al intentar editar el repuesto externo del presupuesto";
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/presupuesto-repuesto-externo/agregar/' . $id);
                }
                
            } else {
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('partes-comunes/form-items.phtml');
            }
        }
        
        try {
            
            $repuestoExterno = new Default_Model_PresupuestoRepuestoExterno();
            $repuestoExterno->setId($id);
            $rowRepuestoExterno = $repuestoExterno->getRow();
            $rowPresupuesto = $repuestoExterno->getPresupuesto();
            $form->populate($rowRepuestoExterno->toArray());
            $form->submit->setLabel('Guardar cambios');
            $form->setAction('/presupuesto-repuesto-externo/editar/' . $id);
            $form->cancel->setAttrib('onclick', "javascript:goTo('/presupuesto/view/$rowPresupuesto->id/repuestos-externos');");
            $this->view->form = $form;
            $this->view->presupuesto = $rowPresupuesto;
            
        } catch(Exception $e) {
            $mSession->mensajes[] = "Ocurrió un error al requerir la información del repuesto externo a editar";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/presupuesto/view/' . $id . '/repuestos-externos');
        }
        
        $this->renderScript('presupuesto/form-item.phtml');
    }

    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $id = (int)$this->_getParam('id');
        $presupuesto_id = (int)$this->_getParam('from_id');
        
        try {
            
            $repuesto = new Default_Model_PresupuestoRepuestoExterno();
            $repuesto->setId($id);
            $repuesto->eliminar();
            $this->_redirect('/presupuesto/view/' . $presupuesto_id);
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar eliminar el repuesto externo";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/presupuesto/view/' . $presupuesto_id);
            
        }
    }
    
    public function addFromSolicitudAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if(!$this->_getParam('id') || !$this->_getParam('from_id')){
            $this->_redirect('/presupuesto/index/1/id/DESC');
        }
        $presupuesto_id = (int)$this->_getParam('id');
        $solicitud_id = (int)$this->_getParam('from_id');
        
        try {

            $item = new Default_Model_PresupuestoRepuestoExterno();
            $item->crearFromSolicitud($presupuesto_id, $solicitud_id);
            $mSession->mensajes[] = "El repuesto fue agregado de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/presupuesto/view/' . $presupuesto_id);
            
        } catch(Exception $e) {
            
            $mSession->mensajes[] = "Ocurrió un error al intentar agregar el repuesto desde la solicitud de taller.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/presupuesto/view/'. $presupuesto_id);
        }
    }
}