<?php
class PresupuestoRepuestoInternoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Presupuestos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        
        $this->view->propietario = Default_Model_SistemaPropietario::get();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function agregarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_PresupuestoRepuestoExterno();
        $id = (int)$this->_getParam('id');
        $this->view->title = "Agregar repuesto externo al presupuesto ";
        $this->view->titleBreadcrumb = "Formulario repuesto externo ";
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    $item = new Default_Model_PresupuestoRepuestoExterno();
                    $item->crear($form->getValues());
                    $mSession->mensajes[] = "El repuesto externo fue agregado de forma satisfactoria. "
                                          . "¿Desea agregar otro o prefiere <a href=\"/presupuesto/view/" 
                                          . $id ."/repuestos-externos\">Volver al presupuesto</a>?";
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/presupuesto-repuesto-externo/agregar/' . $id);
                } catch(Exception $e){
                    $mSession->mensajes[] = "Ocurrió un error al intentar agregar el repuesto externo al presupuesto";
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/presupuesto-repuesto-externo/agregar/' . $id);
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
            
        try {
            $presupuesto = new Default_Model_Presupuesto();
            $presupuesto->setId($id);
            $form->presupuesto_id->setValue($id);
            $form->setAction('/presupuesto-repuesto-externo/agregar/' . $id);
            $form->cancel->setAttrib('onclick', "javascript:goTo('/presupuesto/view/$id/repuestos-externos');");
            $this->view->form = $form;
            $row = $presupuesto->getRow();
            $this->view->presupuesto = $row;
        } catch(Exception $e) {
            $mSession->mensajes[] = "Ocurrió un error al requerir la información del presupuesto";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/presupuesto/view/' . $id);
        }
        
        $this->renderScript('presupuesto/form-item.phtml');
    }

    public function getFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $form = new Default_Form_PresupuestoRepuestoExterno();

            if($this->_request->getParam('id')) {
                
                $id = (int)$this->_getParam('id');
                
                try {
                    
                    $item = new Default_Model_PresupuestoRepuestoExterno();
                    $item->setId($id);
                    $form->populate($item->getRow()->toArray());
                    $form->setAction('/presupuesto-repuesto/edit');
                    $form->submit->setLabel('Guardar');
                    
                } catch(Exception $e){
                    
                    echo $e->getMessage();
                    
                }

            } elseif($this->_request->getParam('from_id')) {
                $form->presupuesto_id->setValue($this->_request->getParam('from_id'));
            }
            $this->view->title = "Formulario repuesto";
            $this->view->form = $form;
            $this->renderScript('partes-comunes/form-items.phtml');
        }
    }

    public function newAction()
    {
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
        
        $this->view->title = "Formulario repuesto";
        
        if($_POST) {
            $request = $this->getRequest();
            $form = new Default_Form_PresupuestoRepuesto();

            if ($this->getRequest()->isPost()) {
                if ($form->isValid($request->getPost())) {

                    try {

                        $item = new Default_Model_PresupuestoRepuesto();
                        $item->crear($form->getValues());
                        $this->view->estado = 1;
                        $this->renderScript('partes-comunes/form-items.phtml');

                    } catch (Exception $e) {
                        echo $e->getMessage();
                    }

                } else {
                    $form->populate($request->getPost());
                    $this->view->form = $form;
                    $this->renderScript('partes-comunes/form-items.phtml');
                }
            }
        }
    }

    public function editAction()
    {
        $request = $this->getRequest();
        $form = new Default_Form_PresupuestoRepuesto();

        $this->view->title = "Formulario repuesto";
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $id = $form->getValue('id');
                    $item = new Default_Model_PresupuestoRepuesto();
                    $item->editar($form->getValues(), $id);
                    
                    $this->view->estado = 2;
                    $this->renderScript('partes-comunes/form-items.phtml');

                } catch (Exception $e) {
                    echo $e->getMessage();
                }
            } else {
                $form->setAction('/presupuesto-repuesto/edit');
                $form->submit->setLabel('Guardar');
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('partes-comunes/form-items.phtml');
            }
        }
    }

    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $id = (int)$this->_getParam('id');
        $presupuesto_id = (int)$this->_getParam('from_id');
        
        try {
            
            $repuesto = new Default_Model_PresupuestoRepuestoExterno();
            $repuesto->setId($id);
            $repuesto->eliminar();
            $this->_redirect('/presupuesto/view/' . $presupuesto_id);
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar eliminar el repuesto externo";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/presupuesto/view/' . $presupuesto_id);
            
        }
    }
    
    public function addFromSolicitudAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        
        if(!$this->_getParam('id') || !$this->_getParam('from_id')){
            $this->_redirect('/presupuesto/index/1/id/DESC');
        }
        
        $presupuesto_id = (int)$this->_getParam('id');
        $solicitud_id = (int)$this->_getParam('from_id');
        
        $modelSolicitud = new Default_Model_SolicitudCompraRepuesto();
        
        $dbAdapter = $modelSolicitud->getDefaultAdapter();
        $dbAdapter->beginTransaction();
        
        try {

            $whereSolicitud = $dbAdapter->quoteInto("id=?", $solicitud_id);
            $rowSolicitud = $modelSolicitud->fetchRow($whereSolicitud);

            $modelItems = new Default_Model_ItemSolicitudCompraRepuesto();
            $whereItems = $dbAdapter->quoteInto("solicitud_id", $solicitud_id);
            $rowsItems = $modelItems->fetchAll($whereItems);

            $modelRepuesto = new Default_Model_PresupuestoRepuesto();

            if(count($rowsItems) > 0 ) {
                foreach($rowsItems as $item) {

                    $rowRepuesto = $modelRepuesto->createRow();
                    $rowRepuesto->presupuesto_id = $presupuesto_id;
                    $rowRepuesto->nombre = $item->nombre;
                    $rowRepuesto->calidad_solicitada = $item->calidad_solicitada;
                    $rowRepuesto->cantidad_requerida = $item->cantidad_solicitada;
                    $rowRepuesto->muestra = $item->muestra;
                    $rowRepuesto->solicitado_por = Default_Model_Empleado::getNombreByRut($rowSolicitud->creador);
                    $rowRepuesto->save();

                }
                $rowSolicitud->estado = 'AGREGADA';
                $rowSolicitud->save();
            }
            
            $dbAdapter->commit();
            
            $mSession->mensajes[] = "Los ítems fueron agregados de forma satisfactoria.";
            $mSession->claseMensaje = "confirmacion";
            
            $this->_redirect('/presupuesto/view/' . $presupuesto_id);
            
        } catch(Exception $e) {
            
            $dbAdapter->rollBack();
            $mSession->mensajes[] = "Ocurrió un error al intentar agregar los ítems de la solicitud de compra de repuestos.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            
            $this->_redirect('/presupuesto/view/'. $presupuesto_id);
            
        }
    }
}