<?php
class PresupuestoServicioExternoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Presupuestos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        
        $this->view->propietario = Default_Model_SistemaPropietario::get();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function agregarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_PresupuestoServicioExterno();
        $id = (int)$this->_getParam('id');
        $this->view->title = "Agregar servicio externo al presupuesto ";
        $this->view->titleBreadcrumb = "Formulario servicio externo ";
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    $item = new Default_Model_PresupuestoServicioExterno();
                    $item->crear($form->getValues());
                    $mSession->mensajes[] = "El servicio externo fue agregado de forma satisfactoria. "
                                          . "¿Desea agregar otro o prefiere <a href=\"/presupuesto/view/" 
                                          . $id ."/servicios-externos\">Volver al presupuesto</a>?";
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/presupuesto-servicio-externo/agregar/' . $id);
                } catch(Exception $e){
                    $mSession->mensajes[] = "Ocurrió un error al intentar agregar el servicio externo al presupuesto";
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/presupuesto-servicio-externo/agregar/' . $id);
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
            
        try {
            $presupuesto = new Default_Model_Presupuesto();
            $presupuesto->setId($id);
            $form->presupuesto_id->setValue($id);
            $form->setAction('/presupuesto-servicio-externo/agregar/' . $id);
            $form->cancel->setAttrib('onclick', "javascript:goTo('/presupuesto/view/$id/servicios-externos');");
            $this->view->form = $form;
            $row = $presupuesto->getRow();
            $this->view->presupuesto = $row;
        } catch(Exception $e) {
            $mSession->mensajes[] = "Ocurrió un error al requerir la información del presupuesto";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/presupuesto/view/' . $id);
        }
        
        $this->renderScript('presupuesto/form-item.phtml');
    }
    
    public function editarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_PresupuestoServicioExterno();
        $id = (int)$this->_getParam('id');
        $this->view->title = "Editar servicio externo del presupuesto ";
        $this->view->titleBreadcrumb = "Formulario servicio externo ";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $id = $form->getValue('id');
                    $item = new Default_Model_PresupuestoServicioExterno();
                    $item->editar($form->getValues(), $id);
                    $mSession->mensajes[] = "El servicio externo fue editado de forma satisfactoria";
                    $mSession->claseMensaje = "confirmacion";
                    $this->_redirect('/presupuesto/view/' . $form->getValue('presupuesto_id') . '/servicios-externos');

                } catch (Exception $e) {
                    $mSession->mensajes[] = "Ocurrió un error al intentar editar el servicio externo del presupuesto";
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/presupuesto-servicio-externo/agregar/' . $id);
                }
                
            } else {
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('partes-comunes/form-items.phtml');
            }
        }
        
        try {
            
            $servicioExterno = new Default_Model_PresupuestoServicioExterno();
            $servicioExterno->setId($id);
            $rowServicioExterno = $servicioExterno->getRow();
            $rowPresupuesto = $servicioExterno->getPresupuesto();
            $form->populate($rowServicioExterno->toArray());
            $form->submit->setLabel('Guardar cambios');
            $form->setAction('/presupuesto-servicio-externo/editar/' . $id);
            $form->cancel->setAttrib('onclick', "javascript:goTo('/presupuesto/view/$rowPresupuesto->id/servicios-externos');");
            $this->view->form = $form;
            $this->view->presupuesto = $rowPresupuesto;
            
        } catch(Exception $e) {
            $mSession->mensajes[] = "Ocurrió un error al requerir la información del servicio externo a editar";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/presupuesto/view/' . $id . '/servicios-externos');
        }
        
        $this->renderScript('presupuesto/form-item.phtml');
    }
    
    public function eliminarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        $id = (int)$this->_getParam('id');
        $presupuesto_id = (int)$this->_getParam('from_id');
        
        try {
            
            $repuesto = new Default_Model_PresupuestoServicioExterno();
            $repuesto->setId($id);
            $repuesto->eliminar();
            $mSession->mensajes[] = "El servicio externo ha sido eliminado de forma satisfactoria";
            $mSession->claseMensaje = "confirmacion";
            $this->_redirect('/presupuesto/view/' . $presupuesto_id . '/servicios-externos');
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar eliminar el servicio externo";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/presupuesto/view/' . $presupuesto_id . '/servicios-externos');
            
        }
    }
}