<?php
class ProveedorController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Proveedores';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
	
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            $response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $proveedor = new Default_Model_Proveedor();
        $proveedores = $proveedor->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $proveedor->getOrderByOptions();
        $this->view->orderBy = $proveedor->getOrderBy();
        $this->view->orderType = $proveedor->getOrderType();
        $this->view->action = '/proveedor/index/';
        $this->view->proveedores = $proveedores;
        $this->view->title = 'Proveedores';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaProveedores();
        
        $this->view->form = $form;
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Proveedor();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    $proveedor = new Default_Model_Proveedor();
                    $rut = $proveedor->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes[] = 'El proveedor fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_redirect('/proveedor/view/' . $rut);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el proveedor.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/proveedor/index/1/razon_social/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Crear proveedor";
        $this->view->form = $form;
        $this->renderScript('proveedor/form.phtml');
    }
 
    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        $proveedor = new Default_Model_Proveedor();
        $request = $this->getRequest();
        $form = new Default_Form_Proveedor();
        $form->id->setRequired(true);
        $form->submit->setLabel('Guardar cambios');
        $form->id->setValue($id);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    
                    $proveedor->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'El proveedor fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/proveedor/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/proveedor/index/1/razon_social/ASC');
                }
                
            } else {
                $form->populate($request->getPost());
            }
        } 
        $this->view->title = "Editar proveedor";
        
        $proveedor->setId($id);
        $form->populate($proveedor->getRow()->toArray());
        
        $form->setAction('/proveedor/edit/' . $id);
        $this->view->form = $form;
        $this->renderScript('proveedor/form.phtml');
    }
    
    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');

        $proveedor = new Default_Model_Proveedor();
        $proveedor->setId($id);
        $this->view->proveedor = $proveedor->getRow();
        $this->view->title = 'Proveedor';
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $proveedor = new Default_Model_Proveedor();
            $proveedor->setId($id);
            $proveedor->eliminar();
            $mSession->mensajes[] = 'El proveedor fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/proveedor/index/1/razon_social/ASC');
            
        } catch (Exception $e) {
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el proveedor';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/proveedor/index/1/razon_social/ASC');
            
        }
        
        
    }

    public function estadoCuentaAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('proveedores', 'rut', App_Rut::cleanToDb($this->_getParam('id')))){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $this->view->title = "Estado de cuenta";
        }
    }

    public function searchToFormAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            $param = $this->_getParam('term');
            $proveedor = new Default_Model_Proveedor();
            $data = $proveedor->searchToForm($param);
            $result = Zend_Json_Encoder::encode($data);
            echo $result;
        }
    }

    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));
            
            $proveedor = new Default_Model_Proveedor();
            $this->view->proveedores = $proveedor->searchToTooltip($criterio, $valor);
            $this->renderScript('proveedor/search.phtml');
        }
    }

    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();

            $this->view->t  = $this->_getParam('t');
            $rut = App_Rut::cleanToDb($this->_getParam('id'));
            
            $proveedor = new Default_Model_Proveedor();
            $proveedor->setRut($rut);
            $this->view->proveedor = $proveedor->getRow();
            $this->renderScript('proveedor/view-tooltip.phtml');
        }
    }
    
    public function getListadoPopupAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $proveedor = new Default_Model_Proveedor();
            $this->view->proveedores = $proveedor->getAllToPopup();
            $this->renderScript('proveedor/listado-popup.phtml');
        }
    }
}