<?php
class RemAfpController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Remuneraciones - AFPs';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $afp = new Default_Model_RemAfp();
        $afps = $afp->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $afp->getOrderByOptions();
        $this->view->orderBy = $afp->getOrderBy();
        $this->view->orderType = $afp->getOrderType();
        $this->view->action = '/rem-afp/index/';
        $this->view->afps = $afps;
        $this->view->title = 'AFPs';
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $request = $this->getRequest();
        $form = new Default_Form_RemAfp();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $afp = new Default_Model_RemAfp();
                    $afp->crear($form->getValues());
                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/rem-afp/index/1/nombre/ASC');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/rem-afp/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $afp = new Default_Model_RemAfp();
        $request = $this->getRequest();
        $form = new Default_Form_RemAfp();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $afp->editar($form->getValues(), $form->getValue('id'));
                    $mSession->mensajes[] = 'La AFP fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/rem-afp/index/1/nombre/ASC');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/rem-afp/index/1/nombre/ASC');
                }
                
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $id = (int)$this->_getParam('id');
        $afp->setId($id);
        $form->populate($afp->getRow()->toArray());
        $form->setAction('/rem-afp/edit');
        $form->submit->setLabel("Guardar cambios");
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');

        try {

            $afp = new Default_Model_RemAfp();
            $afp->setId($id);
            $afp->eliminar();
            $mSession->mensajes[] = 'La AFP fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/rem-afp/index/1/nombre/ASC');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la AFP';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/rem-afp/index/1/nombre/ASC');
        }
        
    }
}