<?php
class RemAnticipoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Remuneraciones - Anticipos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            $response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }

    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $anticipo = new Default_Model_RemAnticipo();
        $anticipos = $anticipo->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $anticipo->getOrderByOptions();
        $this->view->orderBy = $anticipo->getOrderBy();
        $this->view->orderType = $anticipo->getOrderType();
        $this->view->action = '/rem-anticipo/index/';
        $this->view->anticipos = $anticipos;
        $this->view->title = 'Anticipos de sueldo';
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_RemAnticipo();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                 try {

                    $anticipo = new Default_Model_RemAnticipo();
                    $id = $anticipo->crear($form->getValues(), $this->usuario->id);
                   
                    $mSession->mensajes[] = 'El anticipo fue registrado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/rem-anticipo/view/' . $id);
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar registrar el anticipo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/rem-anticipo/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->renderScript('rem-anticipo/form.phtml');
    }
    
    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $anticipo = new Default_Model_RemAnticipo();
        $request = $this->getRequest();
        $form = new Default_Form_RemAnticipo();
        $form->id->setRequired(true);
        $form->setAction('/rem-anticipo/edit');
        $form->submit->setLabel('Guardar cambios');
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $anticipo->editar($form->getValues(), $form->getValue('id'), $this->usuario->id);
                    $mSession->mensajes[] = 'El anticipo fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/rem-anticipo/view/' . $form->getValue('id'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el anticipo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/rem-anticipo/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        
        $id = (int)$this->_getParam('id');
        $anticipo->setid($id);
        $form->populate($anticipo->getRow()->toArray());
        $form->id->setValue($id);
        $this->view->form = $form;
        $this->renderScript('rem-anticipo/form.phtml');
    }
    
    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $anticipo = new Default_Model_RemAnticipo();
            $anticipo->setId($id);
            $this->view->anticipo = $anticipo->getRowFull();
            $this->view->title = "Anticipo de sueldo ";

            if($anticipo->getEstado() == 'BORRADOR'){
                $this->renderScript('rem-anticipo/view-borrador.phtml');
            } else {
                $this->renderScript('rem-anticipo/view.phtml');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar el anticipo";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/rem-anticipo/index/1/id/DESC');
        }
    }
    
    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');

        try {
            
            $anticipo = new Default_Model_RemAnticipo();
            $anticipo->setId($id);
            
            if($anticipo->getEstado() =='BORRADOR'){
                $anticipo->eliminar();
                $mSession->mensajes[] = 'El anticipo fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
            } else {
                $mSession->mensajes[] = 'Está intentando eliminar un anticipo que no es un borrador. Esta operación no está permitida.';
                $mSession->claseMensaje = 'error';
            }
            $this->_redirect('/rem-anticipo/index/1/nombre/DESC');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el anticipo.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/rem-anticipo/view/' . $id);
        }
    }
    
    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $anticipo = new Default_Model_RemAnticipo();
            $anticipo->setId($id);
            
            if($anticipo->getEstado()=='BORRADOR'){
                
                $anticipo->setEstado('TERMINADO');
                $mSession->claseMensaje = 'confirmacion';
                $mSession->mensajes[] = 'El anticipo fue terminado de forma satisfactoria. Ahora puede imprimirlo.';
            } 
            
            $this->_redirect('/rem-anticipo/view/' . $id);
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar terminar el anticipo';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/rem-anticipo/view/' . $id);
        }
    }
}