<?php
class RemEmpleadoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Remuneraciones - Empleados';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            $response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }

    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $empleado = new Default_Model_RemEmpleado();
        $empleados = $empleado->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $empleado->getOrderByOptions();
        $this->view->orderBy = $empleado->getOrderBy();
        $this->view->orderType = $empleado->getOrderType();
        $this->view->action = '/rem-empleado/index/';
        $this->view->empleados = $empleados;
        $this->view->title = 'Empleados';
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_RemEmpleado();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                 try {

                    $empleado = new Default_Model_RemEmpleado();
                    $id = $empleado->crear($form->getValues(), $this->usuario->id);
                   
                    $mSession->mensajes[] = 'El empleado fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/rem-empleado/view/' . $id);
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el empleado.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/rem-empleado/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->renderScript('rem-empleado/form.phtml');
    }
    
    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $empleado = new Default_Model_RemEmpleado();
        $request = $this->getRequest();
        $form = new Default_Form_RemEmpleado();
        $form->id->setRequired(true);
        $form->setAction('/rem-empleado/edit');
        $form->submit->setLabel('Guardar cambios');
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $empleado->editar($form->getValues(), $form->getValue('id'));
                    $mSession->mensajes[] = 'El empleado fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/rem-empleado/view/' . $form->getValue('id'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el empleado.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/rem-empleado/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        
        $id = (int)$this->_getParam('id');
        $empleado->setid($id);
        $form->populate($empleado->getRow()->toArray());
        $form->id->setValue($id);
        $this->view->form = $form;
        $this->renderScript('rem-empleado/form.phtml');
    }
    
    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        $empleado = new Default_Model_RemEmpleado();
        $empleado->setId($id);
        $dataContrato = $empleado->getDataContrato();
        
        $this->view->empleado = $empleado->getRowFull();
        $this->view->cargasFamiliares = $empleado->getCargasFamiliares();
        $this->view->contrato = $dataContrato['contrato'];
        $this->view->anexos = $dataContrato['anexos'];
        $this->view->finiquito = $dataContrato['finiquito'];
        $this->view->sueldoVigente = $dataContrato['sueldoVigente'];
        $this->view->title = $this->view->empleado->nombre;
    }
    
    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');

        try {
            
            $empleado = new Default_Model_RemEmpleado();
            $empleado->setId($id);
            $empleado->eliminar();
            $mSession->mensajes[] = 'El empleado fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/rem-empleado/index/1/nombre/ASC');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el empleado.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/rem-empleado/view/' . $id);
        }
    }
    
    public function getListadoPopupAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $empleado = new Default_Model_RemEmpleado();
            $this->view->empleados = $empleado->getAllToPopup();
            $this->renderScript('rem-empleado/listado-popup.phtml');
        }
    }

    public function newContratoAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_RemContrato();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                 try {

                    $contrato = new Default_Model_RemContrato();
                    $contrato->crear($form->getValues(), $this->usuario->id);
                   
                    $mSession->mensajes[] = 'El contrato fue ingresado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/rem-empleado/view/' . $form->getValue('empleado_id'));
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el empleado.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/rem-empleado/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->empleado_id->setValue((int)$this->_getParam('from_id'));
        $this->view->form = $form;
        $this->renderScript('rem-empleado/form.phtml');
    }
    
    public function newAnexoAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_RemAnexo();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                 try {

                    $anexo = new Default_Model_RemAnexo();
                    $empleado_id = $anexo->crear($form->getValues(), $this->usuario->id);
                   
                    $mSession->mensajes[] = 'El anexo de contrato fue ingresado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/rem-empleado/view/' . $empleado_id);
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar ingresar el anexo de contrato.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/rem-empleado/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $contrato_id = (int)$this->_getParam('id');
        $contrato = new Default_Model_RemContrato();
        $contrato->setId($contrato_id);
        $dataContrato = $contrato->getRow()->toArray();

        $form->contrato_id->setValue($contrato_id);
        
        if($dataContrato['fecha_t'] == NULL) {
            $form->tipo_contrato->setAttrib('disabled', 'disabled');
        } else {
            $form->tipo_contrato->setValue(1);
            $form->fecha_t->setValue($dataContrato['fecha_t']);
        }
        
        $this->view->form = $form;
        $this->renderScript('rem-empleado/form.phtml');
    }
    
     public function newFiniquitoAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_RemFiniquito();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                 try {

                    $contrato = new Default_Model_RemContrato();
                    $empleado_id = $contrato->ingresarFiniquito($form->getValues(), $this->usuario->id);
                   
                    $mSession->mensajes[] = 'El finiquito del contrato fue ingresado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/rem-empleado/view/' . $empleado_id);
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar ingresar el finiquito del contrato.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/rem-empleado/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->contrato_id->setValue((int)$this->_getParam('id'));
        $this->view->form = $form;
        $this->renderScript('rem-empleado/form.phtml');
    }
}