<?php
class RemuneracionesController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $cierre = new Default_Model_RemuneracionCierre();
            $cierres = $cierre->fetchAll(null, 'id DESC');

            $paginador = Zend_Paginator::factory($cierres);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->cierres = $paginador;
            $this->view->title = "Cierres de remuneraciones de meses anteriores";
            $this->renderScript('remuneraciones/index.phtml');
            
        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_CierreMesRemuneracion(null, $this->path);

            if($this->_request->getParam('id')) {

                $remuneracion_cierre = new Default_Model_CierreMesRemuneracion();
                $id = $remuneracion_cierre->getAdapter()->quote($this->_request->getParam('id'));
                $row = $proveedor->fetchRow('rut='.$rut)->toArray();
                $form->populate($row);
                $form->setAction('/remuneraciones/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar cierre de mes";

            } else {

                $this->view->title = "Configurar montos y cerrar mes";
                $cierre = new Default_Model_RemuneracionCierre();
                $ultimo = $cierre->fetchRow(null, 'id DESC');
                $fecha_i = new Zend_Date($ultimo->periodo_t);
                $inicio = $fecha_i->addDay(1)->toString("yyyy-MM-dd");
                $termino = $fecha_i->addDay(31)->toString("yyyy-MM-dd");
                $this->view->ultimo = $ultimo;
                $form->periodo_i->setValue($inicio);
                $form->periodo_t->setValue($termino);
                $this->view->total_pozo = 1400000;
            }
            $this->view->form = $form;
            $this->renderScript('remuneraciones/form.phtml');
        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_CierreMesRemuneracion(null, $this->path);
        $this->view->title = "Configurar cierre de mes";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    $remuneracion_cierre = new Default_Model_RemuneracionCierre();
                    $row = $remuneracion_cierre->createRow();
                    $row->mes = $form->getValue('mes');
                    $row->periodo_i = $form->getValue('periodo_i');
                    $row->periodo_t = $form->getValue('periodo_t');
                    $row->total_horas_mes = $form->getValue('total_horas_mes');
                    //$row->monto_total = $form->getValue('monto_total');
                    $row->descuentos_perdidas_existencias = $form->getValue('descuentos_perdidas_existencias');
                    $row->descuentos_danos_vehiculos = $form->getValue('descuentos_danos_vehiculos');
                    $row->descuentos_otros = $form->getValue('descuentos_otros');
                    //$row->monto_final = $form->getValue('monto_final');
                    $row->save();
                    $mSession->mensajes[] = 'El mes ha sido cerrado de forma satisfactoria.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('index','remuneraciones');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar cerrar el mes.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('new','remuneraciones');
                }
            } else {

                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('remuneraciones/form.phtml');
            }
        } else {
            $this->_forward('logout','index');
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Proveedor();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $rut = App_Rut::cleanToDb($form->getValue('rut'));
                    $proveedor = new Default_Model_Proveedor();
                    $row = $proveedor->fetchRow('rut='.$rut);
                    $row->razon_social = $form->getValue('razon_social');
                    $row->direccion = $form->getValue('direccion');
                    $row->comuna = $form->getValue('comuna');
                    $row->ciudad = $form->getValue('ciudad');
                    $row->telefono = $form->getValue('telefono');
                    $row->giro = $form->getValue('giro');
                    $row->web = $form->getValue('web');
                    $row->monto_linea_credito = $form->getValue('monto_linea_credito');
                    $row->plazo_pago_max = $form->getValue('plazo_pago_max');
                    $row->save();

                    $mSession->mensajes[] = 'El proveedor fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view', 'proveedor', null, array('rut'=> $rut));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('edit','proveedor');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/proveedor/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar proveedor";
                $this->renderScript('proveedor/form.phtml');
            }
        } 
        
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $rut = $this->_getParam('rut');
            $proveedor = new Default_Model_VistaProveedores();
            $this->view->proveedor = $proveedor->fetchRow('rut=' . $rut);
            $this->view->title = 'Proveedor';
            //$this->view->contactos = $proveedor->getContactos($id);

            if(false==$this->view->proveedor) {
                $this->_forward('index','proveedor');
            } else {
                $this->renderScript('proveedor/view.phtml');
            }
        }
    }

    public function preferenciasComisionesAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_PreferenciasRemBonos(null, $this->path);

            $preferencias = new Default_Model_RemuneracionPreferencia();
            $row = $preferencias->getAll();
            $form->populate($row);
            $form->setAction('/remuneraciones/set-preferencias');
            $this->view->title = "Configurar las preferencias de remuneraciones";
            $this->view->form = $form;
            $this->renderScript('remuneraciones/preferencias-bono.phtml');

        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function preferenciasCalculoSueldoAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_PreferenciasRemCalculoSueldo(null, $this->path);

            $preferencias = new Default_Model_RemuneracionPreferencia();
            $row = $preferencias->getAll();
            $form->populate($row);
            $form->setAction('/remuneraciones/set-preferencias');
            $this->view->title = "Configurar las preferencias de remuneraciones";
            $this->view->form = $form;
            $this->renderScript('remuneraciones/preferencias-calculo-sueldo.phtml');

        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function setPreferenciasAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_PreferenciasRemuneraciones(null, $this->path);
        $this->view->title = "Configurar las preferencias de remuneraciones";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $preferencias = new Default_Model_RemuneracionPreferencia();
                    $row = $preferencias->fetchRow("id='0'");
                    $row->bp_base = $form->getValue('bp_base');
                    $row->bp_dist = $form->getValue('bp_dist');
                    $row->bp_horas_just = $form->getValue('bp_horas_just');
                    $row->bp_porcentaje = $form->getValue('bp_porcentaje');
                    $row->cv_base = $form->getValue('cv_base');
                    $row->cv_dist = $form->getValue('cv_dist');
                    
                    $row->save();
                    $mSession->mensajes[] = 'Las preferencias fueron guardadas de forma satisfactoria.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('preferencias','remuneraciones');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar guardar las preferencias.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','remuneraciones');
                }
            } else {

                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('remuneraciones/preferencias.phtml');
            }
        } else {
            $this->_forward('logout','index');
        }
    }

    public function comisionesAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_ComisionVenta(null, $this->path);
            $comisiones = new Default_Model_ComisionVenta();
            $this->view->comisiones = $comisiones->fetchAll(null, 'id DESC');
            $this->view->title = "Comisiones de ventas";
            
            $this->view->form = $form;
            $this->renderScript('remuneraciones/comisiones.phtml');

        } else {
            $this->_forward('logout', 'index');
        }
    }

    public function addComisionAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_ComisionVenta(null, $this->path);

            if ($this->getRequest()->isPost()) {
                if ($form->isValid($request->getPost())) {

                    $comision = new Default_Model_ComisionVenta();
                    $row = $comision->createRow();
                    $row->desde = $form->getValue('desde');
                    $row->hasta = $form->getValue('hasta');

                    if($form->getValue('valor')!='') {
                        $row->valor = $form->getValue('valor');
                    } else {
                        $row->valor = NULL;
                    }
                    $row->save();
                    $form->reset();
                }
            }
            $comisiones = new Default_Model_ComisionVenta();
            $this->view->comisiones = $comisiones->fetchAll(null, 'valor');
            $this->view->title = "Comisiones de ventas";

            $this->view->form = $form;
            $this->renderScript('remuneraciones/comisiones.phtml');

        } else {
            $this->_forward('logout', 'index');
        }
    }
}