<?php
class ReservaController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->path = '/reserva';
        $this->view->pageTitle = 'Reservas';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $reserva = new Default_Model_ClienteReserva();
        $reservas = $reserva->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $reserva->getOrderByOptions();
        $this->view->orderBy = $reserva->getOrderBy();
        $this->view->orderType = $reserva->getOrderType();
        $this->view->action = '/reserva/index/';
        $this->view->reservas = $reservas;
        $this->view->title = 'Reservas';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaClientesReservas();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_ClienteReserva();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $reserva = new Default_Model_ClienteReserva();
                    $reserva->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes[] = 'La reserva fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/reserva/index/1/id/DESC');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la reserva.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/reserva/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->cancel->setAttrib("onclick", 'goTo("/reserva/index/1/DESC");');
        $this->view->form = $form;
        $this->view->title = "Crear reserva";
        $this->renderScript('reserva/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_ClienteReserva();
        $reserva = new Default_Model_ClienteReserva();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $id = (int)$form->getValue('id');
                    $reserva->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'La reserva fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/reserva/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/reserva/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $id = (int)$this->_getParam('id');
        $reserva->setId($id);
        $form->populate($reserva->getRow()->toArray());
        $form->setAction('/reserva/edit/'. $id);
        $form->cancel->setAttrib("onclick", 'goTo("/reserva/view/'.$id.'");');
        $form->submit->setLabel('Guardar cambios');
        $this->view->title = "Editar reserva";
        $this->view->form = $form;
        $this->renderScript('reserva/form.phtml');
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id', 0);
        $reserva = new Default_Model_ClienteReserva();
        $reserva->setId($id);
        $this->view->title = "Reserva Nº $id";
        $this->view->reserva = $reserva->getRow();
    }

    public function concretarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        $reserva = new Default_Model_ClienteReserva();
        $reserva->setId($id);
        $reserva->setEstado('CONCRETADA');
        $mSession->mensajes[] = 'La reserva fue concretada de forma exitosa.';
        $mSession->claseMensaje = 'confirmacion';
        $this->_redirect('/reserva/index/1/id/DESC');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');

        $reserva = new Default_Model_ClienteReserva();
        $reserva->setId($id);
        $reserva->eliminar();
        $mSession->mensajes[] = 'La reserva fue eliminada de forma exitosa.';
        $mSession->claseMensaje = 'confirmacion';
        $this->_redirect('/reserva/index/1/id/DESC');
    }
}