<?php
class ServicioController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $servicio = new Default_Model_VistaServicios();
            $order = 'codigo';
            $servicios = $servicio->fetchAll(null, $order);

            $paginador = Zend_Paginator::factory($servicios);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->title = "Servicios";
            $this->view->servicios = $paginador;
            $this->renderScript('servicio/index.phtml');
        }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Servicio(null, $this->path);

            if($this->_getParam('id')) {

                $servicio = new Default_Model_Servicio();
                $codigo = $this->_getParam('id');
                $where = $servicio->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $servicio->fetchRow($where)->toArray();
                $form->populate($row);
                $form->id->setValue($codigo);
                $form->codigo->setAttrib('disabled', 'disabled');
                $form->setAction('/servicio/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar servicio código : $codigo";

            } else {

                $this->view->title = "Crear servicio";

            }
            $this->view->form = $form;
            $this->renderScript('servicio/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Servicio(null, $this->path);
        $this->view->title = "Crear servicio";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $servicio = new Default_Model_Servicio();
                    $row = $servicio->createRow();
                    $row->codigo = $form->getValue('codigo');
                    $row->creador = $this->usuario->rut;
                    $row->categoria_id = $form->getValue('categoria_id');
                    if($form->getValue('area_id')==''){
                        $row->area_id = NULL;
                    } else {
                        $row->area_id = $form->getValue('area_id');
                    }
                    $row->mano_obra_id = $form->getValue('mano_obra_id');
                    $row->nombre = ucfirst($form->getValue('nombre'));
                    $row->horas_trabajo = $form->getValue('horas_trabajo');
                    if($form->getValue('descripcion')==''){
                        $row->descripcion = NULL;
                    } else {
                        $row->descripcion = $form->getValue('descripcion');
                    }
                    $row->save();

                    $precioServicio = new Default_Model_PrecioServicio();
                    $row_precio = $precioServicio->createRow();
                    $row_precio->creador  = $this->usuario->rut;
                    $row_precio->servicio = $row->codigo;
                    $row_precio->precio_unitario_neto = $this->_calcularPrecioVentaSugerido($row->codigo);
                    $row_precio->save();

                    $mSession->mensajes[] = 'El servicio fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_forward('view','servicio', null, array('id' => $row->codigo));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el servicio.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index','servicio');
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('servicio/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_Servicio();
        $form->id->setRequired(true);

        if ($this->getRequest()->isPost()) {
            
            if ($form->isValid($request->getPost())) {

                try {
                    $servicio = new Default_Model_Servicio();
                    $codigo = $form->getValue('id');
                    $where = $servicio->getAdapter()->quoteInto("codigo=?", $codigo);
                    $row = $servicio->fetchRow($where);
                    $row->codigo = $form->getValue('codigo');
                    $row->creador = $this->usuario->rut;
                    $row->categoria_id = $form->getValue('categoria_id');
                    if($form->getValue('area_id')==''){
                        $row->area_id = NULL;
                    } else {
                        $row->area_id = $form->getValue('area_id');
                    }
                    $row->mano_obra_id = $form->getValue('mano_obra_id');
                    $row->nombre = ucfirst($form->getValue('nombre'));
                    $row->horas_trabajo = $form->getValue('horas_trabajo');
                    if($form->getValue('descripcion')==''){
                        $row->descripcion = NULL;
                    } else {
                        $row->descripcion = $form->getValue('descripcion');
                    }
                    $row->save();

                    $mSession->mensajes[] = 'El servicio fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'servicio', null, array('id' => $form->getValue('codigo')));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el servicio.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','servicio');
                }
            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/servicio/edit');
                $form->codigo->setAttrib('disabled', 'disabled');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar servicio";
                $this->renderScript('servicio/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() &&
           $this->_getParam('id') &&
           $this->_helper->validateRecordExists('vista_servicios', 'codigo', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {

                $codigo = $this->_getParam('id');
                $servicio = new Default_Model_Servicio();
                $where = $servicio->getAdapter()->quoteInto("codigo=?", $codigo);
                $servicio->delete($where);
                $mSession->mensajes[] = 'El servicio fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_forward('index','servicio');

            } catch (Exception $e) {

                $mSession->error['mensajes'][]      = $e->getMessage();
                $mSession->error['tipo']            = 1;
                $mSession->error['registro_id']     = $codigo;
                $mSession->error['registro_tabla']  = 'servicios';
                $this->_forward('error-delete-registro','error');

            }
            
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() && 
           $this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $servicio = new Default_Model_VistaServicios();
            $codigo = $this->_getParam('id');
            $where = $servicio->getAdapter()->quoteInto("codigo=?", $codigo);
            $row = $servicio->fetchRow($where);
            
            $costo = $row['neto_hora'] * $row['horas_trabajo'];
            
            if($row->precio_unitario_neto > 0){
                $this->view->margen = $this->_helper->calcularMargen($costo, $row->precio_unitario_neto);
            }
            
            $this->view->title = "Servicio";
            $this->view->servicio = $row;
            
            if($row->estado=='BORRADOR') {
                 $this->renderScript('servicio/view-draft.phtml');
            } else {

                $this->renderScript('servicio/view-admin.phtml');
            }
        } else {
            $this->_forward('index', 'servicio');
        }
    }

    public function historialPreciosAction()
    {
        if($this->getRequest()->isXmlHttpRequest() &&
           $this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $codigo = $this->_getParam('id');
            $precioServicio = new Default_Model_PrecioServicio();
            $wherePrecio = $precioServicio->getAdapter()->quoteInto("servicio=?", $codigo);
            $orderPrecio = 'id DESC';
            $rowsPrecios = $precioServicio->fetchAll($wherePrecio, $orderPrecio);

            $this->view->precios = $rowsPrecios;
            $this->renderScript('servicio/historial-precios.phtml');

        }
    }

    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $servicio = new Default_Model_VistaServicios();

            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));


            if($criterio!='' AND $valor!='') {

                if($criterio=='codigo') {

                    $valor = strtoupper($valor);
                    $where = "$criterio='$valor'";

                } else {

                    $where = "$criterio LIKE '%$valor%'";
                }

                $this->view->servicios = $servicio->fetchAll($where)->toArray();
            }

            $this->renderScript('servicio/search.phtml');
        }
    }

    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $this->view->t  = $this->_getParam('t');
            $codigo = $this->_getParam('id');
            $servicio = new Default_Model_VistaServicios();
            $where = $servicio->getAdapter()->quoteInto("codigo=?", $codigo);
            $this->view->servicio = $servicio->fetchRow($where)->toArray();
            $this->renderScript('servicio/view-tooltip.phtml');
        }
    }

    public function ajustarPrecioVentaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id')){

            $codigo = $this->_getParam('id');
            $valor = (int)$this->_getParam('valor');

            try {

                $precio = new Default_Model_PrecioServicio();
                $row = $precio->createRow();
                $row->creador  = $this->usuario->rut;
                $row->servicio = $codigo;
                $row->precio_unitario_neto = $valor;
                $row->save();
                
                $servicio = new Default_Model_VistaServicios();
                $where_servicio = $servicio->getAdapter()->quoteInto("codigo=?", $codigo);
                $row_servicio = $servicio->fetchRow($where_servicio)->toArray();

                $costo = $row_servicio['horas_trabajo'] * $row_servicio['neto_hora'];
                
                $margen = $this->_helper->calcularMargen($costo, $valor);

                $data = array();
                $data['mensaje'] = array("valor" => "Valor guardado", "style" => "color:green;");
                $data['valores'] = array(
                    array('id' => '#porcentaje_margen', 'html' => $this->view->formatDecimal($margen,2))
                );

                echo Zend_Json_Encoder::encode($data);

            } catch (Exception $e) {

                echo '<span style="color:red;">No se pudo guardar el nuevo valor</span>';
            }
        }
    }

    public function ajustarHorasRequeridasAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id')){

            $codigo = $this->_getParam('id');
            $valor = $this->_getParam('valor');

            try {

                $servicio = new Default_Model_Servicio();
                $where = $servicio->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $servicio->fetchRow($where);
                $row->horas_trabajo = $valor;
                $row->save();

                $servicio = new Default_Model_VistaServicios();
                $where_servicio = $servicio->getAdapter()->quoteInto("codigo=?", $codigo);
                $row_servicio = $servicio->fetchRow($where_servicio)->toArray();

                $precio = new Default_Model_PrecioServicio();
                $where_precio = $precio->getAdapter()->quoteInto("servicio=?", $codigo);
                $order_precio = 'id DESC';
                $row_precio = $precio->fetchRow($where_precio, $order_precio)->toArray();

                $costo = $row_servicio['horas_trabajo'] * $row_servicio['neto_hora'];

                $margen = (($row_precio['precio_unitario_neto'] / $costo) - 1) * 100;

                $data = array();
                $data['mensaje'] = array("valor" => "Valor guardado", "style" => "color:green;");
                $data['valores'] = array(
                    array('id' => '#total_costo', 'html' => $this->view->formatNumber($costo)),
                    array('id' => '#porcentaje_margen', 'html' => $this->view->formatDecimal($margen, 2))
                );

                echo Zend_Json_Encoder::encode($data);

            } catch (Exception $e) {

                echo '<span style="color:red;">No se pudo guardar el nuevo valor</span>';
            }
        }
    }

    private function _calcularPrecioVentaSugerido($codigo)
    {
        $servicio = new Default_Model_VistaServicios();
        $where = $servicio->getAdapter()->quoteInto("codigo=?", $codigo);
        $row = $servicio->fetchRow($where)->toArray();

        $costo = $row['horas_trabajo'] * $row['neto_hora'];
        $margen = 1 + (Default_Model_PreferenciaMargenDefault::getMargenByValue('SERVICIO', $costo) / 100);
        $precioVenta = round($costo * $margen, -2);
        return $precioVenta;
    }

    public function habilitarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id')){

            $codigo = $this->_getParam('id');

            try {

                $servicio = new Default_Model_Servicio();
                $where = $servicio->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $servicio->fetchRow($where);
                $row->estado = 'DISPONIBLE';
                $row->save();

                $mSession->mensajes[] = 'El servicio ya se encuentra disponible para la venta.';
                $mSession->claseMensaje = 'confirmacion';

                $this->_forward('view', 'servicio', null, array('id' => $codigo));

            } catch (Exception $e) {

                $mSession->mensajes[] = 'Ocurrió un error al intentar habilitar el servicio para la venta.';
                $mSession->mensajes[] = $e->getMessage();
                $mSession->claseMensaje = 'error';
                $this->_forward('index','servicio');
            }
        }
    }

    public function deshabilitarAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id')){

            $codigo = $this->_getParam('id');

            try {

                $servicio = new Default_Model_Servicio();
                $where = $servicio->getAdapter()->quoteInto("codigo=?", $codigo);
                $row = $servicio->fetchRow($where);
                $row->estado = 'NO DISPONIBLE';
                $row->save();

                $mSession->mensajes[] = 'El servicio ya se encuentra disponible para la venta.';
                $mSession->claseMensaje = 'confirmacion';

                $this->_forward('view', 'servicio', null, array('id' => $codigo));

            } catch (Exception $e) {

                $mSession->mensajes[] = 'Ocurrió un error al intentar habilitar el servicio para la venta.';
                $mSession->mensajes[] = $e->getMessage();
                $mSession->claseMensaje = 'error';
                $this->_forward('index','servicio');
            }
        }
    }
}