<?php
class SistemaMargenesDefaultController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Márgenes por defecto';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $margen = new Default_Model_SistemaMargenDefault();
        $this->view->margenes = $margen->getAll();
        $this->view->title = 'Márgenes por defecto';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_SistemaMargenDefault();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $margen = new Default_Model_SistemaMargenDefault();
                    $margen->crear($form->getValues());
                    $mSession->mensajes[] = 'El rango para aplicar un margen por defecto fue creado de forma satisfactoria.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_redirect('/sistema-margenes-default');
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el rango de márgenes por defecto.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-margenes-default');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $margen = new Default_Model_SistemaMargenDefault();
        $request = $this->getRequest();
        $form = new Default_Form_SistemaMargenDefault();
        
        if ($this->getRequest()->isPost()) {
            if($form->isValid($request->getPost())) {
                try {
                    
                    $margen->editar($form->getValues(), $form->getValue('id'));
                    $mSession->mensajes[] = 'El margen fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    
                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar guardar los cambios.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    
                }
                $this->_redirect('/sistema-margenes-default');
            } else {
                $form->populate($request->getPost());
            }
        }
        
        $id = (int)$this->_getParam('id');
        $margen->setId($id);
        $form->populate($margen->getRow()->toArray());
        $form->submit->setLabel('Editar rango');
        $form->setAction('/sistema-margenes-default/edit');
        $this->view->form = $form;
        $this->renderScript('partes-comunes/form-simple.phtml');
    }
    
    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {

            $margen = new Default_Model_SistemaMargenDefault();
            $margen->setId($id);
            $margen->eliminar();
            
            $mSession->mensajes[] = "El rango fue eliminado de forma satisfactoria";
            $mSession->claseMensaje = "confirmacion";
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar eliminar el margen";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            
        }
        $this->_redirect('/sistema-margenes-default');
    }
}