<?php
class SistemaUsuarioController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Usuarios';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }

    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $usuario = new Default_Model_SistemaUsuario();
        $this->view->usuarios = $usuario->getAll();
        $this->view->title = 'Usuarios';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_SistemaUsuario();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                 try {

                    $usuario = new Default_Model_SistemaUsuario();
                    $id = $usuario->crear($form->getValues());
                    $mSession->mensajes[] = 'El usuario fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-usuario/view/' . $id);
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el usuario.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Agregar un usuario al sistema";
        $this->view->form = $form;
        $this->renderScript('sistema-usuario/form.phtml');
    }
    
    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $usuario = new Default_Model_SistemaUsuario();
        $request = $this->getRequest();
        
        $form = new Default_Form_SistemaUsuario();
        $form->id->setRequired(true);
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $usuario->editar($form->getValues(), $form->getValue('id'));
                    $mSession->mensajes[] = 'El usuario fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_redirect('/sistema-usuario/view/' . $form->getValue('id'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el usuario.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        
        $id = (int)$this->_getParam('id');
        $usuario->setId($id);
        
        $form->setAction('/sistema-usuario/edit');
        $form->submit->setLabel('Guardar cambios');
        $form->populate($usuario->getRow()->toArray());
        $form->id->setValue($id);
        $this->view->title = "Editar usuario del sistema";
        $this->view->form = $form;
        $this->renderScript('sistema-usuario/form.phtml');
    }
    
    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $usuario = new Default_Model_SistemaUsuario();
            $usuario->setId($id);
            $this->view->usuarioSistema = $usuario->getRow();
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar visualizar '
                                  . 'el registro del usuario';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            
            $this->_redirect('/sistema-usuario');
        }
    }
    
    public function desactivarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $usuario = new Default_Model_SistemaUsuario();
            $usuario->setId($id);
            $usuario->setEstado('DESHABILITADO');
            $mSession->mensajes[] = 'El usuario fue desactivado exitósamente y no '
                                  . 'podrá volver a ingresar al sistema hasta ser '
                                  . 'activado nuevamente.';
            $mSession->claseMensaje = 'confirmacion';
            
            $this->_redirect('/sistema-usuario/view/' . $id);

        } catch(Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar desactivar el '
                                  . 'acceso del usuario al sistema.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            
            $this->_redirect('/sistema-usuario/view/' . $id);
        }
    }

    public function activarAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $usuario = new Default_Model_SistemaUsuario();
            $usuario->setId($id);
            $usuario->setEstado('ACTIVO');
            $mSession->mensajes[] = 'El usuario fue activado exitósamente y se '
                                  . 'encuentra habilitado para ingresar al sistema';
            $mSession->claseMensaje = 'confirmacion';
            
            $this->_redirect('/sistema-usuario/view/' . $id);

        } catch(Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar activar el '
                                  . 'acceso del usuario al sistema.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            
            $this->_redirect('/sistema-usuario/view/' . $id);
        }
    }

    public function informeNoRequerirAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $usuario = new Default_Model_SistemaUsuario();
            $usuario->setId($id);
            $usuario->setEstadoInforme('DESHABILITADO');
            $mSession->mensajes[] = 'Al usuario ya no se le solicitarán los informes diarios.';
            $mSession->claseMensaje = 'confirmacion';
            
            $this->_redirect('/sistema-usuario/view/' . $id);

        } catch(Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar deshabilitar el informe de producción diaria.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            
            $this->_redirect('/sistema-usuario/view/' . $id);
        }
    }

    public function informeRequerirAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $usuario = new Default_Model_SistemaUsuario();
            $usuario->setId($id);
            $usuario->setEstadoInforme('ACTIVO');
            $mSession->mensajes[] = 'Al usuario se le solicitará diariamente el informe de producción.';
            $mSession->claseMensaje = 'confirmacion';
            
            $this->_redirect('/sistema-usuario/view/' . $id);

        } catch(Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar habilitar el usuario para el informe de producción';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            
            $this->_redirect('/sistema-usuario/view/' . $id);
        }
    }
    
    public function cambiarClaveAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_SistemaUsuarioCambiarClave();
        $this->view->title = 'Cambiar clave';

        if($this->getRequest()->isPost()){
            if($form->isValid($request->getPost())){

                try {
                    $usuario = new Default_Model_SistemaUsuario();
                    $usuario->setId($this->usuario->id);
                    $usuario->verificarClaveActual($form->getValue('clave_actual'));
                    $usuario->cambiarClave($form->getValue('clave_nueva'));
                    
                    $mSession->mensajes[] = 'Su clave fue cambiada de forma satisfactoria. Deberá ingresarla a contar de su próximo ingreso.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/sistema-usuario/cambiar-clave');
                    
                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar cambiar la clave, por favor inténtelo más tarde.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/sistema-usuario/cambiar-clave');
                }
                
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
    }
    
    public function configurarAclAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        $usuario = new Default_Model_SistemaUsuario();
        $usuario->setId($id);
        
        $this->view->usuarioSistema = $usuario->getRow();
    }
}