<?php
class SolicitudBodegaController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $action = $this->getRequest()->getActionName();
        if($action != 'export-pdf' AND $action != 'create-pdf'){
            $auth = Zend_Auth::getInstance();
            if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
                $this->_redirect('/sistema-acceso/logout');
            }
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Solicitudes de compra :: Bodega';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();

        $this->view->propietario = Default_Model_SistemaPropietario::get();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $solicitud = new Default_Model_SolicitudCompra();
        $solicitudes = $solicitud->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type'),
            'BODEGA'
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $solicitud->getOrderByOptions();
        $this->view->orderBy = $solicitud->getOrderBy();
        $this->view->orderType = $solicitud->getOrderType();
        $this->view->action = '/solicitud-bodega/index/';
        $this->view->solicitudes = $solicitudes;
        $this->view->title = 'Solicitudes de compra :: Bodegas';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_SolicitudBodega();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    $solicitud = new Default_Model_SolicitudCompra();
                    $id = $solicitud->crear($form->getValues(), 'BODEGA', $this->usuario->id);
                    $mSession->mensajes[] = 'La solicitud de compra fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_redirect('/solicitud-bodega/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la solicitud de compra.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/solicitud-bodega/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Crear solicitud de compra de artículo";
        $this->view->form = $form;
        $this->renderScript('solicitud-bodega/form.phtml');
    }
    
    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $solicitud = new Default_Model_SolicitudCompra();
        $request = $this->getRequest();
        $form = new Default_Form_SolicitudBodega();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $id = $form->getValue('id');
                    $solicitud->editar($form->getValues(), 'BODEGA', $id);
                    $mSession->mensajes[] = 'La solicitud de compra fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_redirect('/solicitud-bodega/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la solicitud de compra.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/solicitud-bodega/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Editar solicitud de compra de artículo";
        $id = (int)$this->_getParam('id');
        $solicitud->setId($id);
        
        $form->submit->setLabel('Guardar');
        $form->id->setValue($id);
        $form->setAction('/solicitud-compra/edit');
        $form->populate($solicitud->getRow()->toArray());
        $this->view->form = $form;
        $this->renderScript('solicitud-compra/form.phtml');
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');

        try {
            
            $solicitud = new Default_Model_SolicitudCompra();
            $solicitud->setId($id);
            
            if($solicitud->getEstado()=='BORRADOR') {
                $solicitud->setEstado('PENDIENTE');
                $mSession->mensajes[] = 'La solicitud fue enviada a adquisiciones.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_redirect('/solicitud-bodega/view/' . $id);
            } else {
                
                $mSession->mensajes[] = 'La solicitud de repuestos y servicios no tiene ítems o su estado no se puede modificar.';
                $mSession->claseMensaje = 'error';
                $this->_redirect('/solicitud-bodega/view/' . $id);
            }
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar terminar la solicitud de repuestos y servicios.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/solicitud-bodega/index/1/id/DESC' . $id);
        }
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        
        try {
            $solicitud = new Default_Model_SolicitudCompra();
            $solicitud->setId($id);
            $this->view->title = "Solicitud de compra Nº $id";
            $this->view->solicitud = $solicitud->getRowFull();
            if($solicitud->getEstado()=='BORRADOR') {
                $this->renderScript('solicitud-bodega/view-borrador.phtml');
            } else {
                $this->renderScript('solicitud-bodega/view.phtml');
            }
        } catch(Exception $e){
            $mSession->mensajes[] = 'Ocurrió un error al intentar visualizar la solicitud de repuestos y servicios.';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/solicitud-bodega/index/1/id/DESC');
        }
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
            
        $id = (int)$this->_getParam('id');
        
        try {
            
            $solicitud = new Default_Model_SolicitudCompra();
            $solicitud->setId($id);
            $solicitud->eliminar();
            $mSession->mensajes[] = 'La solicitud de compra fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/solicitud-bodega/index/1/id/DESC');
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la solicitud de repuestos y servicios';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/solicitud-bodega/index/1/id/DESC');
            
        }
    }
}