<?php
class TarjetaCreditoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->title = 'Tarjeta Crédito';
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }
    
    public function indexAction()
    {
        $this->_redirect($this->path . '/list');
    }


    public function listAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $tarjetas = new Default_Model_VistaTarjetasCredito();
        $this->view->tarjetas = $tarjetas->fetchAll();
    }


    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_TarjetaCredito(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    $tarjeta = new Default_Model_TarjetaCredito();
                    $row = $tarjeta->createRow();
                    $row->cuenta_corriente_id = $form->getValue('cuenta_corriente_id');
                    $row->tipo = $form->getValue('tipo');
                    $row->numero = $form->getValue('numero');
                    $row->cupo = $form->getValue('cupo');
                    $row->expira_month = $form->getValue('expira_month');
                    $row->expira_year = $form->getValue('expira_year');
                    $row->save();
                    $mSession->mensajes[] = 'La tarjeta de crédito fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la tarjeta de crédito.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_redirect($this->path . '/list');

            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
    }


    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_TarjetaCredito(null, $this->path);
        $form->setAction($this->path . '/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $tarjeta = new Default_Model_TarjetaCredito();

                    $id = (int)$form->getValue('id');

                    $row = $tarjeta->fetchRow('id='.$id);
                    $row->cuenta_corriente_id = $form->getValue('cuenta_corriente_id');
                    $row->tipo = $form->getValue('tipo');
                    $row->numero = $form->getValue('numero');
                    $row->cupo = $form->getValue('cupo');
                    $row->expira_month = $form->getValue('expira_month');
                    $row->expira_year = $form->getValue('expira_year');
                    $row->save();
                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_redirect($this->path . '/list/');

            } else {
                $form->populate($request->getPost());
            }
        } else {
            $id = (int)$this->_request->getParam('id', 0);
            if ($id > 0) {
                $tarjeta = new Default_Model_TarjetaCredito();
                $registro = $tarjeta->fetchRow('id='.$id);
                $form->populate($registro->toArray());
            }
        }
        $this->view->form = $form;
    }


    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_Delete();
        $form->setAction($this->path . '/delete');

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                $tarjeta = new Default_Model_TarjetaCredito();
                $where = 'id = '. $form->getValue('id');
                $tarjeta->delete($where);
                $mSession->mensajes[] = 'El registro fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_redirect($this->path . '/list');
            }
        } else {
            $id = (int)$this->_request->getParam('id', 0);
            if ($id > 0) {
                $tarjeta = new Default_Model_TarjetaCredito();
                $this->view->tarjeta = $tarjeta->fetchRow('id='.$id);
                $form->id->setValue($id);
            }
        }
        $this->view->form = $form;
    }


    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_request->getParam('id', 0);
        $tarjeta = new Default_Model_TarjetaCredito();
        $tarjeta->setId($id);
        $this->view->tarjeta = $tarjeta->getRowById();
        if(false==$this->view->tarjeta) {
            $this->_redirect($this->path . '/list');
        }
    }

}