<?php
class TipoEnvaseController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Tipos de envase';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $currentPage = $this->_getParam('page', 1);
        $tipo = new Default_Model_TipoEnvase();
        $order = "nombre";
        $tipos = $tipo->fetchAll(null, $order)->toArray();
        $paginador = Zend_Paginator::factory($tipos);
        $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                  ->setPageRange($this->paginacion['cant_pages'])
                  ->setCurrentPageNumber($currentPage);
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        $this->view->tipos = $paginador;
        $this->view->title = 'Tipos de envases';
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_TipoEnvase();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    $tipo = new Default_Model_TipoEnvase();
                    $row = $tipo->createRow();
                    $row->nombre = $form->getValue('nombre');
                    $row->save();
                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_redirect('/tipo-envase/index/1/nombre/ASC');
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = 'Crear tipo de envase';
        $this->view->form = $form;
        $this->renderScript('tipo-envase/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $tipo = new Default_Model_TipoEnvase();
        $request = $this->getRequest();
        $form = new Default_Form_TipoEnvase();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $where = $tipo->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $tipo->fetchRow($where);
                    $row->nombre = $form->getValue('nombre');
                    $row->save();
                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_redirect('/tipo-envase/index/1/nombre/ASC');

            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $where = $tipo->getAdapter()->quoteInto("id=?", $id);
        $registro = $tipo->fetchRow($where);
        $form->populate($registro->toArray());
        $form->setAction('/tipo-envase/edit');
        $form->submit->setLabel("guardar cambios");
        $this->view->title = 'Editar tipo de envase';
        $this->view->form = $form;
        $this->renderScript('tipo-envase/form.phtml');
    }

    public function deleteAction()
    {
        if($this->_getParam('id')){
            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            try {
                $model = new Default_Model_TipoEnvase();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);
                $mSession->mensajes[] = 'El tipo de envase fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_redirect('/tipo-envase/index/1/nombre/ASC');
            } catch (Exception $e) {
                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();
                $this->_forward('/error/error-delete-registro');
            }
        }
    }
}