<?php
class TipoManoObraController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function indexAction()
    {
       if($this->getRequest()->isXmlHttpRequest()){

           $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $currentPage = $this->_getParam('page', 1);

            $tipo = new Default_Model_TipoManoObra();
            $tipos = $tipo->fetchAll();

            $paginador = Zend_Paginator::factory($tipos);
            $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                      ->setPageRange($this->paginacion['cant_pages'])
                      ->setCurrentPageNumber($currentPage);

            Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

            $this->view->tipos = $paginador;
            $this->view->title = 'Tipos de mano de obra';

            $this->renderScript('tipo-mano-obra/index.phtml');
       }
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_TipoManoObra(null, $this->path);

            if($this->_request->getParam('id')) {

                $tipo = new Default_Model_TipoManoObra();
                $where = $tipo->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $tipo->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/tipo-mano-obra/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar tipo mano de obra";

            } else {

                $this->view->title = "Crear tipo de mano de obra";

            }
            $this->view->form = $form;
            $this->renderScript('tipo-mano-obra/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_TipoManoObra(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $tipo = new Default_Model_TipoManoObra();
                    $row = $tipo->createRow();
                    $row->nombre = $form->getValue('nombre');
                    $row->neto_hora = $form->getValue('neto_hora');
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->tipo_error = 1;
                    $mSession->errores[] = $e->getMessage();

                    $this->_forward('error-new-registro','error');

                }

                $this->_forward('index', 'tipo-mano-obra');

            } else {
                $this->view->title = 'Crear tipo de mano de obra';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('tipo-mano-obra/form.phtml');
            }
        }
        $this->view->form = $form;
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $tipo = new Default_Model_TipoManoObra();

        $request = $this->getRequest();
        $form = new Default_Form_TipoManoObra(null, $this->path);
        $form->setAction($this->path . '/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $where = $tipo->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $tipo->fetchRow($where);
                    $row->nombre = $form->getValue('nombre');
                    $row->neto_hora = $form->getValue('neto_hora');
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                }

                $this->_forward('index', 'tipo-mano-obra');

            } else {
                $this->view->title = 'Editar tipo de mano de obra';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('tipo-mano-obra/form.phtml');
            }
        } else {

            if ($this->_request->getParam('id')) {

                $where = $tipo->getAdapter()->quoteInto("id=?", $this->_request->getParam('id'));
                $registro = $tipo->fetchRow($where);
                $form->populate($registro->toArray());
            }
        }
        $this->view->form = $form;
    }

    public function deleteAction()
    {
        if($this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {

                $model = new Default_Model_TipoManoObra();
                $where = $model->getAdapter()->quoteInto("id=?" , (int)$this->_getParam('id'));
                $model->delete($where);

                $mSession->mensajes[] = 'El tipo de mano de obra fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

                $this->_forward('index','tipo-mano-obra');

            } catch (Exception $e) {
                
                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();

                $this->_forward('error-delete-registro','error');
            }
        }
    }
}