<?php
class TipoRepuestoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->path = '/tipo-repuesto';
        $this->view->pageTitle = 'Tipos de repuestos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $currentPage = $this->_getParam('page', 1);
        $tipo = new Default_Model_TipoRepuesto();
        $order = "id";
        $tipos = $tipo->fetchAll(null, $order);
        $paginador = Zend_Paginator::factory($tipos);
        $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                  ->setPageRange($this->paginacion['cant_pages'])
                  ->setCurrentPageNumber($currentPage);
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        $this->view->tipos = $paginador;
        $this->view->title = 'Tipos de repuestos';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_TipoRepuesto();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {

                    $tipo = new Default_Model_TipoRepuesto();
                    $row = $tipo->createRow();
                    $row->nombre = $form->getValue('nombre');
                    $row->abreviacion = strtoupper($form->getValue('abreviacion'));
                    $row->save();
                    $mSession->mensajes[] = 'El tipo de repuesto fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/tipo-repuesto/index/1/nombre/ASC');

                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/error/error-delete-registro');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = 'Agregar tipo de repuesto';
        $this->view->form = $form;
        $this->renderScript('tipo-repuesto/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $tipo = new Default_Model_TipoRepuesto();

        $request = $this->getRequest();
        $form = new Default_Form_TipoRepuesto();
        $form->setAction('/tipo-repuesto/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $where = $tipo->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $tipo->fetchRow($where);
                    $row->nombre = $form->getValue('nombre');
                    $row->abreviacion = strtoupper($form->getValue('abreviacion'));
                    $row->save();
                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                }
                $this->_redirect('/tipo-repuesto/index/1/nombre/ASC');
            } else {
                $form->populate($request->getPost());
            }
        } else {
            if ($this->_request->getParam('id')) {
                $where = $tipo->getAdapter()->quoteInto("id=?", $this->_request->getParam('id'));
                $registro = $tipo->fetchRow($where);
                $form->populate($registro->toArray());
            }
        }
        $this->view->title = 'Editar tipo de repuesto';
        $this->view->form = $form;
        $this->renderScript('tipo-repuesto/form.phtml');
    }


    public function deleteAction()
    {
        if($this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {

                $model = new Default_Model_TipoRepuesto();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);

                $mSession->mensajes[] = 'El tipo de repuesto fue eliminado de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_redirect('/tipo-repuesto/index/1/nombre/ASC');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();
                $this->_forward('error-delete-registro','error');

            }
        }
    }
}