<?php
class UnidadMedidaController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->path = '/unidad-medida';
        $this->view->pageTitle = 'Unidades de medida';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $currentPage = $this->_getParam('page', 1);

        $unidad = new Default_Model_UnidadMedida();
        $unidades = $unidad->fetchAll();

        $paginador = Zend_Paginator::factory($unidades);
        $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                  ->setPageRange($this->paginacion['cant_pages'])
                  ->setCurrentPageNumber($currentPage);

        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');

        $this->view->unidades = $paginador;
        $this->view->title = 'Unidades de medida';
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_UnidadMedida(null, $this->path);

            if($this->_request->getParam('id')) {

                $unidad = new Default_Model_UnidadMedida();
                $where = $unidad->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $unidad->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/unidad-medida/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar unidad de medida";

            } else {

                $this->view->title = "Agregar unidad de medida";

            }
            $this->view->form = $form;
            $this->renderScript('unidad-medida/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_UnidadMedida(null, $this->path);

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {

                    $unidad = new Default_Model_UnidadMedida();
                    $row = $unidad->createRow();
                    $row->nombre = $form->getValue('nombre');
                    $row->simbolo = $form->getValue('simbolo');
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                }

                $this->_forward('index', 'unidad-medida');

            } else {
                $this->view->title = 'Crear unidad de medida';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('unidad-medida/form.phtml');
            }
        }
        $this->view->form = $form;
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $unidad = new Default_Model_UnidadMedida();

        $request = $this->getRequest();
        $form = new Default_Form_UnidadMedida();
        $form->setAction($this->path . '/edit');
        $form->submit->setLabel("guardar cambios");

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {

                    $where = $unidad->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $unidad->fetchRow($where);
                    $row->nombre = $form->getValue('nombre');
                    $row->simbolo = $form->getValue('simbolo');
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                }

                $this->_forward('index', 'unidad-medida');

            } else {
                $this->view->title = 'Editar unidad medida';
                $form->populate($request->getPost());
                $this->view->form = $form;
                $this->renderScript('unidad-medida/form.phtml');
            }
        } else {
            if ($this->_request->getParam('id')) {

                $where = $unidad->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $registro = $unidad->fetchRow($where);
                $form->populate($registro->toArray());
            }
        }
        $this->view->form = $form;
    }

    public function deleteAction()
    {
        if($this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {

                $model = new Default_Model_UnidadMedida();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);

                $mSession->mensajes[] = 'La unidad de medida fue eliminada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

                $this->_forward('index','unidad-medida');

            } catch (Exception $e) {

                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();

                $this->_forward('error-delete-registro','error');

            }
        }
    }
}