<?php
class VehiculoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Vehículos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $vehiculo = new Default_Model_Vehiculo();
        $vehiculos = $vehiculo->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $vehiculo->getOrderByOptions();
        $this->view->orderBy = $vehiculo->getOrderBy();
        $this->view->orderType = $vehiculo->getOrderType();
        $this->view->action = '/vehiculo/index/';
        $this->view->vehiculos = $vehiculos;
        $this->view->title = 'Vehículos';
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_Vehiculo();
        $form->modelo_id->setMultiOptions(Default_Model_VehiculoModelo::getPairsToSelect());
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $vehiculo = new Default_Model_Vehiculo();
                    $id = $vehiculo->crear($form->getValues(), $this->usuario->id);
                    $mSession->mensajes[] = 'El vehículo fue agregado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/vehiculo/view/' . $id);

                } catch(Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar agregar el vehículo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/vehiculo/index/1/marca/ASC');
                }
            }  else {
                $form->populate($request->getPost());
            }
        }
        $form->modelo_id->setMultiOptions(array('' => '-- Seleccionar --'));
        $this->view->title = "Agregar vehículo";
        $this->view->form = $form;
        $this->renderScript('vehiculo/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $vehiculo = new Default_Model_Vehiculo();
        $request = $this->getRequest();
        $form = new Default_Form_Vehiculo();
        $form->modelo_id->setMultiOptions(Default_Model_VehiculoModelo::getPairsToSelect());

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {

                    $id = $form->getValue('id');
                    $vehiculo->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'El vehículo fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/vehiculo/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/vehiculo/index/1/marca/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = $this->_getParam('id');
        $vehiculo->setId($id);
        $dataVehiculo = $vehiculo->getRow()->toArray();
        $form->populate($dataVehiculo);
        $form->marca_id->setValue($vehiculo->getMarcaId($dataVehiculo['modelo_id']));
        $form->submit->setLabel('Guardar cambios');
        $form->setAction('/vehiculo/edit');
        $form->id->setValue($id);
        $this->view->title = 'Editar vehículo';
        $this->view->form = $form;
        $this->renderScript('vehiculo/form.phtml');
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = $this->_getParam('id');
        $vehiculo = new Default_Model_Vehiculo();
        $vehiculo->setId($id);
        $this->view->vehiculo = $vehiculo->getRowFull();
        $this->view->pauta = $vehiculo->getPautaMantenimiento();
        $this->view->servicios = $vehiculo->getHistorialDeServicio();
        $this->view->title = 'Vehículo';
    }

    public function viewPopupAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $this->_helper->layout->disableLayout();
            
            $id = (int)$this->_getParam('id');
            $vehiculo = new Default_Model_Vehiculo();
            $vehiculo->setId($id);
            $this->view->vehiculo = $vehiculo->getRow();
        }
    }
    
    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            $vehiculo = new Default_Model_Vehiculo();
            $vehiculo->setId($id);
            $vehiculo->eliminar();
            $mSession->mensajes[] = 'El vehículo fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/vehiculo/index/1/marca/ASC');
            
        } catch (Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el vehículo';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/vehiculo/index/1/marca/ASC');
        }
    }

    public function searchTooltipAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();
            
            $filter_tags    = new Zend_Filter_StripTags();
            $criterio       = $filter_tags->filter(trim($this->_getParam('criterio')));
            $valor          = $filter_tags->filter(trim($this->_getParam('valor')));
            $this->view->t  = $filter_tags->filter(trim($this->_getParam('t')));
            
            $vehiculo = new Default_Model_Vehiculo();
            $this->view->vehiculos = $vehiculo->searchToTooltip($criterio, $valor);
            $this->renderScript('vehiculo/search.phtml');
        }
    }
    
    public function seleccionarPautaMantenimientoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){

            $this->_helper->layout->disableLayout();
            
            $id = (int)$this->_getParam('id');
            $modeView = $this->_getParam('mode_view');
            if($modeView=='0'){
                $this->view->pautas = Default_Model_PautaMantenimiento::getAllToSelect();
            } else {
                $this->view->pautas = Default_Model_PautaMantenimientoModelo::getAllToSelect($id);
            }
        }
    }
    
    public function historialAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $id = (int)$this->_getParam('id');
            try{
                $vehiculo = new Default_Model_Vehiculo();
                $vehiculo->setId($id);
                $this->view->servicios = $vehiculo->getUltimosServicios(10);
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    
    /*
    public function listByClienteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $vehiculo = new Default_Model_Vehiculo();
            $vehiculo->setCliente($id);
            $this->view->vehiculos = $vehiculo->getVehiculos();
            $this->view->cliente = $vehiculo->getCliente();
            
            $form = new Default_Form_FilterByCliente();
            $form->setAction('/vehiculo/fliter-by-cliente/');
            
            $this->view->form = $form;
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar el listado de vehículos asociados al cliente";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/cliente/view/' . $id);
        }
    }
    public function asignarPautaAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $patente = strtoupper($this->_getParam('patente'));
        $pauta_id = (int)$this->_getParam('pauta_id');

        try {

            $vehiculo = new Default_Model_Vehiculo();
            $vehiculo->asignarPauta($pauta_id);

            $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

        } catch (Exception $e) {

            $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

        }
        
    }

    public function eliminarAsociacionPautaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('patente') AND
           $this->_helper->validateRecordExists('vehiculos', 'patente', $this->_getParam('patente'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $patente = $this->_getParam('patente');

            try {

                $vehiculo = new Default_Model_Vehiculo();
                $where = $vehiculo->getAdapter()->quoteInto("patente=?", $patente);
                $row = $vehiculo->fetchRow($where);
                $row->pauta_id = null;
                $row->save();

                $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

            } catch (Exception $e) {

                $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

            }
        }
    }
    */
}