<?php
class VehiculoMarcaController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Marcas de vehículos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $marca = new Default_Model_VehiculoMarca();
        $marcas = $marca->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $marca->getOrderByOptions();
        $this->view->orderBy = $marca->getOrderBy();
        $this->view->orderType = $marca->getOrderType();
        $this->view->action = '/vehiculo-marca/index/';
        $this->view->marcas = $marcas;
        $this->view->title = 'Marcas de vehículos';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaMarcasVehiculos();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $request = $this->getRequest();
        $form = new Default_Form_VehiculoMarca();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $marca = new Default_Model_VehiculoMarca();
                    $marca->crear($form->getValues());
                    $mSession->mensajes[] = 'La marca de vehículos fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/vehiculo-marca/index/1/nombre/ASC');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la marca de vehículos.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/vehiculo-marca/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Agregar marca de vehículo";
        $this->view->form = $form;
        $this->renderScript('vehiculo-marca/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $marca = new Default_Model_VehiculoMarca();
        $request = $this->getRequest();
        $form = new Default_Form_VehiculoMarca();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $marca->editar($form->getValues(), $form->getValue('id'));
                    $mSession->mensajes[] = 'la marca de vehículos fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/vehiculo-marca/index/1/nombre/ASC');

                } catch (Exception $e) {
                    
                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la marca de vehículos.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/vehiculo-marca/index/1/nombre/ASC');
                }
                
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Editar marca de vehículo";
        $id = (int)$this->_getParam('id');
        $marca->setId($id);
        $form->populate($marca->getRow()->toArray());
        $form->setAction('/vehiculo-marca/edit');
        $form->submit->setLabel("Guardar cambios");
        $this->view->form = $form;
        $this->renderScript('vehiculo-marca/form.phtml');
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');

        try {

            $marca = new Default_Model_VehiculoMarca();
            $marca->setId($id);
            $marca->eliminar();
            $mSession->mensajes[] = 'La marca de vehículos fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/vehiculo-marca/index/1/nombre/ASC');

        } catch (Exception $e) {

            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la marca de vehículos';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/vehiculo-marca/index/1/nombre/ASC');
        }
        
    }
}