<?php
class VehiculoModeloController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/sistema-acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Modelos de vehículos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }

    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $modelo = new Default_Model_VehiculoModelo();
        $modelos = $modelo->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $modelo->getOrderByOptions();
        $this->view->orderBy = $modelo->getOrderBy();
        $this->view->orderType = $modelo->getOrderType();
        $this->view->action = '/vehiculo-modelo/index/';
        $this->view->modelos = $modelos;
        $this->view->title = 'Modelos de vehículos';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaModelosVehiculos();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $request = $this->getRequest();
        $form = new Default_Form_VehiculoModelo();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $modelo = new Default_Model_VehiculoModelo();
                    $modelo->crear($form->getValues());
                    $mSession->mensajes[] = 'El modelo de vehículo fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/vehiculo-modelo/index/1/marca/ASC');

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el modelo de vehículo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/vehiculo-modelo/index/1/marca/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Agregar modelo de vehículo";
        $this->view->form = $form;
        $this->renderScript('vehiculo-modelo/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $modelo = new Default_Model_VehiculoModelo();
        $request = $this->getRequest();
        $form = new Default_Form_VehiculoModelo();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    $id = (int)$form->getValue('id');
                    $modelo->editar($form->getValues(), $id);
                    $mSession->mensajes[] = 'El modelo de vehículo fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/vehiculo-modelo/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el modelo de vehículo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/vehiculo-modelo/index/1/marca/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->title = "Editar modelo de vehículo";
        $id = (int)$this->_getParam('id');
        $modelo->setId($id);
        $form->populate($modelo->getRow()->toArray());
        $form->setAction('/vehiculo-modelo/edit');
        $form->submit->setLabel('Guardar cambios');
        $this->view->form = $form;
        $this->renderScript('/vehiculo-modelo/form.phtml');
    }

    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');

        try {
           
            $modelo = new Default_Model_VehiculoModelo();
            $modelo->setId($id);
            $this->view->modelo = $modelo->getRowFull();
            $this->view->title = 'Modelo de vehículo';
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar el registro.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/vehiculo-modelo/index/1/marca/ASC');
        }
    }
    
    public function detalleAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $id = (int)$this->_getParam('id');
            try {
                $modelo = new Default_Model_VehiculoModelo();
                $modelo->setId($id);
                $this->view->modelo = $modelo->getRowFull();
                $this->view->num_informaciones = $modelo->getNumInformacionesAdicionales();
                $this->view->informaciones = $modelo->getInformacionesAdicionales();
                
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $id = (int)$this->_getParam('id');
        
        try {
            
            $modelo = new Default_Model_VehiculoModelo();
            $modelo->setId($id);
            $modelo->eliminar();
            $mSession->mensajes[] = 'El modelo de vehículo fue eliminado de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/vehiculo-modelo/index/1/marca/ASC');
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar el modelo de vehículo';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/vehiculo-modelo/index/1/marca/ASC');
            
        }
    }
   
    public function pautasAsociadasAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            $this->_helper->layout->disableLayout();
            $id = (int)$this->_getParam('id');
            try{
                $modelo = new Default_Model_VehiculoModelo();
                $modelo->setId($id);
                $this->view->informaciones = $modelo->getPautasAsociadas();
            } catch(Exception $e){
                echo $e->getMessage();
            }
        }
    }
    
    public function asignarPautaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('pauta_id') AND
           $this->_helper->validateRecordExists('pautas_mantenciones', 'id', $this->_getParam('pauta_id')) AND 
           $this->_getParam('modelo_id') AND
           $this->_helper->validateRecordExists('modelos_vehiculos', 'id', $this->_getParam('modelo_id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $modelo_id = $this->_getParam('modelo_id');
            $pauta_id = (int)$this->_getParam('pauta_id');

            try {

                $pautaModelo = new Default_Model_PautaModelo();
                $where = "pauta_id='$pauta_id' AND modelo_id='$modelo_id'";
                $row = $pautaModelo->fetchRow($where);

                if(!$row){
                    $new = $pautaModelo->createRow();
                    $new->modelo_id = $modelo_id;
                    $new->pauta_id = $pauta_id;
                    $new->save();
                }

                $this->_forward('view', 'modelo-vehiculo', null, array('id' => $modelo_id));

            } catch (Exception $e) {

                $this->_forward('view', 'modelo-vehiculo', null, array('id' => $modelo_id));

            }
        }
    }

    public function eliminarAsociacionPautaAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('patente') AND
           $this->_helper->validateRecordExists('vehiculos', 'patente', $this->_getParam('patente'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $patente = $this->_getParam('patente');

            try {

                $vehiculo = new Default_Model_Vehiculo();
                $where = $vehiculo->getAdapter()->quoteInto("patente=?", $patente);
                $row = $vehiculo->fetchRow($where);
                $row->pauta_id = null;
                $row->save();

                $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

            } catch (Exception $e) {

                $this->_forward('view', 'vehiculo', null, array('patente' => $patente));

            }
        }
    }
}