<?php
class VehiculoRecepcionController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        $action = $this->getRequest()->getActionName();
        if($action != 'export-pdf' AND $action != 'create-pdf'){
            $auth = Zend_Auth::getInstance();
            if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
                $this->_redirect('/sistema-acceso/logout');
            }
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Recepción de vehículos';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
	
        $this->view->propietario = Default_Model_SistemaPropietario::get();
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
           //$response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $recepcion = new Default_Model_VehiculoRecepcion();
        $recepciones = $recepcion->getAll(
            $this->_getParam('page', 1), 
            $this->_getParam('order_by'), 
            $this->_getParam('order_type')
        );
        
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /*****************************************************************/
        $this->view->orderByOptions = $recepcion->getOrderByOptions();
        $this->view->orderBy = $recepcion->getOrderBy();
        $this->view->orderType = $recepcion->getOrderType();
        $this->view->action = '/recepcion/index/';
        $this->view->recepciones = $recepciones;
        $this->view->title = 'Recepciones';
    }

    public function findAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_BusquedaRecepcionesVehiculos();
        
        $this->view->form = $form;
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_RecepcionVehiculoSintomas();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                    
                $mSession->sintomas = $form->getValues();
                $this->_redirect('/vehiculo-recepcion/estado');
               
            } else {
                $form->populate($request->getPost());
            }
        }
        
        if($this->_request->getParam('from_id')) {
            $patente = strtoupper($this->_getParam('from_id'));
            $form->vehiculo->setValue($patente);
        }
        
        if($this->_getParam('id')){
            
            try {
                
                $id = (int)$this->_getParam('id');
                $recepcion = new Default_Model_VehiculoRecepcion();
                $recepcion->setId($id);
                $data = $recepcion->getRow()->toArray();
                $data['vehiculo'] = $recepcion->getPatenteByVehiculoId($data['vehiculo_id']);
                $mSession->estado = $data;
                $form->populate($data);
                
            } catch (Exception $e){
                
                $mSession->mensajes[] = "Ocurrió un error al intentar editar la recepción.";
                $mSession->mensajes[] = $e->getMessage();
                $mSession->claseMensaje = "error";
                $this->_redirect('/vehiculo-recepcion/index/1/id/DESC');
                
            }
        }
        
        $this->view->title = 'Crear recepción de vehículo';
        $this->view->form = $form;
        $this->renderScript('vehiculo-recepcion/form.phtml');
    }
    
    public function estadoAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_RecepcionVehiculoEstado();
        
        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $data = array_merge($mSession->sintomas, $form->getValues());
                    
                    $recepcion = new Default_Model_VehiculoRecepcion();
                    
                    if($data['id']){
                        $id = $recepcion->editar($data, $data['id']);
                    } else {
                        $id = $recepcion->crear($data, $this->usuario->id);
                    }
                    
                    unset($mSession->sintomas);
                    unset($mSession->estado);
                    
                    $mSession->mensajes[] = 'La recepción fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/vehiculo-recepcion/view/' . $id);

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la recpeción del vehículo.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/vehiculo-recepcion/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        
        if($mSession->sintomas['id']){
            $form->populate($mSession->estado);
        }
        
        $this->view->title = 'Recepción de vehículo: Estado';
        $this->view->form = $form;
        $this->renderScript('vehiculo-recepcion/form.phtml');
    }
    
    public function viewAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');

        try {
            
            $recepcion = new Default_Model_VehiculoRecepcion();
            $recepcion->setId($id);
            
            $this->view->title = "Recepción de vehículo Nº $id";
            $this->view->recepcion = $recepcion->getRowFull();
            $this->view->vehiculo = $recepcion->getVehiculo();
            
            if($recepcion->getEstado()=='BORRADOR') {
                $this->renderScript('vehiculo-recepcion/view-borrador.phtml');
            } else {
                $this->renderScript('vehiculo-recepcion/view.phtml');
            }
            
        } catch(Exception $e){
            
            $mSession->mensajes[] = "Ocurrió un error al intentar visualizar la recepción dle vehículo.";
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = "error";
            $this->_redirect('/vehiculo-recepcion/index/1/id/DESC');
            
        }
    }

    public function viewSmallAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            $this->_helper->viewRenderer->setNoRender();

            $id = (int)$this->_getParam('id');
            
            $recepcion = new Default_Model_VehiculoRecepcion();
            $recepcion->setId($id);
            $this->view->recepcion = $recepcion->getRow();
            $this->view->vehiculo = $recepcion->getVehiculo();
            $this->renderScript('vehiculo-recepcion/view-small.phtml');
        }
    }

    public function deleteAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $id = (int)$this->_getParam('id');
        
        try {
            
            $recepcion = new Default_Model_VehiculoRecepcion();
            $recepcion->setId($id);
            $mSession->mensajes[] = 'La recepción fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/vehiculo-recepcion/index/1/id/DESC');
            
        } catch(Exception $e) {
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar eliminar la recepción';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/vehiculo-recepcion/index/1/id/DESC');
            
        }
    }

    public function finishAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        $id = (int)$this->_getParam('id');
        try {
            $recepcion = new Default_Model_VehiculoRecepcion();
            $recepcion->setId($id);
            $recepcion->setEstado('TERMINADA');
            $mSession->mensajes[] = 'La recepción concluyó de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_redirect('/vehiculo-recepcion/view/' . $id);
            
        } catch (Exception $e) {
            
            $mSession->mensajes[] = 'Ocurrió un error al intentar terminar la recepción';
            $mSession->mensajes[] = $e->getMessage();
            $mSession->claseMensaje = 'error';
            $this->_redirect('/vehiculo-recepcion/view/' . $id);
            
        }
    }

    public function listByVehiculoAction()
    {
        if($this->getRequest()->isXmlHttpRequest()){
            
            $this->_helper->layout->disableLayout();
            
            $id = strtoupper($this->_getParam('id'));
            $recepcion = new Default_Model_VehiculoRecepcion();
            $this->view->recepciones = $recepcion->getRowsByVehiculo($id);
        }
    }

    public function printAction()
    {
        $this->_helper->layout->setLayout('print');

        $id = (int)$this->_getParam('id');
        
        try {
            
            $recepcion = new Default_Model_VehiculoRecepcion();
            $recepcion->setId($id);
            
            if($recepcion->getEstado()!=='TERMINADA'){
                $this->_redirect('/vehiculo-recepcion/view/' . $id);
            }
            
            $this->view->title = "Recepción Nº $id";
            $this->view->recepcion = $recepcion->getRow();
            $this->view->vehiculo = $recepcion->getVehiculo();
            $this->view->cliente = $recepcion->getCliente();
            $this->view->condiciones_generales = Default_Model_DocumentoCondicionGeneral::getTexto('RECEPCION_VEHICULO');
            
        } catch(Exception $e){
            echo $e->getMessage();
        }
    }
}