<?php
class CategoriaServicioController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Categorías de servicios';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
        }
    }
    
    public function indexAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $currentPage = $this->_getParam('page', 1);
        $categoria = new Default_Model_CategoriaServicio();
        $order = "nombre";
        $categorias = $categoria->fetchAll(null, $order);
        $paginador = Zend_Paginator::factory($categorias);
        $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                  ->setPageRange($this->paginacion['cant_pages'])
                  ->setCurrentPageNumber($currentPage);

        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        $this->view->categorias = $paginador;
        $this->view->title = 'Categorías de servicios';
    }

    public function getFormAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        if($this->getRequest()->isXmlHttpRequest()){

            $request = $this->getRequest();
            $form = new Default_Form_Categoria(null, $this->path);

            if($this->_request->getParam('id')) {

                $categoria = new Default_Model_CategoriaServicio();
                $where = $categoria->getAdapter()->quoteInto("id=?", (int)$this->_request->getParam('id'));
                $row = $categoria->fetchRow($where)->toArray();
                $form->populate($row);
                $form->setAction('/categoria-servicio/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar categoría de servicios";

            } else {

                $this->view->title = "Agregar categoría de servicios";

            }
            $this->view->form = $form;
            $this->renderScript('categoria-servicio/form.phtml');
        }
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }
        
        $request = $this->getRequest();
        $form = new Default_Form_Categoria(null);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
        
                    $categoria = new Default_Model_CategoriaServicio();
                    $row = $categoria->createRow();
                    $row->nombre = $form->getValue('nombre');
                    $row->save();

                    $mSession->mensajes[] = 'El registro fue creado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('/categoria-servicio/index/1/nombre/ASC');
                } catch (Exception $e) {
                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('/categoria-servicio/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $form->setAction('/categoria-servicio/new');
        $this->view->title = 'Crear categoría de servicios';
        $this->view->form = $form;
        $this->renderScript('categoria-servicio/form.phtml');
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $categoria = new Default_Model_CategoriaServicio();
        $request = $this->getRequest();
        $form = new Default_Form_Categoria(null, $this->path);

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                try {
                    
                    $where = $categoria->getAdapter()->quoteInto("id=?", (int)$form->getValue('id'));
                    $row = $categoria->fetchRow($where);
                    $row->nombre = $form->getValue('nombre');
                    $row->save();
                    $mSession->mensajes[] = 'El registro fue editado de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_redirect('/categoria-servicio/index/1/nombre/ASC');
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar el registro.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/categoria-servicio/index/1/nombre/ASC');
                }
            } else {
                $form->populate($request->getPost());
            }
        } 
        $id = (int)$this->_getParam('id');
        $where = $categoria->getAdapter()->quoteInto("id=?", $id);
        $registro = $categoria->fetchRow($where);
        $form->populate($registro->toArray());
        $form->setAction('/categoria-servicio/edit');
        $form->submit->setLabel("guardar cambios");
        $this->view->title = 'Editar categoría de servicios';
        $this->view->form = $form;
        $this->renderScript('categoria-servicio/form.phtml');
    }


    public function deleteAction()
    {
        if($this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            try {
                $model = new Default_Model_CategoriaServicio();
                $where = $model->getAdapter()->quoteInto("id = ?" , (int)$this->_getParam('id'));
                $model->delete($where);
                $mSession->mensajes[] = 'La categoría fue eliminada de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';
                $this->_redirect('/categoria-servicio/index/1/nombre/ASC');

            } catch (Exception $e) {
                $mSession->tipo_error = 1;
                $mSession->errores[] = $e->getMessage();
                $this->_redirect('/error/error-delete-registro');
            }
        }
    }
}