<?php
class DtBoletaController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Boletas';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            $response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {

        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        /* Paginación y orden de los los listados
         ****************************************************************/
        $orderByOptionsKeys = array('id', 'cliente');
        $orderByOptionsValues = array('Nº boleta', 'Cliente');
        $orderByOptions = array_combine($orderByOptionsKeys, $orderByOptionsValues);
        
        $orderTypeOptions = array('ASC', 'DESC');
        $currentPage = $this->_getParam('page', 1);

        if(in_array($this->_getParam('order_by'), $orderByOptionsKeys)) {
            $orderBy = $this->_getParam('order_by');
        } else {
            $orderBy = 'id';
        }

        if(in_array($this->_getParam('order_type'), $orderTypeOptions)) {
            $orderType = $this->_getParam('order_type');
        } else {
            $orderType = 'DESC';
        }

        $order = "$orderBy $orderType";
        $boleta = new Default_Model_VistaDtBoletas();
        $boletas = $boleta->fetchAll(null, $order);
        $paginador = Zend_Paginator::factory($boletas);
        $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                  ->setPageRange($this->paginacion['cant_pages'])
                  ->setCurrentPageNumber($currentPage);
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /****************************************************************/
        $this->view->orderByOptions = $orderByOptions;
        $this->view->orderBy = $orderBy;
        $this->view->orderType = $orderType;
        $this->view->action = '/dt-boleta/index/';
        $this->view->boletas = $paginador;
        $this->view->title = "Boletas de Venta";
    }

    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');
        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_DtBoleta();
        $boleta = new Default_Model_DtBoleta();

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                $db = $boleta->getAdapter();
                $db->beginTransaction();

                try {
                    
                    $notaVenta = new Default_Model_NotaVenta();
                    $whereNota = $notaVenta->getAdapter()->quoteInto("id=?", $form->getValue('nota_id'));
                    $rowNota = $notaVenta->fetchRow($whereNota);
                    
                    if($rowNota->estado=='TERMINADA') {
                        
                        $row = $boleta->createRow();
                        $row->creador = $this->usuario->rut;
                        $row->numero = $form->getValue('numero');
                        $row->nota_id = $form->getValue("nota_id");
                        $row->fecha_emision = $form->getValue('fecha');
                        $row->iva = $this->view->getPref('IVA');
                        $row->estado = 'BORRADOR';
                        $row->save();
                        $id = $row->id;
                        
                        $itemNotaVenta = new Default_Model_ItemNotaVenta();
                        $where = $itemNotaVenta->getAdapter()->quoteInto("nota_id=?", $form->getValue('nota_id'));
                        $itemsNotaVenta = $itemNotaVenta->fetchAll($where);

                        $itemDteBoleta = new Default_Model_DtItemBoleta();

                        foreach($itemsNotaVenta as $item){

                            $rowItem = $itemDteBoleta->createRow();
                            $rowItem->boleta_id = $id;
                            $rowItem->nombre = $item->nombre;
                            $rowItem->cantidad = $item->cantidad;
                            $rowItem->unidad_medida = $item->unidad_medida;
                            $rowItem->valor_neto = $item->valor_neto - $item->descuento;
                            $rowItem->save();
                        }
                        
                        $rowNota->estado = 'FACTURADA';
                        $rowNota->save();
                        
                        $db->commit();

                        $mSession->mensajes[] = 'La boleta fue creada de forma exitosa.';
                        $mSession->claseMensaje = 'confirmacion';
                        $this->_redirect('/dt-boleta/view/' . $id );
                        
                    } else {
                        $mSession->mensajes[] = 'Por favor seleccione una nota de venta terminada y no facturada';
                        $mSession->claseMensaje = 'error';
                        $this->_redirect('/dt-boleta/new/');
                        
                    }
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect('/dt-boleta/index/1/id/DESC');
                }
            } else {
                $form->populate($request->getPost());
            }
        }
        $this->view->form = $form;
        $this->view->title = 'Crear boleta';
        $this->renderScript('dt-boleta/form.phtml');
    }

    public function addNotaVentaAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();

        $form = new Default_Form_DteBoleta(null, $this->path);
        $boleta = new Default_Model_DteBoleta();

        $this->view->title = 'Crear boleta';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {


                $db = $boleta->getAdapter();
                $db->beginTransaction();

                try {

                    $row = $boleta->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->numero = $form->getValue('numero');
                    $row->fecha_emision = $form->getValue('fecha');
                    $row->sub_total = 0;
                    $row->desc_global = 0;
                    $row->neto = 0;
                    $row->iva = 0;
                    $row->total = 0;
                    $row->estado = 'BORRADOR';
                    $row->save();
                    $id = $row->id;

                    $itemNotaVenta = new Default_Model_ItemNotaVenta();
                    $where = $itemNotaVenta->getAdapter()->quoteInto("nota_id=?", $form->getValue('nota_id'));
                    $itemsNotaVenta = $itemNotaVenta->fetchAll($where);

                    $itemDteBoleta = new Default_Model_DteItemBoleta();

                    foreach($itemsNotaVenta as $item){

                        $rowItem = $itemDteBoleta->createRow();
                        $rowItem->boleta_id = $id;
                        $rowItem->codigo = $item->codigo;
                        $rowItem->nombre = $item->nombre;
                        $rowItem->descripcion = $item->descripcion;
                        $rowItem->cantidad = $item->cantidad;
                        $rowItem->unidad_medida = $item->unidad_medida;
                        $rowItem->valor_neto = $item->valor_neto;
                        $rowItem->descuento = $item->descuento;
                        $rowItem->table = $item->table;
                        $rowItem->save();
                    }

                    $db->commit();

                    $mSession->mensajes[] = 'La boleta fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view','dte-boleta', null, array('id' => $id ));

                } catch (Exception $e) {

                    $db->rollBack();

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','dte-boleta');
                }

            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('dte-boleta/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cotizacion = new Default_Model_Cotizacion();

        $request = $this->getRequest();
        $form = new Default_Form_Cotizacion();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {
                    
                    $id = (int)$form->getValue('id');
                    $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
                    $row = $cotizacion->fetchRow($where);
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->fecha = $form->getValue('fecha');
                    $row->validez = $form->getValue('validez');
                    $row->atencion_a = $form->getValue('atencion_a');
                    $row->emitida_por = $form->getValue('emitida_por');
                    $row->referencia = $form->getValue('referencia');
                    $row->autoriza_ext_presupuesto = $form->getValue('autoriza_ext_presupuesto');
                    $row->tope_ext_presupuesto = $form->getValue('tope_ext_presupuesto');
                    $row->aviso_ext_presupuesto = $form->getValue('aviso_ext_presupuesto');
                    $row->iva = $this->view->getPref('IVA');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->save();

                    $mSession->mensajes[] = 'La cotizacion fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'cotizacion', null, array('id'=> $id));
                    
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index','cotizacion');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/cotizacion/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar cotización";
                $this->renderScript('cotizacion/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $cotizacion = new Default_Model_Cotizacion();
            $id = (int)$this->_getParam('id');
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $cotizacion->delete($where);
            $mSession->mensajes[] = 'La cotización fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','cotizacion');
        }
    }

    public function emitirAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND 
           $this->_getParam('id') AND $this->_helper->validateRecordExists('dte_boletas', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $boleta = new Default_Model_DteBoleta();
            $where = $boleta->getAdapter()->quoteInto("id=?", (int)$this->_getParam('id'));
            $row = $boleta->fetchRow($where);

            if($row->estado=='BORRADOR') {

                $row->estado = 'EMITIDA';
                $row->save();
                $mSession->mensajes[] = 'La boleta fue emitida de forma exitosa, ahora puede imprimirla.';
                $mSession->claseMensaje = 'confirmacion';

            }
            $this->_forward('view','dte-boleta', null, array('id' => $row->id));
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('dte_boletas', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $boleta = new Default_Model_VistaDteBoletas();
            $where = $boleta->getAdapter()->quoteInto("id=?", $id);
            $row = $boleta->fetchRow($where);

            $items = new Default_Model_DteItemBoleta();
            $where_items = $items->getAdapter()->quoteInto("boleta_id=?", $id);

            $this->view->title = "Boleta Nº $id";
            $this->view->dteboleta = $row;
            $this->view->items = $items->fetchAll($where_items);

            if($row->estado=='BORRADOR') {

                $this->renderScript('dte-boleta/view-borrador.phtml');

            } elseif($row->estado=='EMITIDA') {

                $this->view->title .= " : Emitida";
                $this->renderScript('dte-boleta/view-emitida.phtml');

            } elseif($row->estado=='ANULADA') {

                $this->view->title .= " : Anulada";
                $this->renderScript('dte-boleta/view-anulada.phtml');

            } else {
                $this->renderScript('dte-boleta/view-simple.phtml');
            }
        }
    }
}