<?php
class DtNotaCreditoController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/acceso/logout');
        }
    }
    
    public function init()
    {
        $this->view->pageTitle = 'Notas de crédito';
        $this->usuario = $this->view->usuario = Zend_Auth::getInstance()->getIdentity();
        $this->paginacion = Zend_Registry::get('paginacion');
        if(!$this->getRequest()->isXmlHttpRequest()){
            $response = $this->getResponse();
            $response->insert('header' , $this->view->render("header.phtml"));
            $response->insert('tools', $this->view->render("busquedas-rapidas.phtml"));
        }
    }
    
    public function indexAction()
    {

        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        /* Paginación y orden de los los listados
         ****************************************************************/
        $orderByOptionsKeys = array('id', 'cliente');
        $orderByOptionsValues = array('Nº Nota', 'Cliente');
        $orderByOptions = array_combine($orderByOptionsKeys, $orderByOptionsValues);
        
        $orderTypeOptions = array('ASC', 'DESC');
        $currentPage = $this->_getParam('page', 1);

        if(in_array($this->_getParam('order_by'), $orderByOptionsKeys)) {
            $orderBy = $this->_getParam('order_by');
        } else {
            $orderBy = 'id';
        }

        if(in_array($this->_getParam('order_type'), $orderTypeOptions)) {
            $orderType = $this->_getParam('order_type');
        } else {
            $orderType = 'DESC';
        }

        $order = "$orderBy $orderType";
        $nota = new Default_Model_DtNotaCredito();
        $notas = $nota->fetchAll(null, $order);
        $paginador = Zend_Paginator::factory($notas);
        $paginador->setItemCountPerPage($this->paginacion['cant_items'])
                  ->setPageRange($this->paginacion['cant_pages'])
                  ->setCurrentPageNumber($currentPage);
        Zend_View_Helper_PaginationControl::setDefaultViewPartial('pagination_control.phtml');
        /****************************************************************/
        $this->view->orderByOptions = $orderByOptions;
        $this->view->orderBy = $orderBy;
        $this->view->orderType = $orderType;
        $this->view->action = '/dt-nota-credito/index/';
        $this->view->notas = $paginador;
        $this->view->title = "Notas de Crédito";
    }
    
    public function newAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();

        $form = new Default_Form_DtNotaCredito();
        $nota = new Default_Model_DtNotaCredito();

        $this->view->title = 'Crear nota de crédito';

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {
                
                try {
                    
                    $row = $nota->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->numero = $form->getValue('numero');
                    $row->fecha_emision = $form->getValue('fecha');
                    $row->estado = 'BORRADOR';
                    $row->save();
                    $id = $row->id;

                    $mSession->mensajes[] = 'La boleta fue creada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view','boleta', null, array('id' => $id ));
                    
                } catch (Exception $e) {

                    $db->rollBack();

                    $mSession->mensajes[] = 'Ocurrió un error al intentar crear la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_forward('index','cotizacion');
                }
                
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('dte-boleta/form.phtml');
            }
        }
    }

    public function editAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $cotizacion = new Default_Model_Cotizacion();

        $request = $this->getRequest();
        $form = new Default_Form_Cotizacion();

        if ($this->getRequest()->isPost()) {

            if ($form->isValid($request->getPost())) {

                try {
                    
                    $id = (int)$form->getValue('id');
                    $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
                    $row = $cotizacion->fetchRow($where);
                    $row->cliente = App_Rut::cleanToDb($form->getValue('cliente'));
                    $row->fecha = $form->getValue('fecha');
                    $row->validez = $form->getValue('validez');
                    $row->atencion_a = $form->getValue('atencion_a');
                    $row->emitida_por = $form->getValue('emitida_por');
                    $row->referencia = $form->getValue('referencia');
                    $row->autoriza_ext_presupuesto = $form->getValue('autoriza_ext_presupuesto');
                    $row->tope_ext_presupuesto = $form->getValue('tope_ext_presupuesto');
                    $row->aviso_ext_presupuesto = $form->getValue('aviso_ext_presupuesto');
                    $row->iva = $this->view->getPref('IVA');
                    if($form->getValue('observaciones')!='') {
                        $row->observaciones = $form->getValue('observaciones');
                    } else {
                        $row->observaciones = NULL;
                    }
                    $row->save();

                    $mSession->mensajes[] = 'La cotizacion fue editada de forma exitosa.';
                    $mSession->claseMensaje = 'confirmacion';
                    $this->_forward('view', 'cotizacion', null, array('id'=> $id));
                    
                    
                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar editar la cotizacion.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';

                    $this->_forward('index','cotizacion');
                }

            } else {

                $form->populate($request->getPost());
                $this->view->form = $form;
                $form->setAction('/cotizacion/edit');
                $form->submit->setLabel('Guardar cambios');
                $this->view->title = "Editar cotización";
                $this->renderScript('cotizacion/form.phtml');
            }
        }
    }

    public function deleteAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');
            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $cotizacion = new Default_Model_Cotizacion();
            $id = (int)$this->_getParam('id');
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $cotizacion->delete($where);
            $mSession->mensajes[] = 'La cotización fue eliminada de forma exitosa.';
            $mSession->claseMensaje = 'confirmacion';
            $this->_forward('index','cotizacion');
        }
    }

    public function finishAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND $this->_getParam('id')){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }
            $v_cotizacion = new Default_Model_VistaCotizaciones();
            $id = $v_cotizacion->getAdapter()->quote($this->_getParam('id'));
            $v_row = $v_cotizacion->fetchRow('id='.$id);

            $cotizacion = new Default_Model_Cotizacion();
            $row = $cotizacion->fetchRow('id='.$id);

            if($v_row->estado=='BORRADOR') {

                if((NULL!=$v_row->total_neto) AND ($v_row->total_neto >= $this->preferencias['CT_MONTO_APROB'])) {
                    $row->estado = 'PENDIENTE';
                    $row->iva = $this->view->getPref('IVA');
                } else {
                    $row->estado = 'EMITIDA';
                    $row->iva = $this->view->getPref('IVA');
                }
                $row->save();
                $mSession->mensajes[] = 'La cotización fue emitida de forma exitosa.';
                $mSession->claseMensaje = 'confirmacion';

            }
            $this->_forward('view','cotizacion', null, array('id' => $row->id));
        }
    }

    public function viewAction()
    {
        if($this->getRequest()->isXmlHttpRequest() AND
           $this->_getParam('id') AND
           $this->_helper->validateRecordExists('cotizaciones', 'id', $this->_getParam('id'))){

            $mSession = new Zend_Session_Namespace('expressauto');

            if($mSession->mensajes!='') {
                $this->view->mensajes = $mSession->mensajes;
                $this->view->claseMensaje = $mSession->claseMensaje;
                $mSession->mensajes = '';
                $mSession->claseMensaje = '';
            }

            $id = (int)$this->_getParam('id');
            $cotizacion = new Default_Model_VistaCotizaciones();
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $row = $cotizacion->fetchRow($where);

            $envio = new Default_Model_EnvioDocumento();
            $where_envio = "documento_id='$id' AND tipo='cotizacion'";
            $order_envio = "id DESC";
            $count_envio = '1';
            $rows_envios = $envio->fetchAll($where_envio, $order_envio, $count_envio)->toArray();

            $items = new Default_Model_ItemCotizacion();
            $where_items = $items->getAdapter()->quoteInto("cotizacion_id=?", $id);

            

            if(false==$row) {
                $this->_forward('index','cotizacion');
            } else {

                $this->view->title = "Cotización Nº $id";
                $this->view->cotizacion = $row;
                $this->view->items = $items->fetchAll($where_items);
                $this->view->envios = $rows_envios;

                if($row->estado=='BORRADOR') {

                    $this->renderScript('cotizacion/view-borrador.phtml');

                } elseif($row->estado=='PENDIENTE') {

                    $this->view->title .= " : Pendiente aprobación";
                    $this->renderScript('cotizacion/view-pendiente.phtml');

                } elseif($row->estado=='EMITIDA') {

                    $this->view->title .= " : Emitida";
                    $this->renderScript('cotizacion/view-emitida.phtml');

                } elseif($row->estado=='APROBADA') {

                    $this->view->title .= " : Aprobada por el cliente";
                    $this->renderScript('cotizacion/view-aprobada.phtml');

                } elseif($row->estado=='RECHAZADA') {

                    $this->view->title .= " : Rechazada";
                    //$rechazo = new Default_Model_RechazoCotizacion();
                    //$this->view->rechazo = $rechazo->fetchRow('cotizacion_id=' . $row->id);
                    $this->renderScript('cotizacion/view-rechazada.phtml');
                    
                } else {
                    $this->renderScript('cotizacion/view-simple.phtml');
                }
            }
        }
    }
    
    public function printAction()
    {
        if($this->_getParam('id') AND
           $this->_helper->validateRecordExists('vista_cotizaciones','id', $this->_getParam('id'))){

            $this->_helper->layout->setLayout('print');

            $cotizacion = new Default_Model_VistaCotizaciones();
            $id = (int)$this->_getParam('id');
            $where = $cotizacion->getAdapter()->quoteInto("id=?", $id);
            $row = $cotizacion->fetchRow($where);

            if(false!==$row AND $row->estado=='EMITIDA') {
                $item = new Default_Model_ItemCotizacion();
                $where_items = $item->getAdapter()->quoteInto("cotizacion_id=?",$id);
                $items = $item->fetchAll($where_items);
                $this->view->title = "Cotización Nº $id";
                $this->view->cotizacion = $row;
                $this->view->items = $items;
                $this->view->modeView = $this->_getParam('mode_view');
                $this->view->condiciones_generales = Default_Model_CondicionGeneral::getTexto('COTIZACION');
            }
        }
    }
}