<?php
class SendAttachController extends Zend_Controller_Action
{
    public function preDispatch()
    {
        $auth = Zend_Auth::getInstance();
        $mSession = new Zend_Session_Namespace('expressauto');
        
        if (!$auth->hasIdentity() || $mSession->sistema!=="expressauto") {
            $this->_redirect('/acceso/logout');
        }
    }
    
    public function init()
    {
        $this->usuario = Zend_Auth::getInstance()->getIdentity();
        $propietario = new Default_Model_Propietario();
        $this->view->propietario = $propietario->fetchRow()->toArray();
        $this->_helper->layout->disableLayout();
        $this->_helper->viewRenderer->setNoRender();
    }

    public function sendAction()
    {
        $mSession = new Zend_Session_Namespace('expressauto');

        if($mSession->mensajes!='') {
            $this->view->mensajes = $mSession->mensajes;
            $this->view->claseMensaje = $mSession->claseMensaje;
            $mSession->mensajes = '';
            $mSession->claseMensaje = '';
        }

        $request = $this->getRequest();
        $form = new Default_Form_SendAttach();
        $form->copia->setLabel('Enviar una copia a mi casilla ('.  $this->usuario->mail .')');
        $this->view->title = "Enviar documento adjunto por mail";

        if ($this->getRequest()->isPost()) {
            if ($form->isValid($request->getPost())) {

                try {
                    
                    $mail = new App_HtmlMailerDocument('UTF-8');
                    $mail->setFrom($this->usuario->mail, $this->usuario->empleado);
                    $mail->setType(Zend_Mime::MULTIPART_RELATED);
                    $mail->setSubject($form->getValue('asunto'))
                         ->setViewParam('nombre', $form->getValue('nombre'))
                         ->setViewParam('usuario', $this->usuario->empleado)
                         ->setViewParam('mensaje', $form->getValue('texto_mensaje'));

                    $mail->addTo($form->getValue('mail'), $form->getValue('nombre'));

                    if($form->copia->getValue()==1){
                        $mail->addBcc($this->usuario->mail);
                    }

                    $path = $form->getValue('documento') . $form->getValue('id');
                    $pdf = new App_Pdf($path);
                    $attach = $mail->createAttachment($pdf->getContent());
                    $attach->filename = $form->getValue('archivo');

                    $mail->sendHtmlTemplate('send-attach.phtml');

                    $envio = new Default_Model_EnvioDocumento();
                    $row = $envio->createRow();
                    $row->creador = $this->usuario->rut;
                    $row->tipo = $form->getValue('documento');
                    $row->documento_id = $form->getValue('id');
                    $row->nombre = $form->getValue('nombre');
                    $row->mail = $form->getValue('mail');
                    $row->save();
                    
                    $mSession->mensajes[] = 'El mensaje fue enviado de forma satisfactoria.';
                    $mSession->claseMensaje = 'confirmacion';

                    $this->_redirect($form->getValue('back'));

                } catch (Exception $e) {

                    $mSession->mensajes[] = 'Ocurrió un error al intentar enviar el mensaje, por favor inténtelo más tarde.';
                    $mSession->mensajes[] = $e->getMessage();
                    $mSession->claseMensaje = 'error';
                    $this->_redirect($form->getValue('back'));
                }
            } else {
                $this->view->form = $form;
                $form->populate($request->getPost());
                $this->renderScript('send-attach/form.phtml');
            }
        }
    }


    private function _getDefaultSubject($documento, $id)
    {
        $asuntos = array(
            'cotizacion'    => "ExpressAuto - Cotización Nº $id",
            'orden-compra'  => "ExpressAuto - Orden de compra Nº $id"
        );

        foreach($asuntos as $key => $value){
            if($documento==$key){
                return $value;
                break;
            }
        }
    }

    private function _getDefaultMessage($documento)
    {
        $mensajes = array(
            'cotizacion'    => "Adjunto cotización según lo solicitado",
            'orden-compra'  => "Adjunto orden de compra"
        );

        foreach($mensajes as $key => $value){
            if($documento==$key){
                return $value;
                break;
            }
        }
    }
}