<?php
class Default_Form_Articulo extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $descripcionCodigoReferencia = 'Recuerde que este código es el que genera las equivalencias de los artículos.';

        $optionsCategoria = array('table' => 'articulos_categorias', 'field' => 'id');
        $validadorCategoria = new Zend_Validate_Db_RecordExists($optionsCategoria);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $categoria_id = new Zend_Form_Element_Hidden('categoria_id');
        $categoria_id->setRequired(true)
                     ->addValidator($validadorCategoria);
        
        $categoria_nombre = new Zend_Form_Element_Text('categoria_nombre');
        $categoria_nombre->setLabel('ID Categoría')
                         ->setRequired(true)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->setAttrib('class', 'show-list input-xlarge')
                         ->setAttrib('data-url', '/articulo-categoria/get-listado-popup')
                         ->setAttrib('data-title', 'Seleccionar categoría');
        
        $codigo_proveedor = new Zend_Form_Element_Text('codigo_proveedor');
        $codigo_proveedor->setLabel('Código proveedor')
                         ->setRequired(false)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim');
        
        $codigo_referencia = new Zend_Form_Element_Text('codigo_referencia');
        $codigo_referencia->setLabel('Código referencia')
                         ->setRequired(false)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->setAttrib('class', 'help')
                         ->setAttrib('title', $descripcionCodigoReferencia);

        $fabricante_id = new Zend_Form_Element_Select('fabricante_id');
        $fabricante_id->setLabel('Marca / Fabricante')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOptions(Default_Model_ArticuloFabricante::getPairsToSelect());

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre del artículo')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');
        
        $stock_minimo = new Zend_Form_Element_Text('stock_minimo');
        $stock_minimo->setLabel('Stock mínimo')
                     ->setRequired(true)
                     ->addFilter('StripTags')
                     ->addFilter('StringTrim')
                     ->addValidator('Int');

        $descripcion = new Zend_Form_Element_Textarea('descripcion');
        $descripcion->setLabel('Descripción')
                    ->setRequired(false)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setAttrib('class', 'input-xlarge')
                    ->setAttrib('rows','3');

        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $codigo_proveedor, $codigo_referencia, $categoria_id,
                $categoria_nombre, $fabricante_id, $nombre,
                $descripcion, $submit, $cancel, $stock_minimo, $id
            ));


        $this->addDisplayGroup(
            array(
                'categoria_nombre', 'nombre', 'stock_minimo',
                'fabricante_id', 'codigo_proveedor', 'codigo_referencia',
                'descripcion'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id', 'categoria_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        $categoria_id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'articulo',
                'action'    => '/articulo/new'
            ));
    } 
} 