<?php
class Default_Form_ArticuloEgreso extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $optionsArticulo = array('table' => 'articulos', 'field' => 'id');
        $validadorArticulo = new Zend_Validate_Db_RecordExists($optionsArticulo);

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $articulo_id = new Zend_Form_Element_Text('articulo_id');
        $articulo_id->setLabel('ID artículo')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setAttrib('class', 'input-small show-list')
                    ->setAttrib('data-url', '/articulo/get-listado-popup')
                    ->setAttrib('data-title', 'Seleccionar artículo')     
                    ->addValidator($validadorArticulo);

        $tipo_egreso_id = new Zend_Form_Element_Select('tipo_egreso_id');
        $tipo_egreso_id->setLabel('Tipo egreso')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOptions(Default_Model_ArticuloTipoEgreso::getPairsToSelect());

        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setLabel('Cantidad a retirar')
                     ->setRequired(true)
                     ->addFilter('StripTags')
                     ->addFilter('StringTrim')
                     ->addValidator('Int')
                     ->setAttrib('class', 'help')
                     ->setAttrib('title', 'Sólo números enteros');

        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
                      ->setAttrib('rows', '3')
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Registrar egreso')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $tipo_egreso_id, $articulo_id,
                $cantidad, $observaciones, 
                $submit, $cancel, $id
            ));

        $this->addDisplayGroup(
            array(
                'articulo_id', 'cantidad', 'tipo_egreso_id', 'observaciones'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );
        
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'articulo-egreso',
                'action'    => '/articulo-egreso/new'
            ));
    } 
} 
