<?php
class Default_Form_ArticuloIngreso extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $optionsArticulo = array('table' => 'articulos', 'field' => 'id');
        $validadorArticulo = new Zend_Validate_Db_RecordExists($optionsArticulo);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $articulo_id = new Zend_Form_Element_Text('articulo_id');
        $articulo_id->setLabel('ID artículo')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setAttrib('class', 'input-small show-list')
                    ->setAttrib('data-url', '/articulo/get-listado-popup')
                    ->setAttrib('data-title', 'Seleccionar artículo')     
                    ->addValidator($validadorArticulo);

        $tipo_id = new Zend_Form_Element_Select('tipo_id');
        $tipo_id->setLabel('Tipo')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addMultiOption('','-- Seleccionar --')
                ->addMultiOptions(Default_Model_ArticuloTipoIngreso::getPairsToSelect());

        $almacen_id = new Zend_Form_Element_Select('almacen_id');
        $almacen_id->setLabel('Almacén')
                   ->setRequired(true)
                   ->addMultiOption('', '-- Seleccionar --')
                   ->addMultiOptions(Default_Model_ArticuloAlmacen::getPairsToSelect());
       
        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setLabel('Cantidad a ingresar')
                     ->setRequired(true)
                     ->addFilter('StripTags')
                     ->addFilter('StringTrim')
                     ->addValidator('Int')
                     ->setAttrib('class', 'help input-small')
                     ->setAttrib('title', 'Sólo números enteros');
        
        $costo_unitario_neto = new Zend_Form_Element_Text('costo_unitario_neto');
        $costo_unitario_neto->setLabel('Costo unitario neto')
                     ->setRequired(true)
                     ->addFilter('StripTags')
                     ->addFilter('StringTrim')
                     ->addValidator('Int')
                     ->setDescription('Sólo números enteros');

        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
                      ->addFilter('StripTags')
                      ->setAttrib('rows', '3')  
                      ->addFilter('StringTrim');

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Registrar ingreso')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $articulo_id, $tipo_id, $almacen_id, $cantidad,
                $costo_unitario_neto, $observaciones, $submit, 
                $cancel, $id
            ));

        $this->addDisplayGroup(
            array(
                'articulo_id', 'cantidad', 'tipo_id', 
                'almacen_id', 'costo_unitario_neto', 
                'observaciones'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );
        
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'articulo-ingreso',
                'action'    => '/articulo-ingreso/new'
            ));

    } 
} 
