<?php
class Default_Form_BancoCuenta extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $id = new Zend_Form_Element_Hidden('id');
        $id->addFilter('StripTags')
           ->addFilter('StringTrim')
           ->addValidator('Int');
        
        $banco_id = new Zend_Form_Element_Select('banco_id');
        $banco_id->setLabel('Banco')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption('', '-- Seleccionar --')
                 ->addMultiOptions(Default_Model_Banco::getPairsToSelect());
        
        $tipo_id = new Zend_Form_Element_Select('tipo_id');
        $tipo_id->setLabel('Tipo de Cuenta')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption('', '-- Seleccionar --')
                 ->addMultiOptions(Default_Model_BancoCuentaTipo::getPairsToSelect());
        
        $numero = new Zend_Form_Element_Text('numero');
        $numero->setLabel('Número')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');
        
        $titular = new Zend_Form_Element_Text('titular');
        $titular->setLabel('Titular')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim');
        
        $monto_aprobado = new Zend_Form_Element_Text('monto_aprobado');
        $monto_aprobado->setLabel('Monto aprobado')
                       ->setRequired(true)
                       ->setValue(0)
                       ->addFilter('StripTags')
                       ->addFilter('StringTrim');
        
        $fecha_apertura = new Zend_Form_Element_Text('fecha_apertura');
        $fecha_apertura->setLabel('Fecha de apertura')
                       ->setRequired(true)
                       ->addFilter('StripTags')
                       ->addFilter('StringTrim')
                       ->addValidator('Date')
                       ->setAttrib('class', 'show-calendar');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn');
        
        $this->addElements(array(
            $id, $banco_id, $tipo_id, $numero, $titular, $monto_aprobado, 
            $fecha_apertura, $submit, $cancel
        ));
        $this->addDisplayGroup(array(
            'banco_id', 'tipo_id', 'numero', 'titular', 'monto_aprobado', 
            'fecha_apertura'
        ), 'infoInputs');

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'span6'))
            )
        );

        $this->addDisplayGroup(array('submit', 'cancel', 'id'),'submitButtons');

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
        
        $this->setAttribs(array(
            'class'     => 'form-horizontal',
            'name'      => 'banco-cuenta',
            'action'    => '/banco-cuenta/new'
        ));

    } 
} 
