<?php
class Default_Form_Cliente extends Zend_Form 
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);

        $id = new Zend_Form_Element_Hidden('id');
        $id->addFilter('StripTags')
           ->addFilter('StringTrim')
           ->addValidator('Int');
        
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');
             
        $direccion = new Zend_Form_Element_Text('direccion');
        $direccion->setLabel('Dirección')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim'); 
         
        $ciudad = new Zend_Form_Element_Text('ciudad');
        $ciudad->setLabel('Ciudad')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');

        $telefono = new Zend_Form_Element_Text('telefono');
        $telefono->setLabel('Teléfono')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim'); 

        $mail = new Zend_Form_Element_Text('mail');
        $mail->setLabel('Email')
              ->setRequired(false)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator('EmailAddress');
        
        $preferencia_repuestos = new Zend_Form_Element_Select('preferencia_repuestos');
        $preferencia_repuestos->setLabel('¿Que tipo de repuesto prefiere?')
                              ->setRequired(true)
                              ->addFilter('StripTags')
                              ->addFilter('StringTrim')
                              ->addMultiOption("", "-- Seleccionar --")
                              ->addMultiOptions(Default_Model_TipoRepuesto::getPairsToSelect());
        
        $preferencia_recepcion_cotizaciones = new Zend_Form_Element_Select('preferencia_recepcion_cotizaciones');
        $preferencia_recepcion_cotizaciones->setLabel('¿Como desea recibir sus cotizaciones?')
                                           ->setRequired(true)
                                           ->addFilter('StripTags')
                                           ->addFilter('StringTrim')
                                           ->addMultiOption("Mail", "Mail")
                                           ->addMultiOption("Teléfono", "Teléfono");
        
        $preferencia_despacho_documentos = new Zend_Form_Element_Text('preferencia_despacho_documentos');
        $preferencia_despacho_documentos->setLabel('¿Desea recibir la documentación en alguna dirección postal diferente?')
                                           ->setRequired(false)
                                           ->addFilter('StripTags')
                                           ->addFilter('StringTrim')
                                           ->setDescription("Dejar vacío en caso de no haber una dirección postal diferente");
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn');

        $this->addElements(
            array(
                $nombre, $direccion,
                $ciudad, $telefono, $mail, 
                $submit, $cancel, $id, 
                $preferencia_repuestos, 
                $preferencia_recepcion_cotizaciones,
                $preferencia_despacho_documentos
            ));

        $this->addDisplayGroup(
            array(
                'nombre', 'direccion', 'ciudad', 'telefono', 'mail'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'span6'))
            )
        );

        $this->addDisplayGroup(
            array(
                'preferencia_repuestos', 
                'preferencia_recepcion_cotizaciones', 
                'preferencia_despacho_documentos' , 
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'span6'))
            )
        );
        
        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));

        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'cliente',
                'action'    => '/cliente/new'
            ));
    } 
} 
