<?php
class Default_Form_ClienteFull extends Zend_Form 
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);

        $id = new Zend_Form_Element_Hidden('id');
        $id->addFilter('StripTags')
           ->addFilter('StringTrim')
           ->addValidator('Int');
        
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setAttrib('class','input-xlarge');
             
        $direccion = new Zend_Form_Element_Text('direccion');
        $direccion->setLabel('Dirección')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class','input-xlarge'); 
         
        $ciudad = new Zend_Form_Element_Text('ciudad');
        $ciudad->setLabel('Ciudad')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');

        $telefono = new Zend_Form_Element_Text('telefono');
        $telefono->setLabel('Teléfono')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('title', 'Sin código de ciudad ni país')  
              ->setAttrib('class','input-small help'); 

        $mail = new Zend_Form_Element_Text('mail');
        $mail->setLabel('Email')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator('EmailAddress');
        
        $preferencia_repuestos = new Zend_Form_Element_Select('preferencia_repuestos');
        $preferencia_repuestos->setLabel('Preferencia repuestos')
                              ->setRequired(true)
                              ->addFilter('StripTags')
                              ->addFilter('StringTrim')
                              ->addMultiOption("", "-- Seleccionar --")
                              ->addMultiOptions(Default_Model_TipoRepuesto::getPairsToSelect());
        
        $preferencia_recepcion_cotizaciones = new Zend_Form_Element_Select('preferencia_recepcion_cotizaciones');
        $preferencia_recepcion_cotizaciones->setLabel('Recepción teléfono')
                                           ->setRequired(true)
                                           ->addFilter('StripTags')
                                           ->addFilter('StringTrim')
                                           ->addMultiOption("Mail", "Mail")
                                           ->addMultiOption("Teléfono", "Teléfono");
        
        $preferencia_despacho_documentos = new Zend_Form_Element_Text('preferencia_despacho_documentos');
        $preferencia_despacho_documentos->setLabel('Dirección Postal')
                                        ->setRequired(false)
                                        ->addFilter('StripTags')
                                        ->addFilter('StringTrim')
                                        ->setDescription("Dejar vacío en caso de no haber una dirección postal diferente");
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear cliente')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');

        $this->addElements(
            array(
                $nombre, $direccion, $ciudad, $telefono, 
                $mail, $submit, $cancel, $id, 
                $preferencia_repuestos, 
                $preferencia_despacho_documentos,
                $preferencia_recepcion_cotizaciones
            ));

        $this->addDisplayGroup(
            array(
                'nombre', 'direccion', 'ciudad', 'telefono', 'mail',
                'preferencia_repuestos', 'preferencia_recepcion_cotizaciones',
                 'preferencia_despacho_documentos',  
            ),
            'infoInputs',
             array('Legend' => 'Formulario cliente')   
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );

        $this->addDisplayGroup( array('submit', 'cancel', 'id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            'Errors',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->clearDecorators();
        $this->setDecorators(array('FormElements','Form'));
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'cliente',
                'action'    => '/cliente/new'
            ));
        

    } 
} 
