<?php
class Default_Form_ClienteInfoFacturacionFull extends Zend_Form
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);

        $opcionesRut = array('table' => 'clientes', 'field' => 'rut');
        $validadorRut = new Zend_Validate_Db_RecordExists($opcionesRut);
        
        $validadorFormatoRut = new App_Validate_ValidRut();
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));
        
        $cliente_rs = new Zend_Form_Element_Text('cliente_rs');
        $cliente_rs->setLabel('Nombre')
               ->setRequired(false)
               ->setAttrib('disabled', 'disabled');
        
        $cliente_rut = new Zend_Form_Element_Text('cliente_rut');
        $cliente_rut->setLabel('R.U.T.')
                ->setRequired(false)
                ->setAttrib('disabled', 'disabled');
        
        $cliente_direccion = new Zend_Form_Element_Text('cliente_direccion');
        $cliente_direccion->setLabel('Dirección')
                          ->setRequired(false)
                          ->setAttrib('disabled', 'disabled'); 
         
        $cliente_ciudad = new Zend_Form_Element_Text('cliente_ciudad');
        $cliente_ciudad->setLabel('Ciudad')
                       ->setRequired(false)
                       ->setAttrib('disabled', 'disabled');

        $cliente_telefono = new Zend_Form_Element_Text('cliente_telefono');
        $cliente_telefono->setLabel('Teléfono')
                         ->setRequired(false)
                         ->setAttrib('disabled', 'disabled'); 
        
        $copiar = new Zend_Form_Element_Checkbox('copiar');
        $copiar->setLabel('Copiar datos')
                  ->setRequired(true)
                  ->addFilter('StripTags')
                  ->addFilter('StringTrim');
        
        $cliente = new Zend_Form_Element_Hidden('cliente');
        $cliente->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator($validadorRut);
        
        $razon_social = new Zend_Form_Element_Text('razon_social');
        $razon_social->setLabel('Razón social')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class', 'tooltip')
              ->setDescription('Ingrese la Razón Social de la Empresa o el Nombre completo en caso de ser Persona Natural');
             
        $rut = new Zend_Form_Element_Text('rut');
        $rut->setLabel('R.U.T.')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator($validadorFormatoRut)
              ->setAttrib('class', 'tooltip')
              ->setDescription('Formato : 12345678-9');
             
        $direccion = new Zend_Form_Element_Text('direccion');
        $direccion->setLabel('Dirección')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim'); 
         
        $comuna = new Zend_Form_Element_Text('comuna');
        $comuna->setLabel('Comuna')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class', 'autocomplete')
              ->setDescription('/ajax-aux/comunas');
        
        $ciudad = new Zend_Form_Element_Text('ciudad');
        $ciudad->setLabel('Ciudad')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class', 'autocomplete')
              ->setDescription('/ajax-aux/ciudades');
        
        $telefono = new Zend_Form_Element_Text('telefono');
        $telefono->setLabel('Teléfono')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim'); 
              
        $giro = new Zend_Form_Element_Text('giro');
        $giro->setLabel('Giro')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Guardar datos de facturación')
               ->setAttrib('class','cliente')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'))
               ->setAttrib('onclick', 'javascript:history.back();');

        $this->addElements(
            array(
                $razon_social, $rut, $direccion,
                $comuna, $ciudad, $telefono, $giro,
                $submit, $cancel, $cliente, $id,
                $copiar, $cliente_ciudad, $cliente_direccion,
                $cliente_rs, $cliente_telefono, $cliente_rut
            ));

        $this->addDisplayGroup(
            array(
                'cliente_rs', 'cliente_rut', 'cliente_direccion', 
                'cliente_telefono', 'cliente_ciudad', 'copiar'
            ),
            'infoCliente',
            array('legend' => 'Cliente')
        );

        $infoCliente = $this->getDisplayGroup('infoCliente');
        $infoCliente->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );
        
        $this->addDisplayGroup(
            array(
                'razon_social','rut','direccion',
                'telefono', 'comuna','ciudad', 'giro'
            ),
            'infoInputs',
            array('legend' => 'Datos de facturación')
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id', 'cliente'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido',
                'name'      => 'cliente-info-facturacion',
                'action'    => '/cliente-info-facturacion/new'
            ));

    } 
} 
