<?php
class Default_Form_ClienteReserva extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $hecha_por = new Zend_Form_Element_Text('hecha_por');
        $hecha_por->setLabel('Hecha por')
                  ->setRequired(true)
                  ->addFilter('StripTags')
                  ->addFilter('StringTrim');

        $vehiculo = new Zend_Form_Element_Text('vehiculo');
        $vehiculo->setLabel('Patente Vehículo')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->setAttrib('class', 'input-small')
                ->addFilter('StringToUpper')
                ->setDescription('El vehículo y el cliente deben estar previamente registrados');

        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setLabel('Fecha')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Date')
               ->setAttrib('class', 'show-calendar input-small');

        $hora = new Zend_Form_Element_Select('hora');
        $hora->setLabel('Hora')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim')
            ->addMultiOption('','-- Seleccionar --')
            ->addMultiOptions(array(
                '08:00:00'  => '08:00',
                '09:00:00'  => '09:00',
                '10:00:00'  => '10:00',
                '11:00:00'  => '11:00',
                '12:00:00'  => '12:00',
                '15:00:00'  => '15:00',
                '16:00:00'  => '16:00',
                '17:00:00'  => '17:00',
                '18:00:00'  => '18:00'))
            ->setDescription('Hora de llegada del cliente');

        $comentarios = new Zend_Form_Element_Textarea('comentarios');
        $comentarios->setLabel('Comentarios / Observaciones')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setAttrib('rows', '5')
                    ->setAttrib('class', 'input-xxlarge')
                    ->setDescription('Ingrese una pequeña descripción de los servicios que solicita el cliente');

        $tipo = new Zend_Form_Element_Select('tipo');
        $tipo->setLabel('Tipo servicio')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('', '-- Seleccionar --')
               ->addMultiOption('REV GENERAL', 'REVISION GENERAL')
               ->addMultiOption('MANT PROGRAMADO', 'MANTENIMIENTO PROGRAMADO')
               ->addMultiOption('REPARACIONES', 'REPARACIONES')
               ->addMultiOption('OTRO', 'OTRO MOTIVO');

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear reserva')
               ->setAttrib('class', 'btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn');
        
        $this->addElements(
            array(
                $hecha_por, $vehiculo, $fecha,
                $comentarios, $submit, $cancel, 
                $id, $hora, $tipo
            ));

        $this->addDisplayGroup(
            array('hecha_por','vehiculo', 'tipo', 'fecha', 'hora', 'comentarios'),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(array(
            'FormElements',
            'Fieldset'
        ));

        $this->addDisplayGroup(array('submit', 'cancel', 'id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'reserva',
                'action'    => '/reserva/new'
            ));

    } 
} 
