<?php
class Default_Form_Cotizacion extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $optionsRecepcion = array('table' => 'recepciones_vehiculos', 'field' => 'id');
        $validadorRecepcion = new Zend_Validate_Db_RecordExists($optionsRecepcion);
        
        $optionsPresupuesto = array('table' => 'presupuestos', 'field' => 'id');
        $validadorPresupuesto = new Zend_Validate_Db_RecordExists($optionsPresupuesto);

        $descripcionRecepcionId = 'Ingrese el Nº de recepción si es que corresponde. '
                                . 'De lo contrario dejar en blanco';
        
        $descripcionPresupuestoId = 'Si ingresa un número de presupuesto, se tomarán los '
                                  . 'ítems seleccionados de este y se agregarán automáticamente'
                                  . 'a la cotización.';

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $cliente_id = new Zend_Form_Element_Select('cliente_id');
        $cliente_id->setLabel('Cliente')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->addMultiOption('', '-- Seleccionar --')
                   ->addMultiOptions(Default_Model_Cliente::getPairsToSelect());

        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setLabel('Fecha emisión')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Date')
               ->setAttrib('class', 'show-calendar')
               ->setValue(date("Y-m-d"));

        $validez = new Zend_Form_Element_Text('validez');
        $validez->setLabel('Validez (días)')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Int')
               ->setAttrib('class', 'help') 
               ->setAttrib('title', 'Días de validez. Sólo números enteros.')
               ->setValue((int)Default_Model_SistemaPreferencia::getPref('CT_VALIDEZ'));

        $atencion_a = new Zend_Form_Element_Text('atencion_a');
        $atencion_a->setLabel('Atención a')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim');

        $recepcion_id = new Zend_Form_Element_Text('recepcion_id');
        $recepcion_id->setLabel('Nº Recepción')
                   ->setRequired(false)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->addValidator($validadorRecepcion)
                   ->setAttrib('title', $descripcionRecepcionId)
                   ->setAttrib("class", "help");

        $emitida_por = new Zend_Form_Element_Text('emitida_por');
        $emitida_por->setLabel('Emitida por')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setValue('');

        $tope_ext_presupuesto = new Zend_Form_Element_Text('tope_ext_presupuesto');
        $tope_ext_presupuesto->setLabel('Tope ext. presupuesto')
                             ->setRequired(false)
                             ->addFilter('StripTags')
                             ->addFilter('StringTrim')
                             ->setValue(0);

        $aviso_ext_presupuesto = new Zend_Form_Element_Text('aviso_ext_presupuesto');
        $aviso_ext_presupuesto->setLabel('Avisar al número/mail')
                              ->setRequired(false)
                              ->addFilter('StripTags')
                              ->addFilter('StringTrim');

        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->setAttrib('rows', '4')
                      ->setAttrib('class', 'input-xlarge');
        
        $presupuesto_id = new Zend_Form_Element_Text('presupuesto_id');
        $presupuesto_id->setLabel('Importar presupuesto Nº')
                   ->setRequired(false)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->addValidator($validadorPresupuesto)
                   ->setAttrib('title', $descripcionPresupuestoId)
                   ->setAttrib("class", "help");
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $cliente_id, $fecha, $validez, $atencion_a, 
                $emitida_por, $observaciones, $submit, $cancel, $id, 
                $recepcion_id, $tope_ext_presupuesto, 
                $aviso_ext_presupuesto, $presupuesto_id
            ));

        $this->addDisplayGroup(
            array(
                'cliente_id', 'fecha', 'validez', 'atencion_a', 
                'emitida_por', 'presupuesto_id'
                
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'span5'))
        ));
        
        $this->addDisplayGroup(
            array(
                'recepcion_id', 
                'tope_ext_presupuesto',
                'aviso_ext_presupuesto',
                'observaciones'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(array(
            'FormElements',
            'Fieldset',
            array('HtmlTag',array('tag'=>'div','class'=>'span5'))
        ));

        $this->addDisplayGroup(array('submit', 'cancel','id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));    
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'cotizacion',
                'action'    => '/cotizacion/new'
            ));

    } 
} 
