<?php
class Default_Form_DatosFacturacion extends Zend_Form
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);

        $validadorFormatoRut = new App_Validate_ValidRut();
        
        $helpRazonSocial = 'Razón Social de la Empresa o el Nombre completo '
                         . 'en caso de Persona Natural que requiera factura';
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $rut = new Zend_Form_Element_Text('rut');
        $rut->setLabel('R.U.T.')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class', 'input-small')
              ->addValidator($validadorFormatoRut);
        
        $razon_social = new Zend_Form_Element_Text('razon_social');
        $razon_social->setLabel('Razón social')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class', 'help')
              ->setAttrib('title', $helpRazonSocial);
             
        $direccion = new Zend_Form_Element_Text('direccion');
        $direccion->setLabel('Dirección')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim'); 
         
        $comuna = new Zend_Form_Element_Text('comuna');
        $comuna->setLabel('Comuna')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');
        
        $ciudad = new Zend_Form_Element_Text('ciudad');
        $ciudad->setLabel('Ciudad')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');
        
        $telefono = new Zend_Form_Element_Text('telefono');
        $telefono->setLabel('Teléfono')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->setAttrib('class', 'input-small')  
              ->addFilter('StringTrim'); 
              
        $giro = new Zend_Form_Element_Text('giro');
        $giro->setLabel('Giro')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');

        $this->addElements(
            array(
                $razon_social, $rut, $direccion,
                $comuna, $ciudad, $telefono, $giro,
                $submit, $cancel, $id
            ));

        $this->addDisplayGroup(
            array(
                'razon_social','rut','direccion',
                'telefono', 'comuna','ciudad', 'giro'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'datos-facturacion',
                'action'    => '/datos-facturacion/new'
            ));

    } 
} 
