<?php
class Default_Form_DteBoleta extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);
        
        $optionsCliente = array('table' => 'clientes', 'field' => 'id');
        $validadorCliente = new Zend_Validate_Db_RecordExists($optionsCliente);
        
        $validadorFloat = new App_Validate_Float();
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $numero = new Zend_Form_Element_Text('numero');
        $numero->setLabel('Nº')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->setAttrib('class', 'input-mini help')
                ->setAttrib('title', 'Verifique el Nº directamente en la boleta a imprimir')
                ->addValidator('Int');
        
        $cliente = new Zend_Form_Element_Text('cliente');
        $cliente->setLabel('ID Cliente')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->setAttrib('class', 'show-list input-small')
                ->setAttrib('data-url', '/cliente/get-listado-popup')
                ->setAttrib('data-title', 'Seleccionar cliente')
                ->addValidator($validadorCliente);
        
        $fecha = new Zend_Form_Element_Text('fecha_emision');
        $fecha->setLabel('Fecha emisión')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator('Date')
                ->setAttrib('class', 'show-calendar input-small')
                ->setValue(date("Y-m-d"));

        $forma_pago = new Zend_Form_Element_Select('forma_pago');
        $forma_pago->setLabel('Forma de pago')
                   ->setRequired(true)
                   ->addMultiOption('','-- Seleccionar --')
                   ->addMultiOptions(Default_Model_PagoRecibidoForma::getPairsToSelect());

        $desc_global = new Zend_Form_Element_Text('desc_global');
        $desc_global->setLabel('% Descuento global')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator('Int')
                ->addValidator($validadorFloat)
                ->setValue(0);
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear boleta')
               ->setAttrib('class', 'btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib("onclick", "javascript:history.back();") 
               ->setAttrib('class', 'btn');
        
        $this->addElements(
            array(
                $submit, $cancel, $id, $cliente, 
                $numero, $fecha, $forma_pago,
                $desc_global
            ));

        $this->addDisplayGroup(
            array(
                'numero', 'cliente', 'fecha_emision', 'forma_pago',
                'desc_global'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(array('FormElements','Fieldset'));

        $this->addDisplayGroup(array('submit', 'cancel', 'id'), 'submitButtons');

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(array('FormElements',array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'dte-boleta',
                'action'    => '/dte-boleta/new'
            ));

    } 
} 
