<?php
class Default_Form_DteFacturaCompra extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);
        
        $validadorRut = new App_Validate_ValidRut();
        
        $optionsProveedor = array('table' => 'proveedores', 'field' => 'rut');
        $validadorProveedor = new Zend_Validate_Db_RecordExists($optionsProveedor);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $proveedor = new Zend_Form_Element_Text('proveedor');
        $proveedor->setLabel('R.U.T. Proveedor')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addFilter('Alnum')
                ->setAttrib('class', 'show-list input-small')
                ->setAttrib('data-url', '/proveedor/get-listado-popup')
                ->setAttrib('data-title', 'Seleccionar proveedor')
                ->addValidator($validadorProveedor);
        
        $numero = new Zend_Form_Element_Text('numero');
        $numero->setLabel('Nº')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setAttrib('class', ' help')
               ->setAttrib('title', 'Verifique el Nº directamente en la factura de compra a imprimir')
               ->addValidator('Int');
        
        $fecha = new Zend_Form_Element_Text('fecha_emision');
        $fecha->setLabel('Fecha emisión')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator('Date')
                ->setAttrib('class', 'show-calendar input-small')
                ->setValue(date("Y-m-d"));
        
        $contacto = new Zend_Form_Element_Text('contacto');
        $contacto->setLabel('Nombre contacto')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim');
        
        $rut_solicitante = new Zend_Form_Element_Text('rut_solicitante');
        $rut_solicitante->setLabel('RUT solicitante')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator($validadorRut);
        
        $ref_orden_compra = new Zend_Form_Element_Text('ref_orden_compra');
        $ref_orden_compra->setLabel('Ref. orden de compra')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim');
        
        $ref_cotizacion = new Zend_Form_Element_Text('ref_cotizacion');
        $ref_cotizacion->setLabel('Ref. cotización')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class', 'btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib("onclick", "javascript:history.back();") 
               ->setAttrib('class', 'btn');
        
        $this->addElements(
            array(
                $proveedor, $id, $numero,$fecha,  
                $contacto, $rut_solicitante, $ref_cotizacion, 
                $ref_orden_compra, $submit, $cancel
            ));
        
        $this->addDisplayGroup(
            array(
                'numero','proveedor', 'fecha_emision', 
                'contacto', 'rut_solicitante', 
                'ref_orden_compra', 'ref_cotizacion'
            ),
            'infoInputs' 
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(array('FormElements', 'Fieldset'));
        
        $this->addDisplayGroup(array('submit', 'cancel', 'id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'dte-factura-compra',
                'action'    => '/dte-factura-compra/new'
            ));

    } 
} 
