<?php
class Default_Form_DteGuiaDespacho extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);
        
        $validadorRut = new App_Validate_ValidRut();
        
        $optionsCliente = array('table' => 'clientes', 'field' => 'id');
        $validadorCliente = new Zend_Validate_Db_RecordExists($optionsCliente);
        
        $optionsRutFacturacion = array('table' => 'datos_facturacion', 'field' => 'rut');
        $validadorRutFacturacion = new Zend_Validate_Db_RecordExists($optionsRutFacturacion);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $cliente = new Zend_Form_Element_Text('cliente');
        $cliente->setLabel('ID Cliente')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->setAttrib('class', 'show-list input-small')
                ->setAttrib('data-url', '/cliente/get-listado-popup')
                ->setAttrib('data-title', 'Seleccionar cliente')
                ->addValidator($validadorCliente);
        
        $rut = new Zend_Form_Element_Text('rut');
        $rut->setLabel('R.U.T. Facturación')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addFilter('Alnum')
                ->setAttrib('class', 'show-list input-small')
                ->setAttrib('data-url', '/datos-facturacion/get-listado-popup')
                ->setAttrib('data-title', 'Seleccionar datos de facturación')
                ->addValidator($validadorRutFacturacion);

        $numero = new Zend_Form_Element_Text('numero');
        $numero->setLabel('Nº')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setAttrib('class', 'input-mini help')
               ->setAttrib('title', 'Verifique el Nº directamente en la guía a imprimir')
               ->addValidator('Int');
        
        $fecha = new Zend_Form_Element_Text('fecha_emision');
        $fecha->setLabel('Fecha emisión')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator('Date')
                ->setAttrib('class', 'show-calendar input-small')
                ->setValue(date("Y-m-d"));

        $contacto = new Zend_Form_Element_Text('contacto');
        $contacto->setLabel('Nombre contacto')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim');
        
        $rut_solicitante = new Zend_Form_Element_Text('rut_solicitante');
        $rut_solicitante->setLabel('RUT solicitante')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->setAttrib('class', 'input-small')
                ->addValidator($validadorRut);
        
        $referencia = new Zend_Form_Element_Textarea('referencia');
        $referencia->setLabel('Referencia')
                ->setRequired(false)
                ->setAttrib('rows', '3')
                ->addFilter('StripTags')
                ->addFilter('StringTrim');
        
        $tipo_traslado = new Zend_Form_Element_Select('tipo_traslado');
        $tipo_traslado->setLabel('Tipo de traslado')
                      ->setRequired(true)
                      ->addMultiOption('', '-- Seleccionar --')
                      ->addMultiOptions(Default_Model_DteGuiaDespachoTipo::getPairsToSelect());
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class', 'btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib("onclick", "javascript:history.back();") 
               ->setAttrib('class', 'btn');
        
        $this->addElements(
            array(
                $submit, $cancel, $id, $numero, 
                $fecha, $rut, $contacto, 
                $rut_solicitante, $referencia, 
                $tipo_traslado, $cliente
            ));
        
        $this->addDisplayGroup(
            array(
                'numero','cliente', 'rut', 'fecha_emision', 'tipo_traslado'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements', 
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'span6'))
        ));
        
        $this->addDisplayGroup(
            array(
                'contacto', 'rut_solicitante', 'referencia'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements', 
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'span6'))
        ));
        
        $this->addDisplayGroup(array('submit', 'cancel', 'id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'dte-guia-despacho',
                'action'    => '/dte-guia-despacho/new'
            ));

    } 
} 
