<?php
class Default_Form_DteGuiaDespachoItem extends Zend_Form
{
    public function __construct($options = null)
    {
        parent::__construct($options);

        $validadorGuia = new Zend_Validate_Db_RecordExists(array(
            'table' => 'dte_guias_despacho',
            'field' => 'id'
        ));

        $validadorFloat = new App_Validate_Float();

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $guia_id = new Zend_Form_Element_Hidden('guia_id');
        $guia_id->addValidator('Int')
                ->addValidator($validadorGuia);    
                
                
        $codigo = new Zend_Form_Element_Text('codigo');
        $codigo->setLabel('Código')
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setAttrib('class', 'input-small') 
               ->setRequired(false);

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setRequired(true);
        
        $descripcion = new Zend_Form_Element_Textarea('descripcion');
        $descripcion->setLabel('Descripción')
                    ->setRequired(false)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setAttrib('rows', '3');
        
        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setLabel('Cantidad')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setAttrib('class', 'input-small')
                 ->addValidator($validadorFloat);
        
        $unidad_medida = new Zend_Form_Element_Select('unidad_medida');
        $unidad_medida->setLabel('Unidad de medida')
                      ->setRequired(true)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->addMultiOption('', '-- Seleccionar --')
                      ->addMultiOptions(Default_Model_AuxUnidadMedida::getPairsToSelectBasic())
                     ->setValue('U');

        $neto = new Zend_Form_Element_Text('neto');
        $neto->setLabel('Valor unitario neto')
             ->setRequired(true)
             ->addFilter('StripTags')
             ->addFilter('StringTrim')
             ->setAttrib('class', 'input-small')   
             ->addValidator('Int');

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Agregar')
               ->setAttrib('class','btn btn-primary');
        
        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn')
               ->setAttrib('data-dismiss', 'modal');

        $this->addElements(
            array(
                $id, $guia_id, $codigo, $cantidad,
                $descripcion, $submit, $neto, $nombre, 
                $unidad_medida, $cancel
            ));

        $this->addDisplayGroup(
            array(
                'cantidad', 'unidad_medida', 
                'neto', 'nombre', 'codigo',
                'descripcion'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            ));

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id', 'guia_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal form-popup span7 ajax',
                'name'      => 'item',
                'action'    => "/dte-guia-despacho-item/new/0/0/0"
            ));
    }
}
