<?php
class Default_Form_DteNotaCreditoAnulacion extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);
        
        $optionsValFactura = array('table' => 'dte_facturas', 'field' => 'numero');
        $validadorFactura = new Zend_Validate_Db_RecordExists($optionsValFactura);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $numero = new Zend_Form_Element_Text('numero');
        $numero->setLabel('Nº Nota')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setAttrib('class', 'input-mini help')
               ->setAttrib('title', 'Verifique el Nº directamente en la factura a imprimir')
               ->addValidator('Int');
        
        $fecha = new Zend_Form_Element_Text('fecha_emision');
        $fecha->setLabel('Fecha emisión')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator('Date')
              ->setAttrib('class', 'show-calendar input-small')
              ->setValue(date("Y-m-d"));
        
        $ref_dte_factura = new Zend_Form_Element_Text('ref_dte_factura');
        $ref_dte_factura->setLabel('Nº Factura')
                        ->setRequired(true)
                        ->addFilter('StripTags')
                        ->addFilter('StringTrim')
                        ->setAttrib('class', 'input-mini help')
                        ->setAttrib('title', 'Verifique el Nº directamente en la nota de crédito a imprimir')
                        ->addValidator('Int')
                        ->addValidator($validadorFactura);
        
        $ref_detalle = new Zend_Form_Element_Textarea('ref_detalle');
        $ref_detalle->setLabel('Motivo anulación')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setAttrib('class', 'input-xlarge help')
                    ->setAttrib('title', 'Indique claramente el motivo de la anulación de la factura')
                    ->setAttrib('rows', '3');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class', 'btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib("onclick", "javascript:history.back();") 
               ->setAttrib('class', 'btn');
        
        $this->addElements(
            array(
                $id, $numero, $fecha, $ref_dte_factura,
                $ref_detalle, $submit, $cancel
            ));
        
        $this->addDisplayGroup(
            array(
                'numero', 'ref_dte_factura', 'fecha_emision',
                'ref_detalle',    'ref_orden_compra', 'ref_cotizacion'
            ),
            'infoInputs'   
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(array('FormElements', 'Fieldset'));
        
        $this->addDisplayGroup(array('submit', 'cancel', 'id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'dte-nota-credito',
                'action'    => '/dte-nota-credito/new'
            ));

    } 
} 
