<?php
class Default_Form_DtrGuiaDespacho extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);
        
        $optionsProveedor = array('table' => 'proveedores', 'field' => 'rut');
        $validadorProveedor = new Zend_Validate_Db_RecordExists($optionsProveedor);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $proveedor = new Zend_Form_Element_Text('proveedor');
        $proveedor->setLabel('Proveedor')
                  ->setRequired(true)
                  ->addFilter('StripTags')
                  ->addFilter('StringTrim')
                  ->addFilter('Alnum')  
                  ->setAttrib('class', 'show-list input-small')
                  ->setAttrib('data-url', '/proveedor/get-listado-popup')
                  ->setAttrib('data-title', 'Seleccionar proveedor')
                  ->addValidator($validadorProveedor);
        
        $numero = new Zend_Form_Element_Text('numero');
        $numero->setLabel('Nº Guía de Despacho')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setAttrib('class', 'input-mini')
               ->addValidator('Int');
        
        $fecha = new Zend_Form_Element_Text('fecha_emision');
        $fecha->setLabel('Fecha emisión')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator('Date')
                ->setAttrib('class', 'show-calendar input-small')
                ->setValue(date("Y-m-d"));
        
        $total = new Zend_Form_Element_Text('total');
        $total->setLabel('Total')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator('Int');

        $entregada_por = new Zend_Form_Element_Select('entregada_por');
        $entregada_por->setLabel('Entregada / Rendida por')
                      ->setRequired(true)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->addMultiOption('', '-- Seleccionar --')
                      ->addMultiOptions(Default_Model_RemEmpleado::getPairsToSelect());
        
        $referencia = new Zend_Form_Element_Textarea('referencia');
        $referencia->setLabel('Referencia')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->setAttrib('rows', '3');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class', 'btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib("onclick", "javascript:history.back();") 
               ->setAttrib('class', 'btn');
        
        $this->addElements(
            array(
                $proveedor,  $id, $numero, 
                $fecha,  $total, $entregada_por, 
                $submit, $cancel, $referencia
            ));
        
        $this->addDisplayGroup(
            array(
                'proveedor', 'numero', 
                'fecha_emision', 'total', 
                'entregada_por', 'referencia'
            ),
            'infoInputs' 
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(array('FormElements', 'Fieldset'));
        
        $this->addDisplayGroup(array('submit', 'cancel', 'id', 'ref_dtr_factura'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'dtr-guia-despacho',
                'action'    => '/dtr-guia-despacho/new'
            ));

    } 
} 
