<?php
class Default_Form_DtrNotaCredito extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);
        
        $optionsProveedor = array('table' => 'proveedores', 'field' => 'rut');
        $validadorProveedor = new Zend_Validate_Db_RecordExists($optionsProveedor);
        
        $optionsFactura = array('table' => 'dtr_facturas', 'field' => 'numero');
        $validadorFactura = new Zend_Validate_Db_RecordExists($optionsFactura);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $proveedor = new Zend_Form_Element_Text('proveedor');
        $proveedor->setLabel('RUT Proveedor')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addFilter('Alnum')
                ->setAttrib('class', 'show-list input-small')
                ->setAttrib('data-url', '/proveedor/get-listado-popup')
                ->setAttrib('data-title', 'Seleccionar proveedor')
                ->addValidator($validadorProveedor);
        
        $ref_dtr_factura = new Zend_Form_Element_Text('ref_dtr_factura');
        $ref_dtr_factura->setLabel('Nº DTR Factura')
                        ->setRequired(true)
                        ->addFilter('StripTags')
                        ->addFilter('StringTrim')
                        ->setAttrib('class', 'help')
                        ->setAttrib('title', 'La factura debe estar previamente ingresada en el sistema')
                        ->addValidator($validadorFactura);
        
        $ref_detalle = new Zend_Form_Element_Textarea('ref_detalle');
        $ref_detalle->setLabel('Detalle emisión nota')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->setAttrib('rows', '3')
                    ->setAttrib('class', 'help')
                    ->setAttrib('title', 'Detalle o motivo de la emisión de la nota de crédito.')
                    ->addFilter('StringTrim');
        
        $numero = new Zend_Form_Element_Text('numero');
        $numero->setLabel('Nº Nota de Crédito')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Int');
        
        $fecha = new Zend_Form_Element_Text('fecha_emision');
        $fecha->setLabel('Fecha emisión')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addValidator('Date')
                ->setAttrib('class', 'show-calendar input-small')
                ->setValue(date("Y-m-d"));
        
        $neto = new Zend_Form_Element_Text('neto');
        $neto->setLabel('Neto')
             ->setRequired(true)
             ->addFilter('StripTags')
             ->addFilter('StringTrim')
             ->addValidator('Int');
        
        $iva = new Zend_Form_Element_Text('iva');
        $iva->setLabel('I.V.A.')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim')
            ->addValidator('Int');
        
        $total = new Zend_Form_Element_Text('total');
        $total->setLabel('Total')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator('Int');

        $entregada_por = new Zend_Form_Element_Select('entregada_por');
        $entregada_por->setLabel('Entregada / Rendida por')
                      ->setRequired(true)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->addMultiOption('', '-- Seleccionar --')
                      ->addMultiOptions(Default_Model_RemEmpleado::getPairsToSelect());
        
        
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class', 'btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib("onclick", "javascript:history.back();") 
               ->setAttrib('class', 'btn');
        
        $this->addElements(
            array(
                $proveedor, $ref_detalle,  $id, $numero, 
                $fecha,  $neto, $iva, $total, $entregada_por, 
                $submit, $cancel, $ref_dtr_factura
            ));
        
        $this->addDisplayGroup(
            array(
                'proveedor', 'numero', 'fecha_emision', 
                'ref_dtr_factura', 'ref_detalle'
                
            ),
            'infoInputs'   
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements', 
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'span6'))
            ));
        
        $this->addDisplayGroup(
            array(
                'neto', 'iva', 'total', 'entregada_por'
            ),
            'infoInputs2'   
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements', 
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'span6'))
            ));
        
        $this->addDisplayGroup(array('submit', 'cancel', 'id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'dtr-nota-credito',
                'action'    => '/dtr-nota-credito/new'
            ));

    } 
} 
