<?php
class Default_Form_EgresoCajaChica extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/caja-chica/user')
    { 
        parent::__construct($options);

        $validadorCiclo = new Zend_Validate_Db_RecordExists(
            array(
                'table' => 'cc_ciclos_cajas',
                'field' => 'id'
            )
        );

        $descripcionDetalles = "Por favor indique una referencia sobre el motivo del egreso";
        $descripcionOrdenesServicios = "Los Nº de orden serán validados. Si es más de una orden, ingrese los números separados por una coma. Ej: 81, 83";

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $ciclo_id = new Zend_Form_Element_Hidden('ciclo_id');
        $ciclo_id->addValidator('Int')
                   ->setDecorators(array('ViewHelper'))
                   ->addValidator($validadorCiclo);

        $entregado_a = new Zend_Form_Element_Select('entregado_a');
        $entregado_a->setLabel('Entregado a')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOptions(Default_Model_Empleado::getPairsToSelect());

        $maximo = new Zend_Form_Element_Text('maximo');
        $maximo->setRequired(false)
               ->setLabel('Monto máximo egreso')
               ->setAttrib('class', 'tooltip')
               ->setDescription('Monto máximo disponible para el egreso.');

        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setLabel('Cantidad entregada ($)')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator('Int')
                 ->setAttrib('class', 'tooltip')
                 ->setDescription('Número sin puntos ni signos');

        $ordenes_servicios = new Zend_Form_Element_Text('ordenes_servicios');
        $ordenes_servicios->setRequired(false)
                       ->setLabel('Nº de órdenes de servicios (sólo si corresponde)')
                       ->addFilter('StripTags')
                       ->addFilter('StringTrim')
                       ->setAttrib("class", "tooltip")
                       ->setDescription($descripcionOrdenesServicios);


        $detalles = new Zend_Form_Element_Textarea('detalles');
        $detalles->setLabel('Detalles egreso')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setAttrib("class", "tooltip")
                 ->setDescription($descripcionDetalles);
        
        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Registrar egreso')
               ->setAttrib('class','caja-chica')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $ciclo_id, $entregado_a,
                $cantidad, $detalles,
                $submit, $cancel, $back, $id,
                $maximo, $ordenes_servicios
            ));

        $this->addDisplayGroup(
            array(
                'entregado_a', 'maximo', 'cantidad', 'ordenes_servicios', 'detalles'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left-ancho'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back', 'id', 'ciclo_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'egreso-caja-chica',
                'action'    => $path . '/new'
            ));
    } 
} 
