<?php
class Default_Form_FormaPago extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $validadorLocale = new App_Validate_Float();
        $validadorRango = new Zend_Validate_Between(array('min' => '0', 'max' => '100'));

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $tipo = new Zend_Form_Element_Select('tipo');
        $tipo->setLabel('Tipo de pago')
               ->setRequired(true)
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOption('CONTADO', 'CONTADO')
               ->addMultiOption('DOCUMENTO BANCARIO', 'DOCUMENTO BANCARIO')
               ->addMultiOption('TARJETA BANCARIA', 'TARJETA BANCARIA');
              
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');

        $porcentaje_recargo = new Zend_Form_Element_Text('porcentaje_recargo');
        $porcentaje_recargo->setLabel('Recargo (%)')
                           ->setRequired(true)
                           ->addValidator($validadorRango)
                           ->addValidator($validadorLocale);

        $detallar = new Zend_Form_Element_Select('detallar');
        $detallar->setLabel('Detallar')
               ->setRequired(true)
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOption('NO', 'NO')
               ->addMultiOption('DOCUMENTO', 'DOCUMENTO')
               ->addMultiOption('CODIGO', 'CODIGO');

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear forma de pago')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $id, $tipo, $nombre, $porcentaje_recargo,
                $detallar, $submit, $cancel
            ));

        $this->addDisplayGroup(
            array(
                'tipo', 'nombre', 'porcentaje_recargo', 'detallar'
            ),
            'infoInputs',
            array('legend' => 'Formulario formas de pago')    
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'forma-pago',
                'action'    => '/forma-pago/new'
            ));
    } 
} 
