<?php
class Default_Form_ItemCotizacion extends Zend_Form
{
    public function __construct($options = null)
    {
        parent::__construct($options);

        $validadorVehiculo = new Zend_Validate_Db_RecordExists(array(
            'table' => 'vehiculos',
            'field' => 'patente'
        ));

        $validadorFloat = new App_Validate_Float();

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $cotizacion_id = new Zend_Form_Element_Hidden('cotizacion_id');
        $cotizacion_id->addValidator('Int');

        $codigo = new Zend_Form_Element_Text('codigo');
        $codigo->setLabel('Código')
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setRequired(false);

        $vehiculo = new Zend_Form_Element_Text('vehiculo');
        $vehiculo->setLabel('Patente Vehículo')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addFilter('StringToUpper')
                 ->setRequired(false)
                 ->addValidator($validadorVehiculo);
        
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->setAttrib('class', 'span11')
                 ->addFilter('StringTrim');
        
        $descripcion = new Zend_Form_Element_Textarea('descripcion');
        $descripcion->setLabel('Descripción')
                    ->setRequired(false)
                    ->addFilter('StripTags', array('allowTags' => array('p', 'ul', 'ol', 'li')))
                    ->addFilter('StringTrim')
                    ->setAttrib('class', 'span11')
                    ->setAttrib('style', 'height:178px;');
        
        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setLabel('Cantidad')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator($validadorFloat);
        
        $unidad_medida = new Zend_Form_Element_Select('unidad_medida');
        $unidad_medida->setLabel('Unidad de medida')
                      ->setRequired(true)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->addMultiOptions(Default_Model_AuxUnidadMedida::getPairsToSelectBasic())
                      ->setValue('u');
        
        $tipo = new Zend_Form_Element_Select('tipo');
        $tipo->setLabel('Tipo')
             ->setRequired(true)
             ->addFilter('StripTags')
             ->addFilter('StringTrim')
             ->addMultiOption('', '-- Seleccionar --')
             ->addMultiOption('IN', 'INSUMOS')
             ->addMultiOption('SI', 'SERVICIOS INTERNOS')
             ->addMultiOption('SE', 'SERVICIOS EXTERNOS')
             ->addMultiOption('RI', 'REPUESTOS INTERNOS')
             ->addMultiOption('RE', 'REPUESTOS EXTERNOS');   
                
        $precio_venta = new Zend_Form_Element_Text('precio_venta');
        $precio_venta->setLabel('Precio de venta')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->setAttrib('class', 'help')
                   ->setAttrib('title', 'Valor bruto')
                   ->addValidator('Int');
        
        $descuento = new Zend_Form_Element_Text('descuento');
        $descuento->setLabel('Valor descuento')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->setValue(0);

        $tipo_descuento = new Zend_Form_Element_Select('tipo_descuento');
        $tipo_descuento->setLabel('Tipo descuento')
                       ->setRequired(true)
                       ->addMultiOption('MONTO', '$ monto')
                       ->addMultiOption('PORCENTAJE', '% porcentaje');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Agregar')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn');

        $this->addElements(
            array(
                $id, $cotizacion_id, $codigo, $cantidad,
                $descripcion, $precio_venta,
                $nombre, $unidad_medida, $descuento,
                $tipo_descuento, $vehiculo, $tipo,
                $submit, $cancel
            ));

        $this->addDisplayGroup(
            array(
                'tipo', 'vehiculo', 'unidad_medida', 'codigo', 
                'nombre', 'descripcion', 'cantidad', 'precio_venta', 
                'tipo_descuento', 'descuento', 
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            ));
        
        $this->addDisplayGroup(array('submit', 'cancel','id', 'cotizacion_id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));
        
        $id->setDecorators(array('ViewHelper'));
        $cotizacion_id->setDecorators(array('ViewHelper'));
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
             
        $this->setAttribs(array(
            'class'     => 'form-horizontal',
            'name'      => 'item-cotizacion'
        ));
    }
}
