<?php
class Default_Form_ItemSolicitudCompra extends Zend_Form
{
    public function __construct($options = null)
    {
        parent::__construct($options);

        $validadorFloat = new App_Validate_Float();

        $optionsSolicitud = array('table' => 'solicitudes_compras', 'field' => 'id');
        $validadorSolicitud = new Zend_Validate_Db_RecordExists($optionsSolicitud);

        $optionsOrden = array('table' => 'ordenes_servicios', 'field' => 'id');
        $validadorOrden = new Zend_Validate_Db_RecordExists($optionsOrden);

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $solicitud_id = new Zend_Form_Element_Hidden('solicitud_id');
        $solicitud_id->addValidator('Int')
                     ->addValidator($validadorSolicitud)
                     ->setDecorators(array('ViewHelper'));

        $orden_id = new Zend_Form_Element_Text('orden_id');
        $orden_id->setLabel('Nº orden de servicio')
                 ->addValidator('Int')
                 ->addValidator($validadorOrden);

        $buscador = new Zend_Form_Element_Text('buscador');
        $buscador->setRequired(false);

        $codigo = new Zend_Form_Element_Text('codigo');
        $codigo->setLabel('Código artículo/servicio (proveedor)')
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setRequired(false);

        $tipo_valor = new Zend_Form_Element_Radio('tipo_valor');
        $tipo_valor->setLabel('Tipo valor')
                   ->setRequired(true)
                   ->addMultiOption('BRUTO', 'Bruto')
                   ->addMultiOption('NETO', 'Neto')
                   ->setValue('BRUTO');

        $valor_neto = new Zend_Form_Element_Text('valor_neto');
        $valor_neto->setLabel('Valor unitario neto')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->addValidator('Int');

        $tipo_descuento = new Zend_Form_Element_Radio('tipo_descuento');
        $tipo_descuento->setLabel('Tipo descuento')
                       ->setRequired(true)
                       ->addMultiOption('PORCENTAJE', '% porcentaje')
                       ->addMultiOption('MONTO', '$ monto')
                       ->setValue('PORCENTAJE');

        $descuento = new Zend_Form_Element_Text('descuento');
        $descuento->setLabel('Valor descuento')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->setValue(0);

        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setLabel('Cantidad')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator($validadorFloat);

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim');

        $unidad_medida = new Zend_Form_Element_Select('unidad_medida');
        $unidad_medida->setLabel('Unidad de medida')
                      ->setRequired(true)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->addMultiOption('', '-- Seleccionar --')
                      ->addMultiOptions(Default_Model_UnidadMedida::getPairsToSelectBasic());

        $descripcion = new Zend_Form_Element_Textarea('descripcion');
        $descripcion->setLabel('Descripción')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setAttrib('style', 'width:400px;height:77px;');

        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Agregar a la solicitud')
               ->setDecorators(array('ViewHelper'));

        $this->addElements(
            array(
                $id, $solicitud_id, $codigo, $cantidad,
                $descripcion, $submit, $buscador, $valor_neto,
                $nombre, $unidad_medida, $descuento,
                $tipo_descuento, $tipo_valor, $orden_id
            ));

        $this->addDisplayGroup(
            array(
                'buscador'
            ),
            'busquedaInputs'
        );

        $busquedaInputs = $this->getDisplayGroup('busquedaInputs');
        $busquedaInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-busqueda'))
            ));

        $this->addDisplayGroup(
            array(
                'cantidad', 'tipo_valor', 'valor_neto', 'tipo_descuento', 'descuento', 'orden_id'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            ));

        $this->addDisplayGroup(
            array(
                'unidad_medida', 'codigo', 'nombre', 'descripcion'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'id', 'solicitud_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'item',
                'action'    => "/item-solicitud-compra/new"
            ));
    }
}
