<?php
class Default_Form_NotaVenta extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $optionsRecepcion = array('table' => 'recepciones_vehiculos', 'field' => 'id');
        $validadorRecepcion = new Zend_Validate_Db_RecordExists($optionsRecepcion);
        
        $descripcionRecepcionId = 'Por favor ingrese el Nº de recepción si '
                                . 'es que corresponde. De lo contrario dejar en blanco';

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $cliente_id = new Zend_Form_Element_Select('cliente_id');
        $cliente_id->setLabel('Cliente')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->addMultiOption('', '-- Seleccionar --')
                   ->addMultiOptions(Default_Model_Cliente::getPairsToSelect());

        $recepcion_id = new Zend_Form_Element_Text('recepcion_id');
        $recepcion_id->setLabel('Nº Recepción')
                   ->setRequired(false)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->addValidator($validadorRecepcion)
                   ->setAttrib('title', $descripcionRecepcionId)
                   ->setAttrib('class', 'help input-small');

        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->setAttrib('rows', '4')
                      ->setAttrib('class', 'input-xlarge');
            
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
               
        $this->addElements(
            array(
                $id, $cliente_id, $observaciones,
                $submit, $cancel, $recepcion_id
            ));

        $this->addDisplayGroup(
            array(
                'cliente_id', 'recepcion_id', 'observaciones'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));

        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'nota-venta',
                'action'    => '/nota-venta/new'
            ));
    } 
} 
