<?php
class Default_Form_OrdenCompra extends Zend_Form
{ 
    public function __construct($usuario, $options = null)
    { 
        parent::__construct($options);

        $validadorFloat = new App_Validate_Float();

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $proveedor_id = new Zend_Form_Element_Select('proveedor_id');
        $proveedor_id->setLabel('Proveedor')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->addMultiOption('', '-- Seleccionar --')
                   ->addMultiOptions(Default_Model_Proveedor::getPairsToSelect());

        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setLabel('Fecha emisión')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Date')
               ->setAttrib('class', 'show-calendar')
               ->setValue(date("Y-m-d"));

        $validez = new Zend_Form_Element_Text('validez');
        $validez->setLabel('Validez (días)')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Int')
               ->setValue((int)Default_Model_SistemaPreferencia::getPref('OC_VALIDEZ'));

        $proveedor_paga_flete = new Zend_Form_Element_Checkbox('proveedor_paga_flete');
        $proveedor_paga_flete->setLabel('Proveedor paga flete')
                             ->setRequired(true)
                             ->addFilter('StripTags')
                             ->addFilter('StringTrim')
                             ->setCheckedValue('SI')
                             ->setUncheckedValue('NO');

        $atencion_a = new Zend_Form_Element_Text('atencion_a');
        $atencion_a->setLabel('Atención a')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim');

        $descuento_global = new Zend_Form_Element_Text('descuento_global');
        $descuento_global->setLabel('Descuento global %')
                         ->setRequired(true)
                         ->setAttrib('class', 'help')
                         ->setAttrib('title', 'Porcentaje de descuento aplicado al total de la orden. Sólo números enteros o decimales. Ej.: 7,5')
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->addValidator($validadorFloat)
                         ->setValue(0);

        $emitida_por = new Zend_Form_Element_Text('emitida_por');
        $emitida_por->setLabel('Emitida por')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setValue($usuario);

        $condiciones_pago = new Zend_Form_Element_Text('condiciones_pago');
        $condiciones_pago->setLabel('Condiciones de pago')
                         ->setRequired(true)
                         ->setAttrib('class', 'help')
                         ->setAttrib('title', 'Plazo para pagar la compra en días.')
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->setValue((int)Default_Model_SistemaPreferencia::getPref('OC_COND_PAGO'));

        $referencia = new Zend_Form_Element_Text('referencia');
        $referencia->setLabel('Doc. referencia')
            ->addFilter('StripTags')
            ->addFilter('StringTrim');

        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
                      ->setAttrib('rows','5')
                      ->setAttrib('class', 'input-xlarge')
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim');
            

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear orden')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $id, $proveedor_id, $fecha, $validez,
                $atencion_a, $emitida_por,
                $condiciones_pago, $referencia,
                $observaciones, $submit, $cancel,
                $proveedor_paga_flete, $descuento_global
            ));

        $this->addDisplayGroup(
            array(
                'proveedor_id', 'fecha', 'validez','atencion_a', 
                'emitida_por', 'condiciones_pago', 'descuento_global'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(array(
            'FormElements',
            'Fieldset',
            array('HtmlTag', array('tag' => 'div', 'class' => 'span6'))
        ));
        
        $this->addDisplayGroup(
            array(
                'proveedor_paga_flete', 'referencia', 'observaciones'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(array(
            'FormElements',
            'Fieldset',
            array('HtmlTag', array('tag' => 'div', 'class' => 'span6'))
        ));

        $this->addDisplayGroup(array('submit', 'cancel', 'id', 'proveedor'), 'submitButtons');

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'orden-compra',
                'action'    => '/orden-compra/new'
            ));
    } 
} 
