<?php
class Default_Form_PagoRecibido extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $optionsCliente = array('table' => 'clientes', 'field' => 'id');
        $validadorCliente = new Zend_Validate_Db_RecordExists($optionsCliente);

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $cliente = new Zend_Form_Element_Text('cliente');
        $cliente->setLabel('ID Cliente')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->setAttrib('class', 'show-list input-small')
                ->setAttrib('data-url', '/cliente/get-listado-popup')
                ->setAttrib('data-title', 'Seleccionar cliente')
                ->addValidator($validadorCliente);

        $forma_id = new Zend_Form_Element_Select('forma_id');
        $forma_id->setLabel('Forma de pago')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addMultiOption('', '-- Seleccionar --')
                ->addMultiOptions(Default_Model_PagoRecibidoForma::getPairsToSelect());
        
        $tipo = new Zend_Form_Element_Select('tipo');
        $tipo->setLabel('Tipo de operación')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->setAttrib('class', 'input-small')
                ->addMultiOption('', '-- Seleccionar --')
                ->addMultiOption('PAGO', 'PAGO')
                ->addMultiOption('ABONO', 'ABONO')
                ->setValue('PAGO');

        $monto = new Zend_Form_Element_Text('monto');
        $monto->setLabel('Monto cancelado')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->setAttrib('class', 'input-small')   
              ->addValidator('Int');

        $observaciones = new Zend_Form_Element_Textarea('observaciones');
        $observaciones->setLabel('Observaciones')
                      ->setRequired(false)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->setAttrib('rows', '4');

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $cliente, $forma_id, $monto,
                $observaciones,$submit, $cancel,
                $id, $tipo
            ));

        $this->addDisplayGroup(
            array(
                'cliente', 'tipo', 'forma_id', 'monto', 'observaciones'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            ));


        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));    
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'pago-recibido',
                'action'    => '/pago-recibido/new'
            ));

    } 
} 
