<?php
class Default_Form_PagoRecibidoDocumentoBancario extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $optionsPago = array('table' => 'pagos_recibidos', 'field' => 'id');
        $validadorPago = new Zend_Validate_Db_RecordExists($optionsPago);

        $pago_id = new Zend_Form_Element_Hidden('pago_id');
        $pago_id->setRequired(true)
                ->addValidator('Int')
                ->addValidator($validadorPago);

        $tipo_id = new Zend_Form_Element_Select('tipo_id');
        $tipo_id->setLabel('Tipo de operación')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->addMultiOption('', '-- Seleccionar --')
                ->addMultiOptions(Default_Model_PagoRecibidoDocumentoBancarioTipo::getPairsToSelect())
                ->setValue(1);
        
        $fecha_cobro = new Zend_Form_Element_Text('fecha_cobro');
        $fecha_cobro->setLabel('Fecha de cobro')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setAttrib('class', 'show-calendar input-small')   
                    ->addValidator('Date');
        
        $banco = new Zend_Form_Element_Text('banco');
        $banco->setLabel('Banco')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->setAttrib('class', 'input-small');
        
        $cuenta = new Zend_Form_Element_Text('cuenta');
        $cuenta->setLabel('Cuenta')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->setAttrib('class', 'input-small');
        
        $serie = new Zend_Form_Element_Text('serie');
        $serie->setLabel('Serie')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->setAttrib('class', 'input-small');
        
        $titular = new Zend_Form_Element_Text('titular');
        $titular->setLabel('Titular')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn')
               ->setAttrib('data-dismiss', 'modal');
        
        $this->addElements(
            array(
                $pago_id, $tipo_id, $fecha_cobro, 
                $cuenta, $serie, $titular, $banco,
                $submit, $cancel
            ));

        $this->addDisplayGroup(
            array(
                'tipo_id', 'fecha_cobro', 'banco', 'cuenta', 
                'serie', 'titular'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            ));


        $this->addDisplayGroup(
            array('submit', 'cancel', 'pago_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $pago_id->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));    
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal form-popup span7 ajax',
                'name'      => 'item',
                'action'    => '/pago-recibido/new-documento-bancario'
            ));

    } 
} 
