<?php
class Default_Form_PresupuestoRepuestoExterno extends Zend_Form
{
    public function __construct($options = null)
    {
        parent::__construct($options);

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $presupuesto_id = new Zend_Form_Element_Hidden('presupuesto_id');
        $presupuesto_id->addValidator('Int');
        
        $calidad_solicitada = new Zend_Form_Element_Select('calidad_solicitada');
        $calidad_solicitada->setLabel('Calidad solicitada')
                      ->setRequired(true)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->addMultiOption('', '-- Seleccionar --')
                      ->addMultiOptions(Default_Model_TipoRepuesto::getPairsToSelect());

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre / Desc.')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setAttrib('class', 'input-xxlarge help')
                 ->setAttrib("title", "Máximo de 100 caracteres.");
        
        $cantidad_requerida = new Zend_Form_Element_Text('cantidad_requerida');
        $cantidad_requerida->setLabel('Cantidad requerida')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator('Int')
                 ->setAttrib("class", "help")
                 ->setAttrib("title", "Sólo números enteros");
        
        $muestra = new Zend_Form_Element_Select('muestra');
        $muestra->setLabel('¿Existe muestra?')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption("1", "Si")
                 ->addMultiOption("0", "No");
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Agregar')
               ->setAttrib('class','btn btn-primary');
        
        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Volver al presupuesto')
               ->setAttrib('class', 'btn');

        $this->addElements(
            array(
                $id, $presupuesto_id, $calidad_solicitada, 
                $cantidad_requerida, $muestra, $nombre, 
                $submit, $cancel 
            ));

        $this->addDisplayGroup(
            array(
                'cantidad_requerida', 'calidad_solicitada'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'span3'))
            ));
        
        $this->addDisplayGroup(
            array(
                'muestra', 'nombre'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'span9'))
            ));

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id', 'presupuesto_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        $presupuesto_id->setDecorators(array('ViewHelper'));

        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
        
        $this->setAttribs(array(
            'class'     => 'vertical',
            'name'      => 'repuesto-externo',
            'action'    => "/presupuesto-repuesto-externo/agregar"
        ));
    }
}
