<?php
class Default_Form_PresupuestoRepuestoExternoCotizado extends Zend_Form
{
    public function __construct($options = null)
    {
        parent::__construct($options);

        $validadorFloat = new App_Validate_Float();
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $presupuesto_repuesto_externo_id = new Zend_Form_Element_Hidden('presupuesto_repuesto_externo_id');
        $presupuesto_repuesto_externo_id->addValidator('Int');
        
        $presupuesto_id = new Zend_Form_Element_Hidden('presupuesto_id');
        
        $proveedor_id = new Zend_Form_Element_Select('proveedor_id');
        $proveedor_id->setLabel('Proveedor')
                  ->setRequired(true)
                  ->addFilter('StripTags')
                  ->addFilter('StringTrim')
                  ->addMultiOption('', '-- Seleccionar --')
                  ->addMultiOptions(Default_Model_Proveedor::getPairsToSelect());
        
        $tipo_repuesto_id = new Zend_Form_Element_Select('tipo_repuesto_id');
        $tipo_repuesto_id->setLabel('Calidad cotizada')
                         ->setRequired(true)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->addMultiOption('', '-- Seleccionar --')
                         ->addMultiOptions(Default_Model_TipoRepuesto::getPairsToSelect());

        $codigo = new Zend_Form_Element_Text('codigo');
        $codigo->setLabel('Código')
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setRequired(false);
        
        $marca = new Zend_Form_Element_Text('marca');
        $marca->setLabel('Marca')
                 ->setRequired(false)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim');

        $valor_unitario_bruto = new Zend_Form_Element_Text('valor_unitario_bruto');
        $valor_unitario_bruto->setLabel('Precio de compra c/IVA')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator('Int')
              ->setAttrib("class", "help")
              ->setAttrib('title', "Monto en pesos. Ingrese un valor entero sin signos ni puntos");
        
        $margen = new Zend_Form_Element_Text('margen');
        $margen->setLabel('Margen a aplicar')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator($validadorFloat)
              ->setAttrib("class", "help calcular_precio_venta")
              ->setAttrib('data-compra', "#valor_unitario_bruto")    
              ->setAttrib("data-target", "#precio_venta")
              ->setAttrib("title", "Porcentaje % - Ingrese un valor entero o decimal separado con punto (.)");
        
        $precio_venta = new Zend_Form_Element_Text('precio_venta');
        $precio_venta->setLabel('Precio de venta c/IVA')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator('Int')
              ->setAttrib("class", "help calcular_margen")
              ->setAttrib('data-compra', "#valor_unitario_bruto")  
              ->setAttrib('data-target', '#margen')
              ->setAttrib("title", "Monto en pesos. Ingrese un valor entero sin signos ni puntos");

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Agregar')
               ->setAttrib('class','btn btn-primary');
        
        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Volver al presupuesto')
               ->setAttrib('class', 'btn');

        $this->addElements(
            array(
                $id, $presupuesto_repuesto_externo_id, $proveedor_id, 
                $tipo_repuesto_id, $codigo, $marca, $precio_venta,
                $valor_unitario_bruto, $margen, $submit, $cancel,
                $presupuesto_id
            ));
        
        $this->addDisplayGroup(
            array(
                'proveedor_id', 'tipo_repuesto_id' ,'codigo', 
                'marca'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag' => 'div', 'class'=> 'span3'))
            ));
        
        $this->addDisplayGroup(
            array(
                'valor_unitario_bruto', 'margen', 
                'precio_venta'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag' => 'div', 'class'=> 'span3'))
            ));
        
        $this->addDisplayGroup(
            array('submit', 'cancel', 'id', 'presupuesto_repuesto_externo_id', 'presupuesto_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        $presupuesto_repuesto_externo_id->setDecorators(array('ViewHelper'));

        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));

        $this->setAttribs(array(
            'class'     => 'form-vertical',
            'name'      => 'repuesto-externo',
            'action'    => "/presupuesto-repuesto-externo-cotizado/agregar"
        ));
    }
}
