<?php
class Default_Form_PresupuestoServicioInterno extends Zend_Form
{
    public function __construct($options = null)
    {
        parent::__construct($options);

        $validadorFloat = new App_Validate_Float();
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $presupuesto_id = new Zend_Form_Element_Hidden('presupuesto_id');
        $presupuesto_id->addValidator('Int');
        
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->setAttrib("class", "help input-xxlarge")
                   ->setAttrib("title", "Máximo de 100 caracteres.");
        
        $costo_bruto_estimado = new Zend_Form_Element_Text('costo_bruto_estimado');
        $costo_bruto_estimado->setLabel('Costo bruto estimado')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator('Int')
              ->setAttrib("class", "help")
              ->setAttrib('title', "Monto en pesos. Ingrese un valor entero sin signos ni puntos");
        
        $margen = new Zend_Form_Element_Text('margen');
        $margen->setLabel('Margen a aplicar')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator($validadorFloat)
              ->setAttrib("class", "help calcular_precio_venta")
              ->setAttrib('data-compra', "#costo_bruto_estimado")
              ->setAttrib('data-target', "#precio_venta")
              ->setAttrib("title", "Porcentaje % - Ingrese un valor entero o decimal separado con punto (.)");
                    
        $precio_venta = new Zend_Form_Element_Text('precio_venta');
        $precio_venta->setLabel('Precio venta c/IVA')
                     ->setRequired(true)
                     ->addFilter('StripTags')
                     ->addFilter('StringTrim')
                     ->addValidator('Int')
                     ->setAttrib("class", "help calcular_margen")
                     ->setAttrib('data-compra', "#costo_bruto_estimado")
                     ->setAttrib('data-target', "#margen")
                     ->setAttrib("title", "Ingrese un valor entero sin puntos ni signos.");
        
        $descripcion = new Zend_Form_Element_Textarea('descripcion');
        $descripcion->setLabel('Descripción servicio')
                 ->setRequired(false)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setAttrib("rows", "5")
                 ->setAttrib("class", "help input-xxlarge")
                 ->setAttrib("title", "Máximo de 200 caracteres.");
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Agregar')
               ->setAttrib('class','btn btn-primary');
        
        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Volver al presupuesto')
               ->setAttrib('class', 'btn');

        $this->addElements(
            array(
                $id, $presupuesto_id, $costo_bruto_estimado, $margen, 
                $precio_venta, $nombre, $descripcion, $submit, $cancel
            ));
        
        $this->addDisplayGroup(
            array(
                'nombre', 'descripcion'
            ),
            'infoInputs2'   
        );
        
        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            ));
        
        $this->addDisplayGroup(
            array(
                 'costo_bruto_estimado', 'margen', 'precio_venta'
            ),
            'infoInputs'   
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            ));

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id', 'presupuesto_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        $presupuesto_id->setDecorators(array('ViewHelper'));

        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
        
        $this->setAttribs(array(
            'class'     => 'form-vertical',
            'name'      => 'item-servicio-interno'
        ));
    }
}
