<?php
class Default_Form_Producto extends Zend_Form
{ 
    public function __construct($options = null, $path = null, $history = '/producto/index/t/a')
    { 
        parent::__construct($options);

        $descripcionUnidades = 'Máximo de unidades a vender del producto. '
                             . 'Deje vacío si no desea poner un límite';

        $descripcionFechaTermino = 'Fecha límite para la venta del producto.'
                                 . 'Se incluye el día de cierre seleccionado';

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $codigo = new Zend_Form_Element_Text('codigo');
        $codigo->setLabel('Código')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addFilter('StringToUpper');

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim');

        $categoria_id = new Zend_Form_Element_Select('categoria_id');
        $categoria_id->setLabel('Categoría')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOptions(Default_Model_CategoriaProducto::getPairsToSelect());

        $unidades = new Zend_Form_Element_Text('unidades');
        $unidades->setLabel('Unidades disponibles')
                 ->setRequired(false)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator('Int')
                 ->setAttrib('class', 'tooltip')
                 ->setDescription($descripcionUnidades);

        $fecha_termino = new Zend_Form_Element_Text('fecha_termino');
        $fecha_termino->setLabel('Fecha de término')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator('Date')
                 ->setAttrib('class', 'show-calendar');

        $descripcion = new Zend_Form_Element_Textarea('descripcion');
        $descripcion->setLabel('Descripción')
               ->addFilter('StripTags')
               ->addFilter('StringTrim');
        
        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Crear producto')
               ->setAttrib('class','producto')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $codigo, $categoria_id, $unidades,
                $fecha_termino, $descripcion, 
                $submit, $cancel, $back, $nombre
            ));
            
        $this->addDisplayGroup(
            array(
                 'codigo', 'nombre', 'categoria_id',
                 'descripcion'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );

        $this->addDisplayGroup(
            array(
                 'unidades',  'fecha_termino'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left'))
            )
        );


        $this->addDisplayGroup(
            array('submit', 'cancel','back'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'producto',
                'action'    => $path . '/new'
            ));
    } 
} 
