<?php
class Default_Form_Proveedor extends Zend_Form 
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);

        $validador_rut = new App_Validate_ValidRut();
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addFilter('StripTags')
           ->addFilter('StringTrim');

        $razon_social = new Zend_Form_Element_Text('razon_social');
        $razon_social->setLabel('Razón social')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class', 'help')
              ->setAttrib('title', 'Ingrese la Razón Social de la Empresa o el Nombre completo en caso de ser Persona Natural');

        $nombre_fantasia = new Zend_Form_Element_Text('nombre_fantasia');
        $nombre_fantasia->setLabel('Nombre de fantasía')
              ->setRequired(false)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');
             
        $rut = new Zend_Form_Element_Text('rut');
        $rut->setLabel('R.U.T.')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator($validador_rut)
              ->setAttrib('class', 'help')
              ->setAttrib('title', 'Formato: 12345678-9');
             
        $direccion = new Zend_Form_Element_Text('direccion');
        $direccion->setLabel('Dirección')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim'); 
         
        $comuna = new Zend_Form_Element_Text('comuna');
        $comuna->setLabel('Comuna')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class', 'autocomplete')
              ->setDescription('/ajax-aux/comunas');
        
        $ciudad = new Zend_Form_Element_Text('ciudad');
        $ciudad->setLabel('Ciudad')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class', 'autocomplete')
              ->setDescription('/ajax-aux/ciudades');
        
        $telefono = new Zend_Form_Element_Text('telefono');
        $telefono->setLabel('Teléfono')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim'); 
              
        $giro = new Zend_Form_Element_Text('giro');
        $giro->setLabel('Giro')
              ->setRequired(false)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim'); 
              
        $web = new Zend_Form_Element_Text('web');
        $web->setLabel('Sitio Web')
            ->setRequired(false)
            ->addFilter('StripTags') 
            ->addFilter('StringTrim');

        $transporte = new Zend_Form_Element_Text('transporte');
        $transporte->setLabel('Medio de transporte')
              ->setRequired(false)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');
        
        $horario_atencion = new Zend_Form_Element_Textarea('horario_atencion');
        $horario_atencion->setLabel('Horario de atención')
                         ->setRequired(false)
                         ->setAttrib("rows", "3")
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim');
            
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');

        $this->addElements(
            array(
                $razon_social, $rut, $direccion, 
                $comuna, $ciudad, $telefono, $giro,
                $web, $cancel, $submit, $id,
                $nombre_fantasia, $transporte, 
                $horario_atencion
            ));

        $this->addDisplayGroup(
            array(
                'razon_social', 'rut', 'direccion',
                'comuna', 'ciudad', 'telefono'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'span6'))
            )
        );
        
        $this->addDisplayGroup(
            array(
                'giro', 'web', 'nombre_fantasia',
                'transporte', 'horario_atencion'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'span6'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));

        $this->setAttribs(array(
            'class'     => 'form-horizontal',
            'name'      => 'proveedor',
            'action'    => '/proveedor/new'
        ));
    } 
} 
