<?php
class Default_Form_RecepcionVehiculoSintomas extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $validador_vehiculo = new Zend_Validate_Db_RecordExists(
            array(
                'table' => 'vehiculos',
                'field' => 'patente'
            )
        );

        $descripcionVehiculo = 'Debe estar registrado previamente, tanto el '
                             . 'cliente como el vehículo';

        $descripcionOtroTaller = 'Consultar si viene de otro taller y describir '
                               . 'lo que se le hizo o lo que se indicó en él.';

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $vehiculo = new Zend_Form_Element_Text('vehiculo');
        $vehiculo->setLabel('Patente del vehículo')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addFilter('StringToUpper')
                 ->addValidator($validador_vehiculo)
                 ->setAttrib('title', $descripcionVehiculo)
                 ->setAttrib("class", "help input-small");

        $p_frenos = new Zend_Form_Element_Checkbox('p_frenos');
        $p_frenos->setRequired(true)
                 ->setCheckedValue('SI')
                 ->setUncheckedValue('NO')
                 ->setLabel('¿Problemas en frenos?')
                 ->setAttrib('title', '- Problemas con los frenos')
                 ->setAttrib('class', 'sintomas');

        $p_suspension = new Zend_Form_Element_Checkbox('p_suspension');
        $p_suspension->setRequired(true)
                     ->setCheckedValue('SI')
                     ->setUncheckedValue('NO')
                     ->setLabel('¿Problemas de suspensión?')
                     ->setAttrib('title', '- Problemas con la suspensión')
                     ->setAttrib('class', 'sintomas');

        $p_direccion = new Zend_Form_Element_Checkbox('p_direccion');
        $p_direccion->setRequired(true)
                    ->setCheckedValue('SI')
                    ->setUncheckedValue('NO')
                    ->setLabel('¿Problemas de dirección?')
                    ->setAttrib('title', '- Problemas con la dirección')
                    ->setAttrib('class', 'sintomas');

        $p_luces = new Zend_Form_Element_Checkbox('p_luces');
        $p_luces->setRequired(true)
                ->setCheckedValue('SI')
                ->setUncheckedValue('NO')
                ->setLabel('¿Problemas de luces?')
                ->setAttrib('title', '- Problemas con las luces')
                ->setAttrib('class', 'sintomas');

        $p_calefaccion = new Zend_Form_Element_Checkbox('p_calefaccion');
        $p_calefaccion->setRequired(true)
                      ->setCheckedValue('SI')
                      ->setUncheckedValue('NO')
                      ->setLabel('¿Problemas de calefacción/AC?')
                      ->setAttrib('title', '- Problemas con la calefacción/aire acondicionado')
                      ->setAttrib('class', 'sintomas');

        $p_tablero = new Zend_Form_Element_Checkbox('p_tablero');
        $p_tablero->setRequired(true)
                  ->setCheckedValue('SI')
                  ->setUncheckedValue('NO')
                  ->setLabel('¿Algún testigo de fallo encendido?')
                  ->setAttrib('title', '- Testigos de fallo encendido en el tablero')
                  ->setAttrib('class', 'sintomas');

        $p_transmision = new Zend_Form_Element_Checkbox('p_transmision');
        $p_transmision->setRequired(true)
                      ->setCheckedValue('SI')
                      ->setUncheckedValue('NO')
                      ->setLabel('¿Problemas de transmisión/caja?')
                      ->setAttrib('title', '- Problemas con la transmisión/caja de cambios')
                      ->setAttrib('class', 'sintomas');

        $p_motor = new Zend_Form_Element_Checkbox('p_motor');
        $p_motor->setRequired(true)
                ->setCheckedValue('SI')
                ->setUncheckedValue('NO')
                ->setLabel('¿Problemas de motor o desempeño?')
                ->setAttrib('title', '- Problemas con motor/desempeño')
                ->setAttrib('class', 'sintomas');
                
        $otros_sintomas = new Zend_Form_Element_Textarea('otros_sintomas');
        $otros_sintomas->setLabel('Otros síntomas')
                 ->setRequired(false)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setAttrib('class', 'input-xlarge')
                 ->setAttrib('rows','4');

        $otro_taller = new Zend_Form_Element_Textarea('otro_taller');
        $otro_taller->setLabel('¿El vehículo viene de otro taller?')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setAttrib('class', 'input-xlarge help')
                 ->setAttrib('rows','4')
                 ->setAttrib('title', $descripcionOtroTaller);

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Continuar')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $vehiculo, $otros_sintomas,
                $p_motor, $p_calefaccion, $otro_taller,
                $p_frenos, $p_direccion, $p_luces,
                $p_suspension, $p_tablero, $p_transmision,
                $id, $submit, $cancel
                )
        );
            
        $this->addDisplayGroup(
            array(
                'vehiculo', 'p_suspension',
                'p_transmision', 'p_motor', 'p_direccion',
                'p_luces', 'p_calefaccion'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'span3'))
            ));
        
        $this->addDisplayGroup(
            array(
                'p_tablero', 'p_frenos','otros_sintomas', 'otro_taller'
            ),
            'infoInputs2'
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag', array('tag' => 'div', 'class' => 'span4'))
            ));

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'form-vertical',
                'name'      => 'recepcion-vehiculo-sintomas',
                'action'    => '/vehiculo-recepcion/new'
            ));
        
    } 
} 
