<?php
class Default_Form_RemAnexo extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);
        
        $validadorFloat = new App_Validate_Float();

        $optionsContrato = array('table' => 'rem_contratos', 'field' => 'id');
        $validadorContrato = new Zend_Validate_Db_RecordExists($optionsContrato);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $contrato_id = new Zend_Form_Element_Hidden('contrato_id');
        $contrato_id->addValidator('Int')
                    ->setRequired(true)
                    ->addvalidator($validadorContrato);
        
        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setLabel('Fecha firma')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->setAttrib('class', 'show-calendar help input-small')
              ->setAttrib('title', 'Fecha en que se firmó el anexo')
              ->addValidator('Date');
        
        $cargo = new Zend_Form_Element_Text('cargo');
        $cargo->setLabel('Cargo')
               ->setRequired(false)
               ->addFilter('StripTags')
               ->setAttrib('class', 'help')
               ->setAttrib('title', 'Ingresar sólo en caso que haya cambiado respecto del contrato original')
               ->addFilter('StringTrim');

        $sueldo = new Zend_Form_Element_Text('sueldo');
        $sueldo->setLabel('Sueldo bruto')
              ->setRequired(false)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->setAttrib('class', 'help')
              ->setAttrib('title', 'Ingresar sólo en caso que haya cambiado respecto del contrato original')
              ->addValidator('Int');
        
        $horas_contratadas = new Zend_Form_Element_Text('horas_contratadas');
        $horas_contratadas->setLabel('Horas contratadas')
                          ->setRequired(false)
                          ->addFilter('StripTags')
                          ->addFilter('StringTrim')
                          ->setAttrib('class', 'help')
                          ->setAttrib('title', 'Ingresar sólo en caso que haya cambiado respecto del contrato original')
                          ->addValidator($validadorFloat);
        
        $domicilio_empleador = new Zend_Form_Element_Text('domicilio_empleador');
        $domicilio_empleador->setLabel('Domicilio empleador')
                            ->setRequired(false)
                            ->addFilter('StripTags')
                            ->addFilter('StringTrim')
                            ->setAttrib('class', 'help')
                            ->setAttrib('title', 'Ingresar sólo en caso que haya cambiado respecto del contrato original');
        
        $domicilio_lugar_trabajo = new Zend_Form_Element_Text('domicilio_lugar_trabajo');
        $domicilio_lugar_trabajo->setLabel('Domicilio lugar de trabajo')
                                ->setRequired(false)
                                ->addFilter('StripTags')
                                ->addFilter('StringTrim')
                                ->setAttrib('class', 'help')
                                ->setAttrib('title', 'Ingresar sólo en caso que haya cambiado respecto del contrato original');
        
        $tipo_contrato = new Zend_Form_Element_Select('tipo_contrato');
        $tipo_contrato->setLabel('Tipo de contrato')
                      ->setRequired(true)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->addMultiOption('0', 'INDEFINIDO')
                      ->addMultiOption('1', 'PLAZO FIJO');
        
        $fecha_t = new Zend_Form_Element_Text('fecha_t');
        $fecha_t->setLabel('Fecha término')
              ->setRequired(false)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->setAttrib('class', 'show-calendar help input-small')
              ->setAttrib('title', 'Al dejar este campo vacío se asume que ahora el contrato es indefinido')
              ->addValidator('Date');
        
        $detalles = new Zend_Form_Element_Textarea('detalles');
        $detalles->setLabel('Detalles / Información adicional')
              ->setRequired(false)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->setAttrib('rows', '2') 
              ->setAttrib('class', 'help span3')  
              ->setAttrib('title', 'Detalle los cambios respecto de las condiciones anteriores que no aparezcan en los recuadros de arriba.');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $contrato_id, $fecha, $cargo, $sueldo, $horas_contratadas,
                $domicilio_empleador, $domicilio_lugar_trabajo, 
                $tipo_contrato, $fecha_t, $detalles,
                $submit, $cancel, $id
            ));

        $this->addDisplayGroup(
            array(
                'fecha', 'cargo', 'sueldo', 'horas_contratadas', 
                'domicilio_empleador', 'domicilio_lugar_trabajo',  
                'tipo_contrato', 'fecha_t', 'detalles'
            ),
            'infoInputs',
            array('legend' => 'Formulario anexo de contrato')    
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(array('FormElements','Fieldset'));

        $this->addDisplayGroup(array('submit', 'cancel','id','contrato_id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        $contrato_id->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));    
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'rem-anexo-contrato',
                'action'    => '/rem-empleado/new-anexo'
            ));

    } 
} 
