<?php
class Default_Form_RemAnticipo extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $optionsEmpleado = array('table' => 'rem_empleados', 'field' => 'id');
        $validadorEmpleado = new Zend_Validate_Db_RecordExists($optionsEmpleado);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $empleado_id = new Zend_Form_Element_Select('empleado_id');
        $empleado_id->setLabel('ID Empleado')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->addValidator($validadorEmpleado)
                    ->addMultiOption('', '-- Seleccionar --')
                    ->addMultiOptions(Default_Model_RemEmpleado::getPairsToSelect());

        $fecha = new Zend_Form_Element_Text('fecha');
        $fecha->setLabel('Fecha entrega')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addValidator('Date')
               ->setAttrib('class', 'show-calendar input-small')
               ->setValue(date("Y-m-d"));

        $monto = new Zend_Form_Element_Text('monto');
        $monto->setLabel('Monto')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->setValue('');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $empleado_id, $fecha, $monto,
                $submit, $cancel, $id
            ));

        $this->addDisplayGroup(
            array(
                'empleado_id', 'fecha', 'monto'
            ),
            'infoInputs',
            array('legend' => 'Formulario anticipo')    
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(array('FormElements','Fieldset'));

        $this->addDisplayGroup(array('submit', 'cancel','id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));    
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'rem-anticipo',
                'action'    => '/rem-anticipo/new'
            ));

    } 
} 
