<?php
class Default_Form_RemCargaFamiliar extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);
        
        $validadorRut = new App_Validate_ValidRut();

        $optionsEmpleado = array('table' => 'rem_empleados', 'field' => 'id');
        $validadorEmpleado = new Zend_Validate_Db_RecordExists($optionsEmpleado);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $empleado_id = new Zend_Form_Element_Select('empleado_id');
        $empleado_id->setLabel('ID Empleado')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->addValidator($validadorEmpleado)
                    ->addMultiOption('', '-- Seleccionar --')
                    ->addMultiOptions(Default_Model_RemEmpleado::getPairsToSelect());

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');
        
        $rut = new Zend_Form_Element_Text('rut');
        $rut->setLabel('R.U.T.')
            ->setRequired(true)
            ->addFilter('StripTags')
            ->addFilter('StringTrim')
            ->addValidator($validadorRut);
        
        $tipo = new Zend_Form_Element_Select('tipo');
        $tipo->setLabel('Tipo')
             ->setRequired(true)
             ->addFilter('StripTags')
             ->addFilter('StringTrim')
             ->addMultiOption('', '-- Seleccionar --')
             ->addMultiOption('Cónyuge inválido', 'Conyugé inválido')
             ->addMultiOption('Hijo biológico/adoptado menor de 18 años', 'Hijo biológico / adoptado menor de 18 años')
             ->addMultiOption('Hijo biológico/adoptado mayor de 18 años estudiante', 'Hijo biológico/adoptado mayor de 18 años estudiante')
             ->addMultiOption('Hijastro', 'Hijastro')
             ->addMultiOption('Nieto/bisnieto huérfano o abandonado', 'Nieto/bisnieto huérfano o abandonado')
             ->addMultiOption('Madre viuda', 'Madre viuda')
             ->addMultiOption('Ascendiente mayor de 65 años', 'Ascendiente mayor de 65 años')
             ->addMultiOption('Menor al ciudado por resolución judicial', 'Menor al ciudado por resolución judicial');

        $invalido = new Zend_Form_Element_Select('invalido');
        $invalido->setLabel('Inválido')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addMultiOption('0', 'NO')
              ->addMultiOption('1', 'SI');
        
        $fecha_autorizacion = new Zend_Form_Element_Text('fecha_autorizacion');
        $fecha_autorizacion->setLabel('Fecha autorización')
                           ->setRequired(true)
                           ->addFilter('StripTags')
                           ->addFilter('StringTrim')
                           ->setAttrib('class', 'show-calendar span2')    
                           ->addValidator('Date');
        
        $fecha_termino = new Zend_Form_Element_Text('fecha_termino');
        $fecha_termino->setLabel('Fecha término')
                           ->setRequired(false)
                           ->addFilter('StripTags')
                           ->addFilter('StringTrim')
                           ->setAttrib('class', 'show-calendar span2 help')
                           ->setAttrib('title', 'Ingresar sólo cuando la persona deje de ser carga.')
                           ->addValidator('Date');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $empleado_id, $nombre, $rut, $tipo,
                $fecha_autorizacion, $fecha_termino,
                $invalido,$submit, $cancel, $id
            ));

        $this->addDisplayGroup(
            array(
                'empleado_id', 'nombre', 'rut', 'tipo', 
                'invalido', 'fecha_autorizacion', 'fecha_termino'
            ),
            'infoInputs',
            array('legend' => 'Formulario carga familiar')    
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(array('FormElements','Fieldset'));

        $this->addDisplayGroup(array('submit', 'cancel','id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));    
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'rem-carga-familiar',
                'action'    => '/rem-carga-familiar/new'
            ));

    } 
} 
