<?php
class Default_Form_RemContrato extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);
        
        $validadorFloat = new App_Validate_Float();

        $optionsEmpleado = array('table' => 'rem_empleados', 'field' => 'id');
        $validadorEmpleado = new Zend_Validate_Db_RecordExists($optionsEmpleado);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $empleado_id = new Zend_Form_Element_Select('empleado_id');
        $empleado_id->setLabel('ID Empleado')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->addValidator($validadorEmpleado)
                    ->addMultiOption('', '-- Seleccionar --')
                    ->addMultiOptions(Default_Model_RemEmpleado::getPairsToSelect());

        $cargo = new Zend_Form_Element_Text('cargo');
        $cargo->setLabel('Cargo')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');

        $sueldo = new Zend_Form_Element_Text('sueldo');
        $sueldo->setLabel('Sueldo bruto')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->addValidator('Int');
        
        $horas_contratadas = new Zend_Form_Element_Text('horas_contratadas');
        $horas_contratadas->setLabel('Horas contratadas')
                          ->setRequired(true)
                          ->addFilter('StripTags')
                          ->addFilter('StringTrim')
                          ->addValidator($validadorFloat);
        
        $domicilio_empleador = new Zend_Form_Element_Text('domicilio_empleador');
        $domicilio_empleador->setLabel('Domicilio empleador')
                            ->setRequired(true)
                            ->addFilter('StripTags')
                            ->addFilter('StringTrim');
        
        $domicilio_lugar_trabajo = new Zend_Form_Element_Text('domicilio_lugar_trabajo');
        $domicilio_lugar_trabajo->setLabel('Domicilio lugar de trabajo')
                                ->setRequired(true)
                                ->addFilter('StripTags')
                                ->addFilter('StringTrim');
        
        $tipo_gratificacion_legal = new Zend_Form_Element_Select('tipo_gratificacion_legal');
        $tipo_gratificacion_legal->setLabel('Tipo de gratificación legal')
                                 ->setRequired(true)
                                 ->addFilter('StripTags')
                                 ->addFilter('StringTrim')
                                 ->addMultiOption('MENSUAL', 'MENSUAL')
                                 ->addMultiOption('UTILIDADES', 'UTILIDADES');
        
        $tipo_contrato = new Zend_Form_Element_Select('tipo_contrato');
        $tipo_contrato->setLabel('Tipo de contrato')
                      ->setRequired(true)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim')
                      ->addMultiOption('0', 'INDEFINIDO')
                      ->addMultiOption('1', 'PLAZO FIJO');
        
        $fecha_i = new Zend_Form_Element_Text('fecha_i');
        $fecha_i->setLabel('Fecha inicio')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim')
              ->setAttrib('class', 'show-calendar input-small')
              ->addValidator('Date');
        
        $fecha_t = new Zend_Form_Element_Text('fecha_t');
        $fecha_t->setLabel('Fecha término')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->setAttrib('class', 'show-calendar help input-small')
                ->setAttrib('title', 'Al dejar este campo vacío se asume que el contrato es indefinido')
                ->addValidator('Date')
                ->setValue(date("Y-m-d"));
        
        $detalles = new Zend_Form_Element_Textarea('detalles');
        $detalles->setLabel('Detalles / Información adicional')
                 ->setRequired(false)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->setAttrib('rows', '2')
                 ->setAttrib('class', 'span3')
                 ->addValidator('Int');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $empleado_id, $cargo, $sueldo, $horas_contratadas,
                $domicilio_empleador, $domicilio_lugar_trabajo,
                $tipo_gratificacion_legal, $tipo_contrato, $fecha_i, 
                $fecha_t, $detalles, $submit, $cancel, $id
            ));

        $this->addDisplayGroup(
            array(
                'empleado_id', 'cargo', 'sueldo', 'horas_contratadas', 
                'domicilio_empleador', 'domicilio_lugar_trabajo', 
                'tipo_gratificacion_legal', 'tipo_contrato', 
                'fecha_i', 'fecha_t', 'detalles'
            ),
            'infoInputs',
            array('legend' => 'Formulario contrato')    
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(array('FormElements','Fieldset'));

        $this->addDisplayGroup(array('submit', 'cancel','id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));    
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'rem-contrato',
                'action'    => '/rem-empleado/new-contrato'
            ));

    } 
} 
