<?php
class Default_Form_RemEmpleado extends Zend_Form 
{ 
    public function __construct($options = null)
    {
        parent::__construct($options);
        
        $validador_rut = new App_Validate_ValidRut();

        $id = new Zend_Form_Element_Hidden('id');
        $id->addFilter('StripTags')
           ->addFilter('StringTrim')
           ->addValidator('Int');
        
        $rut = new Zend_Form_Element_Text('rut');
        $rut->setLabel('R.U.T.')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator($validador_rut)
              ->setAttrib('class', 'help')
              ->setAttrib('title', 'Formato: 12345678-9');
        
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre completo')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');
             
        $telefono = new Zend_Form_Element_Text('telefono');
        $telefono->setLabel('Teléfono')
              ->setRequired(false)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');
        
        $direccion = new Zend_Form_Element_Text('direccion');
        $direccion->setLabel('Dirección')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim'); 
         
        $ciudad = new Zend_Form_Element_Text('ciudad');
        $ciudad->setLabel('Ciudad')
              ->setRequired(true)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');

         

        $mail = new Zend_Form_Element_Text('mail');
        $mail->setLabel('Email')
              ->setRequired(false)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->addValidator('EmailAddress');
        
        $afp_id = new Zend_Form_Element_Select('afp_id');
        $afp_id->setLabel('AFP')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption("", "-- Seleccionar --")
               ->addMultiOptions(Default_Model_RemAfp::getPairsToSelect());
        
        $salud_id = new Zend_Form_Element_Select('salud_id');
        $salud_id->setLabel('Institución de salud')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption("", "-- Seleccionar")
                 ->addMultiOptions(Default_Model_RemIsapre::getPairsToSelect());
        
        $desc_salud_valor = new Zend_Form_Element_Text('desc_salud_valor');
        $desc_salud_valor->setLabel('Valor descuento salud')
                         ->setRequired(true)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->setAttrib("class", "help")
                         ->setAttrib("title", "El valor puede ser entero o decimal - Los decimales utilizan punto (.) como separador.");
        
        $desc_salud_tipo = new Zend_Form_Element_Select('desc_salud_tipo');
        $desc_salud_tipo->setLabel('Descuento de salud en')
                         ->setRequired(true)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->setAttrib("class", "help")
                         ->setAttrib("title", "El valor puede ser entero o decimal - Los decimales utilizan punto (.) como separador.")
                         ->addMultiOption("", "-- Seleccionar --")
                         ->addMultiOption("UF", "U.F.")
                         ->addMultiOption("PESOS", "PESOS")
                         ->addMultiOption("PORCENTAJE", "PORCENTAJE");
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');

        $this->addElements(
            array(
                $nombre, $direccion, $ciudad, $telefono, $mail, 
                $submit, $cancel, $id, $afp_id, $salud_id,
                $desc_salud_valor, $desc_salud_tipo, $rut
            ));

        $this->addDisplayGroup(
            array(
                'nombre', 'rut', 'direccion', 'ciudad', 'telefono', 'mail', 'afp_id', 'salud_id', 'desc_salud_tipo', 'desc_salud_valor'
            ),
            'infoInputs',
            array(
                'legend'=>'Formulario empleado'
            )    
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));

        $this->setAttribs(array(
            'class'     => 'form-horizontal',
            'name'      => 'rem-empleado',
            'action'    => '/rem-empleado/new'
        ));
    } 
} 
