<?php
class Default_Form_RemFiniquito extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $optionsContrato = array('table' => 'rem_contratos', 'field' => 'id');
        $validadorContrato = new Zend_Validate_Db_RecordExists($optionsContrato);
        
        $contrato_id = new Zend_Form_Element_Hidden('contrato_id');
        $contrato_id->addValidator('Int')
                    ->setRequired(true)
                    ->addvalidator($validadorContrato);
        
        $fecha_termino_contrato = new Zend_Form_Element_Text('fecha_termino_contrato');
        $fecha_termino_contrato->setLabel('Fecha término contrato')
                               ->setRequired(true)
                               ->addFilter('StripTags')
                               ->addFilter('StringTrim')
                               ->setAttrib('class', 'show-calendar help input-small')
                               ->setAttrib('title', 'Fecha que se registró en el finiquito como la de término de contrato.')
                               ->addValidator('Date');
        
        $causal_termino_contrato = new Zend_Form_Element_Text('causal_termino_contrato');
        $causal_termino_contrato->setLabel('Causal término contrato')
                                ->setRequired(true)
                                ->addFilter('StripTags')
                                ->addFilter('StringTrim');
        
        $num_meses_feriado_proporcional = new Zend_Form_Element_Text('num_meses_feriado_proporcional');
        $num_meses_feriado_proporcional->setLabel('Meses feriado proporcional')
                                       ->setRequired(true)
                                       ->addFilter('StripTags')
                                       ->addFilter('StringTrim')
                                       ->addValidator('Int');

        $valor_feriado_proporcional = new Zend_Form_Element_Text('valor_feriado_proporcional');
        $valor_feriado_proporcional->setLabel('Valor Feriado proporcional')
                                   ->setRequired(true)
                                   ->addFilter('StripTags')
                                   ->addFilter('StringTrim')
                                   ->addValidator('Int');
        
        $num_anios_servicio = new Zend_Form_Element_Text('num_anios_servicio');
        $num_anios_servicio->setLabel('Años de servicio a pagar')
                           ->setRequired(true)
                           ->addFilter('StripTags')
                           ->addFilter('StringTrim')
                           ->addValidator('Int');
        
        $valor_indem_anios_servicio = new Zend_Form_Element_Text('valor_indem_anios_servicio');
        $valor_indem_anios_servicio->setLabel('Valor indem. por años de servicio')
                                   ->setRequired(true)
                                   ->addFilter('StripTags')
                                   ->addFilter('StringTrim')
                                   ->addValidator('Int');
        
        $valor_indem_asignaciones = new Zend_Form_Element_Text('valor_indem_asignaciones');
        $valor_indem_asignaciones->setLabel('Valor indem. por asign. o bonos')
                                 ->setRequired(true)
                                 ->addFilter('StripTags')
                                 ->addFilter('StringTrim')
                                 ->addValidator('Int');
        
        $carta_aviso = new Zend_Form_Element_Select('carta_aviso');
        $carta_aviso->setLabel('¿Se envío carta aviso?')
                    ->setRequired(true)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->addMultiOption('SI','SI')
                    ->addMultiOption('NO','NO')
                    ->setAttrib('style', 'width:55px;');
        
        $valor_indem_carta_aviso = new Zend_Form_Element_Text('valor_indem_carta_aviso');
        $valor_indem_carta_aviso->setLabel('Valor indem. por envío de carta aviso')
                                 ->setRequired(true)
                                 ->addFilter('StripTags')
                                 ->addFilter('StringTrim')
                                 ->addValidator('Int');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Ingresar')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $contrato_id, $fecha_termino_contrato, $causal_termino_contrato, 
                $num_meses_feriado_proporcional, $valor_feriado_proporcional,
                $num_anios_servicio, $valor_indem_anios_servicio, 
                $valor_indem_asignaciones, $carta_aviso, $valor_indem_carta_aviso,
                $submit, $cancel
            ));

        $this->addDisplayGroup(
            array(
                'fecha_termino_contrato', 'causal_termino_contrato',
                'num_meses_feriado_proporcional', 'valor_feriado_proporcional', 
                'num_anios_servicio', 'valor_indem_anios_servicio', 
                'valor_indem_asignaciones', 'carta_aviso', 'valor_indem_carta_aviso'
            ),
            'infoInputs',
            array('legend' => 'Formulario finiquito de contrato')    
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(array('FormElements','Fieldset'));

        $this->addDisplayGroup(array('submit', 'cancel','id','contrato_id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $contrato_id->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form',
            array('FormErrors')
        ));    
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'rem-finiquito-contrato',
                'action'    => '/rem-empleado/new-finiquito'
            ));

    } 
} 
