<?php
class Default_Form_RendicionCajaChica extends Zend_Form
{ 
    public function __construct($caja_id, $options = null, $path = null,  $history = '/caja-chica/user')
    { 
        parent::__construct($options);

        $descripcionDocumentoTipo = 'Documento que respalda la compra.';

        $validadorEgreso = new Zend_Validate_Db_RecordExists(
            array(
                'table' => 'vista_cc_egresos_activos',
                'field' => 'id'
            )
        );

        $validadorProveedor = new App_Validate_ValidRut();

        $back = new Zend_Form_Element_Hidden('back');
        $back->setValue($history)
             ->setDecorators(array('ViewHelper'));

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int')
           ->setDecorators(array('ViewHelper'));

        $egreso_id = new Zend_Form_Element_Select('egreso_id');
        $egreso_id->setRequired(true)
                  ->setLabel('Referencia egreso')
                  ->addValidator($validadorEgreso)
                  ->addMultiOption('', '-- Seleccionar --')
                  ->addMultiOptions(Default_Model_VistaCajasChicasEgresosActivos::getPairsToSelect($caja_id));

        $maximo = new Zend_Form_Element_Text('maximo');
        $maximo->setRequired(false)
               ->setLabel('Máximo a rendir')
               ->setAttrib('class', 'tooltip')
               ->setDescription('Monto máximo disponible a rendir.');


        $tipo_rendicion = new Zend_Form_Element_Select('tipo_rendicion');
        $tipo_rendicion->setLabel('Tipo de rendición')
                       ->setRequired(true)
                       ->addFilter('StripTags')
                       ->addFilter('StringTrim')
                       ->addMultiOption('', '-- Seleccionar --')
                       ->addMultiOptions(Default_Model_CajaChicaTipoRendicion::getPairsToSelect());

        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setRequired(true)
                 ->setLabel('Monto a rendir')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator('Int');

        $proveedor = new Zend_Form_Element_Text('proveedor');
        $proveedor->setRequired(true)
                 ->setLabel('R.U.T. Proveedor')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator($validadorProveedor);

        $tipo_documento = new Zend_Form_Element_Select('tipo_documento');
        $tipo_documento->setLabel('Tipo de documento')
                       ->setRequired(true)
                       ->addFilter('StripTags')
                       ->addFilter('StringTrim')
                       ->setAttrib('class', 'tooltip')
                       ->setDescription($descripcionDocumentoTipo)
                       ->addMultiOption('', '-- Seleccionar --')
                       ->addMultiOptions(Default_Model_CajaChicaTipoDocumento::getPairsToSelect());

        $documento_numero = new Zend_Form_Element_Text('documento_numero');
        $documento_numero->setRequired(true)
                 ->setLabel('Nº de documento proveedor')
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator('Int');
        /*
        $saldo = new Zend_Form_Element_Radio('saldo');
        $saldo->setRequired(true)
              ->setLabel('¿En caso de existir un saldo, desea reintegrarlo a la caja chica?')
              ->addMultiOption('1','SI')
              ->addMultiOption('0','NO')
              ->setValue('0');*/
        
        $submit = new Zend_Form_Element_Button('submit');
        $submit->setLabel('Registrar rendición')
               ->setAttrib('class','caja-chica')
               ->setDecorators(array('ViewHelper'));

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setDecorators(array('ViewHelper'));
        
        $this->addElements(
            array(
                $egreso_id, $cantidad, $proveedor,
                $documento_numero, $tipo_documento,
                $tipo_rendicion, $maximo, $submit,
                $cancel, $back, $id
            ));

        $this->addDisplayGroup(
            array(
                'egreso_id', 'maximo',
                'cantidad', 'tipo_rendicion',
                'proveedor', 'tipo_documento',
                'documento_numero'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-left-ancho'))
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel','back', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-float-buttons'))
            ));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'dividido ajax',
                'name'      => 'rendicion-caja-chica',
                'action'    => $path . '/new'
            ));
    } 
} 
