<?php
class Default_Form_SistemaUsuario extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
               ->setRequired(true)
               ->setAttrib('class', 'help') 
              ->setAttrib('title', 'Primer nombre y el primer apellido') 
               ->addFilter('StripTags')
               ->addFilter('StringTrim');
             
        $mail = new Zend_Form_Element_Text('mail');
        $mail->setLabel('Email')
              ->setRequired(false)
              ->addFilter('StripTags') 
              ->addFilter('StringTrim')
              ->setAttrib('class', 'help') 
              ->setAttrib('title', 'Debe ser una dirección válida y accesible, ya que ahí se enviará información constantemente.')  
              ->addValidator('EmailAddress');

        $usuario = new Zend_Form_Element_Text('usuario');
        $usuario->setLabel('Usuario')
              ->setRequired(true)
              ->addValidator('StringLength', false, array(6,20))  
              ->setAttrib('class', 'help') 
              ->setAttrib('title', 'Usuario de acceso al sistema. Mínimo 6 caracteres y máximo 20')  
              ->addFilter('StripTags') 
              ->addFilter('StringTrim');


        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear usuario')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $id, $nombre, $mail,
                $usuario, $submit, $cancel
            ));

        $this->addDisplayGroup(
            array(
                'rut', 'nombre', 'mail', 'usuario'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );
        
        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));
        
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'usuario',
                'action'    => '/sistema-usuario/new'
            ));

    } 
} 
