<?php
class Default_Form_SolicitudBodega extends Zend_Form
{ 
    public function __construct($options = null)
    { 
        parent::__construct($options);
        
        $descripcionCodigoProveedor = 'Recuerde que este código es una referencia y no todos artículos poseen uno.';

        $descripcionPrioridad = "Alta: Compra urgente para servicio en curso o máximo de 24 Hr." . "\n"
                              . "Media: Compra necesaria dentro de los próximos 3 días. "
                              . "Baja: Compra a realizar sin urgencia, generalmente para reponer stock";
        
        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre artículo')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');
        
        $codigo = new Zend_Form_Element_Text('codigo');
        $codigo->setLabel('Código interno')
               ->setRequired(false)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');
        
        $codigo_proveedor = new Zend_Form_Element_Text('codigo_proveedor');
        $codigo_proveedor->setLabel('Código proveedor')
                         ->setRequired(false)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->setAttrib('class', 'help')
                         ->setAttrib('title', $descripcionCodigoProveedor);
        
        $marca = new Zend_Form_Element_Text('marca');
        $marca->setLabel('Marca / Fabricante')
              ->setRequired(true)
              ->addFilter('StripTags')
              ->addFilter('StringTrim');
        
        $cantidad = new Zend_Form_Element_Text('cantidad');
        $cantidad->setLabel('Cantidad solicitada')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addValidator('Int');
        
        $descripcion = new Zend_Form_Element_Textarea('descripcion');
        $descripcion->setLabel('Descripción')
                    ->setRequired(false)
                    ->addFilter('StripTags')
                    ->addFilter('StringTrim')
                    ->setAttrib('rows','5');
        
        $ultimo_precio = new Zend_Form_Element_Text('ultimo_precio_compra');
        $ultimo_precio->setLabel('Último precio de compra')
                      ->setRequired(false)
                      ->addFilter('StripTags')
                      ->addFilter('StringTrim');

        $prioridad = new Zend_Form_Element_Select('prioridad');
        $prioridad->setLabel('Prioridad')
                   ->setRequired(true)
                   ->addFilter('StripTags')
                   ->addFilter('StringTrim')
                   ->addMultiOption('BAJA', 'BAJA')
                   ->addMultiOption('MEDIA', 'MEDIA')
                   ->addMultiOption('ALTA', 'ALTA')
                   ->setAttrib('class', 'help')
                   ->setAttrib('title', $descripcionPrioridad);
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(array(
            $id, $codigo_proveedor, $marca, $cantidad, 
            $codigo, $nombre, $descripcion, 
            $ultimo_precio, $prioridad, $submit, $cancel));
        
        $this->addDisplayGroup(
            array(
                'nombre', 'marca', 'codigo', 'codigo_proveedor', 'ultimo_precio_compra'
            ),
            'infoInputs'  
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );
        
        $this->addDisplayGroup(
            array(
                'descripcion',  'cantidad', 'prioridad'
            ),
            'infoInputs2'  
        );

        $infoInputs2 = $this->getDisplayGroup('infoInputs2');
        $infoInputs2->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id', 'articulo_id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));
        
        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));

        $this->setAttribs(array(
            'name'      => 'solicitud-bodega',
            'action'    => '/solicitud-bodega/new'
        ));
    } 
} 
