<?php
class Default_Form_SolicitudTaller extends Zend_Form
{
    public function __construct($options = null)
    {
        parent::__construct($options);

        $descripcionNombre = 'Ingrese el nombre del repuesto a comprar. Por'
                           . ' ejemplo: "Filtro de aire" o "Correa distribución"'
                           . ' y las características en el cuadro de "Descripción'
                           . ' actual" ';
        
        $optionsVehiculo = array('table' => 'vehiculos', 'field' => 'patente');
        $validadorVehiculo = new Zend_Validate_Db_RecordExists($optionsVehiculo);

        $descripcionCantidad = 'Sólo números enteros sin signos';

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');
        
        $tipo = new Zend_Form_Element_Select('tipo');
        $tipo->setLabel('Tipo')
             ->setRequired(true)
             ->addFilter('StripTags')
             ->addFilter('StringTrim')
             ->addMultiOption('', '-- Seleccionar --')
             ->addMultiOption('REPUESTO', 'REPUESTO')
             ->addMultiOption('SERVICIO', 'SERVICIO')
             ->addMultiOption('INSUMO', 'INSUMO')
             ->addMultiOption('HERRAMIENTA', 'HERRAMIENTA');   

        $vehiculo = new Zend_Form_Element_Text('vehiculo');
        $vehiculo->setLabel('Patente del vehículo')
                 ->setRequired(false)   
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addFilter('StringToUpper')
                 ->setAttrib('class', 'help')
                 ->setAttrib('title', 'Puede quedar en blanco si el ítem es insumo')
                 ->addValidator($validadorVehiculo);

        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre')
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->setRequired(true)
               ->setAttrib('class', 'form-control help')
               ->setAttrib("title", $descripcionNombre);

        $cantidad_solicitada = new Zend_Form_Element_Text('cantidad_solicitada');
        $cantidad_solicitada->setLabel('Cantidad solicitada')
                            ->addFilter('StripTags')
                            ->addFilter('StringTrim')
                            ->setRequired(true)
                            ->setAttrib('class', 'help')
                            ->setAttrib('title', $descripcionCantidad);
        
        $calidad_solicitada = new Zend_Form_Element_Select('calidad_solicitada');
        $calidad_solicitada->setLabel('Calidad solicitada')
                           ->setRequired(true)
                           ->setAttrib('class', 'help')
                           ->setAttrib('title', 'Sólo para repuestos')
                           ->addMultiOptions(Default_Model_TipoRepuesto::getPairsToSelect());

        $muestra = new Zend_Form_Element_Select('muestra');
        $muestra->setLabel('Se adjunta muestra')
                ->setRequired(true)
                ->addMultiOption('SI', 'SI')
                ->addMultiOption('NO', 'NO')
                ->setValue('NO');
        
        $descripcion = new Zend_Form_Element_Textarea('descripcion');
        $descripcion->setLabel('Obs. / Desc.')
                          ->setRequired(false)
                          ->addFilter('StripTags')
                          ->addFilter('StringTrim')
                          ->setAttrib('rows', '5');
        
        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn');

        $this->addElements(
            array(
                $id, $nombre, $cantidad_solicitada,
                $calidad_solicitada, $descripcion, $muestra, 
                $vehiculo, $tipo, $submit, $cancel
            ));

        $this->addDisplayGroup(
            array(
                'tipo', 'vehiculo',  'cantidad_solicitada', 'nombre',
                'calidad_solicitada', 'muestra', 'descripcion'
            ),
            'infoInputs'
        );

        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            ));
        
        $this->addDisplayGroup(array('submit', 'cancel','id'), 'submitButtons');
        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions clear'))
            ));

        $this->setElementDecorators(array(
            'ViewHelper',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group')),
            'Errors'
        ));
        
        $id->setDecorators(array('ViewHelper'));
        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));

        $this->setDecorators(array(
            'FormElements',
            'Form'
        ));
        
        $this->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'solicitud-taller',
                'action'    => "/solicitud-taller/new"
            ));
    }
}
