<?php
class Default_Form_VehiculoModelo extends Zend_Form
{
    public function __construct($options = null)
    { 
        parent::__construct($options);

        $validadorFloat = new App_Validate_Float();

        $descripcionCilindrada = 'Utilice un formato abreviado, por ejemplo : 1.6 o 2.5';

        $id = new Zend_Form_Element_Hidden('id');
        $id->addValidator('Int');

        $marca_id = new Zend_Form_Element_Select('marca_id');
        $marca_id->setLabel('Marca')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim')
               ->addMultiOption('','-- Seleccionar --')
               ->addMultiOptions(Default_Model_VehiculoMarca::getPairsToSelect());
              
        $nombre = new Zend_Form_Element_Text('nombre');
        $nombre->setLabel('Nombre modelo')
               ->setRequired(true)
               ->addFilter('StripTags')
               ->addFilter('StringTrim');

        $version = new Zend_Form_Element_Text('version');
        $version->setLabel('Versión')
                ->setRequired(false)
                ->addFilter('StripTags')
                ->addFilter('StringTrim');

        $cilindrada = new Zend_Form_Element_Text('cilindrada');
        $cilindrada->setLabel('Cilindrada')
                ->setRequired(true)
                ->addFilter('StripTags')
                ->addFilter('StringTrim')
                ->setAttrib('class','help')
                ->setAttrib('placeholder', 'por ej.: 1600') 
                ->setAttrib('title',$descripcionCilindrada);

        $tipo_combustible = new Zend_Form_Element_Select('tipo_combustible');
        $tipo_combustible->setLabel('Tipo combustible')
                         ->setRequired(true)
                         ->addFilter('StripTags')
                         ->addFilter('StringTrim')
                         ->addMultiOption('','-- Seleccionar --')
                         ->addMultiOption('GASOLINA','GASOLINA')
                         ->addMultiOption('DIESEL','DIESEL')
                         ->addMultiOption('ETANOL','ETANOL')
                         ->addMultiOption('ALCOHOL','ALCOHOL');
        
        $transmision = new Zend_Form_Element_Select('transmision');
        $transmision->setLabel('Transmisión')
             ->setRequired(true)
             ->addFilter('StripTags') 
             ->addFilter('StringTrim')
             ->addMultiOption('MANUAL', 'MANUAL')
             ->addMultiOption('AUTOMATICA', 'AUTOMATICA');

        $traccion = new Zend_Form_Element_Select('traccion');
        $traccion->setLabel('Tracción')
                 ->setRequired(true)
                 ->addFilter('StripTags')
                 ->addFilter('StringTrim')
                 ->addMultiOption('','-- Seleccionar --')
                 ->addMultiOption('4x2','4x2')
                 ->addMultiOption('4x4','4x4');

        $cargo_adicional = new Zend_Form_Element_Text('cargo_adicional');
        $cargo_adicional->setLabel('Cargo adicional por dificultad %')
              ->setRequired(true)
              ->setValue(0)
              ->addValidator($validadorFloat);
        
        $mas_informacion = new Zend_Form_Element_Textarea('mas_informacion');
        $mas_informacion->setLabel('Más información')
                        ->setAttrib('class', 'input-xxlarge')
                        ->setAttrib('rows', '6')
                        ->setRequired(false);

        $submit = new Zend_Form_Element_Submit('submit');
        $submit->setLabel('Crear modelo')
               ->setAttrib('class','btn btn-primary');

        $cancel = new Zend_Form_Element_Button('cancel');
        $cancel->setLabel('Cancelar')
               ->setAttrib('class', 'btn') 
               ->setAttrib('onclick', 'javascript:history.back();');
        
        $this->addElements(
            array(
                $id, $marca_id, $nombre, $version, 
                $tipo_combustible, $traccion, $transmision,
                $cilindrada, $cargo_adicional,
                $mas_informacion, $submit, $cancel
            )
        );

        $this->addDisplayGroup(
            array(
                'marca_id', 'nombre', 'version', 'cilindrada', 
                'tipo_combustible', 'traccion',  'transmision', 'cargo_adicional',
                'mas_informacion'
            ),
            'infoInputs'  
        );


        $infoInputs = $this->getDisplayGroup('infoInputs');
        $infoInputs->setDecorators(
            array(
                'FormElements',
                'Fieldset'
            )
        );

        $this->addDisplayGroup(
            array('submit', 'cancel', 'id'),
            'submitButtons'
        );

        $submitButtons = $this->getDisplayGroup('submitButtons');
        $submitButtons->setDecorators(
            array(
                'FormElements',
                array('HtmlTag',array('tag'=>'div','class'=>'form-actions'))
            ));
        
        $this->setElementDecorators(array(
            'ViewHelper',
            'Errors',
            array(array('data' => 'HtmlTag'),  array('tag' =>'div', 'class'=> 'controls')),
            array('Label', array('class' => 'control-label')),
            array(array('row' => 'Htmltag'), array('tag' => 'div', 'class' => 'control-group'))
        ));

        $submit->setDecorators(array('ViewHelper'));
        $cancel->setDecorators(array('ViewHelper'));
        $id->setDecorators(array('ViewHelper'));

        $this->clearDecorators();
        $this->addDecorator('FormElements')
             ->addDecorator('Form')
             ->setAttribs(array(
                'class'     => 'form-horizontal',
                'name'      => 'vehiculo-modelo',
                'action'    => '/vehiculo-modelo/new'
            ));
    } 
} 
