<?php
class Default_Model_Articulo extends Zend_Db_Table_Abstract
{
    protected $_name = 'articulos';
    protected $_primary = 'id';

    private $_orderByOptionsKeys = array('id', 'nombre', 'categoria', 'fabricante');
    private $_orderByOptionsValues = array('ID', 'Nombre', 'Categoría', 'Fabricante / Marca');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El Código configurado no existe - setId ");
        }
        
        $this->_id = (int)$id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el Código - getRow");
        }
        
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getCategoriaNombre()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        return Default_Model_ArticuloCategoria::getNombreById($this->getRow()->categoria_id);
    }
    
    public function getAllToPopup()
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
            ->from(array('a' => 'articulos'), array('id', 'nombre'))
            ->order("nombre");
        return $adapter->fetchAll($select);
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('a' => 'articulos'),
                   array(
                       'id', 'codigo_proveedor', 'nombre',  'estado', 
                       'stock_minimo', 'descripcion', 'creacion'
                    ))
            ->join(array('ca' => 'articulos_categorias'), 'ca.id=a.categoria_id', array('categoria' => 'nombre'))
            ->join(array('fa' => 'articulos_fabricantes'), 'fa.id=a.fabricante_id', array('fabricante' => 'nombre'))
            ->join(array('u' => 'sistema_usuarios'), 'u.id=a.creador', array('creador' => 'nombre'))    
            ->where("a.id = ? ", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
        
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('a' => 'articulos'),
                   array('id', 'codigo_proveedor', 'nombre', 'estado', 'stock_minimo'))
            ->join(array('ca' => 'articulos_categorias'), 'ca.id=a.categoria_id', array('categoria' => 'nombre'))
            ->join(array('fa' => 'articulos_fabricantes'), 'fa.id=a.fabricante_id', array('fabricante' => 'nombre'))
            ->order($order);
        $articulos = $adapter->fetchAll($select);
        
        $paginador = Zend_Paginator::factory($articulos);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function crear($data, $usuario)
    {
        $data['creador'] = $usuario;
        if($data['codigo_proveedor']=='') {$data['codigo_proveedor'] = NULL; }
        if($data['descripcion']=='') {$data['descripcion'] = NULL; }
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data)
    {
        if($data['codigo_proveedor']=='') {$data['codigo_proveedor'] = NULL; }
        if($data['descripcion']=='') {$data['descripcion'] = NULL; }
        
        $row = $this->find($data['id'])->current();
        $row->setFromArray($data);
        $row->save();
    }

    public function getRowsByCategoria($categoria_id)
    {
        $db = Zend_Registry::get('db');
        $db->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $db->select()
            ->from(array('a' => 'articulos'),
                   array('id', 'nombre'))
            ->where('a.categoria_id= ? ', $categoria_id)
            ->order('a.nombre');
        $result = $db->fetchAll($select);
        if(count($result) > 0) {
            return $result;
        } else {
            return false;
        }
    }

    public function getRowsByCategoriaToOrdenCompra($categoria_id)
    {
        $db = Zend_Registry::get('db');
        $db->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $db->select()
            ->from(array('a' => 'articulos'),
                   array('id', 'nombre'))
            ->where('a.categoria_id=?',$categoria_id)
            ->order('a.nombre');
        $result = $db->fetchAll($select);
        if(count($result) > 0) {
            return $result;
        } else {
            return false;
        }
    }

    public static function getRowToItem($articulo_id)
    {
        $db = Zend_Registry::get('db');
        $db->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $db->select()
            ->from(array('a' => 'articulos'), array('id','nombre','descripcion'))
            ->where('a.id=?',$articulo_id);
        $result = $db->fetchRow($select);
        return $result;
    }

    public static function getPairsToSelect()
    {
        $db = new Default_Model_Articulo();
        $result = $db->getAdapter()->fetchPairs("SELECT id, CONCAT(nombre) FROM articulos");
        return $result;
    }


    public function getUltimoIngresoInventario($tipo_ingreso_id)
    {
        $ingreso = new IngresoArticulo();
        $ultimoIngreso = $ingreso->getLastByArticuloAndType($this->_id, $tipo_ingreso_id);
        return $ultimoIngreso;
    }

    public function getEquivalencias()
    {
        $equivalencia = new EquivalenciaArticulo();
        $equivalencias = $equivalencia->getRowsByCodigo($this->_id);
        return $equivalencias;
    }
    
    /*
    public static function getCodigoById($id)
    {
        $db = Zend_Registry::get('db');
        $db->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $db->select()
            ->from(array('ai' => 'articulos'), array('id'))
            ->where('ai.id = ? ', $id);
        $result = $db->fetchOne($select);
        return $result;
    }
    */

    public function getStock()
    {
        /*
        $ingresos = Default_Model_ArticuloIngreso::getIngresosByArticuloId($this->_id);
        $egresos = Defaulkt_Model_ArticuloEgreso::getEgresosByArticuloId($this->_id);
        $stock = $ingresos - $egresos;
         */
        return '0';
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID de artículo - eliminar");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }

    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'ASC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'nombre';
        }
    }

}