<?php
class Default_Model_ArticuloCategoria extends Zend_Db_Table_Abstract
{
    protected $_name = 'articulos_categorias';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'nombre', 'padre_id');
    private $_orderByOptionsValues = array('ID', 'Nombre', 'Categoría padre');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - setId ");
        }
        
        $this->_id = (int)$id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - getRow");
        }
        
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function crear($data)
    {
        if($data['padre_id']=='0') { $data['padre_id']=NULL;}
        if($data['descripcion']=='') { $data['descripcion']=NULL;}
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data, $id)
    {
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ca' => 'articulos_categorias'),
                   array('id', 'padre_id', 'nombre', 'descripcion'))
            ->joinLeft(array('cap' => 'articulos_categorias'), 'cap.id=ca.padre_id', array('padre' => 'nombre'))
            ->order($order);
        $categorias = $adapter->fetchAll($select);
        
        $paginador = Zend_Paginator::factory($categorias);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - eliminar");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public static function getPairsToSelect()
    {
        $adapter = self::getDefaultAdapter();
        $result = $adapter->fetchPairs("SELECT id, nombre FROM articulos_categorias ORDER BY nombre");
        return $result;
    }
    
    public function getAllToPopup()
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
            ->from(array('ca' => 'articulos_categorias'), array('id', 'nombre'))
            ->order("nombre");
        return $adapter->fetchAll($select);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'ASC';
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'nombre';
        }
    }
    
    public static function getNombreById($id)
    {
        $id = (int)$id;
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT nombre FROM articulos_categorias WHERE id='$id'";
        return $adapter->fetchOne($sql);
    }
}