<?php
class Default_Model_ArticuloEgreso extends Zend_Db_Table_Abstract
{
    protected $_name = 'articulos_egresos';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'articulo', 'tipo_id', 'almacen', 'creacion');
    private $_orderByOptionsValues = array('ID', 'Articulo', 'Tipo', 'Almacén', 'Fecha de ingreso');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ai' => 'articulos_egresos'),
                   array('id', 'cantidad', 'observaciones',  'estado'))
            ->join(array('a' => 'articulos'), 'a.id=ai.articulo_id', array('articulo' => 'nombre'))    
            ->join(array('ati' => 'articulos_tipos_ingreso'), 'ati.id=ai.tipo_id', array('tipo' => 'nombre'))
            ->join(array('aa' => 'articulos_almacenes'), 'aa.id=ai.almacen_id', array('almacen' => 'nombre'))
            ->join(array('u' => 'sistema_usuarios'), 'u.id=ai.creador', array('creador' => 'nombre'))    
            ->where("a.id = ? ", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ai' => 'articulos_ingresos'),
                   array('id', 'cantidad', 'costo_unitario_neto', 'observaciones', 'estado', 'creacion'))
            ->join(array('a' => 'articulos'), 'a.id=ai.articulo_id', array('articulo' => 'nombre'))    
            ->join(array('ati' => 'articulos_tipos_ingreso'), 'ati.id=ai.tipo_id', array('tipo' => 'nombre'))
            ->join(array('aa' => 'articulos_almacenes'), 'aa.id=ai.almacen_id', array('almacen' => 'nombre'))
            ->join(array('u' => 'sistema_usuarios'), 'u.id=ai.creador', array('creador' => 'nombre'))    
            ->order($order);
        $articulos = $adapter->fetchAll($select);
        
        $paginador = Zend_Paginator::factory($articulos);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function crear($data, $user)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        $data['creador'] = $user;
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
}