<?php
class Default_Model_ArticuloPedido extends Zend_Db_Table_Abstract
{
    protected $_name = 'articulos_pedidos';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'estado');
    private $_orderByOptionsValues = array('Nº', 'Estado');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ap' => 'articulos_pedidos'),
                   array('id', 'creacion', 'creador', 'almacen_id', 'estado'))
            ->join(array('a' => 'articulos_almacenes'), 'a.id=ap.almacen_id', array('almacen' => 'nombre'))
            ->join(array('e' => 'empleados'), 'e.rut=ap.creador', array('creador' => 'nombre_corto'))    
            ->where("ap.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getItems()
    {
        
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function updateIva()
    {
        $row = $this->getRow();
        $row->iva = Default_Model_Preferencia::getPref('IVA');
        $row->save();
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        $where = null;
        $solicitudes = $this->fetchAll($where, $order);
        $paginador = Zend_Paginator::factory($solicitudes);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            
            $this->delete($where);
            
        } catch (Exception $e) {
            
            return $e->getMessage();
            
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
       
}