<?php
class Default_Model_BancoCuenta extends Zend_Db_Table_Abstract
{
    protected $_name = 'bancos_cuentas';
    protected $_primary = 'id';
    
    private $_id;
    
    public function setId($id)
    {
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - BancoCuenta::setId ");
        }
        $this->_id = (int)$id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - BancoCuenta::getRow");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select()
            ->from(array('c' => $this->_name), array(
                'id', 'numero', 'titular', 'monto_aprobado', 
                'fecha_apertura', 'fecha_cierre', 'estado'
            ))
            ->join(array('b' => 'bancos'), 'b.id=c.banco_id', array('banco' => 'nombre'))
            ->join(array('t' => 'bancos_cuentas_tipos'), 't.id=c.banco_id', array('tipo' => 'nombre'))    
            ->where('c.id=?', $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getAll()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select()
            ->from(array('c' => $this->_name), array(
                'id', 'numero', 'titular', 'monto_aprobado', 
                'fecha_apertura', 'fecha_cierre', 'estado'
            ))
            ->join(array('b' => 'bancos'), 'b.id=c.banco_id', array('banco' => 'nombre'))
            ->join(array('t' => 'bancos_cuentas_tipos'), 't.id=c.banco_id', array('tipo' => 'nombre'));
        return $adapter->fetchAll($select);
    }
    
    public function crear($data)
    {
        if($data['monto_aprobado']=='') {$data['monto_aprobado'] = NULL; }
        $row = $this->createRow();
        $row->setFromArray($data);
        return $row->save();
    }
    
    public function editar($data)
    {
        if($data['monto_aprobado']=='') {$data['monto_aprobado'] = NULL; }
        $row = $this->find($data['id'])->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }

    public static function getPairsToSelect()
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
            ->from(array('c' => $this->_name), array('id', 'CONCAT(numero, " - " , banco)'))
            ->join(array('b' => 'bancos'), 'b.id=c.banco_id', array());
        return $adapter->fetchPairs($select);
    }
}