<?php
class Default_Model_Cliente extends Zend_Db_Table_Abstract
{
    protected $_name = 'clientes';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('nombre', 'ciudad');
    private $_orderByOptionsValues = array('Nombre', 'Ciudad');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $options = array('table' => 'clientes', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - setId ");
        }
        
        $this->_id = (int)$id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - getRow");
        }
        
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getInfoFacturacion()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - getInfoFacturacion");
        }
        
        $modelInfoFacturacion = new Default_Model_ClienteInfoFacturacion();
        $where = $modelInfoFacturacion->getAdapter()->quoteInto("cliente=?", $this->_id);
        return $modelInfoFacturacion->fetchRow($where);
    }
    
    public function getVehiculos()
    {
        $vehiculo = new Default_Model_Vehiculo();
        return $vehiculo->getRowsByCliente($this->_id);
    }
    
    public function crear($data, $creador)
    {
        $data['estado_registro'] = 1;
        $data['creador'] = $creador;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function agregarContacto($data)
    {
        $modelContacto = new Default_Model_LcContacto();
        $modelContacto->crear($data);
        $modelContacto->asociar($this->_id);
    }
    
    public function editar($data, $id)
    {
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function setFlota()
    {
        $row = $this->getRow();
        if($row->cliente_flota == 'NO'){
            $row->cliente_flota = 'SI';
        } else {
            $row->cliente_flota = 'NO';
        }
        $row->save();
        return $row->cliente_flota;
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        $where = null;
        $clientes = $this->fetchAll($where, $order);
        $paginador = Zend_Paginator::factory($clientes);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getAllToPopup()
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
            ->from(array('c' => 'clientes'), array('id', 'nombre'))
            ->order("nombre");
        return $adapter->fetchAll($select);
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - eliminar");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }

    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    public function searchToTooltip($criterio, $valor)
    {
        $adapter = $this->getAdapter();
        
        if($criterio!='' AND $valor!='') {
        
            $valor = $adapter->quote('%' . App_Rut::cleanToDb($valor) . '%');
            $where = "$criterio LIKE $valor";
            return $this->fetchAll($where)->toArray();
        }
        return false;
    }
    
    public function searchToForm($param)
    {
        $sql = "SELECT id, nombre AS value FROM clientes ";
        $sql .= "WHERE nombre LIKE '$param%' ";
        $sql .= "ORDER BY nombre";
        
        $adapter = $this->getAdapter();
        $data = $adapter->fetchAll($sql);
        return $data;
    }

    public static function getPairsToSelect()
    {
        $db = new Default_Model_Cliente();
        $result = $db->getAdapter()->fetchPairs("SELECT id, nombre FROM clientes ORDER BY nombre");
        return $result;
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'ASC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'nombre';
        }
    }
    
    public function getNumVehiculos()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID- getNumVehiculos");
        }
        
        $adapter = $this->getAdapter();
        $cliente = $adapter->quote($this->_id);
        $sql = "SELECT COUNT(*) FROM vehiculos WHERE cliente=$cliente";
        $result = $adapter->fetchOne($sql);
        return $result;
    }
    
    public function getNumCotizaciones()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - getNumCotizaciones");
        }
        
        $adapter = $this->getAdapter();
        $cliente = $adapter->quote($this->_id);
        $sql = "SELECT COUNT(*) FROM cotizaciones WHERE cliente=$cliente";
        $result = $adapter->fetchOne($sql);
        return $result;
    }
    
    public function getNumNotasVentas()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - getNumNotasVentas");
        }
        
        $adapter = $this->getAdapter();
        $cliente = $adapter->quote($this->_id);
        $sql = "SELECT COUNT(*) FROM notas_ventas WHERE cliente=$cliente";
        $result = $adapter->fetchOne($sql);
        return $result;
    }
    
    public static function getPreferenciaRepuestos($id)
    {
        $id = (int)$id;
        
        $db = new Default_Model_Cliente();
        $result = $db->getAdapter()->fetchOne("SELECT preferencia_repuestos FROM clientes WHERE id='$id' LIMIT 1");
        if(!$result) { return '<span style="color:red;">No configurada</span>';}
        $tipoRepuesto = $db->getAdapter()->fetchOne("SELECT nombre FROM tipos_repuestos WHERE id='$result' LIMIT 1");
        return "<span color:green;>" . $tipoRepuesto . "</span>";
    }

    public static function getNombreById($id)
    {
        $id = (int)$id;
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT nombre FROM clientes WHERE id='$id'";
        return $adapter->fetchOne($sql);
    }
}