<?php
class Default_Model_Cotizacion extends Zend_Db_Table_Abstract
{
    protected $_name = 'cotizaciones';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'cliente', 'total_neto');
    private $_orderByOptionsValues = array('Nº', 'Cliente', 'Total Neto');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - Cotizacion::setId()");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Cotizacion::getRow()");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getClienteNombre()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Cotizacion::getClienteNombre()");
        }
        $cliente = new Default_Model_Cliente();
        return $cliente->getNombreById($this->getRow()->cliente);
    }
    
    public function getItems()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Cotizacion::getItems()");
        }
        $modelItems = new Default_Model_ItemCotizacion();
        return $modelItems->getRowsByCotizacionId($this->_id);
    }
    
    public function getDisponiblesByClienteId($cliente_id)
    {
        /*
         * Debo filtrar las cotizaciones que tienen items disponibles
         * que no se han agregado a ninguna nota de venta
         */
        $hoy = new Zend_Date();
        $fecha = $hoy->subMonth(1)->toString("yyyy-MM-dd");
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        
        $sql = "SELECT DISTINCT(ct.id), ct.cliente, ct.iva FROM items_cotizaciones AS ic "
             . "JOIN cotizaciones AS ct ON ct.id=ic.cotizacion_id "
             . "WHERE ct.cliente='$cliente_id' " 
             . "AND ct.archivar='0' "
             . "AND ct.fecha > '$fecha'"
             . "AND ct.estado = 'EMITIDA' "
             . "AND ic.id NOT IN(SELECT items_notas_ventas.item_cotizacion_id FROM items_notas_ventas) "
             . "ORDER BY ct.id DESC";
        
        return $adapter->fetchAll($sql);
    }
    
    public function getUltimoEnvio()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Cotizacion::getUltimoEnvio()");
        }
        
        $modelEnvio = new Default_Model_DocumentoEnvio();
        $where = $modelEnvio->getAdapter()->quoteInto("tipo='cotizacion' AND documento_id=?", $this->_id);
        $order = "id DESC";
        $row = $modelEnvio->fetchRow($where, $order);
        return $row;
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function updateIva()
    {
        $row = $this->getRow();
        $row->iva = Default_Model_SistemaPreferencia::getPref('IVA');
        $row->save();
    }
    
    public function requerirAutorizacion($usuario_id)
    {
        $modelAutorizacion = new Default_Model_DocumentoAutorizacion();
        $data =  array(
            'creado_por' => $usuario_id,
            'documento_controller' => 'cotizacion',
            'documento_nombre' => 'Cotización', 
            'documento_id' => $this->_id,
            'estado' => 0,
            'comentarios' => NULL
        );
        return $modelAutorizacion->crear($data, $usuario_id);
    }
    
    public function crear($data, $user)
    {
        if($data['recepcion_id']==''){ $data['recepcion_id'] = NULL;}
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        if($data['presupuesto_id']==''){ $data['presupuesto_id'] = NULL;}
        
        $data['creador'] = $user;
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');
        
        try {
            $row = $this->createRow();
            $row->setFromArray($data);
            $row->save();
            $id = $row->id;

            if($data['presupuesto_id']!== NULL) {
                $item = new Default_Model_ItemCotizacion();
                $item->importarItemsPresupuesto($data['presupuesto_id'], $id);
            }
            return $id;
        } catch (Exception $ex) {
            $ex->getMessage();
        }
            
    }
    
    public function editar($data, $id)
    {
        if($data['recepcion_id']==''){ $data['recepcion_id'] = NULL;}
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        if($data['presupuesto_id']==''){ $data['presupuesto_id'] = NULL;}
        
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        
        if($data['presupuesto_id']!==NULL) {
            $item = new Default_Model_ItemCotizacion();
            $item->importarItemsPresupuesto($data['presupuesto_id'], $id);
        }
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('cot' => 'cotizaciones'), array(
                'id', 'cliente_id', 'creacion', 'creador', 'fecha', 'validez', 'atencion_a', 
                'emitida_por', 'recepcion_id', 'presupuesto_id', 'archivar', 'modo_visualizacion', 
                'tope_ext_presupuesto', 'aviso_ext_presupuesto', 'iva', 'observaciones', 'estado'
            ))
            ->join(array('cli' => 'clientes'), 'cli.id=cot.cliente_id', array('cliente' => 'nombre'))
            ->order($order);
        $cotizaciones = $adapter->fetchAll($select);
        $paginador = Zend_Paginator::factory($cotizaciones);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getListByCliente($id)
    {
        $where = $this->getAdapter()->quoteInto("cliente=?", $id);
        return $this->fetchAll($where);
    }
    
    public function getNeto($id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT SUM(cantidad * (valor_neto - descuento)) "
             . "FROM cotizaciones_items WHERE cotizaciones_items.cotizacion_id='$id'";
        $totalNeto = $adapter->fetchOne($sql);
        return $totalNeto;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Cotizacion::eliminar()");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function clonar($usuario_id)
    {
        $data = $this->getRow()->toArray();
        
        $antigua_id = $data['id'];
        
        unset($data['id']);
        unset($data['creacion']);
        unset($data['estado']);
        unset($data['archivar']);
        unset($data['presupuesto_id']);
        
        $data['fecha'] = date("Y-m-d");
        $data['creador'] = $usuario_id;
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        $nueva_id = $row->id;
        
        $modelItem = new Default_Model_ItemCotizacion();
        $modelItem->copiarItems($antigua_id, $nueva_id);
        
        return $nueva_id;
    }

    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    public static function getPrefs()
    {
        $model = new Default_Model_SistemaPreferencia();
        $preferencias = $model->fetchAll("nombre LIKE 'CT_%'");
        $data = array();
        foreach($preferencias as $pref){
            $data[$pref->nombre] = $pref->valor;
        }
        return $data;
    }
    
    public static function getTotalNeto($id)
    {
        return self::getNeto($id);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
}