<?php
class Default_Model_DatosFacturacion extends Zend_Db_Table_Abstract
{
    protected $_name = 'datos_facturacion';
    protected $_primary = 'rut';
    
    private $_orderByOptionsKeys = array('razon_social', 'rut', 'ciudad');
    private $_orderByOptionsValues = array('Razón social', 'R.U.T.', 'Ciudad');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_rut = NULL;
    
    public function setRut($rut)
    {
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($rut)){
            throw new Exception("El RUT configurado no existe - setRut");
        }
        
        $this->_rut = App_Rut::cleanToDb($rut);
    }
    
    public function getRow()
    {
        if(NULL == $this->_rut) {
            throw new Exception("No se ha configurado el RUT - getRow");
        }
        
        $row = $this->find($this->_rut)->current();
        return $row;
    }
    
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        $data['rut'] = App_Rut::cleanToDb($data['rut']);
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->rut;
    }
    
    public function editar($data, $id)
    {
        $data['rut'] = App_Rut::cleanToDb($data['rut']); 
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        $where = null;
        $datos = $this->fetchAll($where, $order);
        $paginador = Zend_Paginator::factory($datos);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getAllToPopup()
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
            ->from(array('df' => 'datos_facturacion'), array('rut', 'razon_social'))
            ->order("razon_social");
        return $adapter->fetchAll($select);
    }
    
    public function eliminar()
    {
        if(NULL == $this->_rut) {
            throw new Exception("No se ha configurado el RUT - Eliminar");
        }         
        $where = $this->getAdapter()->quoteInto("rut=?",  $this->_rut);
        
        try {
            $this->delete($where);
            
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }

    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    public static function getData($rut)
    {
        $options = array('table' => 'datos_facturacion', 'field' => 'rut');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($rut)){
            throw new Exception("El RUT configurado no existe - getData ");
        }
        
        $adapter = self::getDefaultAdapter();
        $rut = $adapter->quote($rut);
        $sql = "SELECT * FROM datos_facturacion WHERE rut=$rut";
        $row = $adapter->fetchRow($sql);
        return $row;
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'ASC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'razon_social';
        }
    }
}