<?php
class Default_Model_DocumentoAutorizacion extends Zend_Db_Table_Abstract
{
    protected $_name = 'documentos_autorizaciones';
    protected $_primary = 'id';
    
    /*
     *  Las autorizaciones tienen 2 estados
     *  1 : Revisada
     *  2 : Sin revisar
     */
    
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - setId ");
        }
        
        $this->_id = (int)$id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - getRow");
        }
        
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function crear($data)
    {
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return;
    }
    
    public function getAll()
    {
        $where = $this->getAdapter()->quoteInto("estado=?", '0');
        return $this->fetchAll($where);
    }
    
    public function autorizar($usuario)
    {
        $row = $this->getRow();
        $row->autorizado_por = $usuario;
        $row->autorizacion = date("Y-m-d H:i:s");
        $row->estado = 1;
        $row->save();
        
        if($row->documento_controller == 'cotizacion'){
            $modelDocumento = new Default_Model_Cotizacion();
        } elseif($row->documento_controller == 'orden-compra'){
            $modelDocumento = new Default_Model_OrdenCompra();
        }
        $modelDocumento->setId($row->documento_id);
        $modelDocumento->setEstado('EMITIDA');
    }
    
    public function rechazar($usuario)
    {
        $row = $this->getRow();
        $row->autorizado_por = $usuario;
        $row->autorizacion = date("Y-m-d H:i:s");
        $row->estado = 1;
        $row->save();
        
        if($row->documento_controller == 'cotizacion'){
            $modelDocumento = new Default_Model_Cotizacion();
        } elseif($row->documento_controller == 'orden-compra'){
            $modelDocumento = new Default_Model_OrdenCompra();
        }
        $modelDocumento->setId($row->documento_id);
        $modelDocumento->setEstado('RECHAZADA');
    }
}