<?php
class Default_Model_DteBoleta extends Zend_Db_Table_Abstract
{
    protected $_name = 'dtv_boletas';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'cliente');
    private $_orderByOptionsValues = array('Nº Boleta', 'Cliente');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getItems()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $modelItems = new Default_Model_DteBoletaItem();
        return $modelItems->getRowsByDteBoletaId($this->_id);
    }
    
    public function getNeto($id)
    {
        $adapter = self::getDefaultAdapter();
        $id = $adapter->quote((int)$id);
        $sql = "SELECT SUM(cantidad * (valor_neto - descuento)) FROM items_notas_ventas AS i "
             . "JOIN dtv_boletas_items AS ib ON ib.item_id=i.id "
             . "WHERE boleta_id=$id";
        $totalNeto = $adapter->fetchOne($sql);
        return $totalNeto;
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function getPagos()
    {
        $pagoRecibidoDteBoleta = new Default_Model_PagoRecibidoDteBoleta();
        return $pagoRecibidoDteBoleta->getRowsByDteBoletaId($this->_id);
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function updateIva()
    {
        $row = $this->getRow();
        $row->iva = Default_Model_SistemaPreferencia::getPref('IVA');
        $row->save();
    }
    
    public function crear($data, $user)
    {
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');
        $data['creador'] = $user;
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id, $user)
    {
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');
        $data['creador'] = $user;
        
        unset($data['id']);
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";

        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('b' => 'dtv_boletas'), array(
                'id', 'creacion', 'creador', 'numero', 'fecha_emision', 
                'total', 'forma_pago_id', 'estado'
            ))
            ->join(array('cl' => 'clientes'), 'cl.id=b.cliente_id', array('cliente' => 'nombre'))
            ->order($order);
        $boletas = $adapter->fetchAll($select);
        
        $paginador = Zend_Paginator::factory($boletas);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('b' => 'dtv_boletas'), array(
                'id', 'creacion', 'numero', 'cliente', 'fecha_emision', 'total', 
                'iva', 'forma_pago_id', 'estado'
            ))
            ->join(array('cl' => 'clientes'), 'cl.id=b.cliente_id', array('nombre_cliente' => 'nombre'))
            ->join(array('u' => 'sistema_usuarios'), 'u.id=b.creador', array('usuario' => 'nombre'))
            ->where("b.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function terminar()
    {
        if($this->getEstado()!='BORRADOR'){
            throw new Exception('La boleta que intenta terminar no es un borrador');
        }
        
        if(count($this->getItems()) == 0){
            throw new Exception('Una vez que agregué ítems a la Boleta podrá darla por terminada.');
        }
        
        $this->setEstado('EMITIDA');
        
        return $this;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        if($this->getEstado()!='BORRADOR'){
            throw new Exception("No puede eliminar una Boleta que no sea un borrador");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    public static function getTotalNeto($id)
    {
        return self::getNeto($id);
    }
    
    public static function getNumberById($id)
    {
        $id = (int)$id;
        $options = array('table' => 'dtv_boletas', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - getNumberById");
        }
        
        $adapter = self::getDefaultAdapter();
        $id = $adapter->quote((int)$id);
        $sql = "SELECT numero FROM dtv_boletas WHERE id=$id";
        return $adapter->fetchOne($sql);
    }   
    
    public static function getTotalPagadoById($id)
    {
        $id = (int)$id;
        $options = array('table' => 'dtv_boletas', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - getTotalPagadoById");
        }
        
        $pagoRecibidoDteBoleta = new Default_Model_PagoRecibidoDteBoleta();
        return $pagoRecibidoDteBoleta->getTotalAsignado($id);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
}