<?php
class Default_Model_DteBoletaItem extends Zend_Db_Table_Abstract
{
    protected $_name = 'dtv_boletas_items';
    protected $_primary = 'item_id';

    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function addFromNotaVenta($data, $boleta_id)
    {
        $items = explode(",", $data);
        foreach($items as $item_id){
            $this->_crear($item_id, $boleta_id);
        }
    }
    
    public function getRowsByDteBoletaId($boleta_id)
    {
        if(NULL == $boleta_id) {
            throw new Exception("No se ha enviado el ID de la boleta");
        }
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ib' => 'dtv_boletas_items'))
            ->join(array('i' => 'items_notas_ventas'), 'i.id=ib.item_id', 
                   array(
                       'vehiculo', 'codigo', 'nombre', 'descripcion', 'cantidad', 
                       'unidad_medida', 'valor_neto', 'descuento', 'tipo'
                    ))
            ->where("boleta_id=?", $boleta_id);
        return $adapter->fetchAll($select);
    }
    
    public function eliminar($data = null)
    {
        if(NULL == $data) {
            throw new Exception("No se ha enviado ningún ID para eliminar items");
        }
        
        $items = explode(",", $data);
            
        $adapter = $this->getAdapter();
        foreach($items as $id){
            
            try {
                $where = $adapter->quoteInto("item_id=?",  $id);
                $this->delete($where);
            } catch(Exception $e){
                return $e;
            }
        }
    }
    
    private function _crear($item_id, $boleta_id)
    {
        $row = $this->createRow();
        $row->item_id = (int)$item_id;
        $row->boleta_id = (int)$boleta_id;
        $row->save();
        return $row->id;
    }
}