<?php
class Default_Model_DteGuiaDespacho extends Zend_Db_Table_Abstract
{
    protected $_name = 'dtV_guias_despacho';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('numero', 'cliente');
    private $_orderByOptionsValues = array('Nº Guía de despacho', 'Cliente');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => 'dtv_guias_despacho', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getItems()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $modelItems = new Default_Model_DteGuiaDespachoItem();
        return $modelItems->getRowsByDteGuiaDespachoId($this->_id);
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function updateIva()
    {
        $row = $this->getRow();
        $row->iva = Default_Model_SistemaPreferencia::getPref('IVA');
        $row->save();
    }
    
    public function crear($data, $user)
    {
        if($data['referencia']==''){ $data['referencia'] = NULL;}
        if($data['contacto']==''){ $data['contacto'] = NULL;}
        if($data['rut_solicitante']==''){ $data['rut_solicitante'] = NULL;}
        
        $data['creador'] = $user;
        $data['rut'] = App_Rut::cleanToDb($data['rut']);
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');
        
        $cliente = Default_Model_DatosFacturacion::getData($data['rut']);
        
        $data['razon_social'] = $cliente['razon_social'];
        $data['comuna'] = $cliente['comuna'];
        $data['ciudad'] = $cliente['ciudad'];
        $data['telefono'] = $cliente['telefono'];
        $data['direccion'] = $cliente['direccion'];
        $data['giro'] = $cliente['giro'];
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id, $user)
    {
        if($data['referencia']==''){ $data['referencia'] = NULL;}
        if($data['contacto']==''){ $data['contacto'] = NULL;}
        if($data['rut_solicitante']==''){ $data['rut_solicitante'] = NULL;}
        
        $data['creador'] = $user;
        $data['rut'] = App_Rut::cleanToDb($data['rut']);
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');
        
        $cliente = Default_Model_DatosFacturacion::getData($data['rut']);
        
        $data['razon_social'] = $cliente['razon_social'];
        $data['comuna'] = $cliente['comuna'];
        $data['ciudad'] = $cliente['ciudad'];
        $data['telefono'] = $cliente['telefono'];
        $data['direccion'] = $cliente['direccion'];
        $data['giro'] = $cliente['giro'];
        
        unset($data['id']);
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('gd' => 'dtv_guias_despacho'),
                   array('id', 'numero', 'fecha_emision', 'rut', 'tipo_traslado', 'estado'))
            ->join(array('cl' => 'clientes'), 'cl.id=gd.cliente_id', array('cliente' => 'nombre'))
            ->order($order);
        $guias = $adapter->fetchAll($select);
        $paginador = Zend_Paginator::factory($guias);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getNeto($id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT SUM(cantidad * neto) "
             . "FROM dtv_guias_despacho_items WHERE guia_id='$id'";
        $totalNeto = $adapter->fetchOne($sql);
        return $totalNeto;
    }
    
    public function terminar()
    {
        if($this->getEstado()!='BORRADOR'){
            throw new Exception('La guía que intenta terminar no es un borrador');
        }
        
        if(count($this->getItems()) == 0){
            throw new Exception('Una vez que agregué ítems a la Guía de Despacho podrá darla por terminada.');
        }
        
        $this->setEstado('EMITIDA');
        return $this;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        if($this->getEstado()!='BORRADOR'){
            throw new Exception("No puede eliminar una Guía de despacho que no sea un borrador");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    public static function getTotalNeto($id)
    {
        return self::getNeto($id);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
}