<?php
class Default_Model_DteItemAsociado extends Zend_Db_Table_Abstract
{
    protected $_name = 'dte_items_asociados';
    protected $_primary = 'id';
    
    private $_id = null;
    
    public function setId($id)
    {
        $id = (int)$id;
        
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $row = $this->find($this->_id)->current();
        return $row;
    }
       
    public function crear($data)
    {
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data, $id)
    {
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar($data = null)
    {
        if(NULL == $data) {
            throw new Exception("No se ha enviado ningún ID para eliminar items");
        }
        
        $items = explode(",", $data);
            
        $adapter = $this->getAdapter();
        foreach($items as $id){
            
            try {
                $where = $adapter->quoteInto("id=?",  $id);
                $this->delete($where);
            } catch(Exception $e){
                return $e;
            }
        }
    }
    
    public function getRowsByDteDocumentoId($documento_id, $documento_tipo)
    {
        if(NULL == $documento_id) {
            throw new Exception("No se ha enviado el ID de la boleta");
        }
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ia' => 'dte_items_asociados'), array('id'))
            ->join(array('i' => 'items_notas_ventas'), 'i.id=ia.item_id', 
                   array(
                       'vehiculo', 'codigo', 'nombre', 'descripcion', 'cantidad', 
                       'unidad_medida', 'valor_neto', 'descuento', 'tipo'
                    ))
            ->where("documento_tipo=?", $documento_tipo)
            ->where("documento_id=?", $documento_id);
        return $adapter->fetchAll($select);
    }
}