<?php
class Default_Model_DtrNotaDebito extends Zend_Db_Table_Abstract
{
    protected $_name = 'dtc_notas_debito';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('numero', 'proveedor', 'fecha_emision');
    private $_orderByOptionsValues = array('Nº Nota débito', 'Proveedor', 'Fecha emisión');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        $data['proveedor'] = App_Rut::cleanToDb($data['proveedor']);
        $dataProveedor = Default_Model_Proveedor::getRowByRut($data['proveedor']);
        $data['rut'] = $dataProveedor['rut'];
        $data['razon_social'] = $dataProveedor['razon_social'];
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id, $user)
    {
        $data['creador'] = $user;
        $data['proveedor'] = App_Rut::cleanToDb($data['proveedor']);
        $data['rut'] = $data['proveedor'];
        
        unset($data['id']);
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('n' => 'dtc_notas_debito'), array('id', 'numero', 'fecha_emision', 'estado', 'neto', 'iva', 'total'))
            ->join(array('p' => 'proveedores'), 'p.id=n.proveedor_id', array('proveedor' => 'razon_social', 'rut'))
            ->join(array('u' => 'sistema_usuarios'), 'u.id=n.creador', array('ingresada_por' => 'nombre'))    
            ->join(array('e' => 'rem_empleados'), 'e.id=n.entregada_por', array('entregada_por' => 'nombre'))    
            ->order($order);
        $notas = $adapter->fetchAll($select);
        $paginador = Zend_Paginator::factory($notas);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('n' => 'dtc_notas_debito'),  array('id', 'proveedor', 'numero', 'fecha_emision', 'rut', 'razon_social', 'estado', 'neto', 'iva', 'total'))
            ->join(array('u' => 'sistema_usuarios'), 'u.id=n.creador', array('ingresada_por' => 'nombre'))    
            ->join(array('e' => 'rem_empleados'), 'e.id=n.entregada_por', array('entregada_por' => 'nombre'))
            ->where("n.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function terminar()
    {
        if($this->getEstado()!='BORRADOR'){
            throw new Exception('La nota de débito que intenta terminar no es un borrador');
        }
        
        $this->setEstado('RENDIDA');
        return $this;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        if($this->getEstado()!='BORRADOR'){
            throw new Exception("No puede eliminar una nota de débito que no sea un borrador");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
  
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
}