<?php
class Default_Model_InformeProduccionDiaria extends Zend_Db_Table_Abstract
{
    protected $_name = 'informes_produccion_diaria';
    protected $_primary = 'id';
    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => 'informes_produccion_diaria', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        return $this->find($this->_id)->current();
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ord' => 'ordenes_servicios'), array('*'))
            ->join(array('veh' => 'vehiculos'), 'veh.patente=ord.vehiculo',
                   array('*'))
            ->join(array('cli' => 'clientes'), 'cli.id=veh.cliente',
                   array('nombre_cliente' => 'nombre'))
            ->join(array('mar' => 'marcas_vehiculos'), 'mar.id=veh.marca_id',
                   array('marca' => 'nombre'))
            ->where("ord.id=?", $this->_id);
        
        $orden = $adapter->fetchRow($select);
        return $orden;
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function crear($data, $user)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        $data['creador'] = $user;
        $data['vehiculo'] = strtoupper($data['vehiculo']);
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        $data['vehiculo'] = strtoupper($data['vehiculo']);
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editarInforme($informe, $id)
    {
        $row = $this->find($id)->current();
        $row->informe =$informe;
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ord' => 'ordenes_servicios'),
                   array('*'))
            ->join(array('veh' => 'vehiculos'), 'veh.patente=ord.vehiculo',
                   array('*'))
            ->join(array('cli' => 'clientes'), 'cli.id=veh.cliente',
                   array('nombre_cliente' => 'nombre'))
            ->join(array('mar' => 'marcas_vehiculos'), 'mar.id=veh.marca_id',
                   array('marca' => 'nombre'))
            ->order($order);
        $ordenes = $adapter->fetchAll($select);
        
        $paginador = Zend_Paginator::factory($ordenes);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getItems()
    {
        $item = new Default_Model_OrdenServicioItem();
        return $item->getRowsByOrdenId($this->_id);
    }
    
    public static function getVehiculosDisponibles()
    {
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT DISTINCT(inv.vehiculo) FROM items_notas_ventas AS inv "
             . "WHERE inv.id NOT IN (SELECT item_id FROM ordenes_servicios_items)";
        $result = $adapter->fetchAll($sql);
        $data = array();
        foreach($result as $item){
            $data[$item['vehiculo']] = $item['vehiculo'];
        }
        return $data;
    }
    
    public function getItemsDisponibles()
    {
        $itemNota = new Default_Model_ItemNotaVenta();
        return $itemNota->getItemsDisponibles($this->getRow()->vehiculo);
    }
    
    public function getLastRowsByVehiculo($vehiculo)
    {
        $where = $this->getAdapter()->quoteInto("vehiculo=? AND estado='TERMINADA'", $vehiculo);
        $order = "id DESC LIMIT 5";
        return $this->fetchAll($where, $order);
    }
    
    public function getRecomendaciones()
    {
        $modelRecomendaciones = new Default_Model_OrdenServicioRecomendacion();
        return $modelRecomendaciones->getRowsByOrdenId($this->_id);
    }
    
    public function getRowsByVehiculo($patente)
    {
        $where = $this->getAdapter()->quoteInto("vehiculo=?", $patente);
        return $this->fetchAll($where);
    }
       
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }

    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }

    public static function checkAbiertasByNotaVenta($nota_id)
    {
        $model = new Default_Model_OrdenServicio();
        $adapter = $model->getAdapter();
        $nota_id = $adapter->quote($nota_id);
        $sql = "SELECT COUNT(*) FROM ordenes_servicio WHERE estado!='TERMINADA' AND nota_id=$nota_id";
        $result = $adapter->fetchOne($sql);
        return $result;
    }
    
}