<?php
class Default_Model_ItemCotizacion extends Zend_Db_Table_Abstract
{
    protected $_name = 'cotizaciones_items';
    protected $_primary = 'id';
    
    private $_id = null;
    
    public function setId($id)
    {
        $id = (int)$id;
        
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - ItemCotizacion::setId()");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - ItemCotizacion::getRow()");
        }
        
        $data = $this->find($this->_id)->current()->toArray();
        $data['precio_venta'] = $this->_getBruto($data['valor_neto']);
        $data['descuento'] = $this->_getBruto($data['descuento']);
        return $data;
    }
    
    public function getCotizacion($id)
    {
        $cotizacion = new Default_Model_Cotizacion();
        $cotizacion->setId($id);
        return $cotizacion->getRow();
    }
    
    public function getRowsByCotizacionId($cotizacion_id = null)
    {
        if(NULL == $cotizacion_id) {
            throw new Exception("No se ha enviado el ID de la cotización - ItemCotizacion::getRowsByCotizacionId()");
        }
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select()
            ->from(array('i' => 'cotizaciones_items'), array(
                'id', 'cotizacion_id', 'vehiculo_id', 'codigo', 'nombre', 
                'descripcion', 'cantidad', 'unidad_medida', 'valor_neto', 
                'descuento', 'tipo'))
            ->joinLeft(array('veh' => 'vehiculos'), 'veh.id=i.vehiculo_id', array('vehiculo' =>  'patente'))
            ->where("cotizacion_id=?", $cotizacion_id);
        return $adapter->fetchAll($select);
    }
    
    public function crear($data)
    {
        if($data['vehiculo']==''){ 
            $data['vehiculo_id'] = NULL;
        } else { 
            $data['vehiculo_id'] = Default_Model_Vehiculo::getIdByPatente($data['vehiculo']); 
        }

        if($data['unidad_medida']==''){ 
            $data['unidad_medida'] = NULL; 
        } else { 
            $data['unidad_medida'] = strtoupper($data['unidad_medida']);
        }
        
        if($data['descripcion']==''){ $data['descripcion'] = NULL; } 
        if($data['codigo']==''){ $data['codigo'] = NULL; } 
        
        $data['valor_neto'] = $this->_getNeto($data['precio_venta']);
        $data['descuento'] = $this->_getNeto($this->_calcularDescuento(
            $data['tipo_descuento'], 
            $data['descuento'], 
            $data['valor_neto']
        ));         
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function clonar($data)
    {
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data)
    {
        if($data['vehiculo']==''){ 
            $data['vehiculo_id'] = NULL;
        } else { 
            $data['vehiculo_id'] = Default_Model_Vehiculo::getIdByPatente($data['vehiculo']); 
        }
        
        if($data['unidad_medida']==''){ 
            $data['unidad_medida'] = NULL; 
        } else { 
            $data['unidad_medida'] = strtoupper($data['unidad_medida']);
        }
        
        if($data['descripcion']==''){ $data['descripcion'] = NULL; } 
        if($data['codigo']==''){ $data['codigo'] = NULL; }
        
        $data['valor_neto'] = $this->_getNeto($data['precio_venta']);
        $data['descuento'] = $this->_getNeto($this->_calcularDescuento(
            $data['tipo_descuento'], 
            $data['descuento'], 
            $data['valor_neto']
        ));
        
        $row = $this->find($data['id'])->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar($data = null)
    {
        if(NULL == $data) {
            throw new Exception("No se ha enviado ningún ID para eliminar items - ItemCotizacion::eliminar()");
        }
        
        $items = explode(",", $data);
            
        $adapter = $this->getAdapter();
        foreach($items as $id){
            
            try {
                $where = $adapter->quoteInto("id=?",  $id);
                $this->delete($where);
            } catch(Exception $e){
                return $e;
            }
        }
    }
    
    public function copiarItems($antigua_id, $nueva_id)
    {
        $itemsOrigen = $this->getRowsByCotizacionId($antigua_id);
        foreach($itemsOrigen as $data){
            $data['cotizacion_id'] = $nueva_id;
            unset($data['id']);
            $this->clonar($data);
        }
    }
    
    public function importarItemsPresupuesto($presupuesto_id, $cotizacion_id = NULL)
    {
        try {
            $presupuesto = new Default_Model_Presupuesto();
            $presupuesto->setId($presupuesto_id);
            $rowPresupuesto = $presupuesto->getRow()->toArray();

            $repuestos = $presupuesto->getRepuestosSeleccionados();
            $servicios = $presupuesto->getServiciosExternosSeleccionados();
            $manoObras = $presupuesto->getServicioInternosFull();

            $this->_crearInsumo($rowPresupuesto, $cotizacion_id);
            $this->_importarRepuestos($repuestos, $cotizacion_id, $rowPresupuesto['vehiculo_id']);
            $this->_importarServicios($servicios, $cotizacion_id, $rowPresupuesto['vehiculo_id']);
            $this->_importarManoObras($manoObras, $cotizacion_id, $rowPresupuesto['vehiculo_id']);
            
        } catch (Exception $ex) {
            return $ex;
        }
    }
    
    private function _importarManoObras($manoObras, $cotizacion_id, $vehiculo_id)
    {
        $data = array();
        $iva = 1 + (Default_Model_SistemaPreferencia::getPref('IVA') / 100);
        
        foreach($manoObras as $manoObra){
            
            $data = array(
                'cotizacion_id' => $cotizacion_id,
                'codigo' => NULL,
                'vehiculo_id' => $vehiculo_id,
                'nombre' => $manoObra['nombre'],
                'descripcion' => $manoObra['descripcion'],
                'cantidad' => 1,
                'unidad_medida' => 'U',
                'valor_neto' => ($manoObra['precio_venta'] / $iva) ,
                'descuento' => 0,
                'tipo' => 'SI'
            ); 
            
            $row = $this->createRow();
            $row->setFromArray($data);
            $row->save();
        }
    }
    
    private function _importarServicios($servicios, $cotizacion_id, $vehiculo_id)
    {
        $data = array();
        $iva = 1 + (Default_Model_SistemaPreferencia::getPref('IVA') / 100);
        
        foreach($servicios as $servicio){
            
            $data = array(
                'cotizacion_id' => $cotizacion_id,
                'codigo' => NULL,
                'vehiculo_id' => $vehiculo_id,
                'nombre' => $servicio['nombre'],
                'descripcion' => $servicio['observaciones'],
                'cantidad' => $servicio['cantidad_requerida'],
                'unidad_medida' => 'U',
                'valor_neto' => ($servicio['precio_venta'] / $iva) ,
                'descuento' => 0,
                'tipo' => 'SE'
            ); 
            
            $row = $this->createRow();
            $row->setFromArray($data);
            $row->save();
        }
    }
    
    private function _importarRepuestos($repuestos, $cotizacion_id, $vehiculo_id)
    {
        $data = array();
        $iva = 1 + (Default_Model_SistemaPreferencia::getPref('IVA') / 100);
        
        foreach($repuestos as $repuesto){
            
            $data = array(
                'cotizacion_id' => $cotizacion_id,
                'codigo' => $repuesto['codigo'],
                'vehiculo_id' => $vehiculo_id,
                'nombre' => $repuesto['nombre'],
                'descripcion' => $repuesto['observaciones'],
                'cantidad' => $repuesto['cantidad_requerida'],
                'unidad_medida' => 'U',
                'valor_neto' => ($repuesto['precio_venta'] / $iva) ,
                'descuento' => 0,
                'tipo' => 'RE'
            ); 
            
            $row = $this->createRow();
            $row->setFromArray($data);
            $row->save();
        }
    }
    
    private function _crearInsumo($presupuesto, $cotizacion_id)
    {
        try {
            $iva = 1 + (Default_Model_SistemaPreferencia::getPref('IVA') / 100);
            $data = array(
                'cotizacion_id' => $cotizacion_id,
                'codigo' => NULL,
                'vehiculo_id' => $presupuesto['vehiculo_id'],
                'nombre' => 'Insumos',
                'descripcion' => NULL,
                'cantidad' => 1,
                'unidad_medida' => 'U',
                'valor_neto' => ($presupuesto['insumos'] / $iva),
                'descuento' => 0,
                'tipo' => 'IN'
            ); 

            $row = $this->createRow();
            $row->setFromArray($data);
            return $row->save();
            
        } catch (Exception $ex) {
            return $ex->getMessage();
        }
        
    }
    
    private function _calcularDescuento($tipo, $descuento, $neto)
    {
        if(!isset($tipo) OR !isset($descuento) OR !isset($neto)){
            throw new Exception("No se han enviado todos los datos necesarios para calcular el descuento");
        }

        if($tipo=='MONTO') {
            return $descuento;
        }

        if($tipo=='PORCENTAJE'){
            $monto = round($neto * ($descuento/100));
            return $monto;
        }
    }
    
    private function _getNeto($bruto)
    {
        $neto = $bruto / (1 + Default_Model_SistemaPreferencia::getPref('IVA') / 100);
        return round($neto);
    }
    
    private function _getBruto($neto)
    {
        $bruto = $neto * (1 + Default_Model_SistemaPreferencia::getPref('IVA') /  100);
        return round($bruto);
    }
}