<?php
class Default_Model_ItemNotaVenta extends Zend_Db_Table_Abstract
{
    protected $_name = 'notas_ventas_items';
    protected $_primary = 'id';
    
    public function setId($id)
    {
        $id = (int)$id;
        
        $options = array('table' => 'notas_ventas_items', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getRowsByNotaVentaId($nota_id = null)
    {
        if(NULL == $nota_id) {
            throw new Exception("No se ha enviado el ID de la nota de venta");
        }
        
        $where = $this->getAdapter()->quoteInto("nota_id=?", $nota_id);
        $order = "id";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select()
            ->from(array('i' => 'notas_ventas_items'), array('*'))
            ->joinLeft(array('v' => 'vehiculos'), 'i.vehiculo_id=v.id', array('patente'))
            ->where($where)
            ->order($order);
        $items = $adapter->fetchAll($select);
        return $items;
    }
    
    public function getRowsByNotaVentaIdToFacturacion($nota_id = null)
    {
        if(NULL == $nota_id) {
            throw new Exception("No se ha enviado el ID de la nota de venta");
        }
        
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        
        $sql = "SELECT i.id, i.nota_id, i.vehiculo, i.codigo, i.nombre, "
             . "i.descripcion, i.cantidad, i.unidad_medida, i.valor_neto, "
             . "i.descuento, i.tipo, i.estado  "
             . "FROM notas_ventas_items AS i "
             . "WHERE i.nota_id='$nota_id' "
             . "AND i.id NOT IN(SELECT item_id FROM dte_facturas_items) "
             . "AND i.id NOT IN(SELECT item_id FROM dte_boletas_items) "
             . "ORDER BY i.id";
        return $adapter->fetchAll($sql);
    }
    
    public function getRowsByVehiculoId($vehiculo_id){
        if(NULL == $vehiculo_id) {
            throw new Exception("No se ha enviado el ID del vehículo - ItemNotaVenta::getRowsByVehiculoId()");
        }
        $where = $this->getAdapter()->quoteInto("vehiculo_id=?", $vehiculo_id);
        $items = $this->fetchAll($where);
        return $items;
    }
    
    public function getItemsDisponibles($vehiculo_id)
    {
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        
        $sql = "SELECT i.id, i.nota_id, i.nombre, i.descripcion, i.cantidad "
             . "FROM notas_ventas_items AS i "
             . "WHERE vehiculo_id='$vehiculo_id' AND tipo='SI' AND id NOT IN(SELECT item_id FROM ordenes_servicios_items)";
        
        return $adapter->fetchAll($sql);
    }
    
    public function getAllItemsDisponibles()
    {
        /* 
         * falta filtrar los ítems ya costeados, para esto es 
         * necesario crear la tabla donde buscar esos valores, tal como se hizo con los items de la nota de venta
         */
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('inv' => 'notas_ventas_items'),
                   array('id', 'nota_id', 'vehiculo_id', 'nombre', 'descripcion', 'valor_neto', 'cantidad', 'descuento'))
            ->join(array('v' => 'vehiculos'), 'v.id=inv.vehiculo_id', array('vehiculo' => 'patente'))    
            ->where("tipo='SE'")
            ->orWhere("tipo='RE'");
        return $adapter->fetchAll($select);
    }
    
    public function crear($data)
    {
        if($data['vehiculo']==''){ 
            $data['vehiculo'] = NULL;
        } else {
            $data['vehiculo'] = strtoupper($data['vehiculo']);
        }
        
        $data['descuento'] = $this->_calcularDescuento(
            $data['tipo_descuento'], 
            $data['descuento'], 
            $data['valor_neto']
        );        
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        if($data['vehiculo']==''){ 
            $data['vehiculo'] = NULL;
        } else {
            $data['vehiculo'] = strtoupper($data['vehiculo']);
        }
        
        $data['descuento'] = $this->_calcularDescuento(
            $data['tipo_descuento'], 
            $data['descuento'], 
            $data['valor_neto']
        ); 
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function checkInsumosByNotaVentaId($nota_id)
    {
        $where = "tipo='IN' AND nota_id='$nota_id'";
        $data = array("estado" => '1');
        $this->update($data, $where);
    }
    
    public function terminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        } 
        
        $row = $this->getRow();
        $row->estado = 1;
        $row->save();
    }
    
    public function crearFromCotizacion($items, $nota_id)
    {
        foreach($items as $item){
            $this->_crearFromCotizacion($item, $nota_id);
        }
    }
    
    public function addFromCotizacion($data, $nota_id)
    {
        $dataRow = array();
        $items = explode(",", $data);
        
        $itemCotizacion = new Default_Model_ItemCotizacion();
        
        foreach($items as $id){
            
            $itemCotizacion->setId($id);
            $dataRow = $itemCotizacion->getRow();
            $dataRow['item_cotizacion_id'] = $dataRow['id'];
            unset($dataRow['id']);
            $this->_crearFromCotizacion($dataRow, $nota_id);
            
        }
    }
    
    public function eliminar($data = null)
    {
        if(NULL == $data) {
            throw new Exception("No se ha enviado ningún ID para eliminar items");
        }
        
        $items = explode(",", $data);
            
        $adapter = $this->getAdapter();
        foreach($items as $id){
            $where = $adapter->quoteInto("id=?",  $id);
            $this->delete($where);
        }
    }
    
    public static function getOrdenServicioId($id){
        $adapter = self::getDefaultAdapter();
        $id = $adapter->quote($id);
        $sql = "SELECT orden_id FROM ordenes_servicios_items WHERE item_id=$id LIMIT 1";
        return $adapter->fetchOne($sql);
    }

    private function _crearFromCotizacion($data, $nota_id)
    {
        $data['cotizacion_item_id'] = $data['id'];
        unset($data['id']);
        unset($data['cotizacion_id']);
        $data['nota_id'] = $nota_id;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    private function _calcularDescuento($tipo, $descuento, $neto)
    {
        if(!isset($tipo) OR !isset($descuento) OR !isset($neto)){
            throw new Exception("No se han enviado todos los datos necesarios para calcular el descuento");
        }

        if($tipo=='MONTO') {
            return $descuento;
        }

        if($tipo=='PORCENTAJE'){
            $monto = round($neto * ($descuento/100));
            return $monto;
        }
    }
}