<?php
class Default_Model_ItemOrdenCompra extends Zend_Db_Table_Abstract
{
    protected $_name = 'ordenes_compras_items';
    protected $_primary = 'id';
    
    private $_id = null;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => 'ordenes_compras_items', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $data = $this->find($this->_id)->current()->toArray();
        $data['precio_compra'] = $this->_getBruto($data['valor_neto']);
        $data['descuento'] = $this->_getBruto($data['descuento']);
        return $data;
    }
    
    public function getOrdenCompra($id)
    {
        $orden = new Default_Model_OrdenCompra();
        $orden->setId($id);
        return $orden->getRow();
    }
    
    public function getRowsByOrdenId($orden_id = null)
    {
        if(NULL == $orden_id) {
            throw new Exception("No se ha enviado el ID de la orden de compra - ItemOrdenCompra::getRowsByOrdenId()");
        }
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select()
            ->from(array('i' => 'ordenes_compras_items'), array(
                'id', 'orden_id', 'codigo', 'cantidad', 
                'unidad_medida', 'valor_neto', 'descuento', 
                'nombre', 'descripcion'))
            ->where("orden_id=?", $orden_id);
        return $adapter->fetchAll($select);
    }
    
    public function crear($data)
    {
        $data['valor_neto'] = $this->_getNeto($data['precio_compra']);
        $data['descuento'] = $this->_getNeto($this->_calcularDescuento(
            $data['tipo_descuento'], 
            $data['descuento'], 
            $data['valor_neto']
        )); 
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function copiarItems($antigua_id, $nueva_id)
    {
        $itemsOrigen = $this->getRowsByOrdenId($antigua_id);
        foreach($itemsOrigen as $data){
            $data['orden_id'] = $nueva_id;
            unset($data['id']);
            $this->clonar($data);
        }
    }
    
    public function clonar($data)
    {
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data)
    {
        $data['valor_neto'] = $this->_getNeto($data['precio_compra']);
        $data['descuento'] = $this->_getNeto($this->_calcularDescuento(
            $data['tipo_descuento'], 
            $data['descuento'], 
            $data['valor_neto']
        )); 
        
        $row = $this->find($data['id'])->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar($data = null)
    {
        if(NULL == $data) {
            throw new Exception("No se ha enviado ningún ID para eliminar items");
        }
        
        $items = explode(",", $data);
            
        $adapter = $this->getAdapter();
        foreach($items as $id){
            
            try {
                $where = $adapter->quoteInto("id=?",  $id);
                $this->delete($where);
            } catch(Exception $e){
                return $e;
            }
        }
    }
    
    public function coparItems($id, $nuevaId)
    {
        $itemsOrigen = $this->getRowsByOrdenId($id)->toArray();
        
        foreach($itemsOrigen as $data){
            $data['orden_id'] = $nuevaId;
            $this->crear($data);
        }
    }
    
    private function _calcularDescuento($tipo, $descuento, $neto)
    {
        if(!isset($tipo) OR !isset($descuento) OR !isset($neto)){
            throw new Exception("No se han enviado todos los datos necesarios para calcular el descuento");
        }

        if($tipo=='MONTO') {
            return $descuento;
        }

        if($tipo=='PORCENTAJE'){
            $monto = round($neto * ($descuento/100));
            return $monto;
        }
    }
    
    private function _getNeto($bruto)
    {
        $neto = $bruto / (1 + Default_Model_SistemaPreferencia::getPref('IVA') / 100);
        return round($neto);
    }
    
    private function _getBruto($neto)
    {
        $bruto = $neto * (1 + Default_Model_SistemaPreferencia::getPref('IVA') /  100);
        return round($bruto);
    }
}