<?php
class Default_Model_NotaVenta extends Zend_Db_Table_Abstract
{
    protected $_name = 'notas_ventas';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'cliente', 'total_neto');
    private $_orderByOptionsValues = array('Nº', 'Cliente', 'Total Neto');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - NotaVenta::setId()");
        }
        
        $this->_id = (int)$id;
    }
    
    public function getDisponiblesFacturacion($cliente_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        
        $sql = "SELECT DISTINCT(nv.id), nv.cliente, nv.iva FROM notas_ventas_items AS inv "
             . "JOIN notas_ventas AS nv ON nv.id=inv.nota_id "
             . "WHERE nv.cliente='$cliente_id' "
             . "AND nv.estado!='BORRADOR' "
             . "AND inv.id NOT IN(SELECT dte_facturas_items.item_id FROM dte_facturas_items) "
             . "AND inv.id NOT IN(SELECT dte_boletas_items.item_id FROM dte_boletas_items) "
             . "ORDER BY nv.id DESC";
        
        return $adapter->fetchAll($sql);
    }
    
    public function getVehiculosConTrabajosNoAsignados()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        
        $sql = "SELECT DISTINCT(v.patente), COUNT(*) AS num_trabajos_pendientes FROM notas_ventas_items AS inv "
             . "JOIN vehiculos AS v ON v.patente=inv.vehiculo "
             . "WHERE inv.tipo='SI' AND inv.estado='0' "
             . "AND inv.id NOT IN(SELECT item_id FROM ordenes_servicios_items) "
             . "GROUP BY inv.vehiculo";
        
        return $adapter->fetchAll($sql);
    }
    
    public function getEstado()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        return $this->getRow()->estado;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - NotaVenta::getRow()");
        }
        
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getRowFull()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - NotaVenta::getRowFull()");
        }
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select()
            ->from(array('n' => 'notas_ventas'), array(
                'id', 'creacion', 'creador', 'cliente_id', 'iva', 
                'observaciones', 'estado'))
            ->join(array('c' => 'clientes'), 'c.id=n.cliente_id', array('cliente' =>  'nombre'))
            ->where("n.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }

    public function getItems()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - NotaVenta::getItems()");
        }
        $modelItems = new Default_Model_ItemNotaVenta();
        return $modelItems->getRowsByNotaVentaId($this->_id);
    }
    
    public function getItemsToFacturacion()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - NotaVenta::getItemsToFacturacion()");
        }
        $modelItems = new Default_Model_ItemNotaVenta();
        return $modelItems->getRowsByNotaVentaIdToFacturacion($this->_id);
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function updateIva()
    {
        $row = $this->getRow();
        $row->iva = Default_Model_SistemaPreferencia::getPref('IVA');
        $row->save();
    }
    
    public function requerirAutorizacion($usuario_id)
    {
        $modelAutorizacion = new Default_Model_DocumentoAutorizacion();
        
        $data =  array(
            'creado_por' => $usuario_id,
            'documento_controller' => 'nota_venta',
            'documento_nombre' => 'Nota de Venta', 
            'documento_id' => $this->_id,
            'estado' => 0,
            'comentarios' => NULL
        );
        
        return $modelAutorizacion->crear($data, $usuario_id);
    }
    
    public function terminarAutorizacion($documentoData)
    {
        $modelAutorizacion = new Default_Model_DocumentoAutorizacion();
        $autorizacionData =  array(
            'autorizacion' => date("Y-m-d H:i:s"),
            'autorizado_por' => $usuario_id,
            'estado' => 1
        );
        return $modelAutorizacion->editar($documentoData, $autorizacionData);
    }
    
    public function crear($data, $user)
    {
        if($data['recepcion_id']==''){ $data['recepcion_id'] = NULL;}
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        
        $data['creador'] = $user;
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function crearFromCotizacion($cotizacion_id, $usuario)
    {
        $cotizacion = new Default_Model_Cotizacion();
        $cotizacion->setId($cotizacion_id);
        
        $dataCotizacion = $cotizacion->getRow()->toArray();
        $itemsCotizacion = $cotizacion->getItems();
        
        $id = $this->crear(
            array(
                'cliente_id' => $dataCotizacion['cliente_id'],
                'recepcion_id' => $dataCotizacion['recepcion_id']
            ), 
            $usuario
        );
        
        $itemNotaVenta = new Default_Model_ItemNotaVenta();
        $itemNotaVenta->crearFromCotizacion($itemsCotizacion, $id);

        return $id;
    }
    
    public function editar($data, $id)
    {
        if($data['recepcion_id']==''){ $data['recepcion_id'] = NULL;}
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');

        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function getRowsByCliente($id)
    {
        $order = "id DESC";
        $where = $this->getAdapter()->quoteInto("cliente=?", $id);
        return $this->fetchAll($where, $order);
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select()
            ->from(array('n' => 'notas_ventas'), array(
                'id', 'creacion', 'creador', 'cliente_id', 'iva', 
                'observaciones', 'estado'))
            ->join(array('c' => 'clientes'), 'c.id=n.cliente_id', array('cliente' =>  'nombre'))
            ->order($order);
        $notas = $adapter->fetchAll($select);
        $paginador = Zend_Paginator::factory($notas);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getListByCliente($rut)
    {
        $where = $this->getAdapter()->quoteInto("cliente=?", $rut);
        $notas = $this->fetchAll($where);
        return $notas;
    }
    
    public function getNeto()
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT SUM(cantidad * (valor_neto - descuento)) "
             . "FROM notas_ventas_items WHERE notas_ventas_items.nota_id='$this->_id'";
        $totalNeto = $adapter->fetchOne($sql);
        return $totalNeto;
    }
    
    public function searchToTooltip($criterio, $valor)
    {
        $adapter = $this->getAdapter();
        
        if($criterio!='' AND $valor!='') {
        
            if($criterio=='id') {
                
                $valor = $adapter->quote((int)$valor);
                $where = "$criterio=$valor";
                
            } else {
                
                $valor = $adapter->quote(App_Rut::cleanToDb($valor));
                $where = "$criterio=$valor";
                
            }
            return $this->fetchAll($where)->toArray();
        }
        return false;
    }
    
    public function eliminar()
    {
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        try {
            $this->delete($where);
            return true;
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }

    public function checkInsumos()
    {
        $item = new Default_Model_ItemNotaVenta();
        $item->checkInsumosByNotaVentaId($this->_id);
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    public static function getTotalNeto($id)
    {
        $model = new Default_Model_NotaVenta();
        $model->setId($id);
        return $model->getNeto();
    }
    
    public function checkOrdenesAbiertas()
    {
        return Default_Model_OrdenServicio::checkAbiertasByNotaVenta($this->_id);
    }
    
    public static function getPrefs()
    {
        $model = new Default_Model_SistemaPreferencia();
        $preferencias = $model->fetchAll("nombre LIKE 'NV_%'");
        $data = array();
        foreach($preferencias as $pref){
            $data[$pref->nombre] = $pref->valor;
        }
        return $data;
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
}