<?php
class Default_Model_OrdenCompra extends Zend_Db_Table_Abstract
{
    protected $_name = 'ordenes_compras';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'proveedor', 'total_neto');
    private $_orderByOptionsValues = array('Nº', 'Proveedor', 'Total Neto');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => 'ordenes_compras', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ord' => 'ordenes_compras'), array(
                'id', 'proveedor_id', 'creacion', 'fecha', 'validez', 'atencion_a', 
                'emitida_por', 'proveedor_paga_flete', 'condiciones_pago',
                'descuento_global', 'iva', 'referencia', 'observaciones', 'estado'
            ))
            ->join(array('pro' => 'proveedores'), 'pro.id=ord.proveedor_id', array('proveedor' => 'razon_social'))
            ->where("ord.id=?", $this->_id);
        $orden = $adapter->fetchRow($select);
        return $orden;
    }
    
    public function getProveedorRazonSocial()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        return Default_Model_Proveedor::getRazonSocialByRut($this->getRow()->proveedor);
    }
    
    public function getItems()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $modelItems = new Default_Model_ItemOrdenCompra();
        return $modelItems->getRowsByOrdenId($this->_id);
    }
    
    public function getUltimoEnvio()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $modelEnvio = new Default_Model_DocumentoEnvio();
        $where = $modelEnvio->getAdapter()->quoteInto("tipo='orden-compra' AND documento_id=?", $this->_id);
        $order = "id DESC";
        $row = $modelEnvio->fetchRow($where, $order);
        return $row;
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function updateIva()
    {
        $row = $this->getRow();
        $row->iva = Default_Model_SistemaPreferencia::getPref('IVA');
        $row->save();
    }
    
    public function requerirAutorizacion($usuario_id)
    {
        $modelAutorizacion = new Default_Model_DocumentoAutorizacion();
        
        $data =  array(
            'creado_por' => $usuario_id,
            'documento_controller' => 'orden-compra',
            'documento_nombre' => 'Orden de compra', 
            'documento_id' => $this->_id,
            'estado' => 0,
            'comentarios' => NULL
        );
        
        return $modelAutorizacion->crear($data, $usuario_id);
    }
    
    public function crear($data, $user)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        
        $data['creador'] = $user;
        $data['proveedor'] = App_Rut::cleanToDb($data['proveedor']);
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function clonar($usuario_id)
    {
        $data = $this->getRow()->toArray();
        
        $antigua_id = $data['id'];
        
        unset($data['id']);
        unset($data['creacion']);
        unset($data['estado']);
        
        $data['fecha'] = date("Y-m-d");
        $data['creador'] = $usuario_id;
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        $nueva_id = $row->id;
        
        $modelItem = new Default_Model_ItemOrdenCompra();
        $modelItem->copiarItems($antigua_id, $nueva_id);
        
        return $nueva_id;
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ord' => 'ordenes_compras'), array(
                'id', 'proveedor_id', 'creacion', 'fecha', 'validez', 'atencion_a', 
                'emitida_por', 'proveedor_paga_flete', 'condiciones_pago',
                'descuento_global', 'iva', 'referencia', 'observaciones', 'estado'
            ))
            ->join(array('pro' => 'proveedores'), 'pro.id=ord.proveedor_id', array('proveedor' => 'razon_social'))
            ->order($order);
        $ordenes = $adapter->fetchAll($select);
        $paginador = Zend_Paginator::factory($ordenes);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getRowsByProveedor($rut)
    {
        $where = $this->getAdapter()->quoteInto("proveedor=?", $rut);
        return $this->fetchAll($where);
    }
    
    public function getNeto($id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT SUM(cantidad * (valor_neto - descuento)) "
             . "FROM ordenes_compras_items i WHERE i.orden_id='$id'";
        $totalNeto = $adapter->fetchOne($sql);
        return $totalNeto;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    public static function getTotalNeto($id)
    {
        return self::getNeto($id);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }

    public static function getPrefs()
    {
        $model = new Default_Model_SistemaPreferencia();
        $preferencias = $model->fetchAll("nombre LIKE 'OC_%'");
        $data = array();
        foreach($preferencias as $pref){
            $data[$pref->nombre] = $pref->valor;
        }
        return $data;
    }
}