<?php
class Default_Model_OrdenServicio extends Zend_Db_Table_Abstract
{
    protected $_name = 'ordenes_servicios';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'vehiculo', 'modelo', 'mecanico');
    private $_orderByOptionsValues = array('Nº', 'Vehículo', 'Modelo', 'Asignada a');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => 'ordenes_servicios', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - OrdenServicio::setId()");
        }
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - OrdenServicio::getRow()");
        }
        return $this->find($this->_id)->current();
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ord' => 'ordenes_servicios'), array(
                'id', 'vehiculo_id', 'creacion', 'asignada_a', 'observaciones', 'horas_reales', 
                'requiere_prueba_ruta', 'requiere_control_calidad', 'cierre_fecha',
                'cierre_prueba_ruta', 'cierre_control_calidad', 'cierre_informe', 
                'cierre_recomendaciones', 'estado'
            ))
            ->join(array('veh' => 'vehiculos'), 'veh.id=ord.vehiculo_id', array(
                'patente', 'vin_chassis', 'numero_motor',
                'anio', 'color', 'mas_informacion', 'aire_acondicionado'
            ))
            ->join(array('mod' => 'vehiculos_modelos'), 'mod.id=veh.modelo_id', array(
                'modelo' => 'nombre', 'version', 'cilindrada', 'tipo_combustible',
                'traccion', 'transmision'
            ))    
            ->join(array('cli' => 'clientes'), 'cli.id=veh.cliente_id', array('nombre_cliente' => 'nombre'))
            ->join(array('mar' => 'vehiculos_marcas'), 'mar.id=mod.marca_id', array('marca' => 'nombre'))
            ->join(array('usu' => 'sistema_usuarios'), 'usu.id=ord.asignada_a', array('mecanico' => 'nombre'))    
            ->where("ord.id=?", $this->_id);
        $orden = $adapter->fetchRow($select);
        return $orden;
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function crear($data, $user)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        $data['creador'] = $user;
        $data['patente'] = strtoupper($data['patente']);
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        $data['patente'] = strtoupper($data['patente']);
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function cerrar($data)
    {
        $row = $this->getRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editarInforme($informe, $id)
    {
        $row = $this->find($id)->current();
        $row->cierre_informe = $informe;
        $row->save();
    }
    
    public function editarRecomendaciones($recomendaciones, $id)
    {
        $row = $this->find($id)->current();
        $row->cierre_recomendaciones = $recomendaciones;
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('ord' => 'ordenes_servicios'), array(
                'id', 'creacion', 'vehiculo_id', 'asignada_a', 'observaciones', 'horas_reales', 
                'requiere_prueba_ruta', 'requiere_control_calidad', 'cierre_fecha',
                'cierre_prueba_ruta', 'cierre_control_calidad', 'cierre_informe', 
                'cierre_recomendaciones', 'estado'
            ))
            ->join(array('veh' => 'vehiculos'), 'veh.id=ord.vehiculo_id', array(
                'patente', 'vin_chassis', 'numero_motor',
                'anio', 'color', 'mas_informacion'
            ))
            ->join(array('mod' => 'vehiculos_modelos'), 'mod.id=veh.modelo_id', array(
                'modelo' => 'nombre', 'version', 'cilindrada', 'tipo_combustible',
                'traccion'
            ))    
            ->join(array('cli' => 'clientes'), 'cli.id=veh.cliente_id', array('nombre_cliente' => 'nombre'))
            ->join(array('mar' => 'vehiculos_marcas'), 'mar.id=mod.marca_id', array('marca' => 'nombre'))   
            ->order($order);
        $ordenes = $adapter->fetchAll($select);
        
        $paginador = Zend_Paginator::factory($ordenes);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getItems()
    {
        $item = new Default_Model_OrdenServicioItem();
        return $item->getRowsByOrdenId($this->_id);
    }
    
    public static function getVehiculosDisponibles()
    {
        $adapter = self::getDefaultAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $sql = "SELECT DISTINCT(inv.vehiculo_id) FROM notas_ventas_items AS inv "
             . "WHERE inv.vehiculo_id IS NOT NULL AND inv.id NOT IN (SELECT item_id FROM ordenes_servicios_items)";
        $result = $adapter->fetchAll($sql);
        $data = array();
        if(count($result) > 0) { 
            $modelVehiculo = new Default_Model_Vehiculo();
            foreach($result as $item){
                $modelVehiculo->setId($item['vehiculo_id']);
                $data[$item['vehiculo_id']] = $modelVehiculo->getPatente();
            }
        }
        return $data;
    }
    
    public function getItemsDisponibles()
    {
        $itemNota = new Default_Model_ItemNotaVenta();
        return $itemNota->getItemsDisponibles($this->getRow()->vehiculo_id);
    }
    
    public function getLastRowsByVehiculo($vehiculo)
    {
        $where = $this->getAdapter()->quoteInto("vehiculo=? AND estado='TERMINADA'", $vehiculo);
        $order = "id DESC LIMIT 5";
        return $this->fetchAll($where, $order);
    }
    
    public function getRowsByVehiculo($patente)
    {
        $where = $this->getAdapter()->quoteInto("vehiculo=?", $patente);
        return $this->fetchAll($where);
    }
       
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }

    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }

    public static function checkAbiertasByNotaVenta($nota_id)
    {
        $model = new Default_Model_OrdenServicio();
        $adapter = $model->getAdapter();
        $nota_id = $adapter->quote($nota_id);
        $sql = "SELECT COUNT(*) FROM ordenes_servicio WHERE estado!='TERMINADA' AND nota_id=$nota_id";
        $result = $adapter->fetchOne($sql);
        return $result;
    }
    
}