<?php
class Default_Model_PagoEmitido extends Zend_Db_Table_Abstract
{
    protected $_name = 'pagos_emitidos';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'proveedor', 'monto', 'forma_id');
    private $_orderByOptionsValues = array('Nº ingreso', 'Proveedor', 'Monto pagado', 'Forma de Pago');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function asociarDocumentoTributario($data, $usuario)
    {
        if($data['documento_tipo']=='BOLETA') {
            
            $pagoDtrBoleta = new Default_Model_PagoEmitidoDtrBoleta();
            $pagoDtrBoleta->crear(array(
                'creador' => $usuario,
                'pago_id' => $data['pago_id'],
                'boleta_id' => $data['documento_id'],
                'monto' => $data['monto']
            ));
            
            
        } elseif($data['FACTURA']) {
            
            $pagoDtrFactura = new Default_Model_PagoEmitidoDtrFactura(); 
            $pagoDtrFactura->crear(array(
                'creador' => $usuario,
                'pago_id' => $data['pago_id'],
                'factura_id' => $data['documento_id'],
                'monto' => $data['monto']
            ));
            
        } else {
            throw new Exception('El documento que intenta asociar no corresponde ' . $data['documento_tipo']);
        }
    }
    
    public function getDtrBoletasAsociadas()
    {
        $pagoBoleta = new Default_Model_PagoEmitidoDtrBoleta();
        return $pagoBoleta->getRowsByPagoId($this->_id);
    }
    
    public function getDtrFacturasAsociadas()
    {
        $pagoFactura = new Default_Model_PagoEmitidoDtrFactura();
        return $pagoFactura->getRowsByDtrFacturaId($this->_id);
    }
    
    public function getTotalAsignado()
    {
        $adapter = $this->getAdapter();
        $id = $adapter->quote($this->_id);
        $sqlBoletas = "SELECT SUM(monto) FROM pagos_emitidos_dtr_boletas WHERE pago_id=$id";
        $sqlFacturas = "SELECT SUM(monto) FROM pagos_emitidos_dtr_facturas WHERE pago_id=$id";
        
        $totalAsignadoBoletas = $adapter->fetchOne($sqlBoletas);
        $totalAsignadoFacturas = $adapter->fetchOne($sqlFacturas);
        
        $totalAsignado = (int)$totalAsignadoBoletas + (int)$totalAsignadoFacturas;
        return $totalAsignado;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('pe' => 'pagos_emitidos'),
                   array('id', 'creacion', 'creador', 'tipo', 'monto', 'observaciones', 'estado'))
            ->join(array('p' => 'proveedores'), 'p.rut=pe.proveedor', array('proveedor' => 'razon_social'))
            ->join(array('fp' => 'pagos_emitidos_formas'), 'fp.id=pe.forma_id', array('forma_pago' => 'nombre', 'detallar'))
            ->join(array('u' => 'sistema_usuarios'), 'u.id=pe.creador', array('recibido_por' => 'nombre'))
            ->where("pr.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getInfoExtra()
    {
        return $this->getRowFull()->detallar;
    }
    
    public function getCodigoTransaccion()
    {
        $codigo = new Default_Model_PagoRecibidoCodigoTransaccion();
        return $codigo->getRowByPagoId($this->_id);
    }
    
    public function getDocumentoBancario()
    {
        $documento = new Default_Model_PagoRecibidoDocumentoBancario();
        return $documento->getRowByPagoId($this->_id);
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        
        if($data['observaciones']=='') { $data['observaciones']= NULL; }
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        if($data['observaciones']=='') { $data['observaciones']= NULL; }
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('pe' => 'pagos_emitidos'),
                   array('id', 'creacion', 'creador', 'tipo', 'monto', 'observaciones', 'estado'))
            ->join(array('p' => 'proveedores'), 'p.rut=pe.proveedor', array('proveedor' => 'razon_social'))
            ->join(array('fp' => 'pagos_emitidos_formas'), 'fp.id=pe.forma_id', array('forma_pago' => 'nombre'))
            ->order($order);
        $pagos = $adapter->fetchAll($select);
        
        $paginador = Zend_Paginator::factory($pagos);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
}