<?php
class Default_Model_PagoRecibidoDocumentoBancario extends Zend_Db_Table_Abstract
{
    protected $_name = 'pagos_recibidos_documentos_bancarios';
    protected $_primary = 'pago_id';
    
    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getRowByPagoId($pago_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('db' => 'pagos_recibidos_documentos_bancarios'),
                   array('creacion', 'creador', 'fecha_cobro', 'banco', 'cuenta', 'serie', 'titular', 'estado'))
            ->join(array('td' => 'pagos_recibidos_documentos_bancarios_tipos'), 'td.id=db.tipo_id', array('tipo' => 'nombre'))
            ->where("db.pago_id=?", (int)$pago_id);
        return $adapter->fetchRow($select);
    }
    
    public function crear($data, $usuario)
    {
        $data['creador'] = $usuario;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data, $id)
    {
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("pago_id=?",  $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
}