<?php
class Default_Model_PautaMantenimiento extends Zend_Db_Table_Abstract
{
    protected $_name = 'pautas_mantenimiento';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'creacion', 'marca');
    private $_orderByOptionsValues = array('Nº', 'Fecha creación', 'Marca');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => 'pautas_mantenimiento', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - PautaMantenimiento::setId()");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - PautaMantenimiento::getRow()");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
     public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('pm' => 'pautas_mantenimiento'),
                   array('id', 'modelos_referencia', 'observaciones'))
            ->join(array('m' => 'vehiculos_marcas'), 'm.id=pm.marca_id', array('marca' => 'nombre'));
        return $adapter->fetchRow($select);
    }
    
    public function getItems()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - PautaMantenimiento::getItems()");
        }
        $modelItems = new Default_Model_PautaMantenimientoItem();
        return $modelItems->getRowsByPautaId($this->_id);
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function crear($data, $user)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        $data['creador'] = $user;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('pm' => 'pautas_mantenimiento'),
                   array('id', 'modelos_referencia', 'observaciones'))
            ->join(array('m' => 'vehiculos_marcas'), 'm.id=pm.marca_id', array('marca' => 'nombre'))
            ->order($order);
        $pautas = $adapter->fetchAll($select);
        
        $paginador = Zend_Paginator::factory($pautas);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getAllToSelect()
    {
        return $this->fetchAll();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - PautaMantenimiento::eliminar()");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'ASC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
}