<?php
class Default_Model_Presupuesto extends Zend_Db_Table_Abstract
{
    protected $_name = 'presupuestos';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('pre.id', 'veh.patente', 'mar.nombre', 'cli.nombre');
    private $_orderByOptionsValues = array('Nº', 'Patente', 'Marca', 'Cliente');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => 'presupuestos', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - Presupuesto::setId()");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Presupuesto::getRow()");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getVehiculo()
    {
        $modelVehiculo = new Default_Model_Vehiculo();
        $modelVehiculo->setId($this->getRow()->vehiculo_id);
        return $modelVehiculo->getRowFull();
    }
    
    public function getClienteId()
    {
        $vehiculo = new Default_Model_Vehiculo();
        $vehiculo->setId($this->getRow()->vehiculo_id);
        return $vehiculo->getClienteId();
    }
    
    public function getRowsByVehiculo($vehiculo_id)
    {
        $where = $this->getAdapter()->quoteInto("vehiculo_id=?", int($vehiculo_id));
        return $this->fetchAll($where, "id DESC");
    }
    
    public function getManosObraFull()
    {
        return array();
    }
    
    public function getRepuestosExternos()
    {
        $data = array();
        $modelRepuestoExterno = new Default_Model_PresupuestoRepuestoExterno();
        $data['items'] = $modelRepuestoExterno->getRowsByPresupuesto($this->_id);
        $data['num'] = count($data['items']);
        $data['totalCosto'] = $modelRepuestoExterno->getTotalCostoByPresupuesto($this->_id);
        $data['totalPrecioVenta'] = $modelRepuestoExterno->getTotalPrecioVentaByPresupuesto($this->_id);
        return $data;
    }
    
    public function getRepuestosSeleccionados()
    {
        $modelRepProveedor = new Default_Model_PresupuestoRepuestoExternoCotizado();
        return $modelRepProveedor->getRowsSeleccionadosByPresupuesto($this->_id);
    }
    
    public function getServiciosExternos()
    {
        $data = array();
        $modelServicioTercero = new Default_Model_PresupuestoServicioExterno();
        $data['items'] = $modelServicioTercero->getRowsByPresupuesto($this->_id);
        $data['num'] = count($data['items']);
        $data['totalCosto'] = $modelServicioTercero->getTotalCostoByPresupuesto($this->_id);
        $data['totalPrecioVenta'] = $modelServicioTercero->getTotalPrecioVentaByPresupuesto($this->_id);
        return $data;
    }
    
    public function getServiciosExternosSeleccionados()
    {
        $modelSerTercero = new Default_Model_PresupuestoServicioExternoCotizado();
        return $modelSerTercero->getRowsSeleccionadosByPresupuesto($this->_id);
    }
    
    public function getServiciosInternos()
    {
        $data = array();
        $modelServicioInterno = new Default_Model_PresupuestoServicioInterno();
        $data['items'] = $modelServicioInterno->getRowsByPresupuesto($this->_id);
        $data['num'] = count($data['items']);
        $data['totalCosto'] = $modelServicioInterno->getTotalCostoByPresupuesto($this->_id);
        $data['totalPrecioVenta'] = $modelServicioInterno->getTotalPrecioVentaByPresupuesto($this->_id);
        return $data;
    }
    
    public function getServicioInternosFull()
    {
        $modelServicioInterno = new Default_Model_PresupuestoServicioInterno();
        return $modelServicioInterno->getRowsFullByPresupuesto($this->_id);
    }
    
    public function getListInsumos()
    {
        $modelInsumo = new Default_Model_CobroInsumo();
        return $modelInsumo->getAll();
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function updateIva()
    {
        $row = $this->getRow();
        $row->iva = Default_Model_SistemaPreferencia::getPref('IVA');
        $row->save();
    }
    
    public function crear($data, $user)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        
        $data['vehiculo_id'] = Default_Model_Vehiculo::getIdByPatente($data['vehiculo']);
        $data['creador'] = $user;
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');
        $data['insumos'] = Default_Model_CobroInsumo::getValorDefault();
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        
        $data['iva'] = Default_Model_SistemaPreferencia::getPref('IVA');
        $data['insumos'] = Default_Model_CobroInsumo::getValorDefault();
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('pre' => 'presupuestos'),
                   array('id', 'creacion', 'creador', 'vehiculo_id'))
            ->join(array('veh' => 'vehiculos'), 'veh.id=pre.vehiculo_id',
                   array('patente', 'anio'))
            ->join(array('mod' => 'vehiculos_modelos'), 'mod.id=veh.modelo_id',
                   array('modelo' => 'nombre', 'version', 'cilindrada'))    
            ->join(array('cli' => 'clientes'), 'cli.id=veh.cliente_id',
                   array('nombre_cliente' => 'nombre'))
            ->join(array('mar' => 'vehiculos_marcas'), 'mar.id=mod.marca_id',
                   array('marca' => 'nombre'))    
            ->order($order);
        $presupuestos = $adapter->fetchAll($select);
        
        $paginador = Zend_Paginator::factory($presupuestos);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getListByCliente($rut)
    {
        $where = $this->getAdapter()->quoteInto("cliente=?", $rut);
        return $this->fetchAll($where);
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Presupuesto::eliminar()");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }

    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
}