<?php
class Default_Model_PresupuestoRepuestoExternoCotizado extends Zend_Db_Table_Abstract
{
    protected $_name = 'presupuestos_repuestos_externos_cotizados';
    protected $_primary = 'id';
    
    private $_id = null;
    
    public function setId($id)
    {
        $id = (int)$id;
        
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function crear($data)
    {
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            
            $this->delete($where);
            
        } catch (Exception $e) {
            
            return $e->getMessage();
            
        }
    }
    
    public function getPresupuesto()
    {
        $modelRepuestoExterno = new Default_Model_PresupuestoRepuestoExterno();
        $modelRepuestoExterno->setId($this->getRow()->presupuesto_repuesto_externo_id);
        return $modelRepuestoExterno->getPresupuesto();
    }
    
    public function setSeleccion($valor)
    {
        if(in_array($valor, array(0,1))){
            $row = $this->getRow();
            $row->select = $valor;
            $row->save();
        }
    }
    
    public function getRowsSeleccionadosByPresupuesto($presupuesto_id = null)
    {
        if(NULL == $presupuesto_id) {
            throw new Exception("No se ha enviado el ID del presupuesto");
        }
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        
        $select = $adapter->select()
            ->from(array('prc' => 'presupuestos_repuestos_externos_cotizados'),
                   array('codigo', 'marca', 'precio_venta'))
            ->join(array('pr' => 'presupuestos_repuestos_externos'), 'pr.id=prc.presupuesto_repuesto_externo_id', 
                   array('nombre', 'cantidad_requerida', 'observaciones'))
            ->where("pr.presupuesto_id=?", $presupuesto_id)
            ->where("prc.select='1'");
        return $adapter->fetchAll($select);
    }
    
    public static function getByRepuesto($repuesto_id)
    {
        $model = new Default_Model_PresupuestoRepuestoExternoCotizado();
        $where = $model->getAdapter()->quoteInto("presupuesto_repuesto_externo_id=?", $repuesto_id);
        return $model->fetchAll($where);
    }
}