<?php
class Default_Model_PresupuestoServicioExterno extends Zend_Db_Table_Abstract
{
    protected $_name = 'presupuestos_servicios_externos';
    protected $_primary = 'id';
    
    private $_id = null;
    
    public function setId($id)
    {
        $id = (int)$id;
        
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    
    public function getRowsByPresupuesto($presupuesto_id = null)
    {
        if(NULL == $presupuesto_id) {
            throw new Exception("No se ha enviado el ID del presupuesto");
        }
        
        $where = $this->getAdapter()->quoteInto("presupuesto_id=?", $presupuesto_id);
        $order = "id";
        $items = $this->fetchAll($where, $order);
        return $items;
    }
    
    public function getTotalCostoByPresupuesto($presupuesto_id = NULL)
    {
        if(NULL == $presupuesto_id) {
            throw new Exception("No se ha enviado el ID del presupuesto");
            exit;
        }
        
        $adapter = $this->getAdapter();
        $sql = "SELECT SUM(se.cantidad_requerida * sec.valor_unitario_bruto) as total_costo "
             . "FROM presupuestos_servicios_externos_cotizados AS sec "
             . "JOIN presupuestos_servicios_externos AS se ON se.id=sec.presupuesto_servicio_externo_id "
             . "WHERE se.presupuesto_id='$presupuesto_id' AND sec.select = '1'";
        return $adapter->fetchOne($sql);
    }
    
    public function getTotalPrecioVentaByPresupuesto($presupuesto_id = NULL)
    {
        if(NULL == $presupuesto_id) {
            throw new Exception("No se ha enviado el ID del presupuesto");
            exit;
        }
        
        $adapter = $this->getAdapter();
        $sql = "SELECT SUM(se.cantidad_requerida * sec.precio_venta) as total_precio_venta "
             . "FROM presupuestos_servicios_externos_cotizados AS sec "
             . "JOIN presupuestos_servicios_externos AS se ON se.id=sec.presupuesto_servicio_externo_id "
             . "WHERE se.presupuesto_id='$presupuesto_id' AND sec.select = '1'";
        return $adapter->fetchOne($sql);
    }
    
    public function crear($data)
    {
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getPresupuesto()
    {
        $modelPresupuesto = new Default_Model_Presupuesto();
        $modelPresupuesto->setId($this->getRow()->presupuesto_id);
        return $modelPresupuesto->getRow();
    }
    
    public static function getPresupuestoIdBySolicitudId($solicitud_id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT presupuesto_id FROM presupuestos_servicios_externos WHERE solicitud_id='$solicitud_id'";
        $result = $adapter->fetchOne($sql);
        if($result){
            return $result;
        }
        return FALSE;
    }
}