<?php
class Default_Model_PresupuestoServicioExternoCotizado extends Zend_Db_Table_Abstract
{
    protected $_name = 'presupuestos_servicios_externos_cotizados';
    protected $_primary = 'id';
    
    private $_id = null;
    
    public function setId($id)
    {
        $id = (int)$id;
        
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function crear($data)
    {
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            
            $this->delete($where);
            
        } catch (Exception $e) {
            
            return $e->getMessage();
            
        }
    }
    
    public function setSeleccion($valor)
    {
        if(in_array($valor, array(0,1))){
            $row = $this->getRow();
            $row->select = $valor;
            $row->save();
        }
    }
    
    public function getRowsSeleccionadosByPresupuesto($presupuesto_id = null)
    {
        if(NULL == $presupuesto_id) {
            throw new Exception("No se ha enviado el ID del presupuesto");
        }
        
        $adapter = $this->getAdapter();
        $select = $adapter->select()
            ->from(array('psc' => 'presupuestos_servicios_externos_cotizados'),
                   array('precio_venta'))
            ->join(array('ps' => 'presupuestos_servicios_externos'), 'ps.id=psc.presupuesto_servicio_externo_id', 
                   array('nombre', 'cantidad_requerida', 'observaciones'))
            ->where("ps.presupuesto_id=?", $presupuesto_id)
            ->where("psc.select='1'");
        return $adapter->fetchAll($select);
    }
    
    public static function getByServicioExterno($servicio_id)
    {
        $model = new Default_Model_PresupuestoServicioExternoCotizado();
        $where = $model->getAdapter()->quoteInto("presupuesto_servicio_externo_id=?", $servicio_id);
        return $model->fetchAll($where);
    }
    
    public function getPresupuesto()
    {
        $modelServicioExterno = new Default_Model_PresupuestoServicioExterno();
        $modelServicioExterno->setId($this->getRow()->presupuesto_servicio_externo_id);
        return $modelServicioExterno->getPresupuesto();
    }
}