<?php
class Default_Model_PresupuestoServicioInterno extends Zend_Db_Table_Abstract
{
    protected $_name = 'presupuestos_servicios_internos';
    protected $_primary = 'id';
    
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function crear($data)
    {
        if($data['descripcion']==''){ $data['descripcion'] = NULL;}
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data, $id)
    {
        if($data['descripcion']==''){ $data['descripcion'] = NULL;}
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getRowsFullByPresupuesto($presupuesto_id = null)
    {
        if(NULL == $presupuesto_id) {
            throw new Exception("No se ha enviado el ID del presupuesto");
        }
        
        $adapter = $this->getAdapter();
        $select = $adapter->select()
            ->from(array('pmo' => 'presupuestos_servicios_internos'),
                   array('nombre', 'descripcion', 'costo_bruto_estimado', 'margen', 'precio_venta'))
            ->where("pmo.presupuesto_id=?", $presupuesto_id);
        return $adapter->fetchAll($select);
    }
    
    public function getRowsByPresupuesto($presupuesto_id)
    {
        $where = $this->getAdapter()->quoteInto("presupuesto_id=?", $presupuesto_id);
        return $this->fetchAll($where);
    }
    
    public function getTotalCostoByPresupuesto($presupuesto_id = NULL)
    {
        if(NULL == $presupuesto_id) {
            throw new Exception("No se ha enviado el ID del presupuesto");
            exit;
        }
        
        $adapter = $this->getAdapter();
        $sql = "SELECT SUM(si.costo_bruto_estimado) as total_costo "
             . "FROM presupuestos_servicios_internos AS si "
             . "WHERE si.presupuesto_id='$presupuesto_id'";
        return $adapter->fetchOne($sql);
    }
    
    public function getTotalPrecioVentaByPresupuesto($presupuesto_id = NULL)
    {
        if(NULL == $presupuesto_id) {
            throw new Exception("No se ha enviado el ID del presupuesto");
            exit;
        }
        
        $adapter = $this->getAdapter();
        $sql = "SELECT SUM(si.precio_venta) as total_precio_venta "
             . "FROM presupuestos_servicios_internos AS si "
             . "WHERE si.presupuesto_id='$presupuesto_id'";
        return $adapter->fetchOne($sql);
    }
    
    public function getPresupuesto()
    {
        $modelPresupuesto = new Default_Model_Presupuesto();
        $modelPresupuesto->setId($this->getRow()->presupuesto_id);
        return $modelPresupuesto->getRow();
    }
}