<?php
class Default_Model_Proveedor extends Zend_Db_Table_Abstract
{
    protected $_name = 'proveedores';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('razon_social', 'rut', 'ciudad');
    private $_orderByOptionsValues = array('Razón social', 'R.U.T.', 'Ciudad');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    public function setId($id)
    {
        $options = array('table' => 'proveedores', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - Proveedor::setId()");
        }
        
        $this->_id = (int)$id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Proveedor::getRow()");
        }
        
        return $this->find($this->_id)->current();
    }
    
    public function crear($data, $creador)
    {
        $data['rut'] = App_Rut::cleanToDb($data['rut']);
        $data['creador'] = $creador;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        $data['rut'] = App_Rut::cleanToDb($data['rut']); 
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function getDataFacturacion($id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select()
            ->from(array('p' => 'proveedores'), 
                   array('rut', 'razon_social', 'direccion', 'comuna', 'ciudad', 'telefono', 'giro'))
            ->where("id=?", (int)$id);
        return $adapter->fetchRow($select);
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        $where = null;
        $proveedores = $this->fetchAll($where, $order);
        $paginador = Zend_Paginator::factory($proveedores);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getAllToPopup()
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
            ->from(array('p' => 'proveedores'), array('id', 'razon_social'))
            ->order("razon_social");
        return $adapter->fetchAll($select);
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Proveedor::eliminar()");
        }         
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }

    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    public function searchToTooltip($criterio, $valor)
    {
        $adapter = $this->getAdapter();
        
        if($criterio!='' AND $valor!='') {
        
            if($criterio=='rut') {
                
                $valor = $adapter->quote(App_Rut::cleanToDb($valor));
                $where = "$criterio=$valor";
                
            } else {
                
                $valor = $adapter->quote('%' . App_Rut::cleanToDb($valor) . '%');
                $where = "$criterio LIKE $valor";
                
            }
            return $this->fetchAll($where)->toArray();
        }
        return false;
    }
    
    public function searchToForm($param)
    {
        $sql = "SELECT rut, razon_social AS value FROM proveedores ";
        $sql .= "WHERE razon_social LIKE '$param%' ";
        $sql .= "ORDER BY razon_social";
        
        $adapter = $this->getAdapter();
        $data = $adapter->fetchAll($sql);
        return $data;
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'ASC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'razon_social';
        }
    }
    
    public static function getPairsToSelect()
    {
        $adapter = self::getDefaultAdapter();
        $result = $adapter->fetchPairs("SELECT id, razon_social FROM proveedores ORDER BY razon_social");
        return $result;
    }
    
    public static function getRazonSocial($id)
    {
        $adapter = self::getDefaultAdapter();
        $result = $adapter->fetchOne("SELECT razon_social FROM proveedores WHERE id='$id' LIMIT 1");
        return $result;
    }
    
    public static function getRowById($id)
    {
        $adapter = self::getDefaultAdapter();
        $result = $adapter->fetchRow("SELECT * FROM proveedores WHERE id='$id' LIMIT 1");
        return $result;
    }
}