<?php
class Default_Model_RemAnexo extends Zend_Db_Table_Abstract
{
    protected $_name = 'rem_anexos';
    protected $_primary = 'id';
    
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getRowsByContratoId($contrato_id)
    {
        if($contrato_id == NULL || $contrato_id == '') {
            throw new Exception('No se ha enviado en ID de contrato - getLastByContratoId()');
        }
        
        $order = "id DESC";
        $where = $this->getAdapter()->quoteInto("contrato_id = ?", $contrato_id);
        $this->getAdapter()->setFetchMode(Zend_Db::FETCH_ASSOC);
        return $this->fetchAll($where, $order);
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        
        if($data['sueldo'] == '') { $data['sueldo'] = NULL; }
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $this->_getEmpleadoIdByContratoId($row->contrato_id);
    }
    
    private function _getEmpleadoIdByContratoId($id)
    {
        $contrato = new Default_Model_RemContrato();
        $contrato->setId($id);
        return $contrato->getRow()->empleado_id;
    }
    
    public function editar($data, $id, $user)
    {
        $data['creador'] = $user;
        
        if($data['detalles'] == '') { $data['detalles'] = NULL; }
        if($data['fecha_t'] == '') { $data['fecha_t'] = NULL; }
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
}