<?php
class Default_Model_RemContrato extends Zend_Db_Table_Abstract
{
    protected $_name = 'rem_contratos';
    protected $_primary = 'id';
    
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        
        if($data['fecha_t'] == '' OR $data['tipo_contrato'] == '0' ) { $data['fecha_t'] = NULL; }
        if($data['detalles'] == '') { $data['detalles'] = NULL; }
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function editar($data, $id, $user)
    {
        $data['creador'] = $user;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getRowsByEmpleadoId($empleado_id)
    {
       $where = $this->getAdapter()->quoteInto("empleado_id=?", $empleado_id);
        return $this->fetchAll($where);
    }
    
    public function getActualByEmpleadoId($empleado_id)
    {
        $data = array(
            'contrato' => NULL, 
            'anexos' => NULL, 
            'finiquito' => NULL,
            'sueldoVigente' => NULL
        );
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $empleado_id = $adapter->quote($empleado_id);
        
        $sql = "SELECT c.id, c.cargo, c.sueldo, c.horas_contratadas, c.fecha_i, "
             . "c.fecha_t, c.detalles, c.domicilio_empleador, "
             . "c.domicilio_lugar_trabajo, c.tipo_gratificacion_legal "
             . "FROM rem_contratos AS c "
             . "WHERE empleado_id=$empleado_id "
             . "AND c.fecha_i < CURDATE() "
             . "AND (c.fecha_t IS NULL || c.fecha_t > CURDATE()) "
             . "ORDER BY c.id DESC LIMIT 1";
        
        $contrato = $adapter->fetchRow($sql);
        
        if($contrato) {
            $data['contrato'] = $contrato;
            $data['sueldoVigente'] = $contrato->sueldo;
            
            $anexos = $this->_getAnexos($contrato->id);
            
            if(count($anexos) > 0 ){
                
                $data['anexos'] = $anexos;
                $data['sueldoVigente'] = $anexos[0]['sueldo'];
                $finiquito = $this->_getFiniquito($contrato->id);
                
                if($finiquito){
                    $data['finiquito'] = $finiquito;
                }
            }
        }
        return $data;
    }
    
    public function ingresarFiniquito($data, $user)
    {
        $finiquito = new Default_Model_RemFiniquito();
        $finiquito->crear($data, $user);
        return $this->_getEmpleadoId($data['contrato_id']);
    }
    
    private function _getEmpleadoId($id)
    {
        $adapter = self::getDefaultAdapter();
        $value = $adapter->quote($id);
        return $adapter->fetchOne("SELECT empleado_id FROM rem_contratos WHERE id=$value");
    }
    
    private function _getAnexos($contrato_id)
    {
        $anexo = new Default_Model_RemAnexo();
        return $anexo->getRowsByContratoId($contrato_id);
    }
    
    private function _getFiniquito($contrato_id)
    {
        $anexo = new Default_Model_RemFiniquito();
        return $anexo->getRowByContratoId($contrato_id);
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
}