<?php
class Default_Model_RemEmpleado extends Zend_Db_Table_Abstract
{
    protected $_name = 'rem_empleados';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('nombre');
    private $_orderByOptionsValues = array('Nombre');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - setId ");
        }
        $this->_id = (int)$id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - getRow");
        }
        
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('e' => 'rem_empleados'),
                   array(
                       'id', 'rut', 'nombre', 'telefono', 'direccion', 'ciudad', 'mail',
                       'afp_id', 'salud_id',  'desc_salud_tipo', 'desc_salud_valor'
                    ))
            ->join(array('afp' => 'rem_afps'), 'afp.id=e.afp_id', array('afp' => 'nombre', 'porcentaje_descuento'))
            ->join(array('is' => 'rem_inst_salud'), 'is.id=e.salud_id', array('institucion_salud' => 'nombre'))
            ->where("e.id = ? ", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getCargasFamiliares()
    {
        $carga = new Default_Model_RemCargaFamiliar();
        return $carga->getRowsByEmpleadoId($this->_id);
    }
    
    public function getDataContrato()
    {
        $empleado = new Default_Model_RemContrato();
        return $empleado->getActualByEmpleadoId($this->_id);
    }
    
    public function crear($data, $creador)
    {
        $data['creador'] = $creador;
        $data['rut'] = App_Rut::cleanToDb($data['rut']);
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        $data['rut'] = App_Rut::cleanToDb($data['rut']);
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        $where = null;
        $empleados = $this->fetchAll($where, $order);
        $paginador = Zend_Paginator::factory($empleados);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getAllToPopup()
    {
        $adapter = $this->getAdapter();
        $select = $adapter->select()
            ->from(array('e' => 'rem_empleados'), array('id', 'nombre'))
            ->order("nombre");
        return $adapter->fetchAll($select);
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - eliminar");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }

    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }

    public static function getPairsToSelect()
    {
        $db = new Default_Model_Cliente();
        $result = $db->getAdapter()->fetchPairs("SELECT id, nombre FROM rem_empleados ORDER BY nombre");
        return $result;
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'ASC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'nombre';
        }
    }
}