<?php
class Default_Model_SolicitudCompra extends Zend_Db_Table_Abstract
{
    protected $_name = 'solicitudes_compras';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'prioridad', 'nombre', 'estado');
    private $_orderByOptionsValues = array('Nº', 'Prioridad', 'Artículo', 'Estado');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('s' => 'solicitudes_compras'), array(
                'id', 'creacion', 'creador', 'origen', 'vehiculo_id', 'tipo', 
                'prioridad', 'articulo_id', 'codigo_proveedor', 'cantidad_solicitada', 
                'calidad_solicitada', 'marca', 'nombre', 'descripcion', 'ultimo_precio_compra', 
                'muestra', 'estado'))
            ->join(array('u' => 'sistema_usuarios'), 'u.id=s.creador', array('usuario' => 'nombre'))
            ->joinLeft(array('veh' => 'vehiculos'), 'veh.id=s.vehiculo_id', array('patente'))
            ->joinLeft(array('mod' => 'vehiculos_modelos'), 'mod.id = veh.modelo_id',  array('modelo' => 'nombre'))
            ->joinLeft(array('mar' => 'vehiculos_marcas'), 'mar.id=mod.marca_id',  array('marca' => 'nombre'))    
            ->where("s.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function updateIva()
    {
        $row = $this->getRow();
        $row->iva = Default_Model_Preferencia::getPref('IVA');
        $row->save();
    }
    
    public function crear($data, $user, $origen = 'TALLER' )
    {
        if(!isset($data['vehiculo']) || $data['vehiculo'] == '') {
            $data['vehiculo_id'] = NULL;
        } else {
            $data['vehiculo_id'] = Default_Model_Vehiculo::getIdByPatente($data['vehiculo']);
        }
        
        if(!isset($data['articulo_id']) || $data['articulo_id'] == '') {
            $data['articulo_id'] = NULL;
        }
        
        if(!isset($data['calidad_solicitada']) || $data['calidad_solicitada'] == '') {
            $data['calidad_solicitada'] = NULL;
        }
        
        if(!isset($data['descripcion']) || $data['descripcion'] == '') {
            $data['descripcion'] = NULL;
        }
        
        if(!isset($data['codigo_proveedor']) || $data['codigo_proveedor'] == '') {
            $data['codigo_proveedor'] = NULL;
        }
        
        if(!isset($data['ultimo_precio_compra']) || $data['ultimo_precio_compra'] == '') {
            $data['ultimo_precio_compra'] = NULL;
        }
        
        $data['creador'] = $user;
        $data['origen'] = $origen;
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $user, $id)
    {
        if($data['vehiculo'] == '') {
            $data['vehiculo_id'] = NULL;
        } else {
            $data['vehiculo_id'] = Default_Model_Vehiculo::getIdByPatente($data['vehiculo']);
        }
        if($data['descripcion']==''){ $data['observaciones'] = NULL;}
        $data['creador'] = $user;
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getAll($currentPage = 1, $orderBy = NULL, $orderType = NULL, $origen = NULL)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        if($origen !== NULL && in_array($origen, array('BODEGA','TALLER'))){
            $where = "origen='$origen'";
        } else {
            $where = NULL;
        }
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('s' => 'solicitudes_compras'), array(
                'id', 'creacion', 'creador', 'origen', 'vehiculo_id', 'tipo', 
                'prioridad', 'articulo_id', 'codigo_proveedor', 'cantidad_solicitada', 
                'calidad_solicitada', 'marca', 'nombre', 'descripcion', 'ultimo_precio_compra', 
                'muestra', 'estado'))
            ->join(array('u' => 'sistema_usuarios'), 'u.id=s.creador', array('usuario' => 'nombre'))
            ->where($where)    
            ->order($order);
        $solicitudes = $adapter->fetchAll($select);
        
        $paginador = Zend_Paginator::factory($solicitudes);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getRowsEnviadasByVehiculo($vehiculo_id)
    {
        $where = $this->getAdapter()->quoteInto("estado='ENVIADA' AND vehiculo_id=?", $vehiculo_id);
        return $this->fetchAll($where);
    }
    
    public function getRowsDisponiblesToPresupuesto($vehiculo_id)
    {
        $adapter = $this->getAdapter();
        $sql = "SELECT * FROM solicitudes_compras s "
             . "WHERE s.estado='ENVIADA' " 
             . "AND (s.tipo='REPUESTO' OR s.tipo='SERVICIO') "
             . "AND s.vehiculo_id='$vehiculo_id' "
             . "AND s.id NOT IN(SELECT solicitud_id FROM presupuestos_repuestos_externos WHERE solicitud_id IS NOT NULL) "
             . "AND s.id NOT IN(SELECT solicitud_id FROM presupuestos_servicios_externos WHERE solicitud_id IS NOT NULL)";
        return $adapter->fetchAll($sql);
    }
    
    public static function getPresupuestoId($id)
    {
        $presupuesto_repuesto_id = Default_Model_PresupuestoRepuestoExterno::getPresupuestoIdBySolicitudId($id);
        if($presupuesto_repuesto_id !== FALSE) {
            return $presupuesto_repuesto_id;
        }
        $presupuesto_servicio_id = Default_Model_PresupuestoServicioExterno::getPresupuestoIdBySolicitudId($id);
        if($presupuesto_servicio_id !== FALSE) {
            return $presupuesto_servicio_id;
        }
        return FALSE;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            
            $this->delete($where);
            
        } catch (Exception $e) {
            
            return $e->getMessage();
            
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
}