<?php
class Default_Model_Vehiculo extends Zend_Db_Table_Abstract
{
    protected $_name = 'vehiculos';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('patente', 'cliente', 'marca_id', 'modelo', 'anio');
    private $_orderByOptionsValues = array('Patente', 'Cliente', 'Marca', 'Modelo', 'Año');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    public function setId($id)
    {
        $options = array('table' => 'vehiculos', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        if(!$validador->isValid($id)){
            throw new Exception("El ID solicitado no existe - Vehiculo::setId() ");
        }
        $this->_id = $id; 
    }
    
    public function filtrar($marca_id = NULL, $modelo_id = NULL)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('v' => 'vehiculos'),
                   array(
                       'id', 'patente', 'cliente_id', 'vin_chassis', 
                       'numero_motor', 'modelo_id', 'anio', 'color',
                       'aire_acondicionado'
                   ))
            ->join(array('mod' => 'vehiculos_modelos'), 'mod.id = v.modelo_id', 
                   array(
                        'modelo' => 'nombre', 'version', 'cilindrada', 
                        'tipo_combustible', 'traccion', 'transmision'
                   ))
            ->join(array('mar' => 'vehiculos_marcas'), 'mar.id=mod.marca_id', 
                   array(
                       'marca' => 'nombre'
                   ));    
        if($marca_id !== NULL){
            $select->where("v.marca_id=?", $marca_id);
        }
        $vehiculos = $adapter->fetchAll($select);
        return $vehiculos;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - Vehiculo::getRow()");
        }
        
        return $this->find($this->_id)->current();
    }
    
    public function getMarcaId($modelo_id)
    {
        $modelo= new Default_Model_VehiculoModelo();
        $modelo->setId($modelo_id);
        return $modelo->getRow()->marca_id;
    }
    
    public function getPatente()
    {
        return $this->getRow()->patente;
    }
    
    public function getClienteId()
    {
        return $this->getRow()->cliente_id;
    }
    
    public static function getIdByPatente($patente)
    {
        $adapter = self::getDefaultAdapter();
        $patenteUpper = strtoupper($patente);
        $sql = "SELECT id FROM vehiculos WHERE patente='$patenteUpper'";
        $id = $adapter->fetchOne($sql);
        if(!$id){
            throw new Exception('NO existe un vehículo con la patente indicada - Vehiculo::getIdByPatente');
        }
        return $id;
    }
    
    public static function getPatenteById($id)
    {
        $adapter = self::getDefaultAdapter();
        $sql = "SELECT patente FROM vehiculos WHERE id='$id'";
        $patente = $adapter->fetchOne($sql);
        if(!$patente){
            throw new Exception('NO existe un vehículo con el ID indicado - Vehiculo::getPatenteById');
        }
        return $patente;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select()
            ->from(array('v' => 'vehiculos'),
                   array(
                       'id', 'patente', 'cliente_id', 'vin_chassis', 
                       'numero_motor', 'modelo_id', 'anio', 'color',
                       'aire_acondicionado'
                   ))
            ->join(array('mod' => 'vehiculos_modelos'), 'mod.id = v.modelo_id', 
                   array(
                        'modelo' => 'nombre', 'version', 'cilindrada', 
                        'tipo_combustible', 'traccion', 'transmision'
                   ))
            ->join(array('mar' => 'vehiculos_marcas'), 'mar.id=mod.marca_id', 
                   array(
                       'marca' => 'nombre'
                   ))    
            ->join(array('c' => 'clientes'), 'c.id=v.cliente_id', 
                   array(
                       'cliente' => 'nombre'
                   ))
            ->where("v.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('v' => 'vehiculos'),
                   array(
                       'id', 'patente', 'cliente_id', 'vin_chassis', 
                       'numero_motor', 'modelo_id', 'anio', 'color',
                       'aire_acondicionado'
                   ))
            ->join(array('mod' => 'vehiculos_modelos'), 'mod.id = v.modelo_id', 
                   array(
                        'modelo' => 'nombre', 'version', 'cilindrada', 
                        'tipo_combustible', 'traccion', 'transmision'
                   ))
            ->join(array('mar' => 'vehiculos_marcas'), 'mar.id=mod.marca_id', 
                   array(
                       'marca' => 'nombre'
                   ))    
            ->join(array('c' => 'clientes'), 'c.id=v.cliente_id', 
                   array(
                       'cliente' => 'nombre'
                   ))
            ->order($order);
        
        $vehiculos = $adapter->fetchAll($select);
        $paginador = Zend_Paginator::factory($vehiculos);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getHistorialDeServicio()
    {
        $item = new Default_Model_ItemNotaVenta();
        return $item->getRowsByVehiculoId($this->_id);
    }
    
    public function crear($data, $user)
    {
        $data['creador'] = $user;
        
        if($data['operacion'] == 'CREAR'){
            $modelo = new Default_Model_VehiculoModelo();
            $data['modelo_id'] = $modelo->crear($data);
        }
        
        $data['patente'] = strtoupper($data['patente']);
        $data['vin_chassis'] = strtoupper($data['vin_chassis']);
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        if($data['operacion'] == 'CREAR'){
            $modelo = new Default_Model_VehiculoModelo();
            $data['modelo_id'] = $modelo->crear($data);
        }
        
        $data['patente'] = strtoupper($data['patente']); 
        $data['vin_chassis'] = strtoupper($data['vin_chassis']);
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
    }
    
    public function getVehiculos()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('v' => 'vehiculos'),
                   array(
                       'id', 'patente', 'cliente_id', 'vin_chassis', 
                       'numero_motor', 'modelo_id', 'anio', 'color',
                       'aire_acondicionado'
                   ))
            ->join(array('mod' => 'vehiculos_modelos'), 'mod.id = v.modelo_id', 
                   array(
                        'modelo' => 'nombre', 'version', 'cilindrada', 
                        'tipo_combustible', 'traccion', 'transmision'
                   ))
            ->join(array('mar' => 'vehiculos_marcas'), 'mar.id=mod.marca_id', 
                   array(
                       'marca' => 'nombre'
                   ))    
            ->join(array('c' => 'clientes'), 'c.id=v.cliente_id', 
                   array(
                       'cliente' => 'nombre'
                   ))
            ->where("cliente=?", $this->_clienteId);
        $vehiculos = $adapter->fetchAll($select);
        return $vehiculos;
    }
    
    public function getUltimosServicios($cantidad)
    {
        $orden = new Default_Model_OrdenServicioItem();
        return $orden->getLastRowsByVehiculoId($this->_id, $cantidad);
    }
    
    public function getRowsByCliente($id)
    {
        $where = $this->getAdapter()->quoteInto("cliente=?", $id);
        return $this->fetchAll($where);
    }
    
    public function getPautaMantenimiento()
    {
        $modelPautaVehiculo = new Default_Model_PautaMantenimientoVehiculo();
        return $modelPautaVehiculo->getRow($this->_id);
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado lel ID - Vehiculo::eliminar()");
        }
        $where = $this->getAdapter()->quoteInto("id=?",  (int)$this->_id);
        try {
            $this->delete($where);
        } catch (Exception $e) {
            return $e->getMessage();
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    public function searchToTooltip($criterio, $valor)
    {
        $adapter = $this->getAdapter();
        
        if($criterio!='' AND $valor!='') {
        
            if($criterio=='patente') {
                
                $valor = $adapter->quote(strtoupper($valor));
                $where = "$criterio=$valor";
                
            } else {
                
                $valor = $adapter->quote('%' . $valor . '%');
                $where = "$criterio LIKE $valor";
                
            }
            return $this->fetchAll($where)->toArray();
        }
        return false;
    }
    
    public function searchToForm($param)
    {
        $sql = "SELECT patente, modelo AS value FROM vehiculos ";
        $sql .= "WHERE modelo LIKE '$param%' ";
        $sql .= "ORDER BY modelo";
        
        $adapter = $this->getAdapter();
        $data = $adapter->fetchAll($sql);
        return $data;
    }

    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'ASC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'marca_id';
        }
    }
    
    
    /*
    public function setCliente($clienteId)
    {
        $clienteId = (int)$clienteId;
        $options = array('table' => 'clientes', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($clienteId)){
            throw new Exception("El ID de cliente configurado no existe - setCliente ");
        }
        
        $this->_clienteId = $clienteId;
    }
    
    
    
    public function getCliente()
    {
        $modelCliente = new Default_Model_Cliente();
        $modelCliente->setId($this->_clienteId);
        return $modelCliente->getRow();
    }
    */
}