<?php
class Default_Model_VehiculoModelo extends Zend_Db_Table_Abstract
{
    protected $_name = 'vehiculos_modelos';
    protected $_primary = 'id';

    private $_orderByOptionsKeys = array('nombre', 'marca');
    private $_orderByOptionsValues = array('Nombre', 'Marca');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;

    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => $this->_name, 'field' => $this->_primary);
        $validador = new Zend_Validate_Db_RecordExists($options);
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - VehiculoModelo::setId()");
        }
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - VehiculoModelo::getRow()");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
        
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('mod' => $this->_name),
                   array(
                       'id', 'marca_id', 'nombre', 'version', 'cilindrada', 
                       'tipo_combustible', 'traccion', 'transmision', 'cargo_adicional'
                       ))
            ->join(array('mar' => 'vehiculos_marcas'), 'mar.id = mod.marca_id', array('marca' => 'nombre'))    
            ->order($order);
        $modelos = $adapter->fetchAll($select);
        
        $paginador = Zend_Paginator::factory($modelos);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('mod' => $this->_name),
                   array(
                       'id', 'marca_id', 'nombre', 'version', 'cilindrada', 
                       'tipo_combustible', 'traccion', 'transmision', 'cargo_adicional'
                       ))
            ->join(array('mar' => 'vehiculos_marcas'), 'mar.id = mod.marca_id', array('marca' => 'nombre'))    
            ->where("mod.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }

    public function crear($data)
    {
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }

    public function getRowsByMarca($marca_id)
    {
        $where = $this->getAdapter()->quoteInto("marca_id=?", $marca_id);
        return $this->fetchAll($where);
    }
    
    public function getRowsToSelectByMarcaId($marca_id)
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_ASSOC);
        $select = $adapter->select()
            ->from(array('m' => $this->_name), array('id', "nombre"))
            ->where("m.marca_id=?", $marca_id);
        $rows = $adapter->fetchAll($select);
        if($rows){
            return $rows;
        }
        return NULL;
    }
    
    public function getPautasMantenimiento()
    {
        $modelPauta = new Default_Model_PautaModelo();
        return $modelPauta->getRowsByModeloId($this->_id);
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            
            $this->delete($where);
            
        } catch (Exception $e) {
            
            return $e->getMessage();
            
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'ASC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'marca';
        }
    }

    public static function getPairsToSelect()
    {
        $adapter = self::getDefaultAdapter();
        $result = $adapter->fetchPairs("SELECT id, nombre FROM vehiculos_modelos ORDER BY nombre");
        return $result;
    }

    public static function getPairsToSelectByMarca($marca_id)
    {
        $sql = "SELECT id, nombre FROM vehiculos_modelos WHERE marca_id='$marca_id' ORDER BY nombre";
        $adapter = self::getDefaultAdapter();
        $result = $adapter->fetchPairs($sql);
        return $result;
    }

    public static function getMarcaIdByModeloId($modelo_id)
    {
        $db = Zend_Registry::get('db');
        $db->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $db->select()
            ->from(array('mv' => 'vehiculos_modelos'),
                   array('marca_id'))
            ->where('mv.id = ? ', $modelo_id);
        $marca_id = $db->fetchOne($select);
        return $marca_id;
    }

}