<?php
class Default_Model_VehiculoRecepcion extends Zend_Db_Table_Abstract
{
    protected $_name = 'vehiculos_recepciones';
    protected $_primary = 'id';
    
    private $_orderByOptionsKeys = array('id', 'cliente', 'vehiculo');
    private $_orderByOptionsValues = array('Nº', 'Cliente', 'Vehículo');
    private $_orderTypeOptions = array('ASC', 'DESC');
    private $_orderBy = NULL;
    private $_orderType = NULL;
    private $_id = NULL;
    
    
    public function setId($id)
    {
        $id = (int)$id;
        $options = array('table' => 'vehiculos_recepciones', 'field' => 'id');
        $validador = new Zend_Validate_Db_RecordExists($options);
        
        if(!$validador->isValid($id)){
            throw new Exception("El ID configurado no existe - VehiculoRecepcion::setId()");
        }
        
        $this->_id = $id;
    }
    
    public function getRow()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID - VehiculoRecepcion::getRow()");
        }
        $row = $this->find($this->_id)->current();
        return $row;
    }
    
    public function crear($data, $user)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        if($data['otros_sintomas']==''){ $data['otros_sintomas'] = NULL;}
        $data['creador'] = $user;
        $data['vehiculo_id'] = $this->_getVehiculoIdByPatente($data['vehiculo']);
        
        $row = $this->createRow();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function editar($data, $id)
    {
        if($data['observaciones']==''){ $data['observaciones'] = NULL;}
        if($data['otros_sintomas']==''){ $data['otros_sintomas'] = NULL;}
        $data['vehiculo_id'] = $this->_getVehiculoIdByPatente($data['vehiculo']);
        
        $row = $this->find($id)->current();
        $row->setFromArray($data);
        $row->save();
        return $row->id;
    }
    
    public function getAll($currentPage = 1, $orderBy = null, $orderType = null)
    {
        $this->_setOrderBy($orderBy);
        $this->_setOrderType($orderType);
        $order = "$this->_orderBy $this->_orderType";
        
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('r' => $this->_name),
                   array(
                       'id', 'creacion', 'entregado_por', 'estado'
                       ))
            ->join(array('v' => 'vehiculos'), 'v.id=r.vehiculo_id', array('patente'))    
            ->join(array('mod' => 'vehiculos_modelos'), 'mod.id=v.modelo_id', array('modelo' => 'nombre'))
            ->join(array('mar' => 'vehiculos_marcas'), 'mar.id=mod.marca_id', array('marca' => 'nombre'))
            ->join(array('c' => 'clientes'), 'c.id=v.cliente_id', array('cliente' => 'nombre'))
            ->order($order);
        $vehiculos = $adapter->fetchAll($select);
        $paginador = Zend_Paginator::factory($vehiculos);
        $paginador->setItemCountPerPage(10)
                  ->setCurrentPageNumber($currentPage);
        return $paginador;
    }
    
    public function getRowFull()
    {
        $adapter = $this->getAdapter();
        $adapter->setFetchMode(Zend_Db::FETCH_OBJ);
        $select = $adapter->select()
            ->from(array('r' => 'vehiculos_recepciones'),
                   array(
                       'id', 'creacion', 'creador', 'entregado_por', 'estado',
                       'km_ingreso', 'nivel_combustible', 'panel_radio', 'gata', 'extintor',
                       'botiquin', 'neumatico_repuesto', 'detalles_carroceria', 'observaciones',
                       'p_suspension', 'p_transmision', 'p_motor', 'p_direccion', 'p_luces',
                       'p_calefaccion', 'p_tablero', 'p_frenos', 'otros_sintomas', 'otro_taller'
                       ))
            ->join(array('v' => 'vehiculos'), 'v.id=r.vehiculo_id', array('patente'))    
            ->join(array('c' => 'clientes'), 'c.id=v.cliente_id', array('cliente' => 'nombre'))
            ->join(array('u' => 'sistema_usuarios'), 'u.id=r.creador', array('recibido_por' => 'nombre'))
            ->where("r.id=?", $this->_id);
        return $adapter->fetchRow($select);
    }
    
    public function getRowsByVehiculo($id = NULL)
    {
        if(NULL == $id){
            throw new Exception("No se indicó el ID del vehículo - VehiculoRecepcion::getRowsByVehiculo()");
        }
        $vehiculo = strtoupper($vehiculo);
        $where = $this->getAdapter()->quoteInto("vehiculo_id=?", $id);
        return $this->fetchAll($where, "id DESC");
    }
    
    public function getEstado()
    {
        return $this->getRow()->estado;
    }
    
    public function setEstado($estado)
    {
        $row = $this->getRow();
        $row->estado = $estado;
        $row->save();
    }
    
    public function getCliente()
    {
        $modelVehiculo = new Default_Model_Vehiculo();
        $modelVehiculo->setPatente($this->getRow()->vehiculo);
        return $modelVehiculo->getCliente();
    }
    
    public function getVehiculo()
    {
        $modelVehiculo = new Default_Model_Vehiculo();
        $modelVehiculo->setId($this->getRow()->vehiculo_id);
        return $modelVehiculo->getRowFull();
    }
    
    private function _getVehiculoIdByPatente($patente)
    {
        $modelVehiculo = new Default_Model_Vehiculo();
        return $modelVehiculo->getIdByPatente($patente);
    }
    
    public function getPatenteByVehiculoId($vehiculo_id)
    {
        $modelVehiculo = new Default_Model_Vehiculo();
        $modelVehiculo->setId($vehiculo_id);
        return $modelVehiculo->getPatente();
    }
    
    public static function getClienteByVehiculo($vehiculo)
    {
        $modelVehiculo = new Default_Model_Vehiculo();
        $modelVehiculo->setPatente($vehiculo);
        
        return $modelVehiculo->getCliente()->nombre;
    }
    
    public function eliminar()
    {
        if(NULL == $this->_id) {
            throw new Exception("No se ha configurado el ID");
        }
        
        $where = $this->getAdapter()->quoteInto("id=?",  $this->_id);
        
        try {
            
            $this->delete($where);
            
        } catch (Exception $e) {
            
            return $e->getMessage();
            
        }
    }
    
    public function getOrderBy()
    {
        return $this->_orderBy;
    }
    
    public function getOrderType()
    {
        return $this->_orderType;
    }
    
    public function getOrderByOptions()
    {
        return array_combine($this->_orderByOptionsKeys, $this->_orderByOptionsValues);
    }
    
    private function _setOrderType($orderType)
    {
        if(in_array($orderType, $this->_orderTypeOptions)) {
            $this->_orderType = $orderType;
        } else {
            $this->_orderType = 'DESC';
        }
    }
    
    private function _setOrderBy($orderBy)
    {
        if(in_array($orderBy, $this->_orderByOptionsKeys)) {
            $this->_orderBy =  $orderBy;
        } else {
            $this->_orderBy = 'id';
        }
    }
}